
-- 当前余额变更记录表
CREATE TABLE `blade_now_money_record` (
  `id` bigint(64) NOT NULL COMMENT 'id',
  `create_user_id` bigint(64) NOT NULL COMMENT '创建人ID\r\n',
  `update_user_id` bigint(64) NOT NULL COMMENT '修改人ID',
  `create_time` datetime NOT NULL COMMENT '创建时间',
  `update_time` datetime NOT NULL COMMENT '修改时间',
  `is_delete` int(16) NOT NULL COMMENT '1：删除，0：未删除',
  `before_money` decimal(19,2) NOT NULL COMMENT '操作前余额',
  `after_money` decimal(19,2) NOT NULL COMMENT '操作后余额',
  `type` int(16) NOT NULL COMMENT '操作类型，1：收入，2：支出',
  `fluctuant_amount` decimal(19,2) NOT NULL COMMENT '增加或扣减金额',
  `charge_amount` decimal(19,2) NOT NULL COMMENT '手续费金额',
  `tax_amount` decimal(19,2) NOT NULL COMMENT '税费金额',
  `source` varchar(32) NOT NULL COMMENT '来源',
  `user_app_id` bigint(64) NOT NULL COMMENT '钱包id',
  `param_str` text NOT NULL COMMENT '传入参数json',
  `data_id` bigint(64) DEFAULT NULL COMMENT '来源ID，（如订单id）',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;


-- 提现记录表
CREATE TABLE `blade_withdrawal_record` (
  `id` bigint(64) NOT NULL COMMENT 'id',
  `create_user_id` bigint(64) NOT NULL COMMENT '创建人ID',
  `update_user_id` bigint(64) NOT NULL COMMENT '更新人ID',
  `create_time` datetime NOT NULL COMMENT '创建时间',
  `update_time` datetime NOT NULL COMMENT '更新时间',
  `is_delete` int(16) NOT NULL COMMENT '1，删除。0，未删除',
  `user_app_id` bigint(64) NOT NULL COMMENT '钱包id',
  `create_user_name` varchar(64) DEFAULT NULL COMMENT '创建人姓名',
  `withdrawal_amount` decimal(19,2) NOT NULL COMMENT '提现金额',
  `charge_amount` decimal(19,2) NOT NULL COMMENT '提现金额',
  `status` int(16) NOT NULL COMMENT '状态。0：待审核，1：审核失败，2:审核通过，提现成功',
  `audit_user_id` bigint(64) DEFAULT NULL COMMENT '审核人ID',
  `audit_time` datetime DEFAULT NULL COMMENT '审核时间',
  `audit_msg` varchar(255) DEFAULT NULL COMMENT '审核人意见',
  `audit_user_name` varchar(64) DEFAULT NULL COMMENT '审核人姓名',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;


-- 快递单号记录表
CREATE TABLE `t_courier_number` (
  `id` bigint(255) NOT NULL COMMENT 'id',
  `order_id` bigint(255) NOT NULL COMMENT '订单id',
  `order_type` int(255) NOT NULL COMMENT '订单类型，0交割订单，若有其他后期扩展',
  `courier_number` varchar(255) NOT NULL COMMENT '快递单号',
  `delivery_code` varchar(255) NOT NULL COMMENT '快递公司编码',
  `status` int(255) NOT NULL COMMENT '状态；0未收货，1已收货',
  `query_time` datetime DEFAULT NULL COMMENT '最新一次查询快递100的时间',
  `create_user_name` varchar(255) NOT NULL COMMENT '创建人姓名',
  `create_user_id` bigint(255) NOT NULL COMMENT '创建人id',
  `update_user_id` bigint(255) NOT NULL COMMENT '更新人id',
  `create_time` datetime NOT NULL COMMENT '创建时间',
  `update_time` datetime NOT NULL COMMENT '更新时间',
  `is_delete` int(255) NOT NULL COMMENT '0为未删除，1为已删除',
  `response_json` text COMMENT '最后一次查询的响应json',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;


alter table t_courier_number add delivery_name varchar(255) comment '快递公司名称';
ALTER TABLE t_courier_number MODIFY order_id varchar(255);

-- 快递单号详情
CREATE TABLE `t_courier_data` (
  `id` bigint(255) NOT NULL COMMENT 'id',
  `courier_number_id` bigint(255) NOT NULL COMMENT '快递单号id',
  `time` datetime DEFAULT NULL COMMENT '时间，原始格式',
  `context` varchar(255) DEFAULT NULL COMMENT '内容',
  `ftime` datetime DEFAULT NULL COMMENT '格式化后时间',
  `area_code` varchar(255) DEFAULT NULL COMMENT '本数据元对应的行政区域的编码，实时查询接口中提交resultv2=1或者resultv2=4标记后才会出现',
  `area_name` varchar(255) DEFAULT NULL COMMENT '本数据元对应的行政区域的名称，实时查询接口中提交resultv2=1或者resultv2=4标记后才会出现',
  `status` varchar(255) DEFAULT NULL COMMENT '本数据元对应的物流状态名称或者高级状态名称，实时查询接口中提交resultv2=1或者resultv2=4标记后才会出现',
  `location` varchar(255) DEFAULT NULL COMMENT '本数据元对应的快件当前地点，实时查询接口中提交resultv2=4标记后才会出现',
  `area_center` varchar(255) DEFAULT NULL COMMENT '本数据元对应的行政区域经纬度，实时查询接口中提交resultv2=4标记后才会出现',
  `area_pin_yin` varchar(255) DEFAULT NULL COMMENT '	本数据元对应的行政区域拼音，实时查询接口中提交resultv2=4标记后才会出现',
  `status_code` varchar(255) DEFAULT NULL COMMENT '本数据元对应的高级物流状态值，实时查询接口中提交resultv2=4标记后才会出现',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- 快递公司编码表
DROP TABLE IF EXISTS `t_delivery`;
CREATE TABLE `t_delivery`  (
                               `id` bigint(255) NOT NULL COMMENT 'id',
                               `name` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '快递公司名称',
                               `code` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '快递公司编码',
                               `type` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '快递公司类型',
                               PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_general_ci ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of t_delivery
-- ----------------------------
INSERT INTO `t_delivery` VALUES (1, '圆通速递', 'yuantong', '国内运输商');
INSERT INTO `t_delivery` VALUES (2, '韵达快递', 'yunda', '国内运输商');
INSERT INTO `t_delivery` VALUES (3, '申通快递', 'shentong', '国内运输商');
INSERT INTO `t_delivery` VALUES (4, '中通快递', 'zhongtong', '国内运输商');
INSERT INTO `t_delivery` VALUES (5, '极兔速递', 'jtexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (6, '邮政快递包裹', 'youzhengguonei', '国际邮政');
INSERT INTO `t_delivery` VALUES (7, '顺丰速运', 'shunfeng', '国际运输商');
INSERT INTO `t_delivery` VALUES (8, 'EMS', 'ems', '国际邮政');
INSERT INTO `t_delivery` VALUES (9, '京东物流', 'jd', '国内运输商');
INSERT INTO `t_delivery` VALUES (10, '邮政标准快递', 'youzhengbk', '国内运输商');
INSERT INTO `t_delivery` VALUES (11, '德邦快递', 'debangkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (12, '百世快递', 'huitongkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (13, '丰网速运', 'fengwang', '国内运输商');
INSERT INTO `t_delivery` VALUES (14, '德邦', 'debangwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (15, '中通国际', 'zhongtongguoji', '国际运输商');
INSERT INTO `t_delivery` VALUES (16, '飞豹快递', 'feibaokuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (17, '中通快运', 'zhongtongkuaiyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (18, '安能快运', 'annengwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (19, '优速', 'youshuwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (20, '京东快运', 'jingdongkuaiyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (21, '跨越速运', 'kuayue', '国内运输商');
INSERT INTO `t_delivery` VALUES (22, '韵达快运', 'yundakuaiyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (23, '联昊通', 'lianhaowuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (24, '宅急送', 'zhaijisong', '国内运输商');
INSERT INTO `t_delivery` VALUES (25, '百世快运', 'baishiwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (26, '日日顺物流', 'rrs', '国内运输商');
INSERT INTO `t_delivery` VALUES (27, 'UPS-全球件', 'upsen', '国际运输商');
INSERT INTO `t_delivery` VALUES (28, '速必达', 'subida', '国内运输商');
INSERT INTO `t_delivery` VALUES (29, '安得物流', 'annto', '国内运输商');
INSERT INTO `t_delivery` VALUES (30, '特急送', 'lntjs', '国内运输商');
INSERT INTO `t_delivery` VALUES (31, 'FedEx-国际件', 'fedex', '国际运输商');
INSERT INTO `t_delivery` VALUES (32, '顺心捷达', 'sxjdfreight', '国内运输商');
INSERT INTO `t_delivery` VALUES (33, '壹米滴答', 'yimidida', '国内运输商');
INSERT INTO `t_delivery` VALUES (34, 'EWE全球快递', 'ewe', '国际运输商');
INSERT INTO `t_delivery` VALUES (35, '哪吒速运', 'nezhasuyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (36, '丹鸟', 'danniao', '国内运输商');
INSERT INTO `t_delivery` VALUES (37, 'UPS', 'ups', '国际运输商');
INSERT INTO `t_delivery` VALUES (38, '顺丰快运', 'shunfengkuaiyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (39, '海信物流', 'savor', '国内运输商');
INSERT INTO `t_delivery` VALUES (40, '加运美', 'jiayunmeiwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (41, '京广速递', 'jinguangsudikuaijian', '国内运输商');
INSERT INTO `t_delivery` VALUES (42, 'DHL-中国件', 'dhl', '国际运输商');
INSERT INTO `t_delivery` VALUES (43, '国际包裹', 'youzhengguoji', '国际运输商');
INSERT INTO `t_delivery` VALUES (44, 'DHL-全球件', 'dhlen', '国际运输商');
INSERT INTO `t_delivery` VALUES (45, 'Titan泰坦国际速递', 'timelytitan', '国际运输商');
INSERT INTO `t_delivery` VALUES (46, '汇森速运', 'huisenky', '国内运输商');
INSERT INTO `t_delivery` VALUES (47, 'USPS', 'usps', '国际邮政');
INSERT INTO `t_delivery` VALUES (48, '信丰物流', 'xinfengwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (49, '春风物流', 'spring56', '国内运输商');
INSERT INTO `t_delivery` VALUES (50, '递四方', 'disifang', '国内运输商');
INSERT INTO `t_delivery` VALUES (51, '拉火速运', 'lahuoex', '国内运输商');
INSERT INTO `t_delivery` VALUES (52, '中远e环球', 'cosco', '国际运输商');
INSERT INTO `t_delivery` VALUES (53, '同城快寄', 'shpost', '国内运输商');
INSERT INTO `t_delivery` VALUES (54, '速腾快递', 'suteng', '国内运输商');
INSERT INTO `t_delivery` VALUES (55, '申通国际', 'stosolution', '国际运输商');
INSERT INTO `t_delivery` VALUES (56, '耀飞同城快递', 'yaofeikuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (57, '转运四方', 'zhuanyunsifang', '国际运输商');
INSERT INTO `t_delivery` VALUES (58, '中铁快运', 'ztky', '国内运输商');
INSERT INTO `t_delivery` VALUES (59, '顺昌国际', 'shunchangguoji', '国内运输商');
INSERT INTO `t_delivery` VALUES (60, '天地华宇', 'tiandihuayu', '国内运输商');
INSERT INTO `t_delivery` VALUES (61, 'DPD', 'dpd', '国际运输商');
INSERT INTO `t_delivery` VALUES (62, '美快国际物流', 'meiquick', '国际运输商');
INSERT INTO `t_delivery` VALUES (63, '安能快递', 'ane66', '国内运输商');
INSERT INTO `t_delivery` VALUES (64, '宇鑫物流', 'yuxinwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (65, 'D速快递', 'dsukuaidi', '国际运输商');
INSERT INTO `t_delivery` VALUES (66, '联邦快递', 'lianbangkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (67, 'Fedex-国际件-中文', 'fedexcn', '国际运输商');
INSERT INTO `t_delivery` VALUES (68, '澳邮中国快运', 'auexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (69, 'TNT-全球件', 'tnten', '国际运输商');
INSERT INTO `t_delivery` VALUES (70, '中远快运', 'zy100', '国内运输商');
INSERT INTO `t_delivery` VALUES (71, '易客满', 'ecmscn', '国际运输商');
INSERT INTO `t_delivery` VALUES (72, 'EMS-国际件', 'emsguoji', '国际邮政');
INSERT INTO `t_delivery` VALUES (73, 'AAE-中国件', 'aae', '国际运输商');
INSERT INTO `t_delivery` VALUES (74, '苏宁物流', 'suning', '国内运输商');
INSERT INTO `t_delivery` VALUES (75, '盛辉物流', 'shenghuiwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (76, '承诺达', 'ytchengnuoda', '国内运输商');
INSERT INTO `t_delivery` VALUES (77, 'SYNSHIP快递', 'synship', '国际运输商');
INSERT INTO `t_delivery` VALUES (78, '天天快递', 'tiantian', '国内运输商');
INSERT INTO `t_delivery` VALUES (79, '佳怡物流', 'jiayiwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (80, 'CJ物流', 'doortodoor', '国际运输商');
INSERT INTO `t_delivery` VALUES (81, '威盛快递', 'wherexpess', '国内运输商');
INSERT INTO `t_delivery` VALUES (82, '宏递快运', 'hd', '国内运输商');
INSERT INTO `t_delivery` VALUES (83, '盛丰物流', 'sfwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (84, '威时沛运货运', 'wtdchina', '国内运输商');
INSERT INTO `t_delivery` VALUES (85, '平安达腾飞', 'pingandatengfei', '国内运输商');
INSERT INTO `t_delivery` VALUES (86, 'COE', 'coe', '国际运输商');
INSERT INTO `t_delivery` VALUES (87, '嘉里大通', 'jialidatong', '国内运输商');
INSERT INTO `t_delivery` VALUES (88, '富腾达国际货运', 'ftd', '国际运输商');
INSERT INTO `t_delivery` VALUES (89, '安迅物流', 'anxl', '国内运输商');
INSERT INTO `t_delivery` VALUES (90, '天翼快递', 'tykd', '国内运输商');
INSERT INTO `t_delivery` VALUES (91, '宅急便', 'zhaijibian', '国际运输商');
INSERT INTO `t_delivery` VALUES (92, '德坤物流', 'dekuncn', '国内运输商');
INSERT INTO `t_delivery` VALUES (93, 'UBI Australia', 'gotoubi', '国际运输商');
INSERT INTO `t_delivery` VALUES (94, '顺达快递', 'sundarexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (95, '时安达速递', 'goex', '国内运输商');
INSERT INTO `t_delivery` VALUES (96, '速邮达', 'suyoda', '国内运输商');
INSERT INTO `t_delivery` VALUES (97, '日本（Japan Post）', 'japanposten', '国际邮政');
INSERT INTO `t_delivery` VALUES (98, '泰进物流', 'taijin', '国内运输商');
INSERT INTO `t_delivery` VALUES (99, '速通物流', 'sut56', '国内运输商');
INSERT INTO `t_delivery` VALUES (100, 'TNT', 'tnt', '国际运输商');
INSERT INTO `t_delivery` VALUES (101, 'DPD Germany', 'dpdgermany', '国际运输商');
INSERT INTO `t_delivery` VALUES (102, '新顺丰（NSF）', 'nsf', '国际运输商');
INSERT INTO `t_delivery` VALUES (103, '四季安物流', 'sja56', '国内运输商');
INSERT INTO `t_delivery` VALUES (104, '邦泰快运', 'btexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (105, '御风速运', 'yufeng', '国内运输商');
INSERT INTO `t_delivery` VALUES (106, '荣庆物流', 'rokin', '国内运输商');
INSERT INTO `t_delivery` VALUES (107, '日本郵便', 'japanpost', '国际运输商');
INSERT INTO `t_delivery` VALUES (108, '斑马物流', 'banma', '国内运输商');
INSERT INTO `t_delivery` VALUES (109, '优邦速运', 'ubonex', '国内运输商');
INSERT INTO `t_delivery` VALUES (110, 'CK物流', 'ckexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (111, '中铁飞豹', 'zhongtiewuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (112, '鑫正一快递', 'zhengyikuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (113, 'Xlobo贝海国际', 'xlobo', '国际运输商');
INSERT INTO `t_delivery` VALUES (114, '佐川急便', 'sagawa', '国际运输商');
INSERT INTO `t_delivery` VALUES (115, '景光物流', 'jgwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (116, '九曳供应链', 'jiuyescm', '国内运输商');
INSERT INTO `t_delivery` VALUES (117, '韵达国际', 'udalogistic', '国际运输商');
INSERT INTO `t_delivery` VALUES (118, '转运中国', 'uszcn', '国际运输商');
INSERT INTO `t_delivery` VALUES (119, '中国邮政（CHINA POST）', 'chinapost', '国际邮政');
INSERT INTO `t_delivery` VALUES (120, '科捷物流', 'kejie', '国内运输商');
INSERT INTO `t_delivery` VALUES (121, '方舟速递', 'arkexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (122, '天马迅达', 'tianma', '国内运输商');
INSERT INTO `t_delivery` VALUES (123, '澳洲飞跃物流', 'rlgaus', '国际运输商');
INSERT INTO `t_delivery` VALUES (124, '黄马甲', 'huangmajia', '国内运输商');
INSERT INTO `t_delivery` VALUES (125, '出口易', 'chukou1', '国际运输商');
INSERT INTO `t_delivery` VALUES (126, '新杰物流', 'sunjex', '国内运输商');
INSERT INTO `t_delivery` VALUES (127, 'Superb Express', 'superb', '国际运输商');
INSERT INTO `t_delivery` VALUES (128, '家家通快递', 'newsway', '国内运输商');
INSERT INTO `t_delivery` VALUES (129, '荷兰邮政(PostNL international registered mail)', 'postnl', '国际邮政');
INSERT INTO `t_delivery` VALUES (130, 'Hermes', 'hermes', '国际运输商');
INSERT INTO `t_delivery` VALUES (131, '国通快递', 'guotongkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (132, '中速快递', 'zhongsukuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (133, '泰嘉物流', 'takesend', '国内运输商');
INSERT INTO `t_delivery` VALUES (134, '中迅三方', 'cd3fwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (135, 'YunExpress', 'yuntrack', '国际运输商');
INSERT INTO `t_delivery` VALUES (136, '诚和通', 'cht361', '国内运输商');
INSERT INTO `t_delivery` VALUES (137, '泛捷国际速递', 'epanex', '国际运输商');
INSERT INTO `t_delivery` VALUES (138, '快捷速递', 'kuaijiesudi', '国内运输商');
INSERT INTO `t_delivery` VALUES (139, '三态速递', 'santaisudi', '国内运输商');
INSERT INTO `t_delivery` VALUES (140, '芝麻开门', 'zhimakaimen', '国内运输商');
INSERT INTO `t_delivery` VALUES (141, 'EMS包裹', 'emsbg', '国际邮政');
INSERT INTO `t_delivery` VALUES (142, '微特派', 'weitepai', '国内运输商');
INSERT INTO `t_delivery` VALUES (143, '铁中快运', 'tzky', '国内运输商');
INSERT INTO `t_delivery` VALUES (144, '叁虎物流', 'sanhuwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (145, 'Aramex', 'aramex', '国际运输商');
INSERT INTO `t_delivery` VALUES (146, '飞鹰物流', 'hnfy', '国内运输商');
INSERT INTO `t_delivery` VALUES (147, 'DHL-德国件（DHL Deutschland）', 'dhlde', '国际运输商');
INSERT INTO `t_delivery` VALUES (148, '全联速运', 'guexp', '国内运输商');
INSERT INTO `t_delivery` VALUES (149, '秦岭智能速运', 'qinling', '国内运输商');
INSERT INTO `t_delivery` VALUES (150, '澳天速运', 'aotsd', '国际运输商');
INSERT INTO `t_delivery` VALUES (151, '联合速递', 'lhexpressus', '国际运输商');
INSERT INTO `t_delivery` VALUES (152, '中汲物流', 'zhongji', '国内运输商');
INSERT INTO `t_delivery` VALUES (153, '联合速运', 'unitedex', '国内运输商');
INSERT INTO `t_delivery` VALUES (154, '源安达', 'yuananda', '国内运输商');
INSERT INTO `t_delivery` VALUES (155, '圆通国际', 'yuantongguoji', '国际运输商');
INSERT INTO `t_delivery` VALUES (156, '燕文物流', 'yw56', '国际运输商');
INSERT INTO `t_delivery` VALUES (157, '程光快递', 'flyway', '国际运输商');
INSERT INTO `t_delivery` VALUES (158, '众邮快递', 'zhongyouex', '国内运输商');
INSERT INTO `t_delivery` VALUES (159, 'OCS', 'ocs', '国际运输商');
INSERT INTO `t_delivery` VALUES (160, '明通国际快递', 'tnjex', '国际运输商');
INSERT INTO `t_delivery` VALUES (161, '鼎润物流', 'la911', '国内运输商');
INSERT INTO `t_delivery` VALUES (162, 'GLS', 'gls', '国际运输商');
INSERT INTO `t_delivery` VALUES (163, '安达速递', 'adapost', '国内运输商');
INSERT INTO `t_delivery` VALUES (164, '百腾物流', 'baitengwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (165, '金岸物流', 'jinan', '国内运输商');
INSERT INTO `t_delivery` VALUES (166, '富吉速运', 'fujisuyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (167, 'DPD UK', 'dpduk', '国际运输商');
INSERT INTO `t_delivery` VALUES (168, '澳大利亚(Australia Post)', 'auspost', '国际邮政');
INSERT INTO `t_delivery` VALUES (169, '比利时（Bpost）', 'bpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (170, '城晓国际快递', 'ckeex', '国际运输商');
INSERT INTO `t_delivery` VALUES (171, 'MoreLink', 'morelink56', '国内运输商');
INSERT INTO `t_delivery` VALUES (172, '嘉贤物流', 'jiaxianwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (173, '安鲜达', 'exfresh', '国内运输商');
INSERT INTO `t_delivery` VALUES (174, '亚洲顺物流', 'yzswuliu', '国际运输商');
INSERT INTO `t_delivery` VALUES (175, '三志物流', 'sanzhi56', '国内运输商');
INSERT INTO `t_delivery` VALUES (176, '速尔快递', 'suer', '国内运输商');
INSERT INTO `t_delivery` VALUES (177, 'TNT Australia', 'tntau', '国际运输商');
INSERT INTO `t_delivery` VALUES (178, '三象速递', 'sxexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (179, '品骏快递', 'pjbest', '国内运输商');
INSERT INTO `t_delivery` VALUES (180, '聚盟共建', 'jumstc', '国内运输商');
INSERT INTO `t_delivery` VALUES (181, '亚马逊中国', 'yamaxunwuliu', '国际运输商');
INSERT INTO `t_delivery` VALUES (182, '大田物流', 'datianwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (183, '华翰物流', 'huahanwuliu', '国际运输商');
INSERT INTO `t_delivery` VALUES (184, '新西兰（New Zealand Post）', 'newzealand', '国际邮政');
INSERT INTO `t_delivery` VALUES (185, '中邮速递', 'wondersyd', '国内运输商');
INSERT INTO `t_delivery` VALUES (186, '昌宇国际', 'changwooair', '国际运输商');
INSERT INTO `t_delivery` VALUES (187, '递四方美国', 'disifangus', '国际运输商');
INSERT INTO `t_delivery` VALUES (188, '成都立即送', 'lijisong', '国内运输商');
INSERT INTO `t_delivery` VALUES (189, '中集冷云', 'cccc58', '国内运输商');
INSERT INTO `t_delivery` VALUES (190, '速达通', 'sdto', '国内运输商');
INSERT INTO `t_delivery` VALUES (191, '三真驿道', 'zlink', '国内运输商');
INSERT INTO `t_delivery` VALUES (192, '商桥物流', 'shangqiao56', '国内运输商');
INSERT INTO `t_delivery` VALUES (193, '优优速递', 'youyou', '国内运输商');
INSERT INTO `t_delivery` VALUES (194, '澳德物流', 'auod', '国际运输商');
INSERT INTO `t_delivery` VALUES (195, '一正达速运', 'yizhengdasuyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (196, '达发物流', 'dfwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (197, '美七国际快递', 'usa7ex', '国内运输商');
INSERT INTO `t_delivery` VALUES (198, '英国邮政大包EMS', 'parcelforcecn', '国际邮政');
INSERT INTO `t_delivery` VALUES (199, '极地快递', 'polarexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (200, 'dhl小包', 'dhlecommerce', '国际运输商');
INSERT INTO `t_delivery` VALUES (201, '上海快通', 'shanghaikuaitong', '国内运输商');
INSERT INTO `t_delivery` VALUES (202, '商壹国际物流', 'com1express', '国际运输商');
INSERT INTO `t_delivery` VALUES (203, '顺丰-荷兰', 'shunfengnl', '国际运输商');
INSERT INTO `t_delivery` VALUES (204, 'J&T Express 泰国', 'jtexpressth', '国际运输商');
INSERT INTO `t_delivery` VALUES (205, '速递中国', 'sendtochina', '国际运输商');
INSERT INTO `t_delivery` VALUES (206, '美乐维冷链物流', 'mlw', '国内运输商');
INSERT INTO `t_delivery` VALUES (207, '想乐送', 'leshines', '国内运输商');
INSERT INTO `t_delivery` VALUES (208, '长江国际速递', 'changjiang', '国际运输商');
INSERT INTO `t_delivery` VALUES (209, '速派快递', 'fastgoexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (210, '中邮物流', 'zhongyouwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (211, '海外环球', 'haiwaihuanqiu', '国际运输商');
INSERT INTO `t_delivery` VALUES (212, '中环快递', 'zhonghuan', '国内运输商');
INSERT INTO `t_delivery` VALUES (213, 'YDH', 'ydhex', '国内运输商');
INSERT INTO `t_delivery` VALUES (214, '黑猫宅急便', 'tcat', '国际运输商');
INSERT INTO `t_delivery` VALUES (215, '新元国际', 'xynyc', '国际运输商');
INSERT INTO `t_delivery` VALUES (216, '运通中港', 'yuntongkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (217, 'EFS Post（平安快递）', 'efs', '国际邮政');
INSERT INTO `t_delivery` VALUES (218, '安捷物流', 'anjie88', '国内运输商');
INSERT INTO `t_delivery` VALUES (219, '乌克兰邮政包裹', 'ukrpostcn', '国际邮政');
INSERT INTO `t_delivery` VALUES (220, '鸿泰物流', 'hnht56', '国内运输商');
INSERT INTO `t_delivery` VALUES (221, '加拿大龙行速运', 'longcps', '国内运输商');
INSERT INTO `t_delivery` VALUES (222, 'E2G速递', 'express2global', '国内运输商');
INSERT INTO `t_delivery` VALUES (223, '洋包裹', 'yangbaoguo', '国际运输商');
INSERT INTO `t_delivery` VALUES (224, 'CCES/国通快递', 'cces', '国际运输商');
INSERT INTO `t_delivery` VALUES (225, '佰麒快递', 'beckygo', '国内运输商');
INSERT INTO `t_delivery` VALUES (226, 'TNT Italy', 'tntitaly', '国际运输商');
INSERT INTO `t_delivery` VALUES (227, '迅达速递', 'xdexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (228, '百福东方', 'baifudongfang', '国际运输商');
INSERT INTO `t_delivery` VALUES (229, '无忧物流', 'aliexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (230, '北京EMS', 'bjemstckj', '国际邮政');
INSERT INTO `t_delivery` VALUES (231, '大韩通运', 'cjkoreaexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (232, 'EMS-国际件-英文', 'emsinten', '国际邮政');
INSERT INTO `t_delivery` VALUES (233, '顺丰冷链', 'shunfenglengyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (234, 'Kerry Express-泰国', 'kerrythailanden', '国际运输商');
INSERT INTO `t_delivery` VALUES (235, '直德邮', 'zdepost', '国际运输商');
INSERT INTO `t_delivery` VALUES (236, '早道佳', 'nbhtt', '国内运输商');
INSERT INTO `t_delivery` VALUES (237, '快捷快物流', 'gdkjk56', '国内运输商');
INSERT INTO `t_delivery` VALUES (238, '荷兰邮政-中国件', 'postnlchina', '国际邮政');
INSERT INTO `t_delivery` VALUES (239, '加拿大(Canada Post)', 'canpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (240, '快捷物流', 'kuaijiewuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (241, '签收快递', 'signedexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (242, '顺捷美中速递', 'passerbyaexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (243, '51跨境通', 'wykjt', '国际运输商');
INSERT INTO `t_delivery` VALUES (244, '欧亚专线', 'euasia', '国际运输商');
INSERT INTO `t_delivery` VALUES (245, '美通', 'valueway', '国内运输商');
INSERT INTO `t_delivery` VALUES (246, '世华通物流', 'szshihuatong56', '国内运输商');
INSERT INTO `t_delivery` VALUES (247, '景顺物流', 'jingshun', '国内运输商');
INSERT INTO `t_delivery` VALUES (248, '纳米比亚(NamPost)', 'namibia', '国际邮政');
INSERT INTO `t_delivery` VALUES (249, '全峰快递', 'quanfengkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (250, 'beiou express', 'beiou', '国内运输商');
INSERT INTO `t_delivery` VALUES (251, '万家物流', 'wanjiawuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (252, 'airpak expresss', 'airpak', '国际运输商');
INSERT INTO `t_delivery` VALUES (253, '顺丰-繁体', 'shunfenghk', '国内运输商');
INSERT INTO `t_delivery` VALUES (254, '安信达', 'anxindakuaixi', '国内运输商');
INSERT INTO `t_delivery` VALUES (255, '中欧物流', 'cneulogistics', '国内运输商');
INSERT INTO `t_delivery` VALUES (256, '丰通快运', 'ftky365', '国内运输商');
INSERT INTO `t_delivery` VALUES (257, '广东邮政', 'guangdongyouzhengwuliu', '国际邮政');
INSERT INTO `t_delivery` VALUES (258, '飞洋快递', 'shipgce', '国际运输商');
INSERT INTO `t_delivery` VALUES (259, '郑州速捷', 'sujievip', '国内运输商');
INSERT INTO `t_delivery` VALUES (260, '原飞航', 'yuanfeihangwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (261, '星云速递', 'nebuex', '国内运输商');
INSERT INTO `t_delivery` VALUES (262, '全一快递', 'quanyikuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (263, '中健云康', 'concare', '国内运输商');
INSERT INTO `t_delivery` VALUES (264, '行云物流', 'xyb2b', '国际运输商');
INSERT INTO `t_delivery` VALUES (265, '人人转运', 'renrenex', '国内运输商');
INSERT INTO `t_delivery` VALUES (266, '联运通物流', 'szuem', '国内运输商');
INSERT INTO `t_delivery` VALUES (267, '汇达物流', 'hdcexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (268, '佳吉快运', 'jiajiwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (269, '明达国际速递', 'tmwexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (270, '永昌物流', 'yongchangwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (271, 'EMS物流', 'emswuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (272, '汇峰物流', 'huif56', '国内运输商');
INSERT INTO `t_delivery` VALUES (273, '万象物流', 'wanxiangwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (274, '泰国138国际物流', 'sd138', '国际运输商');
INSERT INTO `t_delivery` VALUES (275, '泰实货运', 'tjkjwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (276, '番薯国际货运', 'koali', '国际运输商');
INSERT INTO `t_delivery` VALUES (277, '法国(La Poste)', 'csuivi', '国际邮政');
INSERT INTO `t_delivery` VALUES (278, '优速通达', 'yousutongda', '国内运输商');
INSERT INTO `t_delivery` VALUES (279, '友家速递', 'youjia', '国内运输商');
INSERT INTO `t_delivery` VALUES (280, '荷兰邮政-中文(PostNL international registered mail)', 'postnlcn', '国际邮政');
INSERT INTO `t_delivery` VALUES (281, '新西兰中通', 'nzzto', '国际运输商');
INSERT INTO `t_delivery` VALUES (282, '百世国际', 'baishiguoji', '国际运输商');
INSERT INTO `t_delivery` VALUES (283, '恒路物流', 'hengluwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (284, '韩国邮政', 'koreapostcn', '国际邮政');
INSERT INTO `t_delivery` VALUES (285, '海欣斯快递', 'highsince', '国际运输商');
INSERT INTO `t_delivery` VALUES (286, '新易泰', 'lnet', '国内运输商');
INSERT INTO `t_delivery` VALUES (287, '驿将快运', 'yijiangky', '国内运输商');
INSERT INTO `t_delivery` VALUES (288, '一智通', '1ziton', '国内运输商');
INSERT INTO `t_delivery` VALUES (289, '飞远配送', 'feiyuanvipshop', '国内运输商');
INSERT INTO `t_delivery` VALUES (290, '中途速递', 'ztcce', '国内运输商');
INSERT INTO `t_delivery` VALUES (291, '俄罗斯邮政(Russian Post)', 'pochta', '国际邮政');
INSERT INTO `t_delivery` VALUES (292, '深圳邮政', 'szyouzheng', '国际邮政');
INSERT INTO `t_delivery` VALUES (293, '迅速快递', 'xunsuexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (294, 'Flash Express-英文', 'flashexpressen', '国际运输商');
INSERT INTO `t_delivery` VALUES (295, '合众速递(UCS）', 'ucs', '国际运输商');
INSERT INTO `t_delivery` VALUES (296, '加拿大邮政', 'canpostfr', '国际邮政');
INSERT INTO `t_delivery` VALUES (297, 'CNE', 'cnexps', '国际运输商');
INSERT INTO `t_delivery` VALUES (298, '能达速递', 'ganzhongnengda', '国内运输商');
INSERT INTO `t_delivery` VALUES (299, 'FedEx-美国件', 'fedexus', '国际运输商');
INSERT INTO `t_delivery` VALUES (300, '武汉优进汇', 'yjhgo', '国内运输商');
INSERT INTO `t_delivery` VALUES (301, '次晨达物流', 'ccd', '国内运输商');
INSERT INTO `t_delivery` VALUES (302, '凤凰快递', 'fenghuangkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (303, '美国申通', 'stoexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (304, '皮牙子快递', 'bazirim', '国内运输商');
INSERT INTO `t_delivery` VALUES (305, '西班牙(Correos de Espa?a)', 'correosdees', '国际邮政');
INSERT INTO `t_delivery` VALUES (306, '美西快递', 'meixi', '国际运输商');
INSERT INTO `t_delivery` VALUES (307, '德国(Deutsche Post)', 'deutschepost', '国际邮政');
INSERT INTO `t_delivery` VALUES (308, '传喜物流', 'chuanxiwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (309, '冠达丰物流', 'gfdwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (310, '汇通天下物流', 'httx56', '国内运输商');
INSERT INTO `t_delivery` VALUES (311, '卓志速运', 'chinaicip', '国内运输商');
INSERT INTO `t_delivery` VALUES (312, '贰仟家物流', 'erqianjia56', '国内运输商');
INSERT INTO `t_delivery` VALUES (313, '久久物流', 'jiujiuwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (314, '民航快递', 'minghangkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (315, '锦程快递', 'hrex', '国内运输商');
INSERT INTO `t_delivery` VALUES (316, '7E速递', 'qesd', '国际运输商');
INSERT INTO `t_delivery` VALUES (317, '世通物流', 'worldex', '国际运输商');
INSERT INTO `t_delivery` VALUES (318, 'ADP国际快递', 'adp', '国际运输商');
INSERT INTO `t_delivery` VALUES (319, '中国香港(HongKong Post)', 'hkpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (320, '韩国邮政韩文', 'koreapostkr', '国际邮政');
INSERT INTO `t_delivery` VALUES (321, '海星桥快递', 'haixingqiao', '国内运输商');
INSERT INTO `t_delivery` VALUES (322, '汇捷物流', 'hjwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (323, 'ABF', 'abf', '国际运输商');
INSERT INTO `t_delivery` VALUES (324, '快卡', 'kuaika', '国内运输商');
INSERT INTO `t_delivery` VALUES (325, '亚风速递', 'yafengsudi', '国内运输商');
INSERT INTO `t_delivery` VALUES (326, '转瞬达集运', 'zsda56', '国内运输商');
INSERT INTO `t_delivery` VALUES (327, '海带宝', 'haidaibao', '国际运输商');
INSERT INTO `t_delivery` VALUES (328, '好来运', 'hlyex', '国内运输商');
INSERT INTO `t_delivery` VALUES (329, '无限速递', 'igcaexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (330, '意大利(Poste Italiane)', 'italiane', '国际邮政');
INSERT INTO `t_delivery` VALUES (331, 'Safexpress', 'safexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (332, '黑猫同城送', 'ynztsy', '国内运输商');
INSERT INTO `t_delivery` VALUES (333, '6LS EXPRESS', 'lsexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (334, '中华邮政', 'postserv', '国际邮政');
INSERT INTO `t_delivery` VALUES (335, '宇佳物流', 'yujiawl', '国内运输商');
INSERT INTO `t_delivery` VALUES (336, '瑞士邮政', 'swisspostcn', '国际邮政');
INSERT INTO `t_delivery` VALUES (337, '邮邦国际', 'youban', '国际运输商');
INSERT INTO `t_delivery` VALUES (338, '远成物流', 'yuanchengwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (339, '1688国际物流', 'buyer1688', '国际运输商');
INSERT INTO `t_delivery` VALUES (340, '领送送', 'lingsong', '国内运输商');
INSERT INTO `t_delivery` VALUES (341, '南方传媒物流', 'ndwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (342, '联合快递', 'gslhkd', '国内运输商');
INSERT INTO `t_delivery` VALUES (343, '佳成快递 ', 'jiacheng', '国内运输商');
INSERT INTO `t_delivery` VALUES (344, '法国大包、EMS-法文（Chronopost France）', 'chronopostfra', '国际邮政');
INSERT INTO `t_delivery` VALUES (345, '西游寄', 'xiyoug', '国际运输商');
INSERT INTO `t_delivery` VALUES (346, '百米快运', '100mexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (347, '货拉拉物流', 'huolalawuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (348, '秦邦快运', 'qbexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (349, '德国优拜物流', 'ubuy', '国际运输商');
INSERT INTO `t_delivery` VALUES (350, '易境达国际物流', 'uscbexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (351, '永邦国际物流', 'yongbangwuliu', '国际运输商');
INSERT INTO `t_delivery` VALUES (352, '中通冷链', 'ztocc', '国内运输商');
INSERT INTO `t_delivery` VALUES (353, 'A2U速递', 'a2u', '国际运输商');
INSERT INTO `t_delivery` VALUES (354, '五六快运', 'wuliuky', '国内运输商');
INSERT INTO `t_delivery` VALUES (355, '中宏物流', 'zhonghongwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (356, '中外运速递', 'zhongwaiyun', '国际运输商');
INSERT INTO `t_delivery` VALUES (357, '速舟物流', 'cnspeedster', '国内运输商');
INSERT INTO `t_delivery` VALUES (358, '速通鸿达', 'sutonghongda', '国内运输商');
INSERT INTO `t_delivery` VALUES (359, '递五方云仓', 'di5pll', '国内运输商');
INSERT INTO `t_delivery` VALUES (360, '黑猫速运', 'heimao56', '国内运输商');
INSERT INTO `t_delivery` VALUES (361, 'JDIEX', 'jdiex', '国际运输商');
INSERT INTO `t_delivery` VALUES (362, '全速物流', 'quansu', '国内运输商');
INSERT INTO `t_delivery` VALUES (363, '神骏物流', 'shenjun', '国内运输商');
INSERT INTO `t_delivery` VALUES (364, '三三国际物流', 'zenzen', '国际运输商');
INSERT INTO `t_delivery` VALUES (365, '彪记快递', 'biaojikuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (366, 'CDEK', 'cdek', '国际运输商');
INSERT INTO `t_delivery` VALUES (367, '一速递', 'oneexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (368, '增益速递', 'zengyisudi', '国内运输商');
INSERT INTO `t_delivery` VALUES (369, '疯狂快递', 'crazyexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (370, '如家国际快递', 'homecourier', '国际运输商');
INSERT INTO `t_delivery` VALUES (371, '上大物流', 'shangda', '国内运输商');
INSERT INTO `t_delivery` VALUES (372, '飞快达', 'feikuaida', '国内运输商');
INSERT INTO `t_delivery` VALUES (373, '嘉诚速达', 'jcsuda', '国内运输商');
INSERT INTO `t_delivery` VALUES (374, '山西建华', 'shanxijianhua', '国内运输商');
INSERT INTO `t_delivery` VALUES (375, '法国小包（colissimo）', 'colissimo', '国际运输商');
INSERT INTO `t_delivery` VALUES (376, '丹递56', 'dande56', '国内运输商');
INSERT INTO `t_delivery` VALUES (377, '颿达国际快递', 'fardarww', '国际运输商');
INSERT INTO `t_delivery` VALUES (378, '日日顺智慧物联', 'gooday365', '国内运输商');
INSERT INTO `t_delivery` VALUES (379, '上海航瑞货运', 'hangrui', '国内运输商');
INSERT INTO `t_delivery` VALUES (380, '印度尼西亚EMS(Pos Indonesia-EMS)', 'indonesia', '国际邮政');
INSERT INTO `t_delivery` VALUES (381, 'OnTrac', 'ontrac', '国际运输商');
INSERT INTO `t_delivery` VALUES (382, 'TST速运通', 'tstexp', '国际运输商');
INSERT INTO `t_delivery` VALUES (383, '洋口岸', 'ykouan', '国际运输商');
INSERT INTO `t_delivery` VALUES (384, '中技物流', 'zhongjiwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (385, '捷记方舟', 'ajexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (386, '飞康达', 'feikangda', '国内运输商');
INSERT INTO `t_delivery` VALUES (387, '广州安能聚创物流', 'gzanjcwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (388, '韩国（Korea Post）', 'koreapost', '国际邮政');
INSERT INTO `t_delivery` VALUES (389, '顺通快递', 'stkd', '国内运输商');
INSERT INTO `t_delivery` VALUES (390, '运通中港快递', 'ytkd', '国内运输商');
INSERT INTO `t_delivery` VALUES (391, 'globaltracktrace', 'globaltracktrace', '国际运输商');
INSERT INTO `t_delivery` VALUES (392, '远成快运', 'ycgky', '国内运输商');
INSERT INTO `t_delivery` VALUES (393, '远盾物流', 'yuandun', '国内运输商');
INSERT INTO `t_delivery` VALUES (394, '小飞侠速递', 'cyxfx', '国内运输商');
INSERT INTO `t_delivery` VALUES (395, 'DPD Poland', 'dpdpoland', '国际运输商');
INSERT INTO `t_delivery` VALUES (396, '聚鼎物流', 'juding', '国内运输商');
INSERT INTO `t_delivery` VALUES (397, '美国快递', 'meiguokuaidi', '国际运输商');
INSERT INTO `t_delivery` VALUES (398, '腾达速递', 'nntengda', '国内运输商');
INSERT INTO `t_delivery` VALUES (399, '英国大包、EMS（Parcel Force）', 'parcelforce', '国际邮政');
INSERT INTO `t_delivery` VALUES (400, '银雁专送', 'cfss', '国内运输商');
INSERT INTO `t_delivery` VALUES (401, 'DHL HK', 'dhlhk', '国际运输商');
INSERT INTO `t_delivery` VALUES (402, '联邦快递-英文', 'lianbangkuaidien', '国内运输商');
INSERT INTO `t_delivery` VALUES (403, 'Linex', 'linex', '国际运输商');
INSERT INTO `t_delivery` VALUES (404, '晟邦物流', 'nanjingshengbang', '国内运输商');
INSERT INTO `t_delivery` VALUES (405, '浩博物流', 'njhaobo', '国内运输商');
INSERT INTO `t_delivery` VALUES (406, '荷兰包裹(PostNL International Parcels)', 'postnlpacle', '国际邮政');
INSERT INTO `t_delivery` VALUES (407, '秦远物流', 'qinyuan', '国内运输商');
INSERT INTO `t_delivery` VALUES (408, '全日通', 'quanritongkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (409, '沃埃家', 'wowvip', '国内运输商');
INSERT INTO `t_delivery` VALUES (410, '阿富汗(Afghan Post)', 'afghan', '国际邮政');
INSERT INTO `t_delivery` VALUES (411, '华欣物流', 'chinastarlogistics', '国内运输商');
INSERT INTO `t_delivery` VALUES (412, '大洋物流', 'dayangwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (413, '中外运', 'esinotrans', '国际运输商');
INSERT INTO `t_delivery` VALUES (414, '中国香港(HongKong Post)英文', 'hkposten', '国际邮政');
INSERT INTO `t_delivery` VALUES (415, '时达通', 'jssdt56', '国内运输商');
INSERT INTO `t_delivery` VALUES (416, '丹麦(Post Denmark)', 'postdanmarken', '国际邮政');
INSERT INTO `t_delivery` VALUES (417, '易达通快递', 'qexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (418, '顺捷达', 'shunjieda', '国内运输商');
INSERT INTO `t_delivery` VALUES (419, '宜送物流', 'yiex', '国内运输商');
INSERT INTO `t_delivery` VALUES (420, '城际快递', 'chengji', '国内运输商');
INSERT INTO `t_delivery` VALUES (421, '法国大包、EMS-英文(Chronopost France)', 'chronopostfren', '国际邮政');
INSERT INTO `t_delivery` VALUES (422, '哥斯达黎加(Correos de Costa Rica)', 'correos', '国际邮政');
INSERT INTO `t_delivery` VALUES (423, '大道物流', 'dadaoex', '国内运输商');
INSERT INTO `t_delivery` VALUES (424, '极兔国际', 'jet', '国际运输商');
INSERT INTO `t_delivery` VALUES (425, '新速航', 'sunspeedy', '国内运输商');
INSERT INTO `t_delivery` VALUES (426, '泰国邮政（Thailand Thai Post）', 'thailand', '国际邮政');
INSERT INTO `t_delivery` VALUES (427, '创运物流', 'zjcy56', '国内运输商');
INSERT INTO `t_delivery` VALUES (428, '心怡物流', 'alog', '国内运输商');
INSERT INTO `t_delivery` VALUES (429, '八达通', 'bdatong', '国内运输商');
INSERT INTO `t_delivery` VALUES (430, '比利时国际(Bpost international)', 'bpostinter', '国际邮政');
INSERT INTO `t_delivery` VALUES (431, 'DHL Benelux', 'dhlbenelux', '国际运输商');
INSERT INTO `t_delivery` VALUES (432, 'EASY EXPRESS', 'easyexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (433, '飞力士物流', 'flysman', '国内运输商');
INSERT INTO `t_delivery` VALUES (434, 'GTS快递', 'gts', '国际运输商');
INSERT INTO `t_delivery` VALUES (435, '美泰物流', 'meitai', '国内运输商');
INSERT INTO `t_delivery` VALUES (436, '中环转运', 'zhonghuanus', '国际运输商');
INSERT INTO `t_delivery` VALUES (437, '澳世速递', 'ausexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (438, '奥地利(Austrian Post)', 'austria', '国际邮政');
INSERT INTO `t_delivery` VALUES (439, '奔腾物流', 'benteng', '国内运输商');
INSERT INTO `t_delivery` VALUES (440, '上海缤纷物流', 'bflg', '国内运输商');
INSERT INTO `t_delivery` VALUES (441, 'BHT', 'bht', '国际运输商');
INSERT INTO `t_delivery` VALUES (442, 'CHS中环国际快递', 'chszhonghuanguoji', '国际运输商');
INSERT INTO `t_delivery` VALUES (443, 'Toll', 'dpexen', '国际运输商');
INSERT INTO `t_delivery` VALUES (444, '澳州顺风快递', 'emms', '国际运输商');
INSERT INTO `t_delivery` VALUES (445, '7号速递', 'express7th', '国内运输商');
INSERT INTO `t_delivery` VALUES (446, '凡宇快递', 'fanyukuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (447, 'GE2D跨境物流', 'ge2d', '国际运输商');
INSERT INTO `t_delivery` VALUES (448, '宏捷国际物流', 'hongjie', '国际运输商');
INSERT INTO `t_delivery` VALUES (449, '环球速运', 'huanqiu', '国际运输商');
INSERT INTO `t_delivery` VALUES (450, '大达物流', 'idada', '国内运输商');
INSERT INTO `t_delivery` VALUES (451, '艾姆勒', 'imlb2c', '国际运输商');
INSERT INTO `t_delivery` VALUES (452, '佳吉快递', 'jiajikuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (453, 'LUCFLOW EXPRESS', 'longfx', '国内运输商');
INSERT INTO `t_delivery` VALUES (454, '魔速达', 'mosuda', '国内运输商');
INSERT INTO `t_delivery` VALUES (455, '配思货运', 'peisihuoyunkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (456, '葡萄牙（Portugal CTT）', 'portugalctt', '国际运输商');
INSERT INTO `t_delivery` VALUES (457, '中加国际快递', 'scic', '国际运输商');
INSERT INTO `t_delivery` VALUES (458, '万家康物流', 'wjkwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (459, '伍圆速递', 'wuyuansudi', '国内运输商');
INSERT INTO `t_delivery` VALUES (460, '中融泰隆', 'zrtl', '国内运输商');
INSERT INTO `t_delivery` VALUES (461, '德国雄鹰速递', 'adlerlogi', '国际运输商');
INSERT INTO `t_delivery` VALUES (462, '百世云配', 'baishiyp', '国内运输商');
INSERT INTO `t_delivery` VALUES (463, '贝业物流', 'boyol', '国内运输商');
INSERT INTO `t_delivery` VALUES (464, '百通物流', 'buytong', '国内运输商');
INSERT INTO `t_delivery` VALUES (465, '鑫宸物流', 'cdxinchen56', '国内运输商');
INSERT INTO `t_delivery` VALUES (466, '创一快递', 'chuangyi', '国内运输商');
INSERT INTO `t_delivery` VALUES (467, '深圳德创物流', 'dechuangwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (468, '成都东骏物流', 'dongjun', '国内运输商');
INSERT INTO `t_delivery` VALUES (469, 'EMS-英文', 'emsen', '国际邮政');
INSERT INTO `t_delivery` VALUES (470, '南非EMS', 'emssouthafrica', '国际邮政');
INSERT INTO `t_delivery` VALUES (471, 'GSM', 'gsm', '国际运输商');
INSERT INTO `t_delivery` VALUES (472, '海红网送', 'haihongwangsong', '国内运输商');
INSERT INTO `t_delivery` VALUES (473, '佳辰国际速递', 'jiachenexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (474, '猛犸速递', 'mmlogi', '国际运输商');
INSERT INTO `t_delivery` VALUES (475, 'PostNord(Posten AB)', 'postenab', '国际邮政');
INSERT INTO `t_delivery` VALUES (476, '圣安物流', 'shenganwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (477, '淘特物流快递', 'taote', '国内运输商');
INSERT INTO `t_delivery` VALUES (478, '中运全速', 'topspeedex', '国内运输商');
INSERT INTO `t_delivery` VALUES (479, 'TransRush', 'transrush', '国际运输商');
INSERT INTO `t_delivery` VALUES (480, '海龟国际快递', 'turtle', '国际运输商');
INSERT INTO `t_delivery` VALUES (481, '苏通快运', 'zjstky', '国内运输商');
INSERT INTO `t_delivery` VALUES (482, '智通物流', 'ztong', '国内运输商');
INSERT INTO `t_delivery` VALUES (483, '全球快运', 'abcglobal', '国际运输商');
INSERT INTO `t_delivery` VALUES (484, '青岛安捷快递', 'anjiekuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (485, '爱尔兰(An Post)', 'anposten', '国际邮政');
INSERT INTO `t_delivery` VALUES (486, '邦送物流', 'bangsongwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (487, '比利时(Belgium Post)', 'belgiumpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (488, '长吉物流', 'cjqy', '国内运输商');
INSERT INTO `t_delivery` VALUES (489, '泛远国际物流', 'farlogistis', '国际运输商');
INSERT INTO `t_delivery` VALUES (490, '安的快递', 'gda', '国内运输商');
INSERT INTO `t_delivery` VALUES (491, '晋越快递', 'jinyuekuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (492, '龙枫国际快递', 'lfexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (493, '木春货运', 'mchy', '国际运输商');
INSERT INTO `t_delivery` VALUES (494, 'Ninja Van ', 'ninjavan', '国际运输商');
INSERT INTO `t_delivery` VALUES (495, '瑞典（Sweden Post）', 'ruidianyouzheng', '国际邮政');
INSERT INTO `t_delivery` VALUES (496, '全时速运', 'runhengfeng', '国内运输商');
INSERT INTO `t_delivery` VALUES (497, '丰程物流', 'sccod', '国内运输商');
INSERT INTO `t_delivery` VALUES (498, '顺捷丰达', 'shunjiefengda', '国内运输商');
INSERT INTO `t_delivery` VALUES (499, '申通新西兰', 'stonewzealand', '国际运输商');
INSERT INTO `t_delivery` VALUES (500, '穗佳物流', 'suijiawuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (501, '加拿大雷霆快递', 'thunderexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (502, 'TRAKPAK', 'trakpak', '国际运输商');
INSERT INTO `t_delivery` VALUES (503, '快弟来了', 'xlair', '国内运输商');
INSERT INTO `t_delivery` VALUES (504, '360 Lion Express', '360lion', '国际运输商');
INSERT INTO `t_delivery` VALUES (505, 'AFL', 'afl', '国际运输商');
INSERT INTO `t_delivery` VALUES (506, '亚马逊中国订单', 'amazoncnorder', '国际运输商');
INSERT INTO `t_delivery` VALUES (507, '阿森迪亚', 'asendia', '国际运输商');
INSERT INTO `t_delivery` VALUES (508, 'Asendia USA', 'asendiausa', '国际运输商');
INSERT INTO `t_delivery` VALUES (509, '锋鸟物流', 'beebird', '国内运输商');
INSERT INTO `t_delivery` VALUES (510, '北美国际物流', 'bmxps', '国际运输商');
INSERT INTO `t_delivery` VALUES (511, '捷克（?eská po?ta）', 'ceskaposta', '国际运输商');
INSERT INTO `t_delivery` VALUES (512, '澳通华人物流', 'cllexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (513, 'DHL-荷兰（DHL Netherlands）', 'dhlnetherlands', '国际运输商');
INSERT INTO `t_delivery` VALUES (514, 'DPEX', 'dpex', '国际运输商');
INSERT INTO `t_delivery` VALUES (515, 'E速达', 'exsuda', '国内运输商');
INSERT INTO `t_delivery` VALUES (516, '冠捷物流 ', 'gjwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (517, '共速达', 'gongsuda', '国内运输商');
INSERT INTO `t_delivery` VALUES (518, '海派国际速递', 'hpexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (519, '海硕高铁速递', 'hsgtsd', '国内运输商');
INSERT INTO `t_delivery` VALUES (520, '鸿远物流', 'hyeship', '国内运输商');
INSERT INTO `t_delivery` VALUES (521, '加州猫速递', 'jiazhoumao', '国内运输商');
INSERT INTO `t_delivery` VALUES (522, '捷安达', 'jieanda', '国内运输商');
INSERT INTO `t_delivery` VALUES (523, 'J&T Express 新加坡', 'jtexpresssg', '国际运输商');
INSERT INTO `t_delivery` VALUES (524, '快速递', 'ksudi', '国内运输商');
INSERT INTO `t_delivery` VALUES (525, '马来西亚小包（Malaysia Post(Registered)）', 'malaysiapost', '国际邮政');
INSERT INTO `t_delivery` VALUES (526, '明亮物流', 'mingliangwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (527, '鹏程快递', 'pengcheng', '国内运输商');
INSERT INTO `t_delivery` VALUES (528, '雪域易购', 'qhxyyg', '国内运输商');
INSERT INTO `t_delivery` VALUES (529, 'Quantium', 'quantium', '国际运输商');
INSERT INTO `t_delivery` VALUES (530, '中外运空运', 'sinoairinex', '国际运输商');
INSERT INTO `t_delivery` VALUES (531, '红马甲物流', 'sxhongmajia', '国内运输商');
INSERT INTO `t_delivery` VALUES (532, '越南EMS(VNPost Express)', 'vnpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (533, '新宁物流', 'xinning', '国内运输商');
INSERT INTO `t_delivery` VALUES (534, 'YODEL', 'yodel', '国际运输商');
INSERT INTO `t_delivery` VALUES (535, '壹品速递', 'ypsd', '国内运输商');
INSERT INTO `t_delivery` VALUES (536, '浩运物流', 'zbhy56', '国内运输商');
INSERT INTO `t_delivery` VALUES (537, '中天万运', 'zhongtianwanyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (538, '增速跨境 ', 'zyzoom', '国际运输商');
INSERT INTO `t_delivery` VALUES (539, '明大快递', 'adaexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (540, '阿鲁巴[荷兰]（Post Aruba）', 'aruba', '国际邮政');
INSERT INTO `t_delivery` VALUES (541, '安世通快递', 'astexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (542, '澳货通', 'auex', '国际运输商');
INSERT INTO `t_delivery` VALUES (543, '中联速递', 'auvanda', '国内运输商');
INSERT INTO `t_delivery` VALUES (544, '鑫锐达', 'bjxsrd', '国内运输商');
INSERT INTO `t_delivery` VALUES (545, 'BorderGuru', 'borderguru', '国际邮政');
INSERT INTO `t_delivery` VALUES (546, '百事亨通', 'bsht', '国内运输商');
INSERT INTO `t_delivery` VALUES (547, '能装能送', 'canhold', '国内运输商');
INSERT INTO `t_delivery` VALUES (548, '捷祥物流', 'cdjx56', '国内运输商');
INSERT INTO `t_delivery` VALUES (549, 'CNPEX中邮快递', 'cnpex', '国际运输商');
INSERT INTO `t_delivery` VALUES (550, '哥伦比亚(4-72 La Red Postal de Colombia)', 'colombia', '国际邮政');
INSERT INTO `t_delivery` VALUES (551, '华中快递', 'cpsair', '国内运输商');
INSERT INTO `t_delivery` VALUES (552, '渡石医药', 'dushisc', '国内运输商');
INSERT INTO `t_delivery` VALUES (553, '大亿快递', 'dyexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (554, '希腊EMS（ELTA Courier）', 'eltahell', '国际邮政');
INSERT INTO `t_delivery` VALUES (555, '阿联酋(Emirates Post)', 'emirates', '国际邮政');
INSERT INTO `t_delivery` VALUES (556, '易达国际速递', 'eta100', '国际运输商');
INSERT INTO `t_delivery` VALUES (557, 'Fastway Ireland', 'fastway', '国际运输商');
INSERT INTO `t_delivery` VALUES (558, 'FedRoad 联邦转运', 'fedroad', '国际运输商');
INSERT INTO `t_delivery` VALUES (559, '广东通路', 'guangdongtonglu', '国内运输商');
INSERT INTO `t_delivery` VALUES (560, '瀚朝物流', 'hac56', '国内运输商');
INSERT INTO `t_delivery` VALUES (561, '航宇快递', 'hangyu', '国内运输商');
INSERT INTO `t_delivery` VALUES (562, '海联快递', 'hltop', '国内运输商');
INSERT INTO `t_delivery` VALUES (563, '河南全速通', 'hnqst', '国内运输商');
INSERT INTO `t_delivery` VALUES (564, '汇强快递', 'huiqiangkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (565, '急先达', 'jixianda', '国内运输商');
INSERT INTO `t_delivery` VALUES (566, '考拉国际速递', 'kaolaexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (567, '快服务', 'kfwnet', '国内运输商');
INSERT INTO `t_delivery` VALUES (568, '柬埔寨中通', 'khzto', '国内运输商');
INSERT INTO `t_delivery` VALUES (569, '快达物流', 'kuaidawuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (570, '老挝(Lao Express) ', 'lao', '国际运输商');
INSERT INTO `t_delivery` VALUES (571, '一号线', 'lineone', '国际运输商');
INSERT INTO `t_delivery` VALUES (572, '敏華物流', 'manwah', '国内运输商');
INSERT INTO `t_delivery` VALUES (573, 'PCA Express', 'pcaexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (574, '北极星快运', 'polarisexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (575, '星速递', 'starex', '国内运输商');
INSERT INTO `t_delivery` VALUES (576, '天联快运', 'tlky', '国内运输商');
INSERT INTO `t_delivery` VALUES (577, 'TNT Post', 'tntpostcn', '国际邮政');
INSERT INTO `t_delivery` VALUES (578, '通和天下', 'tonghetianxia', '国内运输商');
INSERT INTO `t_delivery` VALUES (579, 'UEQ快递', 'ueq', '国际运输商');
INSERT INTO `t_delivery` VALUES (580, '宁夏万家通', 'wanjiatong', '国内运输商');
INSERT INTO `t_delivery` VALUES (581, '耀奇物流', 'yaoqi', '国内运输商');
INSERT INTO `t_delivery` VALUES (582, '亿领速运', 'yilingsuyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (583, '邮来速递', 'youlai', '国内运输商');
INSERT INTO `t_delivery` VALUES (584, '雅澳物流', 'yourscm', '国际运输商');
INSERT INTO `t_delivery` VALUES (585, '运通快运', 'ytky168', '国内运输商');
INSERT INTO `t_delivery` VALUES (586, '玥玛速运', 'yue777', '国内运输商');
INSERT INTO `t_delivery` VALUES (587, '忠信达', 'zhongxinda', '国内运输商');
INSERT INTO `t_delivery` VALUES (588, '众派速递', 'zhpex', '国内运输商');
INSERT INTO `t_delivery` VALUES (589, '卓实快运', 'zhuoshikuaiyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (590, '中粮鲜到家物流', 'zlxdjwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (591, '安达信', 'advancing', '国内运输商');
INSERT INTO `t_delivery` VALUES (592, '全程快递', 'agopost', '国内运输商');
INSERT INTO `t_delivery` VALUES (593, '德方物流', 'ahdf', '国内运输商');
INSERT INTO `t_delivery` VALUES (594, '加拿大民航快递', 'airgtc', '国际运输商');
INSERT INTO `t_delivery` VALUES (595, 'amazon-国际订单', 'amusorder', '国际运输商');
INSERT INTO `t_delivery` VALUES (596, '安时递', 'anshidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (597, 'AOL澳通速递', 'aolau', '国际运输商');
INSERT INTO `t_delivery` VALUES (598, '蜜蜂速递', 'bee001', '国内运输商');
INSERT INTO `t_delivery` VALUES (599, '白俄罗斯(Belpochta)', 'belpost', '国际运输商');
INSERT INTO `t_delivery` VALUES (600, '青云物流', 'bjqywl', '国内运输商');
INSERT INTO `t_delivery` VALUES (601, '卢森堡航空', 'cargolux', '国际运输商');
INSERT INTO `t_delivery` VALUES (602, '河北橙配', 'chengpei', '国内运输商');
INSERT INTO `t_delivery` VALUES (603, 'Chronopost Portugal', 'chronopostport', '国际邮政');
INSERT INTO `t_delivery` VALUES (604, 'City-Link', 'citylink', '国际运输商');
INSERT INTO `t_delivery` VALUES (605, 'CNAIR', 'cnair', '国际运输商');
INSERT INTO `t_delivery` VALUES (606, 'CNUP 中联邮', 'cnup', '国际运输商');
INSERT INTO `t_delivery` VALUES (607, 'DCS', 'dcs', '国际运输商');
INSERT INTO `t_delivery` VALUES (608, '递达速运', 'didasuyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (609, 'E跨通', 'ecallturn', '国际运输商');
INSERT INTO `t_delivery` VALUES (610, '龙象国际物流', 'edragon', '国际运输商');
INSERT INTO `t_delivery` VALUES (611, '阿联酋(Emirates Post)', 'emiratesen', '国内运输商');
INSERT INTO `t_delivery` VALUES (612, 'EU-EXPRESS', 'euexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (613, '飛斯特運通', 'exbtr', '国际运输商');
INSERT INTO `t_delivery` VALUES (614, '飞邦快递', 'fbkd', '国内运输商');
INSERT INTO `t_delivery` VALUES (615, '飞狐快递', 'feihukuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (616, 'FOX国际快递', 'fox', '国际运输商');
INSERT INTO `t_delivery` VALUES (617, '广东诚通物流', 'gdct56', '国内运输商');
INSERT INTO `t_delivery` VALUES (618, '容智快运', 'gdrz58', '国内运输商');
INSERT INTO `t_delivery` VALUES (619, 'GHT物流', 'ghtexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (620, '全球速运', 'global99', '国际运输商');
INSERT INTO `t_delivery` VALUES (621, '高捷快运', 'goldjet', '国内运输商');
INSERT INTO `t_delivery` VALUES (622, '光线速递', 'gxwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (623, '海中转运', 'haizhongzhuanyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (624, '云邮跨境快递', 'hkems', '国际运输商');
INSERT INTO `t_delivery` VALUES (625, '宏品物流', 'hongpinwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (626, '红远物流', 'hongywl', '国内运输商');
INSERT INTO `t_delivery` VALUES (627, '驿扬国际速运', 'iyoungspeed', '国际运输商');
INSERT INTO `t_delivery` VALUES (628, '急递', 'jdpplus', '国内运输商');
INSERT INTO `t_delivery` VALUES (629, '极光转运', 'jiguang', '国际运输商');
INSERT INTO `t_delivery` VALUES (630, 'J&T Express 菲律宾', 'jtexpressph', '国际运输商');
INSERT INTO `t_delivery` VALUES (631, '骏丰国际速递', 'junfengguoji', '国际运输商');
INSERT INTO `t_delivery` VALUES (632, '塞内加尔', 'laposte', '国际邮政');
INSERT INTO `t_delivery` VALUES (633, 'LaserShip', 'lasership', '国际运输商');
INSERT INTO `t_delivery` VALUES (634, '乐递供应链', 'ledii', '国内运输商');
INSERT INTO `t_delivery` VALUES (635, '黎巴嫩(Liban Post)', 'libanpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (636, '力展物流', 'lizhan', '国内运输商');
INSERT INTO `t_delivery` VALUES (637, '长风物流', 'longvast', '国内运输商');
INSERT INTO `t_delivery` VALUES (638, '鲁通快运', 'lutong', '国内运输商');
INSERT INTO `t_delivery` VALUES (639, 'LWE', 'lwe', '国际运输商');
INSERT INTO `t_delivery` VALUES (640, '中国澳门(Macau Post)', 'macao', '国际邮政');
INSERT INTO `t_delivery` VALUES (641, 'MyHermes', 'myhermes', '国际运输商');
INSERT INTO `t_delivery` VALUES (642, '偌亚奥国际快递', 'nuoyaao', '国际运输商');
INSERT INTO `t_delivery` VALUES (643, '一号仓', 'onehcang', '国际运输商');
INSERT INTO `t_delivery` VALUES (644, '皇家物流', 'pfcexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (645, '菲律宾（Philippine Postal）', 'phlpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (646, '挪威（Posten Norge）', 'postennorge', '国际邮政');
INSERT INTO `t_delivery` VALUES (647, 'Purolator', 'purolator', '国际运输商');
INSERT INTO `t_delivery` VALUES (648, '千顺快递', 'qskdyxgs', '国内运输商');
INSERT INTO `t_delivery` VALUES (649, '全际通', 'quanjitong', '国内运输商');
INSERT INTO `t_delivery` VALUES (650, '全通快运', 'quantwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (651, '全信通快递', 'quanxintong', '国内运输商');
INSERT INTO `t_delivery` VALUES (652, '速佳达快运', 'scsujiada', '国内运输商');
INSERT INTO `t_delivery` VALUES (653, '速呈', 'sczpds', '国内运输商');
INSERT INTO `t_delivery` VALUES (654, 'International Seur', 'seur', '国际运输商');
INSERT INTO `t_delivery` VALUES (655, '十方通物流', 'sfift', '国内运输商');
INSERT INTO `t_delivery` VALUES (656, '世运快递', 'shiyunkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (657, '新加坡小包(Singapore Post)', 'singpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (658, '嗖一下同城快递', 'sofast56', '国内运输商');
INSERT INTO `t_delivery` VALUES (659, '行必达', 'speeda', '国内运输商');
INSERT INTO `t_delivery` VALUES (660, '申必达', 'speedoex', '国内运输商');
INSERT INTO `t_delivery` VALUES (661, '星运快递', 'staryvr', '国内运输商');
INSERT INTO `t_delivery` VALUES (662, '万家通快递', 'timedg', '国内运输商');
INSERT INTO `t_delivery` VALUES (663, '通达兴物流', 'tongdaxing', '国内运输商');
INSERT INTO `t_delivery` VALUES (664, 'UEX国际物流', 'uex', '国际运输商');
INSERT INTO `t_delivery` VALUES (665, '豌豆物流', 'wandougongzhu', '国内运输商');
INSERT INTO `t_delivery` VALUES (666, '翔腾物流', 'xiangteng', '国内运输商');
INSERT INTO `t_delivery` VALUES (667, '鑫梦成', 'xinmengcheng', '国内运输商');
INSERT INTO `t_delivery` VALUES (668, '袋鼠速递', 'xjdaishu', '国内运输商');
INSERT INTO `t_delivery` VALUES (669, '鑫通宝物流', 'xtb', '国内运输商');
INSERT INTO `t_delivery` VALUES (670, '宇航通物流', 'yhtlogistics', '国内运输商');
INSERT INTO `t_delivery` VALUES (671, '一邦速递', 'yibangwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (672, '英超物流', 'yingchao', '国际运输商');
INSERT INTO `t_delivery` VALUES (673, '越丰物流', 'yuefengwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (674, '韵丰物流', 'yunfeng56', '国内运输商');
INSERT INTO `t_delivery` VALUES (675, '运通速运', 'yuntong', '国内运输商');
INSERT INTO `t_delivery` VALUES (676, '志腾物流', 'zhitengwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (677, 'AAA Cooper Transportation', 'aaacooper', '国际运输商');
INSERT INTO `t_delivery` VALUES (678, '澳捷物流', 'ajlogistics', '国际运输商');
INSERT INTO `t_delivery` VALUES (679, '阿尔巴尼亚(Posta shqipatre)', 'albania', '国际邮政');
INSERT INTO `t_delivery` VALUES (680, 'amazon-国内订单', 'amcnorder', '国际运输商');
INSERT INTO `t_delivery` VALUES (681, '安家同城快运', 'anjiatongcheng', '国内运输商');
INSERT INTO `t_delivery` VALUES (682, '澳速物流', 'aosu', '国际运输商');
INSERT INTO `t_delivery` VALUES (683, '澳邦国际物流', 'ausbondexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (684, '巴林(Bahrain Post)', 'bahrain', '国际邮政');
INSERT INTO `t_delivery` VALUES (685, '帮帮发', 'bangbangpost', '国际运输商');
INSERT INTO `t_delivery` VALUES (686, '飛斯特', 'bester', '国际运输商');
INSERT INTO `t_delivery` VALUES (687, 'BlueDart', 'bluedart', '国际运输商');
INSERT INTO `t_delivery` VALUES (688, '巴西(Brazil Post/Correios)', 'brazilposten', '国际邮政');
INSERT INTO `t_delivery` VALUES (689, 'Canpar', 'canpar', '国际运输商');
INSERT INTO `t_delivery` VALUES (690, 'CBL Logistica', 'cbl', '国内运输商');
INSERT INTO `t_delivery` VALUES (691, 'SQK国际速递', 'chinasqk', '国际运输商');
INSERT INTO `t_delivery` VALUES (692, '中翼国际物流', 'chnexp', '国际运输商');
INSERT INTO `t_delivery` VALUES (693, '中骅物流', 'chunghwa56', '国内运输商');
INSERT INTO `t_delivery` VALUES (694, 'CL日中速运', 'clsp', '国际运输商');
INSERT INTO `t_delivery` VALUES (695, '中澳速递', 'cnausu', '国际运输商');
INSERT INTO `t_delivery` VALUES (696, 'C&C国际速递', 'cncexp', '国际运输商');
INSERT INTO `t_delivery` VALUES (697, '重庆星程快递', 'cqxingcheng', '国内运输商');
INSERT INTO `t_delivery` VALUES (698, '环旅快运', 'crossbox', '国内运输商');
INSERT INTO `t_delivery` VALUES (699, '泰国中通CTO', 'ctoexp', '国际运输商');
INSERT INTO `t_delivery` VALUES (700, '云南诚中物流', 'czwlyn', '国内运输商');
INSERT INTO `t_delivery` VALUES (701, '德中快递', 'decnlh', '国内运输商');
INSERT INTO `t_delivery` VALUES (702, 'Delhivery', 'delhivery', '国际运输商');
INSERT INTO `t_delivery` VALUES (703, 'DHL-波兰（DHL Poland）', 'dhlpoland', '国际运输商');
INSERT INTO `t_delivery` VALUES (704, '叮咚快递', 'dingdong', '国内运输商');
INSERT INTO `t_delivery` VALUES (705, '递四方澳洲', 'disifangau', '国际运输商');
INSERT INTO `t_delivery` VALUES (706, 'DTDC India', 'dtdcindia', '国际运输商');
INSERT INTO `t_delivery` VALUES (707, 'ECMS Express', 'ecmsglobal', '国际运输商');
INSERT INTO `t_delivery` VALUES (708, 'Ecom Express', 'ecomexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (709, 'e直运', 'edtexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (710, 'EFSPOST', 'efspost', '国内运输商');
INSERT INTO `t_delivery` VALUES (711, '艾菲尔国际速递', 'eiffel', '国际运输商');
INSERT INTO `t_delivery` VALUES (712, '希腊包裹（ELTA Hellenic Post）', 'elta', '国际邮政');
INSERT INTO `t_delivery` VALUES (713, '波兰小包(Poczta Polska)', 'emonitoring', '国际运输商');
INSERT INTO `t_delivery` VALUES (714, '英国(大包,EMS)', 'england', '国际邮政');
INSERT INTO `t_delivery` VALUES (715, 'ETEEN专线', 'eteenlog', '国内运输商');
INSERT INTO `t_delivery` VALUES (716, 'E通速递', 'etong', '国际运输商');
INSERT INTO `t_delivery` VALUES (717, '加拿大联通快运', 'fastontime', '国际运输商');
INSERT INTO `t_delivery` VALUES (718, '芬兰(Itella Posti Oy)', 'finland', '国际邮政');
INSERT INTO `t_delivery` VALUES (719, 'FQ狂派速递', 'freakyquick', '国际运输商');
INSERT INTO `t_delivery` VALUES (720, '法翔速运', 'ftlexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (721, 'Gati-英文', 'gatien', '国际运输商');
INSERT INTO `t_delivery` VALUES (722, 'Gati-KWE', 'gatikwe', '国际运输商');
INSERT INTO `t_delivery` VALUES (723, '环创物流', 'ghl', '国内运输商');
INSERT INTO `t_delivery` VALUES (724, '直布罗陀[英国]( Royal Gibraltar Post)', 'gibraltar', '国际邮政');
INSERT INTO `t_delivery` VALUES (725, '潍鸿', 'grivertek', '国际运输商');
INSERT INTO `t_delivery` VALUES (726, '万通快递', 'gswtkd', '国内运输商');
INSERT INTO `t_delivery` VALUES (727, '根西岛', 'guernsey', '国际邮政');
INSERT INTO `t_delivery` VALUES (728, '汉邦国际速递', 'handboy', '国际运输商');
INSERT INTO `t_delivery` VALUES (729, '好又快物流', 'haoyoukuai', '国内运输商');
INSERT INTO `t_delivery` VALUES (730, '开心快递', 'happylink', '国内运输商');
INSERT INTO `t_delivery` VALUES (731, '亚美尼亚(Haypost-Armenian Postal)', 'haypost', '国际邮政');
INSERT INTO `t_delivery` VALUES (732, 'Hi淘易快递', 'hitaoe', '国际运输商');
INSERT INTO `t_delivery` VALUES (733, '互联快运', 'hlkytj', '国内运输商');
INSERT INTO `t_delivery` VALUES (734, '华美快递', 'hmus', '国内运输商');
INSERT INTO `t_delivery` VALUES (735, '顺时达物流', 'hnssd56', '国内运输商');
INSERT INTO `t_delivery` VALUES (736, '高铁速递', 'hre', '国内运输商');
INSERT INTO `t_delivery` VALUES (737, '海淘物流', 'ht22', '国内运输商');
INSERT INTO `t_delivery` VALUES (738, '中国香港环球快运', 'huanqiuabc', '国际运输商');
INSERT INTO `t_delivery` VALUES (739, '华企快运', 'huaqikuaiyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (740, '驼峰国际', 'humpline', '国际运输商');
INSERT INTO `t_delivery` VALUES (741, '户通物流', 'hutongwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (742, '上海昊宏国际货物', 'hyk', '国际运输商');
INSERT INTO `t_delivery` VALUES (743, '冰岛(Iceland Post)', 'iceland', '国际邮政');
INSERT INTO `t_delivery` VALUES (744, '印度(India Post)', 'india', '国际邮政');
INSERT INTO `t_delivery` VALUES (745, '牙买加（Jamaica Post）', 'jamaicapost', '国际邮政');
INSERT INTO `t_delivery` VALUES (746, 'jcex', 'jcex', '国际运输商');
INSERT INTO `t_delivery` VALUES (747, '佳家通货运', 'jiajiatong56', '国内运输商');
INSERT INTO `t_delivery` VALUES (748, '锦程物流', 'jinchengwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (749, '金大物流', 'jindawuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (750, '九宫物流', 'jiugong', '国内运输商');
INSERT INTO `t_delivery` VALUES (751, '佳捷翔物流', 'jjx888', '国内运输商');
INSERT INTO `t_delivery` VALUES (752, '聚中大', 'juzhongda', '国内运输商');
INSERT INTO `t_delivery` VALUES (753, '哈萨克斯坦(Kazpost)', 'kazpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (754, 'KCS', 'kcs', '国际运输商');
INSERT INTO `t_delivery` VALUES (755, '淘韩国际快递', 'krtao', '国际运输商');
INSERT INTO `t_delivery` VALUES (756, '快8速运', 'kuai8', '国内运输商');
INSERT INTO `t_delivery` VALUES (757, '吉尔吉斯斯坦(Kyrgyz Post)', 'kyrgyzpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (758, '蓝镖快递', 'lanbiaokuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (759, '林道国际快递-英文', 'ldxpres', '国际运输商');
INSERT INTO `t_delivery` VALUES (760, '莱索托(Lesotho Post)', 'lesotho', '国际邮政');
INSERT INTO `t_delivery` VALUES (761, 'lazada', 'lgs', '国际运输商');
INSERT INTO `t_delivery` VALUES (762, '联运快递', 'lianyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (763, '联通快递', 'ltparcel', '国际运输商');
INSERT INTO `t_delivery` VALUES (764, '陆本速递 LUBEN EXPRESS', 'luben', '国内运输商');
INSERT INTO `t_delivery` VALUES (765, '卢森堡(Luxembourg Post)', 'luxembourg', '国际邮政');
INSERT INTO `t_delivery` VALUES (766, '路尊物流', 'luzun', '国内运输商');
INSERT INTO `t_delivery` VALUES (767, '马来西亚大包、EMS（Malaysia Post(parcel,EMS)）', 'malaysiaems', '国际邮政');
INSERT INTO `t_delivery` VALUES (768, '马耳他（Malta Post）', 'malta', '国际邮政');
INSERT INTO `t_delivery` VALUES (769, '美邦国际快递', 'meibang', '国际运输商');
INSERT INTO `t_delivery` VALUES (770, '美达快递', 'meidaexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (771, '墨西哥（Correos de Mexico）', 'mexico', '国际邮政');
INSERT INTO `t_delivery` VALUES (772, 'Mexico Senda Express', 'mexicodenda', '国际运输商');
INSERT INTO `t_delivery` VALUES (773, '荷兰速递(Nederland Post)', 'nederlandpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (774, 'OC-Post', 'ocpost', '国际运输商');
INSERT INTO `t_delivery` VALUES (775, '波音速递', 'overseaex', '国内运输商');
INSERT INTO `t_delivery` VALUES (776, '全球速递', 'pdstow', '国际运输商');
INSERT INTO `t_delivery` VALUES (777, '坦桑尼亚（Tanzania Posts Corporation）', 'posta', '国际邮政');
INSERT INTO `t_delivery` VALUES (778, 'PostNord Logistics', 'postnord', '国际运输商');
INSERT INTO `t_delivery` VALUES (779, '千里速递', 'qianli', '国内运输商');
INSERT INTO `t_delivery` VALUES (780, '卡塔尔（Qatar Post）', 'qpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (781, '全川摩运', 'quanchuan56', '国内运输商');
INSERT INTO `t_delivery` VALUES (782, '全速通', 'quansutong', '国内运输商');
INSERT INTO `t_delivery` VALUES (783, '全之鑫物流', 'qzx56', '国内运输商');
INSERT INTO `t_delivery` VALUES (784, '睿和泰速运', 'rhtexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (785, '日日通国际', 'rrthk', '国际运输商');
INSERT INTO `t_delivery` VALUES (786, 'S2C', 's2c', '国际运输商');
INSERT INTO `t_delivery` VALUES (787, '赛澳递', 'saiaodi', '国际运输商');
INSERT INTO `t_delivery` VALUES (788, '三盛快递', 'sanshengco', '国内运输商');
INSERT INTO `t_delivery` VALUES (789, 'Selektvracht', 'selektvracht', '国际运输商');
INSERT INTO `t_delivery` VALUES (790, '尚橙物流', 'shangcheng', '国内运输商');
INSERT INTO `t_delivery` VALUES (791, '上海无疆for买卖宝', 'shanghaiwujiangmmb', '国际运输商');
INSERT INTO `t_delivery` VALUES (792, '商海德物流', 'shd56', '国内运输商');
INSERT INTO `t_delivery` VALUES (793, '盛通快递', 'shengtongscm', '国内运输商');
INSERT INTO `t_delivery` VALUES (794, '神马快递', 'shenma', '国内运输商');
INSERT INTO `t_delivery` VALUES (795, '实利配送', 'shiligyl', '国内运输商');
INSERT INTO `t_delivery` VALUES (796, '阳光快递', 'shiningexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (797, '林道国际快递', 'shlindao', '国际运输商');
INSERT INTO `t_delivery` VALUES (798, '顺士达速运', 'shunshid', '国内运输商');
INSERT INTO `t_delivery` VALUES (799, '四海捷运', 'sihiexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (800, 'skynetworldwide', 'skynetworldwide', '国际运输商');
INSERT INTO `t_delivery` VALUES (801, '斯洛伐克(Slovenská Posta)', 'slovak', '国际邮政');
INSERT INTO `t_delivery` VALUES (802, '斯里兰卡(Sri Lanka Post)', 'slpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (803, '南非（South African Post Office）', 'southafrican', '国际邮政');
INSERT INTO `t_delivery` VALUES (804, '首通快运', 'staky', '国内运输商');
INSERT INTO `t_delivery` VALUES (805, '瑞士(Swiss Post)', 'swisspost', '国际邮政');
INSERT INTO `t_delivery` VALUES (806, '天翔快递', 'tianxiang', '国内运输商');
INSERT INTO `t_delivery` VALUES (807, '老扬州物流', 'tjlyz56', '国内运输商');
INSERT INTO `t_delivery` VALUES (808, 'TNY物流', 'tny', '国际运输商');
INSERT INTO `t_delivery` VALUES (809, 'Toll Priority(Toll Online)', 'tollpriority', '国际运输商');
INSERT INTO `t_delivery` VALUES (810, '天天欧洲物流', 'ttkeurope', '国际运输商');
INSERT INTO `t_delivery` VALUES (811, '天翼物流', 'tywl99', '国内运输商');
INSERT INTO `t_delivery` VALUES (812, '优联吉运', 'uluckex', '国内运输商');
INSERT INTO `t_delivery` VALUES (813, 'UPS Freight', 'upsfreight', '国际运输商');
INSERT INTO `t_delivery` VALUES (814, '速翼快递', 'usasueexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (815, 'USPSCN', 'uspscn', '国际运输商');
INSERT INTO `t_delivery` VALUES (816, '万庚国际速递', 'vangenexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (817, '维普恩物流', 'vps', '国内运输商');
INSERT INTO `t_delivery` VALUES (818, '渥途国际速运', 'wotu', '国际运输商');
INSERT INTO `t_delivery` VALUES (819, '万运国际快递', 'wygj168', '国际运输商');
INSERT INTO `t_delivery` VALUES (820, '国晶物流', 'xdshipping', '国内运输商');
INSERT INTO `t_delivery` VALUES (821, '蓝天物流', 'xflt56', '国内运输商');
INSERT INTO `t_delivery` VALUES (822, '祥龙运通物流', 'xianglongyuntong', '国内运输商');
INSERT INTO `t_delivery` VALUES (823, '新元快递', 'xingyuankuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (824, '西邮寄', 'xipost', '国际运输商');
INSERT INTO `t_delivery` VALUES (825, '鑫世锐达', 'xsrd', '国内运输商');
INSERT INTO `t_delivery` VALUES (826, '鑫远东速运', 'xyd666', '国内运输商');
INSERT INTO `t_delivery` VALUES (827, '也门(Yemen Post)', 'yemen', '国际邮政');
INSERT INTO `t_delivery` VALUES (828, '易通达', 'yitongda', '国内运输商');
INSERT INTO `t_delivery` VALUES (829, '元智捷诚', 'yuanzhijiecheng', '国内运输商');
INSERT INTO `t_delivery` VALUES (830, '中安物流', 'zhonganhuoyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (831, '准实快运', 'zsky123', '国内运输商');
INSERT INTO `t_delivery` VALUES (832, '泰捷达国际物流', 'ztjieda', '国际运输商');
INSERT INTO `t_delivery` VALUES (833, 'ABS courier & freight system', 'abs', '国际运输商');
INSERT INTO `t_delivery` VALUES (834, 'ABX Express', 'abxexpress_my', '国际运输商');
INSERT INTO `t_delivery` VALUES (835, 'aCommerce', 'acommerce', '国际运输商');
INSERT INTO `t_delivery` VALUES (836, 'ACS Courier', 'acscourier', '国际运输商');
INSERT INTO `t_delivery` VALUES (837, '安达易国际速递', 'adiexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (838, 'ADSone', 'adsone', '国际运输商');
INSERT INTO `t_delivery` VALUES (839, 'Agility Logistics', 'agility', '国际运输商');
INSERT INTO `t_delivery` VALUES (840, '卡邦配送', 'ahkbps', '国内运输商');
INSERT INTO `t_delivery` VALUES (841, '奥兰群岛', 'aland', '国际邮政');
INSERT INTO `t_delivery` VALUES (842, 'AlfaTrex', 'alfatrex', '国际运输商');
INSERT INTO `t_delivery` VALUES (843, 'Algeria', 'algeria', '国际邮政');
INSERT INTO `t_delivery` VALUES (844, 'ALLIED', 'alliedexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (845, 'Swiship UK', 'amazon_fba_swiship', '国际运输商');
INSERT INTO `t_delivery` VALUES (846, 'Anjun Logistics', 'anjun_logistics', '国际运输商');
INSERT INTO `t_delivery` VALUES (847, '新干线快递', 'anlexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (848, 'Anteraja', 'anteraja', '国际运输商');
INSERT INTO `t_delivery` VALUES (849, 'APC Postal Logistics', 'apc', '国际运输商');
INSERT INTO `t_delivery` VALUES (850, 'apgecommerce', 'apgecommerce', '国内运输商');
INSERT INTO `t_delivery` VALUES (851, '美国汉邦快递', 'aplus100', '国际运输商');
INSERT INTO `t_delivery` VALUES (852, 'ARC', 'arc', '国际运输商');
INSERT INTO `t_delivery` VALUES (853, '艾瑞斯远', 'ariesfar', '国内运输商');
INSERT INTO `t_delivery` VALUES (854, 'Asendia HK', 'asendiahk', '国际运输商');
INSERT INTO `t_delivery` VALUES (855, '澳达国际物流', 'auadexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (856, 'Austa国际速递', 'austa', '国际运输商');
INSERT INTO `t_delivery` VALUES (857, 'AUV国际快递', 'auvexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (858, '澳新物流', 'axexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (859, '阿塞拜疆EMS(EMS AzerExpressPost)', 'azerbaijan', '国际邮政');
INSERT INTO `t_delivery` VALUES (860, '孟加拉国(EMS)', 'bangladesh', '国际邮政');
INSERT INTO `t_delivery` VALUES (861, '宝通快递', 'baotongkd', '国内运输商');
INSERT INTO `t_delivery` VALUES (862, '报通快递', 'baoxianda', '国内运输商');
INSERT INTO `t_delivery` VALUES (863, '巴巴多斯(Barbados Post)', 'barbados', '国际邮政');
INSERT INTO `t_delivery` VALUES (864, 'BCWELT', 'bcwelt', '国际运输商');
INSERT INTO `t_delivery` VALUES (865, 'BDC快递', 'bdcgcc', '国际运输商');
INSERT INTO `t_delivery` VALUES (866, 'BEE express', 'beeexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (867, '伯利兹(Belize Postal)', 'belize', '国际邮政');
INSERT INTO `t_delivery` VALUES (868, '贝宁', 'benin', '国际邮政');
INSERT INTO `t_delivery` VALUES (869, '笨鸟国际', 'benniao', '国际运输商');
INSERT INTO `t_delivery` VALUES (870, '東邮寄', 'betterlife', '国际运输商');
INSERT INTO `t_delivery` VALUES (871, '不丹邮政 Bhutan Post', 'bhutan', '国际邮政');
INSERT INTO `t_delivery` VALUES (872, '远通盛源', 'bjytsywl', '国内运输商');
INSERT INTO `t_delivery` VALUES (873, '佰乐捷通', 'bljt56', '国内运输商');
INSERT INTO `t_delivery` VALUES (874, '标杆物流', 'bmlchina', '国内运输商');
INSERT INTO `t_delivery` VALUES (875, '波黑(JP BH Posta)', 'bohei', '国际邮政');
INSERT INTO `t_delivery` VALUES (876, '玻利维亚', 'bolivia', '国际运输商');
INSERT INTO `t_delivery` VALUES (877, '堡昕德速递', 'bosind', '国内运输商');
INSERT INTO `t_delivery` VALUES (878, 'Bosta', 'bosta', '国际运输商');
INSERT INTO `t_delivery` VALUES (879, '博茨瓦纳', 'botspost', '国际邮政');
INSERT INTO `t_delivery` VALUES (880, 'BOXC', 'boxc', '国际运输商');
INSERT INTO `t_delivery` VALUES (881, '速方(Sufast)', 'bphchina', '国际运输商');
INSERT INTO `t_delivery` VALUES (882, '百千诚物流', 'bqcwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (883, 'Bridge Express ', 'bridgeexpress ', '国际运输商');
INSERT INTO `t_delivery` VALUES (884, '宏桥国际物流', 'briems', '国内运输商');
INSERT INTO `t_delivery` VALUES (885, 'BRT', 'brt', '国际运输商');
INSERT INTO `t_delivery` VALUES (886, '文莱(Brunei Postal)', 'brunei', '国际邮政');
INSERT INTO `t_delivery` VALUES (887, '保加利亚（Bulgarian Posts）', 'bulgarian', '国际邮政');
INSERT INTO `t_delivery` VALUES (888, 'Buylogic', 'buylogic', '国际运输商');
INSERT INTO `t_delivery` VALUES (889, '展勤快递', 'byht', '国内运输商');
INSERT INTO `t_delivery` VALUES (890, '新喀里多尼亚[法国](New Caledonia)', 'caledonia', '国际运输商');
INSERT INTO `t_delivery` VALUES (891, '柬埔寨(Cambodia Post)', 'cambodia', '国际邮政');
INSERT INTO `t_delivery` VALUES (892, '到了港', 'camekong', '国际运输商');
INSERT INTO `t_delivery` VALUES (893, '喀麦隆(CAMPOST)', 'cameroon', '国际邮政');
INSERT INTO `t_delivery` VALUES (894, 'Campbell’s Express', 'campbellsexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (895, 'CBL Logistics', 'cbl_logistica', '国际运输商');
INSERT INTO `t_delivery` VALUES (896, '广州信邦', 'cbllogistics', '国内运输商');
INSERT INTO `t_delivery` VALUES (897, '钏博物流', 'cbo56', '国内运输商');
INSERT INTO `t_delivery` VALUES (898, 'CEVA Logistics', 'ceva', '国际运输商');
INSERT INTO `t_delivery` VALUES (899, 'CEVA Logistic', 'cevalogistics', '国际运输商');
INSERT INTO `t_delivery` VALUES (900, '城铁速递', 'cex', '国内运输商');
INSERT INTO `t_delivery` VALUES (901, '成达国际速递', 'chengda', '国际运输商');
INSERT INTO `t_delivery` VALUES (902, '城宁供应链', 'chengning', '国内运输商');
INSERT INTO `t_delivery` VALUES (903, '城通物流', 'chengtong', '国内运输商');
INSERT INTO `t_delivery` VALUES (904, '智利(Correos Chile)', 'chile', '国际邮政');
INSERT INTO `t_delivery` VALUES (905, '中邮电商', 'chinapostcb', '国内运输商');
INSERT INTO `t_delivery` VALUES (906, '荣通国际', 'chinaqingguan', '国内运输商');
INSERT INTO `t_delivery` VALUES (907, '同舟行物流', 'chinatzx', '国内运输商');
INSERT INTO `t_delivery` VALUES (908, '嘉荣物流', 'chllog', '国内运输商');
INSERT INTO `t_delivery` VALUES (909, '中国香港骏辉物流', 'chunfai', '国际运输商');
INSERT INTO `t_delivery` VALUES (910, '城市映急', 'city56', '国内运输商');
INSERT INTO `t_delivery` VALUES (911, 'citysprint', 'citysprint', '国际运输商');
INSERT INTO `t_delivery` VALUES (912, 'CE易欧通国际速递', 'cloudexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (913, '群航国际物流', 'cloudlogistics365', '国际运输商');
INSERT INTO `t_delivery` VALUES (914, '中国翼', 'cnws', '国际运输商');
INSERT INTO `t_delivery` VALUES (915, 'Collect+', 'collectplus', '国际运输商');
INSERT INTO `t_delivery` VALUES (916, '邦通国际', 'comexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (917, 'Corporate couriers logistics', 'corporatecouriers', '国际运输商');
INSERT INTO `t_delivery` VALUES (918, '莫桑比克（Correios de Moçambique）', 'correios', '国际运输商');
INSERT INTO `t_delivery` VALUES (919, '乌拉圭（Correo Uruguayo）', 'correo', '国际运输商');
INSERT INTO `t_delivery` VALUES (920, '阿根廷(Correo Argentina)', 'correoargentino', '国际运输商');
INSERT INTO `t_delivery` VALUES (921, 'Correos Express', 'correosexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (922, 'CourierPost', 'courierpost', '国际运输商');
INSERT INTO `t_delivery` VALUES (923, 'Couriers Please', 'couriersplease', '国际运输商');
INSERT INTO `t_delivery` VALUES (924, '新时速物流', 'csxss', '国内运输商');
INSERT INTO `t_delivery` VALUES (925, '塞浦路斯(Cyprus Post)', 'cypruspost', '国际邮政');
INSERT INTO `t_delivery` VALUES (926, 'DACHSER', 'dachser', '国际运输商');
INSERT INTO `t_delivery` VALUES (927, '达速物流', 'dasu', '国内运输商');
INSERT INTO `t_delivery` VALUES (928, '叮当同城', 'ddotbase', '国内运输商');
INSERT INTO `t_delivery` VALUES (929, 'Delivery Station', 'deliverystations', '国际运输商');
INSERT INTO `t_delivery` VALUES (930, 'Deltec Courier', 'deltec', '国际运输商');
INSERT INTO `t_delivery` VALUES (931, 'Deploy', 'deployeg', '国际运输商');
INSERT INTO `t_delivery` VALUES (932, '澳行快递', 'desworks', '国际运输商');
INSERT INTO `t_delivery` VALUES (933, '东风全球速递', 'dfglobalex', '国内运输商');
INSERT INTO `t_delivery` VALUES (934, '达方物流', 'dfpost', '国内运输商');
INSERT INTO `t_delivery` VALUES (935, 'dhluk', 'dhluk', '国内运输商');
INSERT INTO `t_delivery` VALUES (936, '云南滇驿物流', 'dianyi', '国内运输商');
INSERT INTO `t_delivery` VALUES (937, '叮咚澳洲转运', 'dindon', '国际运输商');
INSERT INTO `t_delivery` VALUES (938, 'Direct Link', 'directlink', '国际邮政');
INSERT INTO `t_delivery` VALUES (939, '吉布提', 'djibouti', '国际邮政');
INSERT INTO `t_delivery` VALUES (940, '天翔东捷运', 'djy56', '国内运输商');
INSERT INTO `t_delivery` VALUES (941, '东瀚物流', 'donghanwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (942, '东红物流', 'donghong', '国内运输商');
INSERT INTO `t_delivery` VALUES (943, 'Dotzot', 'dotzot', '国内运输商');
INSERT INTO `t_delivery` VALUES (944, 'DPD Ireland', 'dpd_ireland', '国际运输商');
INSERT INTO `t_delivery` VALUES (945, 'DPE Express', 'dpe_express', '国际运输商');
INSERT INTO `t_delivery` VALUES (946, 'dreevo', 'dreevo', '国际运输商');
INSERT INTO `t_delivery` VALUES (947, '老司机国际快递', 'driverfastgo', '国际运输商');
INSERT INTO `t_delivery` VALUES (948, 'DSV', 'dsv', '国际运输商');
INSERT INTO `t_delivery` VALUES (949, '德淘邦', 'dt8ang', '国内运输商');
INSERT INTO `t_delivery` VALUES (950, 'DTD', 'dtd', '国际运输商');
INSERT INTO `t_delivery` VALUES (951, '多道供应链', 'duodao56', '国内运输商');
INSERT INTO `t_delivery` VALUES (952, '东方航空物流', 'ealceair', '国际运输商');
INSERT INTO `t_delivery` VALUES (953, 'EC-Firstclass', 'ecfirstclass', '国际运输商');
INSERT INTO `t_delivery` VALUES (954, 'Echo', 'echo', '国际运输商');
INSERT INTO `t_delivery` VALUES (955, '东西E全运', 'ecotransite', '国际运输商');
INSERT INTO `t_delivery` VALUES (956, '厄瓜多尔(Correos del Ecuador)', 'ecuador', '国际邮政');
INSERT INTO `t_delivery` VALUES (957, '易达快运', 'edaeuexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (958, 'EGY Express Logistics', 'egyexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (959, '埃及（Egypt Post）', 'egypt', '国际邮政');
INSERT INTO `t_delivery` VALUES (960, 'Egypt Express', 'egyptexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (961, 'Ekart', 'ekart', '国际运输商');
INSERT INTO `t_delivery` VALUES (962, '易联通达', 'el56', '国内运输商');
INSERT INTO `t_delivery` VALUES (963, '波兰小包(Poczta Polska)', 'emonitoringen', '国内运输商');
INSERT INTO `t_delivery` VALUES (964, '高考通知书', 'emsluqu', '国内运输商');
INSERT INTO `t_delivery` VALUES (965, '乌克兰EMS(EMS Ukraine)', 'emsukraine', '国际邮政');
INSERT INTO `t_delivery` VALUES (966, '乌克兰EMS-中文(EMS Ukraine)', 'emsukrainecn', '国际邮政');
INSERT INTO `t_delivery` VALUES (967, '联众国际', 'epspost', '国际运输商');
INSERT INTO `t_delivery` VALUES (968, 'Equick China', 'equick_cn', '国际运输商');
INSERT INTO `t_delivery` VALUES (969, '厄立特里亚', 'eripostal', '国际邮政');
INSERT INTO `t_delivery` VALUES (970, '俄顺达', 'eshunda', '国内运输商');
INSERT INTO `t_delivery` VALUES (971, '东方汇', 'est365', '国内运输商');
INSERT INTO `t_delivery` VALUES (972, 'Estafeta', 'estafeta', '国际运输商');
INSERT INTO `t_delivery` VALUES (973, 'Estes', 'estes', '国际运输商');
INSERT INTO `t_delivery` VALUES (974, '埃塞俄比亚(Ethiopian postal)', 'ethiopia', '国际邮政');
INSERT INTO `t_delivery` VALUES (975, '埃塞俄比亚(Ethiopian Post)', 'ethiopian', '国际邮政');
INSERT INTO `t_delivery` VALUES (976, '中欧国际物流', 'eucnrail', '国际运输商');
INSERT INTO `t_delivery` VALUES (977, '德国 EUC POST', 'eucpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (978, '易邮国际', 'euguoji', '国际运输商');
INSERT INTO `t_delivery` VALUES (979, '易优包裹', 'eupackage', '国内运输商');
INSERT INTO `t_delivery` VALUES (980, '败欧洲', 'europe8', '国际运输商');
INSERT INTO `t_delivery` VALUES (981, 'europeanecom', 'europeanecom', '国际运输商');
INSERT INTO `t_delivery` VALUES (982, '优莎速运', 'eusacn', '国内运输商');
INSERT INTO `t_delivery` VALUES (983, '可可树美中速运', 'excocotree', '国内运输商');
INSERT INTO `t_delivery` VALUES (984, 'Expeditors', 'expeditors', '国际运输商');
INSERT INTO `t_delivery` VALUES (985, '探路速运', 'explorer56', '国内运输商');
INSERT INTO `t_delivery` VALUES (986, '澳洲新干线快递', 'expressplus', '国际运输商');
INSERT INTO `t_delivery` VALUES (987, '易转运', 'ezhuanyuan', '国际运输商');
INSERT INTO `t_delivery` VALUES (988, '颿达国际快递-英文', 'fandaguoji', '国际运输商');
INSERT INTO `t_delivery` VALUES (989, 'Fastway New Zealand', 'fastway_nz', '国际运输商');
INSERT INTO `t_delivery` VALUES (990, 'Fastway South Africa', 'fastway_za', '国际运输商');
INSERT INTO `t_delivery` VALUES (991, '正途供应链', 'fastzt', '国内运输商');
INSERT INTO `t_delivery` VALUES (992, 'FDS', 'fds', '国际运输商');
INSERT INTO `t_delivery` VALUES (993, 'FedEx-英国件（FedEx UK)', 'fedexuk', '国际运输商');
INSERT INTO `t_delivery` VALUES (994, 'FedEx-英国件', 'fedexukcn', '国际运输商');
INSERT INTO `t_delivery` VALUES (995, '奉天物流', 'fengtianexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (996, '丰羿', 'fengyee', '国内运输商');
INSERT INTO `t_delivery` VALUES (997, '斐济(Fiji Post)', 'fiji', '国际邮政');
INSERT INTO `t_delivery` VALUES (998, 'First Flight', 'firstflight', '国际运输商');
INSERT INTO `t_delivery` VALUES (999, 'First Logistics', 'firstlogistics', '国际运输商');
INSERT INTO `t_delivery` VALUES (1000, 'Flash Express', 'flashexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1001, 'Flextock', 'flextock', '国际运输商');
INSERT INTO `t_delivery` VALUES (1002, '花瓣转运', 'flowerkd', '国际运输商');
INSERT INTO `t_delivery` VALUES (1003, 'FODEL', 'fodel', '国际运输商');
INSERT INTO `t_delivery` VALUES (1004, '四方格', 'fourpxus', '国际运输商');
INSERT INTO `t_delivery` VALUES (1005, '全速快递', 'fsexp', '国内运输商');
INSERT INTO `t_delivery` VALUES (1006, '飞云快递系统', 'fyex', '国内运输商');
INSERT INTO `t_delivery` VALUES (1007, '高铁快运', 'gaotieex', '国内运输商');
INSERT INTO `t_delivery` VALUES (1008, 'Gati-中文', 'gaticn', '国际运输商');
INSERT INTO `t_delivery` VALUES (1009, 'GDEX', 'gdex', '国际运输商');
INSERT INTO `t_delivery` VALUES (1010, '全网物流', 'gdqwwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (1011, '新鹏快递', 'gdxp', '国内运输商');
INSERT INTO `t_delivery` VALUES (1012, '格鲁吉亚(Georgian Pos）', 'georgianpost', '国际运输商');
INSERT INTO `t_delivery` VALUES (1013, 'G EXpress', 'gexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1014, '加纳', 'ghanapost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1015, 'GIZTIX', 'giztix', '国际运输商');
INSERT INTO `t_delivery` VALUES (1016, 'GLS Italy', 'gls_italy', '国际运输商');
INSERT INTO `t_delivery` VALUES (1017, '英脉物流', 'gml', '国内运输商');
INSERT INTO `t_delivery` VALUES (1018, 'GOGOX', 'gogox', '国际运输商');
INSERT INTO `t_delivery` VALUES (1019, 'gojavas', 'gojavas', '国际运输商');
INSERT INTO `t_delivery` VALUES (1020, 'Grab', 'grab', '国际运输商');
INSERT INTO `t_delivery` VALUES (1021, '格陵兰[丹麦]（TELE Greenland A/S）', 'greenland', '国际运输商');
INSERT INTO `t_delivery` VALUES (1022, '哥士传奇速递', 'gscq365', '国内运输商');
INSERT INTO `t_delivery` VALUES (1023, '德尚国际速递', 'gslexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1024, 'GT国际快运', 'gtgogo', '国际运输商');
INSERT INTO `t_delivery` VALUES (1025, 'GTT EXPRESS快递', 'gttexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1026, '永邦快递', 'guangdongyongbang', '国内运输商');
INSERT INTO `t_delivery` VALUES (1027, '冠庭国际物流', 'guanting', '国际运输商');
INSERT INTO `t_delivery` VALUES (1028, '天天快物流', 'guoeryue', '国内运输商');
INSERT INTO `t_delivery` VALUES (1029, '国顺达物流', 'guoshunda', '国内运输商');
INSERT INTO `t_delivery` VALUES (1030, '国送快运', 'guosong', '国内运输商');
INSERT INTO `t_delivery` VALUES (1031, '圭亚那', 'guyana', '国际邮政');
INSERT INTO `t_delivery` VALUES (1032, '宏观国际快递', 'gvpexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1033, '贵州星程快递', 'gzxingcheng', '国内运输商');
INSERT INTO `t_delivery` VALUES (1034, '货六六', 'h66', '国内运输商');
INSERT INTO `t_delivery` VALUES (1035, '海红for买卖宝', 'haihongmmb', '国际运输商');
INSERT INTO `t_delivery` VALUES (1036, '海盟速递', 'haimengsudi', '国内运输商');
INSERT INTO `t_delivery` VALUES (1037, '翰丰快递', 'hanfengjl', '国内运输商');
INSERT INTO `t_delivery` VALUES (1038, '汉信快递', 'hanxin', '国内运输商');
INSERT INTO `t_delivery` VALUES (1039, '豪翔物流', 'haoxiangwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (1040, '黑豹物流', 'heibaowuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (1041, '恒瑞物流', 'hengrui56', '国内运输商');
INSERT INTO `t_delivery` VALUES (1042, 'Hermes Germany', 'hermes_de', '国际运输商');
INSERT INTO `t_delivery` VALUES (1043, 'Hermesworld', 'hermesworld', '国际运输商');
INSERT INTO `t_delivery` VALUES (1044, '合心速递', 'hexinexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1045, '环国运物流', 'hgy56', '国内运输商');
INSERT INTO `t_delivery` VALUES (1046, '华瀚快递', 'hhair56', '国内运输商');
INSERT INTO `t_delivery` VALUES (1047, 'Highway', 'highway', '国际运输商');
INSERT INTO `t_delivery` VALUES (1048, '猴急送', 'hjs', '国内运输商');
INSERT INTO `t_delivery` VALUES (1049, '飞豹速递', 'hkeex', '国内运输商');
INSERT INTO `t_delivery` VALUES (1050, '共联配', 'hlpgyl', '国内运输商');
INSERT INTO `t_delivery` VALUES (1051, '中强物流', 'hnzqwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (1052, 'Holisol', 'holisollogistics', '国际运输商');
INSERT INTO `t_delivery` VALUES (1053, '居家通', 'homexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1054, '洪都拉斯', 'honduras', '国际邮政');
INSERT INTO `t_delivery` VALUES (1055, '红背心', 'hongbeixin', '国内运输商');
INSERT INTO `t_delivery` VALUES (1056, '皇家云仓', 'hotwms', '国内运输商');
INSERT INTO `t_delivery` VALUES (1057, '环球通达 ', 'hqtd', '国际运输商');
INSERT INTO `t_delivery` VALUES (1058, '速远同城快递', 'hrbsydrd', '国内运输商');
INSERT INTO `t_delivery` VALUES (1059, '卓烨快递', 'hrbzykd', '国内运输商');
INSERT INTO `t_delivery` VALUES (1060, '克罗地亚（Hrvatska Posta）', 'hrvatska', '国际邮政');
INSERT INTO `t_delivery` VALUES (1061, '寰世达国际物流', 'hsdexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1062, '华通快运', 'htongexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1063, '华通务达物流', 'htwd', '国内运输商');
INSERT INTO `t_delivery` VALUES (1064, '华达快运', 'huada', '国内运输商');
INSERT INTO `t_delivery` VALUES (1065, '环东物流', 'huandonglg', '国内运输商');
INSERT INTO `t_delivery` VALUES (1066, '华夏货运', 'huaxiahuoyun', '国内运输商');
INSERT INTO `t_delivery` VALUES (1067, '汇霖大货网', 'huilin56', '国内运输商');
INSERT INTO `t_delivery` VALUES (1068, '匈牙利（Magyar Posta）', 'hungary', '国际邮政');
INSERT INTO `t_delivery` VALUES (1069, 'hunter Express', 'hunterexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1070, '兰州伙伴物流', 'huoban', '国内运输商');
INSERT INTO `t_delivery` VALUES (1071, '中电华远物流', 'hywuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (1072, '恒宇运通', 'hyytes', '国内运输商');
INSERT INTO `t_delivery` VALUES (1073, '华航快递', 'hzpl', '国内运输商');
INSERT INTO `t_delivery` VALUES (1074, 'IB Courier', 'ibcourier', '国际运输商');
INSERT INTO `t_delivery` VALUES (1075, '爱拜物流', 'ibuy8', '国际运输商');
INSERT INTO `t_delivery` VALUES (1076, '大马鹿', 'idamalu', '国内运输商');
INSERT INTO `t_delivery` VALUES (1077, 'ID Express', 'idexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1078, '泛太优达', 'iex', '国内运输商');
INSERT INTO `t_delivery` VALUES (1079, 'iExpress', 'iexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1080, 'logen路坚', 'ilogen', '国际运输商');
INSERT INTO `t_delivery` VALUES (1081, 'ILYANG', 'ilyang', '国际运输商');
INSERT INTO `t_delivery` VALUES (1082, 'iMile', 'imile', '国际运输商');
INSERT INTO `t_delivery` VALUES (1083, 'INDOPAKET', 'indopaket', '国际运输商');
INSERT INTO `t_delivery` VALUES (1084, '多米尼加（INPOSDOM – Instituto Postal Dominicano）', 'inposdom', '国际邮政');
INSERT INTO `t_delivery` VALUES (1085, 'InPost Paczkomaty', 'inpost_paczkomaty', '国际运输商');
INSERT INTO `t_delivery` VALUES (1086, '捷运达快递', 'interjz', '国内运输商');
INSERT INTO `t_delivery` VALUES (1087, 'Interlink Express', 'interlink', '国际运输商');
INSERT INTO `t_delivery` VALUES (1088, 'Interparcel', 'interparcel', '国际运输商');
INSERT INTO `t_delivery` VALUES (1089, 'UPS i-parcel', 'iparcel', '国际运输商');
INSERT INTO `t_delivery` VALUES (1090, '伊朗（Iran Post）', 'iran', '国际邮政');
INSERT INTO `t_delivery` VALUES (1091, '以色列(Israel Post)', 'israelpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1092, 'Italy SDA', 'italysad', '国际运输商');
INSERT INTO `t_delivery` VALUES (1093, 'IXPRESS', 'ixpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1094, 'janio', 'janio', '国际运输商');
INSERT INTO `t_delivery` VALUES (1095, '骏达快递', 'jdexpressusa', '国内运输商');
INSERT INTO `t_delivery` VALUES (1096, '泽西岛', 'jerseypost', '国际运输商');
INSERT INTO `t_delivery` VALUES (1097, 'Jet Express', 'jetexpresseg', '国际运输商');
INSERT INTO `t_delivery` VALUES (1098, '澳速通国际速递', 'jetexpressgroup', '国际运输商');
INSERT INTO `t_delivery` VALUES (1099, 'J&T Express', 'jetexpresszh', '国际运输商');
INSERT INTO `t_delivery` VALUES (1100, '捷仕', 'jetstarexp', '国内运输商');
INSERT INTO `t_delivery` VALUES (1101, '加佳物流', 'jiajiawl', '国内运输商');
INSERT INTO `t_delivery` VALUES (1102, '捷邦物流', 'jieborne', '国内运输商');
INSERT INTO `t_delivery` VALUES (1103, '近端', 'jinduan', '国内运输商');
INSERT INTO `t_delivery` VALUES (1104, '劲通快递', 'jintongkd', '国内运输商');
INSERT INTO `t_delivery` VALUES (1105, '冀速物流', 'jisu', '国内运输商');
INSERT INTO `t_delivery` VALUES (1106, '久易快递', 'jiuyicn', '国内运输商');
INSERT INTO `t_delivery` VALUES (1107, '吉祥邮（澳洲）', 'jixiangyouau', '国际运输商');
INSERT INTO `t_delivery` VALUES (1108, 'JNE', 'jne', '国际运输商');
INSERT INTO `t_delivery` VALUES (1109, '约旦(Jordan Post)', 'jordan', '国际邮政');
INSERT INTO `t_delivery` VALUES (1110, '骏绅物流', 'jsexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1111, '极兔快递埃及站', 'jtexpresseg', '国际运输商');
INSERT INTO `t_delivery` VALUES (1112, 'J&T Express 马来西亚', 'jtexpressmy', '国际运输商');
INSERT INTO `t_delivery` VALUES (1113, 'Jumia', 'jumia', '国际运输商');
INSERT INTO `t_delivery` VALUES (1114, '聚物物流', 'juwu', '国内运输商');
INSERT INTO `t_delivery` VALUES (1115, '集先锋快递', 'jxfex', '国内运输商');
INSERT INTO `t_delivery` VALUES (1116, 'Kaha Epress', 'kahaexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1117, 'Kangaroo Express', 'kangaroo', '国际运输商');
INSERT INTO `t_delivery` VALUES (1118, '肯尼亚(POSTA KENYA)', 'kenya', '国际邮政');
INSERT INTO `t_delivery` VALUES (1119, 'Kerry Express-泰国', 'kerrythailand', '国际运输商');
INSERT INTO `t_delivery` VALUES (1120, '嘉里大荣物流', 'kerrytj', '国内运输商');
INSERT INTO `t_delivery` VALUES (1121, '启邦国际物流', 'keypon', '国际运输商');
INSERT INTO `t_delivery` VALUES (1122, '货运皇', 'kingfreight', '国际运输商');
INSERT INTO `t_delivery` VALUES (1123, '跨境直邮通', 'kjde', '国际运输商');
INSERT INTO `t_delivery` VALUES (1124, 'Kuehne + Nagel', 'kn', '国际运输商');
INSERT INTO `t_delivery` VALUES (1125, '考拉速递', 'koalaexp', '国内运输商');
INSERT INTO `t_delivery` VALUES (1126, '快淘快递', 'kuaitao', '国内运输商');
INSERT INTO `t_delivery` VALUES (1127, '四川快优达速递', 'kuaiyouda', '国内运输商');
INSERT INTO `t_delivery` VALUES (1128, 'Kuehne+Nagel', 'kuehnenagel', '国际运输商');
INSERT INTO `t_delivery` VALUES (1129, 'KURASI', 'kurasi', '国际运输商');
INSERT INTO `t_delivery` VALUES (1130, '凯信达', 'kxda', '国内运输商');
INSERT INTO `t_delivery` VALUES (1131, '跨跃国际', 'kyue', '国际运输商');
INSERT INTO `t_delivery` VALUES (1132, 'Landmark Global', 'landmarkglobal', '国际运输商');
INSERT INTO `t_delivery` VALUES (1133, '蓝弧快递', 'lanhukuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (1134, '林安物流', 'lasy56', '国内运输商');
INSERT INTO `t_delivery` VALUES (1135, '拉脱维亚(Latvijas Pasts)', 'latvia', '国际运输商');
INSERT INTO `t_delivery` VALUES (1136, '拉脱维亚(Latvijas Pasts)', 'latviaen', '国际邮政');
INSERT INTO `t_delivery` VALUES (1137, '立白宝凯物流', 'lbbk', '国内运输商');
INSERT INTO `t_delivery` VALUES (1138, '两点之间', 'ldzy168', '国内运输商');
INSERT INTO `t_delivery` VALUES (1139, '乐达全球速递', 'ledaexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1140, '楽道物流', 'ledaowuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (1141, '云豹国际货运', 'leopard', '国际运输商');
INSERT INTO `t_delivery` VALUES (1142, '美联快递', 'letseml', '国内运输商');
INSERT INTO `t_delivery` VALUES (1143, 'Laxship', 'lexship', '国际运输商');
INSERT INTO `t_delivery` VALUES (1144, 'Lion Parcel', 'lionparcel', '国际运输商');
INSERT INTO `t_delivery` VALUES (1145, '丽狮物流', 'lishi', '国内运输商');
INSERT INTO `t_delivery` VALUES (1146, '立陶宛（Lietuvos pa?tas）', 'lithuania', '国际运输商');
INSERT INTO `t_delivery` VALUES (1147, '小熊物流', 'littlebearbear', '国内运输商');
INSERT INTO `t_delivery` VALUES (1148, '润禾物流', 'liujiashen', '国内运输商');
INSERT INTO `t_delivery` VALUES (1149, '良藤国际速递', 'lmfex', '国际运输商');
INSERT INTO `t_delivery` VALUES (1150, 'Loadbugs', 'loadbugs', '国际运输商');
INSERT INTO `t_delivery` VALUES (1151, '華信物流WTO', 'logistics', '国际运输商');
INSERT INTO `t_delivery` VALUES (1152, '隆浪快递', 'longlangkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (1153, 'Loomis Express', 'loomisexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1154, '恒通快递', 'lqht', '国内运输商');
INSERT INTO `t_delivery` VALUES (1155, '乐天速递', 'ltexp', '国内运输商');
INSERT INTO `t_delivery` VALUES (1156, '路邦物流', 'lubang56', '国内运输商');
INSERT INTO `t_delivery` VALUES (1157, '吉捷国际速递', 'luckyfastex', '国际运输商');
INSERT INTO `t_delivery` VALUES (1158, '论道国际物流', 'lundao', '国际运输商');
INSERT INTO `t_delivery` VALUES (1159, '卢森堡(Luxembourg Post)', 'luxembourgde', '国际运输商');
INSERT INTO `t_delivery` VALUES (1160, '卢森堡(Luxembourg Post)', 'luxembourgfr', '国际运输商');
INSERT INTO `t_delivery` VALUES (1161, '路遥物流', 'luyao', '国内运输商');
INSERT INTO `t_delivery` VALUES (1162, '马其顿(Macedonian Post)', 'macedonia', '国际邮政');
INSERT INTO `t_delivery` VALUES (1163, 'Maersk', 'maersk', '国际运输商');
INSERT INTO `t_delivery` VALUES (1164, 'mailamericas', 'mailamericas', '国内运输商');
INSERT INTO `t_delivery` VALUES (1165, '麦力快递', 'mailikuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (1166, '迈隆递运', 'mailongdy', '国内运输商');
INSERT INTO `t_delivery` VALUES (1167, 'Mainfreight', 'mainfreight', '国际运输商');
INSERT INTO `t_delivery` VALUES (1168, '马尔代夫(Maldives Post)', 'maldives', '国际邮政');
INSERT INTO `t_delivery` VALUES (1169, '芒果速递', 'mangguo', '国内运输商');
INSERT INTO `t_delivery` VALUES (1170, '今枫国际快运', 'mapleexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1171, 'MAS Courier Servic', 'mascourierservice', '国际运输商');
INSERT INTO `t_delivery` VALUES (1172, 'Matkahuolto', 'matkahuolto', '国际运输商');
INSERT INTO `t_delivery` VALUES (1173, '毛里求斯(Mauritius Post)', 'mauritius', '国际邮政');
INSERT INTO `t_delivery` VALUES (1174, '澳洲迈速快递', 'maxeedexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1175, 'Middle East Courier service', 'mecs', '国际运输商');
INSERT INTO `t_delivery` VALUES (1176, 'Merage ', 'merage', '国际运输商');
INSERT INTO `t_delivery` VALUES (1177, '名航速运', 'mhsy', '国内运输商');
INSERT INTO `t_delivery` VALUES (1178, '银河物流', 'milkyway', '国内运输商');
INSERT INTO `t_delivery` VALUES (1179, '民邦速递', 'minbangsudi', '国内运输商');
INSERT INTO `t_delivery` VALUES (1180, '美龙快递', 'mjexp', '国内运输商');
INSERT INTO `t_delivery` VALUES (1181, 'Mitsui OSK Lines', 'mol', '国际运输商');
INSERT INTO `t_delivery` VALUES (1182, '摩尔多瓦(Posta Moldovei)', 'moldova', '国际邮政');
INSERT INTO `t_delivery` VALUES (1183, '蒙古国(Mongol Post) ', 'mongolpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1184, '黑山(Posta Crne Gore)', 'montenegro', '国际邮政');
INSERT INTO `t_delivery` VALUES (1185, '摩洛哥 ( Morocco Post )', 'morocco', '国际邮政');
INSERT INTO `t_delivery` VALUES (1186, 'MRW', 'mrw', '国际运输商');
INSERT INTO `t_delivery` VALUES (1187, 'Mexico Multipack', 'multipack', '国际运输商');
INSERT INTO `t_delivery` VALUES (1188, '中俄速通（淼信）', 'mxe56', '国内运输商');
INSERT INTO `t_delivery` VALUES (1189, 'mylerz', 'mylerz', '国际运输商');
INSERT INTO `t_delivery` VALUES (1190, '新亚物流', 'nalexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1191, 'NandanCourier', 'nandan', '国际运输商');
INSERT INTO `t_delivery` VALUES (1192, 'NAQEL Express', 'naqel', '国际运输商');
INSERT INTO `t_delivery` VALUES (1193, 'Nationex', 'nationex', '国际运输商');
INSERT INTO `t_delivery` VALUES (1194, '红马速递', 'nedahm', '国内运输商');
INSERT INTO `t_delivery` VALUES (1195, '尼尔快递', 'nell', '国内运输商');
INSERT INTO `t_delivery` VALUES (1196, '尼泊尔（Nepal Postal Services）', 'nepalpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1197, 'Network Courier', 'networkcourier', '国际运输商');
INSERT INTO `t_delivery` VALUES (1198, 'Newgistics', 'newgistics', '国际运输商');
INSERT INTO `t_delivery` VALUES (1199, '尼日利亚(Nigerian Postal)', 'nigerianpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1200, 'ninja xpress', 'ninjaxpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1201, 'Nippon Express', 'nipponexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1202, '牛仔速运', 'niuzaiexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1203, 'NLE', 'nle', '国际运输商');
INSERT INTO `t_delivery` VALUES (1204, '亚欧专线', 'nlebv', '国际运输商');
INSERT INTO `t_delivery` VALUES (1205, '华赫物流', 'nmhuahe', '国内运输商');
INSERT INTO `t_delivery` VALUES (1206, 'Nok Courier', 'nokcourier', '国际运输商');
INSERT INTO `t_delivery` VALUES (1207, 'Norsk Global', 'norsk_global', '国际运输商');
INSERT INTO `t_delivery` VALUES (1208, 'Nova Poshta', 'novaposhta', '国际运输商');
INSERT INTO `t_delivery` VALUES (1209, '诺尔国际物流', 'nuoer', '国际运输商');
INSERT INTO `t_delivery` VALUES (1210, 'NYK Line', 'nyk', '国际运输商');
INSERT INTO `t_delivery` VALUES (1211, 'OCA Argentina', 'ocaargen', '国际运输商');
INSERT INTO `t_delivery` VALUES (1212, '﻿OCS ANA Group', 'ocsindia', '国际运输商');
INSERT INTO `t_delivery` VALUES (1213, '阿曼(Oman Post)', 'oman', '国际邮政');
INSERT INTO `t_delivery` VALUES (1214, '无限配', 'omni2', '国内运输商');
INSERT INTO `t_delivery` VALUES (1215, 'Omni Parcel', 'omniparcel', '国际运输商');
INSERT INTO `t_delivery` VALUES (1216, '爱沙尼亚(Eesti Post)', 'omniva', '国际邮政');
INSERT INTO `t_delivery` VALUES (1217, 'One World Express', 'oneworldexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1218, '昂威物流', 'onway', '国内运输商');
INSERT INTO `t_delivery` VALUES (1219, 'OPEK', 'opek', '国际运输商');
INSERT INTO `t_delivery` VALUES (1220, 'OPEX', 'opex', '国际运输商');
INSERT INTO `t_delivery` VALUES (1221, 'Packlink', 'packlink', '国际运输商');
INSERT INTO `t_delivery` VALUES (1222, '巴基斯坦(Pakistan Post)', 'pakistan', '国际邮政');
INSERT INTO `t_delivery` VALUES (1223, '巴拿马', 'panama', '国际邮政');
INSERT INTO `t_delivery` VALUES (1224, 'Pandu Logistics', 'pandulogistics', '国内运输商');
INSERT INTO `t_delivery` VALUES (1225, '巴拉圭(Correo Paraguayo)', 'paraguay', '国际运输商');
INSERT INTO `t_delivery` VALUES (1226, 'parcel2go', 'parcel2go', '国际运输商');
INSERT INTO `t_delivery` VALUES (1227, '诚一物流', 'parcelchina', '国际运输商');
INSERT INTO `t_delivery` VALUES (1228, 'Park N Pracel', 'parknparcel', '国际运输商');
INSERT INTO `t_delivery` VALUES (1229, 'paxel', 'paxel', '国际运输商');
INSERT INTO `t_delivery` VALUES (1230, 'paxelen', 'paxelen', '国际运输商');
INSERT INTO `t_delivery` VALUES (1231, '普畅物流', 'pcwl56', '国内运输商');
INSERT INTO `t_delivery` VALUES (1232, '派尔快递', 'peex', '国内运输商');
INSERT INTO `t_delivery` VALUES (1233, '陪行物流', 'peixingwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (1234, '鹏远国际速递', 'pengyuanexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1235, 'Perfect Service', 'perfectservice', '国际运输商');
INSERT INTO `t_delivery` VALUES (1236, '秘鲁(SERPOST)', 'peru', '国际邮政');
INSERT INTO `t_delivery` VALUES (1237, 'Presto', 'pesto', '国际运输商');
INSERT INTO `t_delivery` VALUES (1238, 'Parcel Freight Logistics', 'pflogistics', '国际运输商');
INSERT INTO `t_delivery` VALUES (1239, 'pickupp', 'pickupp', '国际运输商');
INSERT INTO `t_delivery` VALUES (1240, '品速心达快递', 'pinsuxinda', '国内运输商');
INSERT INTO `t_delivery` VALUES (1241, '品信快递', 'pinxinkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (1242, '先锋国际快递', 'pioneer', '国际运输商');
INSERT INTO `t_delivery` VALUES (1243, '龙行天下', 'pmt0704be', '国内运输商');
INSERT INTO `t_delivery` VALUES (1244, '葡萄牙（Portugal CTT）', 'portugalctten', '国际运输商');
INSERT INTO `t_delivery` VALUES (1245, 'Portugal Seur', 'portugalseur', '国际运输商');
INSERT INTO `t_delivery` VALUES (1246, 'POS INDONESIA', 'posindonesia', '国际运输商');
INSERT INTO `t_delivery` VALUES (1247, 'PostElbe', 'postelbe', '国际邮政');
INSERT INTO `t_delivery` VALUES (1248, '巴布亚新几内亚(PNG Post)', 'postpng', '国际邮政');
INSERT INTO `t_delivery` VALUES (1249, 'PT Prima Multi Cipta', 'primamulticipta', '国际运输商');
INSERT INTO `t_delivery` VALUES (1250, '土耳其', 'ptt', '国际邮政');
INSERT INTO `t_delivery` VALUES (1251, '急顺通', 'pzhjst', '国内运输商');
INSERT INTO `t_delivery` VALUES (1252, 'ANTS EXPRESS', 'qdants', '国际运输商');
INSERT INTO `t_delivery` VALUES (1253, '雪域快递', 'qhxykd', '国内运输商');
INSERT INTO `t_delivery` VALUES (1254, '启辰国际速递', 'qichen', '国际运输商');
INSERT INTO `t_delivery` VALUES (1255, 'Qxpress', 'qxpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1256, 'R2S Logistics', 'r2slogistics', '国际运输商');
INSERT INTO `t_delivery` VALUES (1257, 'RAM', 'ramgroup_za', '国际运输商');
INSERT INTO `t_delivery` VALUES (1258, 'Rapido Cargo Egypt', 'rapidocargoeg', '国际运输商');
INSERT INTO `t_delivery` VALUES (1259, 'Red Express', 'redexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1260, 'Redur', 'redur', '国际运输商');
INSERT INTO `t_delivery` VALUES (1261, 'Redur Spain', 'redur_es', '国际运输商');
INSERT INTO `t_delivery` VALUES (1262, '叙利亚(Syrian Post)', 'republic', '国际邮政');
INSERT INTO `t_delivery` VALUES (1263, '日昱物流', 'riyuwuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (1264, 'RL Carriers', 'rl_carriers', '国际运输商');
INSERT INTO `t_delivery` VALUES (1265, '罗马尼亚（Posta Romanian）', 'romanian', '国际邮政');
INSERT INTO `t_delivery` VALUES (1266, '皇家国际速运', 'royal', '国内运输商');
INSERT INTO `t_delivery` VALUES (1267, 'rpx', 'rpx', '国际运输商');
INSERT INTO `t_delivery` VALUES (1268, '日日顺快线', 'rrskx', '国内运输商');
INSERT INTO `t_delivery` VALUES (1269, '瑞典（Sweden Post）', 'ruidianyouzhengen', '国际邮政');
INSERT INTO `t_delivery` VALUES (1270, '润百特货', 'runbail', '国内运输商');
INSERT INTO `t_delivery` VALUES (1271, '卢旺达(Rwanda i-posita)', 'rwanda', '国际运输商');
INSERT INTO `t_delivery` VALUES (1272, '佐川急便-英文', 'sagawaen', '国际运输商');
INSERT INTO `t_delivery` VALUES (1273, '赛澳递for买卖宝', 'saiaodimmb', '国际运输商');
INSERT INTO `t_delivery` VALUES (1274, 'Correo El Salvador', 'salvador', '国际邮政');
INSERT INTO `t_delivery` VALUES (1275, '萨摩亚(Samoa Post)', 'samoa', '国际邮政');
INSERT INTO `t_delivery` VALUES (1276, 'SAP EXPRESS', 'sapexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1277, '沙特阿拉伯(Saudi Post)', 'saudipost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1278, 'SCCS', 'sccs', '国际运输商');
INSERT INTO `t_delivery` VALUES (1279, 'SCG', 'scglogistics', '国际运输商');
INSERT INTO `t_delivery` VALUES (1280, '四川星程快递', 'scxingcheng', '国内运输商');
INSERT INTO `t_delivery` VALUES (1281, '首达速运', 'sdsy888', '国内运输商');
INSERT INTO `t_delivery` VALUES (1282, '森鼎国际物流', 'sendinglog', '国际运输商');
INSERT INTO `t_delivery` VALUES (1283, 'Sendle', 'sendle', '国际运输商');
INSERT INTO `t_delivery` VALUES (1284, '塞尔维亚(PE Post of Serbia)', 'serbia', '国际邮政');
INSERT INTO `t_delivery` VALUES (1285, '澳丰速递', 'sfau', '国际运输商');
INSERT INTO `t_delivery` VALUES (1286, 'SFC', 'sfc', '国际运输商');
INSERT INTO `t_delivery` VALUES (1287, 'SFC Service', 'sfcservice', '国际运输商');
INSERT INTO `t_delivery` VALUES (1288, '圣飞捷快递', 'sfjhd', '国内运输商');
INSERT INTO `t_delivery` VALUES (1289, '曹操到', 'sfpost', '国际运输商');
INSERT INTO `t_delivery` VALUES (1290, 'Shadowfax', 'shadowfax', '国际运输商');
INSERT INTO `t_delivery` VALUES (1291, '穗航物流', 'shallexp', '国内运输商');
INSERT INTO `t_delivery` VALUES (1292, '衫达快运', 'shanda56', '国内运输商');
INSERT INTO `t_delivery` VALUES (1293, '尚途国际货运', 'shangtuguoji', '国内运输商');
INSERT INTO `t_delivery` VALUES (1294, '闪货极速达', 'shanhuodidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (1295, '捎客物流', 'shaoke', '国内运输商');
INSERT INTO `t_delivery` VALUES (1296, '杰响物流', 'shbwch', '国内运输商');
INSERT INTO `t_delivery` VALUES (1297, 'ShipBlu', 'shipblu', '国际运输商');
INSERT INTO `t_delivery` VALUES (1298, '王牌快递', 'shipbyace', '国内运输商');
INSERT INTO `t_delivery` VALUES (1299, '苏豪快递', 'shipsoho', '国内运输商');
INSERT INTO `t_delivery` VALUES (1300, 'SHL畅灵国际物流', 'shlexp', '国际运输商');
INSERT INTO `t_delivery` VALUES (1301, 'wish邮', 'shpostwish', '国际运输商');
INSERT INTO `t_delivery` VALUES (1302, 'shreeanjanicourier', 'shreeanjanicourier', '国际运输商');
INSERT INTO `t_delivery` VALUES (1303, '双鹤物流', 'shuanghe', '国内运输商');
INSERT INTO `t_delivery` VALUES (1304, '顺邦国际物流', 'shunbang', '国际运输商');
INSERT INTO `t_delivery` VALUES (1305, 'SiCepat Ekspres', 'sicepat', '国际运输商');
INSERT INTO `t_delivery` VALUES (1306, '四海快递', 'sihaiet', '国内运输商');
INSERT INTO `t_delivery` VALUES (1307, '中外运速递-中文', 'sinoex', '国际运输商');
INSERT INTO `t_delivery` VALUES (1308, 'Siodemka', 'siodemka', '国际运输商');
INSERT INTO `t_delivery` VALUES (1309, '易普递', 'sixroad', '国内运输商');
INSERT INTO `t_delivery` VALUES (1310, 'Sky Express', 'skyexpresseg', '国际运输商');
INSERT INTO `t_delivery` VALUES (1311, 'skynet', 'skynet', '国际运输商');
INSERT INTO `t_delivery` VALUES (1312, 'SkyNet Malaysia', 'skynetmalaysia', '国际运输商');
INSERT INTO `t_delivery` VALUES (1313, '荷兰Sky Post', 'skypost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1314, 'Asendia HK (LATAM)', 'skypostal', '国际运输商');
INSERT INTO `t_delivery` VALUES (1315, '斯洛文尼亚(Slovenia Post)', 'slovenia', '国际邮政');
INSERT INTO `t_delivery` VALUES (1316, 'SMSA Express', 'smsaexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1317, '所罗门群岛', 'solomon', '国际邮政');
INSERT INTO `t_delivery` VALUES (1318, '布基纳法索', 'sonapost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1319, 'Speedaf', 'speedaf', '国际运输商');
INSERT INTO `t_delivery` VALUES (1320, ' Speed Shipping Company', 'speedegypt', '国际运输商');
INSERT INTO `t_delivery` VALUES (1321, 'SpeedEx', 'speedex', '国际运输商');
INSERT INTO `t_delivery` VALUES (1322, '新加坡EMS、大包(Singapore Speedpost)', 'speedpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1323, 'Spoton', 'spoton', '国际运输商');
INSERT INTO `t_delivery` VALUES (1324, 'Sprint', 'sprint', '国际运输商');
INSERT INTO `t_delivery` VALUES (1325, '速速达', 'ssd', '国内运输商');
INSERT INTO `t_delivery` VALUES (1326, '圣卢西亚', 'stlucia', '国际邮政');
INSERT INTO `t_delivery` VALUES (1327, '智德物流', 'stzd56', '国内运输商');
INSERT INTO `t_delivery` VALUES (1328, '速豹', 'subaoex', '国内运输商');
INSERT INTO `t_delivery` VALUES (1329, '速呈宅配', 'sucheng', '国内运输商');
INSERT INTO `t_delivery` VALUES (1330, '特急便物流', 'sucmj', '国内运输商');
INSERT INTO `t_delivery` VALUES (1331, '苏丹（Sudapost）', 'sudapost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1332, '速风快递', 'sufengkuaidi', '国内运输商');
INSERT INTO `t_delivery` VALUES (1333, '速配欧翼', 'superoz', '国际运输商');
INSERT INTO `t_delivery` VALUES (1334, '速品快递', 'supinexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1335, '苏里南', 'surpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1336, '速通国际快运', 'sutongst', '国际运输商');
INSERT INTO `t_delivery` VALUES (1337, '圣文森特和格林纳丁斯', 'svgpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1338, '斯威士兰', 'swaziland', '国际邮政');
INSERT INTO `t_delivery` VALUES (1339, 'Amazon FBA Swiship', 'swiship', '国际运输商');
INSERT INTO `t_delivery` VALUES (1340, '顺友物流', 'sypost', '国际运输商');
INSERT INTO `t_delivery` VALUES (1341, '深圳DPEX', 'szdpex', '国际运输商');
INSERT INTO `t_delivery` VALUES (1342, '中时顺物流', 'szzss', '国内运输商');
INSERT INTO `t_delivery` VALUES (1343, '天美快递', 'taimek', '国内运输商');
INSERT INTO `t_delivery` VALUES (1344, 'Talabat ', 'talabat', '国际运输商');
INSERT INTO `t_delivery` VALUES (1345, '坦桑尼亚(Tanzania Posts)', 'tanzania', '国际邮政');
INSERT INTO `t_delivery` VALUES (1346, '淘布斯国际物流', 'taoplus', '国际运输商');
INSERT INTO `t_delivery` VALUES (1347, 'TCI XPS', 'tcixps', '国际运输商');
INSERT INTO `t_delivery` VALUES (1348, 'GPI', 'tcxbthai', '国际运输商');
INSERT INTO `t_delivery` VALUES (1349, 'TD Cargo', 'tdcargo', '国际运输商');
INSERT INTO `t_delivery` VALUES (1350, 'The BlueBhell Couriers', 'thebluebhellcouriers', '国际运输商');
INSERT INTO `t_delivery` VALUES (1351, 'The Courier Guy', 'thecourierguy', '国际运输商');
INSERT INTO `t_delivery` VALUES (1352, '天纵物流', 'tianzong', '国内运输商');
INSERT INTO `t_delivery` VALUES (1353, 'TiKi', 'tiki', '国际运输商');
INSERT INTO `t_delivery` VALUES (1354, 'TIPSA', 'tipsa', '国际运输商');
INSERT INTO `t_delivery` VALUES (1355, 'Shree Tirupati', 'tirupati', '国际运输商');
INSERT INTO `t_delivery` VALUES (1356, '株式会社T.M.G', 'tmg', '国内运输商');
INSERT INTO `t_delivery` VALUES (1357, 'TNT UK', 'tntuk', '国际运输商');
INSERT INTO `t_delivery` VALUES (1358, '多哥', 'togo', '国际邮政');
INSERT INTO `t_delivery` VALUES (1359, '顶世国际物流', 'topshey', '国际运输商');
INSERT INTO `t_delivery` VALUES (1360, 'The Professional Couriers', 'tpcindia', '国际运输商');
INSERT INTO `t_delivery` VALUES (1361, 'track-parcel', 'trackparcel', '国际运输商');
INSERT INTO `t_delivery` VALUES (1362, 'Trans Kargo', 'transkargologistics', '国际运输商');
INSERT INTO `t_delivery` VALUES (1363, 'Transporter Egypt', 'transporter', '国际运输商');
INSERT INTO `t_delivery` VALUES (1364, '突尼斯EMS(Rapid-Poste)', 'tunisia', '国际邮政');
INSERT INTO `t_delivery` VALUES (1365, 'Turbo', 'turbo', '国际运输商');
INSERT INTO `t_delivery` VALUES (1366, 'UBX', 'ubx', '国际运输商');
INSERT INTO `t_delivery` VALUES (1367, '欧洲UEX', 'uexiex', '国际邮政');
INSERT INTO `t_delivery` VALUES (1368, 'Ufelix', 'ufelix', '国际运输商');
INSERT INTO `t_delivery` VALUES (1369, '乌干达(Posta Uganda)', 'uganda', '国际邮政');
INSERT INTO `t_delivery` VALUES (1370, '邮鸽速运', 'ugoexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1371, '优海国际速递', 'uhi', '国际运输商');
INSERT INTO `t_delivery` VALUES (1372, '乌克兰小包、大包(UkrPoshta)', 'ukraine', '国际运输商');
INSERT INTO `t_delivery` VALUES (1373, '乌克兰小包、大包(UkrPost)', 'ukrpost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1374, 'Uni Express', 'uniexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1375, 'Union Courier SAE', 'unioncourier', '国际运输商');
INSERT INTO `t_delivery` VALUES (1376, 'United express courier service', 'unitedexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1377, 'UParcel', 'uparcel', '国际运输商');
INSERT INTO `t_delivery` VALUES (1378, 'UPS Mail Innovations', 'upsmailinno', '国际运输商');
INSERT INTO `t_delivery` VALUES (1379, '华夏国际速递', 'uschuaxia', '国际运输商');
INSERT INTO `t_delivery` VALUES (1380, 'UTAO优到', 'utaoscm', '国际运输商');
INSERT INTO `t_delivery` VALUES (1381, '乌兹别克斯坦(Post of Uzbekistan)', 'uzbekistan', '国际邮政');
INSERT INTO `t_delivery` VALUES (1382, '瓦努阿图(Vanuatu Post)', 'vanuatu', '国际邮政');
INSERT INTO `t_delivery` VALUES (1383, '越中国际物流', 'vctrans', '国际运输商');
INSERT INTO `t_delivery` VALUES (1384, '越南小包(Vietnam Posts)', 'vietnam', '国际邮政');
INSERT INTO `t_delivery` VALUES (1385, '鹰运国际速递', 'vipexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1386, 'Voo', 'voo', '国际运输商');
INSERT INTO `t_delivery` VALUES (1387, 'Wadily', 'wadily', '国际运输商');
INSERT INTO `t_delivery` VALUES (1388, 'Wahana', 'wahana', '国际运输商');
INSERT INTO `t_delivery` VALUES (1389, '万博快递', 'wanboex', '国内运输商');
INSERT INTO `t_delivery` VALUES (1390, 'WassalNow', 'wassalnow', '国际运输商');
INSERT INTO `t_delivery` VALUES (1391, '万达美', 'wdm', '国内运输商');
INSERT INTO `t_delivery` VALUES (1392, 'Wedel', 'wedel', '国际运输商');
INSERT INTO `t_delivery` VALUES (1393, 'wedepot物流', 'wedepot', '国际运输商');
INSERT INTO `t_delivery` VALUES (1394, '世航通运', 'welogistics', '国内运输商');
INSERT INTO `t_delivery` VALUES (1395, '文捷航空', 'wenjiesudi', '国际运输商');
INSERT INTO `t_delivery` VALUES (1396, '西翼物流', 'westwing', '国内运输商');
INSERT INTO `t_delivery` VALUES (1397, '威速递', 'wexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1398, '香港伟豪国际物流', 'whgjkd', '国际运输商');
INSERT INTO `t_delivery` VALUES (1399, 'Whistl', 'whistl', '国际运输商');
INSERT INTO `t_delivery` VALUES (1400, '万邑通', 'winit', '国内运输商');
INSERT INTO `t_delivery` VALUES (1401, '凡仕特物流', 'wlfast', '国内运输商');
INSERT INTO `t_delivery` VALUES (1402, '万理诺物流', 'wln', '国内运输商');
INSERT INTO `t_delivery` VALUES (1403, '星空国际', 'wlwex', '国际运输商');
INSERT INTO `t_delivery` VALUES (1404, 'wowexpress', 'wowexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1405, 'WTD海外通', 'wtdex', '国际运输商');
INSERT INTO `t_delivery` VALUES (1406, '臣邦同城', 'wto56kj', '国内运输商');
INSERT INTO `t_delivery` VALUES (1407, '微转运', 'wzhaunyun', '国际运输商');
INSERT INTO `t_delivery` VALUES (1408, '鑫宏福物流', 'xhf56', '国内运输商');
INSERT INTO `t_delivery` VALUES (1409, '西安城联速递', 'xianchengliansudi', '国内运输商');
INSERT INTO `t_delivery` VALUES (1410, '湘达物流', 'xiangdawuliu', '国内运输商');
INSERT INTO `t_delivery` VALUES (1411, '西安喜来快递', 'xilaikd', '国内运输商');
INSERT INTO `t_delivery` VALUES (1412, '新颜物流', 'xinyan', '国内运输商');
INSERT INTO `t_delivery` VALUES (1413, '雄达国际物流', 'xiongda', '国际运输商');
INSERT INTO `t_delivery` VALUES (1414, 'Xpert Delivery', 'xpertdelivery', '国际运输商');
INSERT INTO `t_delivery` VALUES (1415, 'XpressBees', 'xpressbees', '国际运输商');
INSERT INTO `t_delivery` VALUES (1416, '迅选物流', 'xunxuan', '国内运输商');
INSERT INTO `t_delivery` VALUES (1417, '西游寄速递', 'xyjexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1418, '一辉物流', 'yatfai', '国内运输商');
INSERT INTO `t_delivery` VALUES (1419, 'YCG物流', 'ycgglobal', '国际运输商');
INSERT INTO `t_delivery` VALUES (1420, '易达丰国际速递', 'ydfexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1421, '云达通', 'ydglobe', '国内运输商');
INSERT INTO `t_delivery` VALUES (1422, '易达通', 'yidatong', '国内运输商');
INSERT INTO `t_delivery` VALUES (1423, '驿递汇速递', 'yidihui', '国内运输商');
INSERT INTO `t_delivery` VALUES (1424, '艺凡快递', 'yifankd', '国内运输商');
INSERT INTO `t_delivery` VALUES (1425, '易航物流', 'yihangmall', '国内运输商');
INSERT INTO `t_delivery` VALUES (1426, 'yikonn', 'yikonn', '国际运输商');
INSERT INTO `t_delivery` VALUES (1427, '银捷速递', 'yinjiesudi', '国内运输商');
INSERT INTO `t_delivery` VALUES (1428, '易欧洲国际物流', 'yiouzhou', '国际运输商');
INSERT INTO `t_delivery` VALUES (1429, '一柒国际物流', 'yiqiguojiwuliu', '国际运输商');
INSERT INTO `t_delivery` VALUES (1430, '一起送', 'yiqisong', '国内运输商');
INSERT INTO `t_delivery` VALUES (1431, '亿顺航', 'yishunhang', '国际运输商');
INSERT INTO `t_delivery` VALUES (1432, '宜送', 'yisong', '国内运输商');
INSERT INTO `t_delivery` VALUES (1433, '易邮速运', 'yiyou', '国内运输商');
INSERT INTO `t_delivery` VALUES (1434, '益加盛快递', 'yjs', '国内运输商');
INSERT INTO `t_delivery` VALUES (1435, '优胜国际速递', 'yoseus', '国际运输商');
INSERT INTO `t_delivery` VALUES (1436, '邮驿帮高铁速运', 'youyibang', '国内运输商');
INSERT INTO `t_delivery` VALUES (1437, '鼹鼠快送', 'ysexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1438, '远航国际快运', 'yuanhhk', '国际运输商');
INSERT INTO `t_delivery` VALUES (1439, '粤九通物流', 'yuejiutong', '国内运输商');
INSERT INTO `t_delivery` VALUES (1440, '宇捷通', 'yujtong', '国内运输商');
INSERT INTO `t_delivery` VALUES (1441, '美国云达', 'yundaexus', '国际运输商');
INSERT INTO `t_delivery` VALUES (1442, '蕴国物流', 'yunguo56', '国内运输商');
INSERT INTO `t_delivery` VALUES (1443, 'Yusen Logistics', 'yusen', '国际运输商');
INSERT INTO `t_delivery` VALUES (1444, '远为快递', 'ywexpress', '国内运输商');
INSERT INTO `t_delivery` VALUES (1445, '西安运逸快递', 'yyexp', '国内运输商');
INSERT INTO `t_delivery` VALUES (1446, '一运全成物流', 'yyqc56', '国内运输商');
INSERT INTO `t_delivery` VALUES (1447, '赞比亚', 'zampost', '国际邮政');
INSERT INTO `t_delivery` VALUES (1448, '俄顺物流', 'zesexpress', '国际运输商');
INSERT INTO `t_delivery` VALUES (1449, '珠峰速运', 'zf365', '国内运输商');
INSERT INTO `t_delivery` VALUES (1450, '招金精炼', 'zhaojin', '国内运输商');
INSERT INTO `t_delivery` VALUES (1451, '众辉达物流', 'zhdwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (1452, '智谷特货', 'zhiguil', '国内运输商');
INSERT INTO `t_delivery` VALUES (1453, '众川国际', 'zhongchuan', '国际运输商');
INSERT INTO `t_delivery` VALUES (1454, '振捷国际货运', 'zjgj56', '国际运输商');
INSERT INTO `t_delivery` VALUES (1455, '明辉物流', 'zsmhwl', '国内运输商');
INSERT INTO `t_delivery` VALUES (1456, 'ZTE中兴物流', 'zteexpress', '国际运输商');

SET FOREIGN_KEY_CHECKS = 1;
