package org.springblade.common.config;

import io.micrometer.core.instrument.Clock;
import io.micrometer.core.instrument.binder.httpcomponents.PoolingHttpClientConnectionManagerMetricsBinder;
import io.micrometer.core.instrument.logging.LoggingMeterRegistry;
import io.micrometer.core.instrument.logging.LoggingRegistryConfig;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.impl.conn.PoolingHttpClientConnectionManager;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.time.Duration;

/**
 * Author pangqijun
 * Date 2022/11/23
 * Description httpClient 配置
 */
@Slf4j
@Configuration
public class HttpClientConfig {

	@Value("${http.connectionRequestTimeout}")
	private Integer connectionRequestTimeout;

	@Value("${http.connectTimeout}")
	private Integer connectTimeout;

	@Value("${http.socketTimeout}")
	private Integer socketTimeout;

	@Value("${http.maxTotal}")
	private Integer maxTotal;

	@Value("${http.defaultMaxPerRoute}")
	private Integer defaultMaxPerRoute;

	/**
	 * 使用httpClient连接池
	 * @return
	 */
	@Bean("httpClient")
	public CloseableHttpClient getHttpClient() {
		log.info("创建httpClient连接池");
		RequestConfig requestConfig = RequestConfig.custom()
			// 从连接池获取连接的超时时间
			.setConnectionRequestTimeout(connectionRequestTimeout)
			// 建立连接的超时时间
			.setConnectTimeout(connectTimeout)
			// 请求的超时时间
			.setSocketTimeout(socketTimeout).build();
		// 有的地方会配置一堆的https ssl的策略，点进这个构造函数他默认已经配置了，所以不用再配；
		PoolingHttpClientConnectionManager manager = new PoolingHttpClientConnectionManager();
		// 配置最大的连接数
		manager.setMaxTotal(maxTotal);
		// 每个路由最大连接数
		manager.setDefaultMaxPerRoute(defaultMaxPerRoute);
//		// 给PoolingHttpClientConnectionManager加上监控
//		new PoolingHttpClientConnectionManagerMetricsBinder(manager, "laker-pool")
//			.bindTo(new LoggingMeterRegistry(new LoggingRegistryConfig() {
//				@Override
//				public String get(String key) {
//					return null;
//				}
//				@Override
//				public Duration step() {
//					// 监控间隔时长
//					return Duration.ofSeconds(30);
//				}
//			}, Clock.SYSTEM));
		return HttpClients.custom().
			setConnectionManager(manager).
			setDefaultRequestConfig(requestConfig).
			evictExpiredConnections().
			build();
	}
}
