package org.springblade.common.utils;

import cn.hutool.core.collection.CollUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.Header;
import org.apache.http.NameValuePair;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpRequestBase;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.message.BasicHeader;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import org.springblade.core.log.exception.ServiceException;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.util.*;

/**
 * Author pangqijun
 * Date 2022/11/23
 * Description HttpUtil
 */
@Slf4j
@Component
public class HttpUtil {

	@Resource
	private CloseableHttpClient httpClient;

	/**
	 * json格式的post请求
	 * @param url 请求地址
	 * @param jsonParam json参数
	 * @param headers 请求头
	 * @return 相应结果
	 */
	public String postJson(String url, String jsonParam, Map<String, String> headers) {
		try {
			// 设置请求头和报文
			HttpPost httpPost = new HttpPost(url);
			this.setHeaders(headers, httpPost);
			StringEntity stringEntity = new StringEntity(jsonParam, ContentType.APPLICATION_JSON);
			httpPost.setEntity(stringEntity);
			CloseableHttpResponse httpResponse = httpClient.execute(httpPost);
			return EntityUtils.toString(httpResponse.getEntity());
		} catch (Exception e) {
			log.error("请求异常" + e.getMessage(), e);
			throw new ServiceException("请求异常" + e.getMessage());
		}
	}

	/**
	 * json格式的表单请求
	 * @param url 请求地址
	 * @param params 参数
	 * @param headers 请求头
	 * @return 相应结果
	 */
	public String postFrom(String url, Map<String, String> params, Map<String, String> headers) {
		try {
			// 设置请求头和报文
			HttpPost httpPost = new HttpPost(url);
			this.setHeaders(headers, httpPost);
			if (CollUtil.isNotEmpty(params)) {
				List<NameValuePair> list = new ArrayList<>();
				for (Map.Entry<String, String> elem : params.entrySet()) {
					list.add(new BasicNameValuePair(elem.getKey(), elem.getValue()));
				}
				httpPost.setEntity(new UrlEncodedFormEntity(list, StandardCharsets.UTF_8));
			}
			CloseableHttpResponse httpResponse = httpClient.execute(httpPost);
			return EntityUtils.toString(httpResponse.getEntity());
		} catch (Exception e) {
			log.error("请求异常" + e.getMessage(), e);
			throw new ServiceException("请求异常" + e.getMessage());
		}
	}

	/**
	 * get请求
	 * @param url 请求地址
	 * @param headers 请求头
	 * @return 相应结果
	 */
	public String get(String url, Map<String, String> headers) {
		try {
			HttpGet httpGet = new HttpGet(url);
			this.setHeaders(headers, httpGet);
			CloseableHttpResponse httpResponse = httpClient.execute(httpGet);
			return EntityUtils.toString(httpResponse.getEntity());
		} catch (IOException e) {
			log.error("请求异常" + e.getMessage(), e);
			throw new ServiceException("请求异常" + e.getMessage());
		}
	}

	/**
	 * 设置请求头
	 * @param headers
	 * @param httpRequestBase
	 */
	private void setHeaders(Map<String, String> headers, HttpRequestBase httpRequestBase) {
		if (CollUtil.isNotEmpty(headers)) {
			List<Header> headerList = new ArrayList<>();
			for (Map.Entry<String, String> entry : headers.entrySet()) {
				Header header = new BasicHeader(entry.getKey(), entry.getValue());
				headerList.add(header);
			}
			httpRequestBase.setHeaders(headerList.toArray(new Header[0]));
		}
	}
}
