package org.springblade.common.utils;


import cn.hutool.core.util.ObjectUtil;
import com.umf.api.service.UmfService;
import com.umf.api.service.UmfServiceImpl;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/***************************************
 * <p>Title: 联动示例demo</p>
 * <p>Description: 定义私钥路径</p>
 * <p>Company: UMF</p>
 * @author  赵宏林
 * @date 2019年5月23日
 ***************************************/

@Configuration
public class MerCallServiceSingleton {

	private static SimpleDateFormat sdf1 = new SimpleDateFormat("yyyyMMdd");
	private static SimpleDateFormat sdf2 = new SimpleDateFormat("yyMMddHHmmssSS");
	private String merdate = sdf1.format(new Date());
	private String refundNo = sdf2.format(new Date());

	@Value("${v4.merId}")
	private String merId;

	@Value("${v4.certPath}")
	private String certPath;

	public UmfService getInstance(){
		return new UmfServiceImpl(merId,certPath);
	}

	//java代码示例
	public static void main(String[] args){
		//模拟付款状态查询
////		Map reqMap = new MerCallServiceSingleton().prepareRefund();
//		Map reqMap = new MerCallServiceSingleton().preparerefund_query();
		UmfService instance = new UmfServiceImpl("53463","D:\\IdeaProjects\\bladex-boot\\src\\main\\resources\\cert\\53463_.key.p8");
////		Map respMap = instance.queryRefundStateMap(reqMap);
//		Map respMap = instance.generalRefundMap(reqMap);
//		System.out.println(respMap.toString());

		Map reqMap = new HashMap();
		reqMap.put("mer_id","53463");
		reqMap.put("mer_date", "20220726");
		reqMap.put("order_id", "20220727120920898568");
		reqMap.put("refund_no", sdf2.format(new Date()));
		reqMap.put("refund_amount", "391991");
		reqMap.put("org_amount","391991");
		Map respMap = instance.generalRefundMap(reqMap);
	}

	//准备退款状态查询
	public Map preparerefund_query(){
		Map reqMap = new HashMap();
		reqMap.put("mer_id","53463");
		reqMap.put("refund_no","220629150927954");
		return reqMap;
	}

	//准备退款请求
	public Map prepareRefund(){
		Map reqMap = new HashMap();
		reqMap.put("mer_id", "53463");
		reqMap.put("mer_date", 20220628);
		reqMap.put("order_id","20220629142522889838");
		reqMap.put("refund_no", refundNo);
		reqMap.put("refund_amount","8");
		reqMap.put("org_amount","10");
		return reqMap;
	}


	/**
	 * 查询打款状态
	 * @return
	 */
	public Map<String,Map> queryPaymentStatus(String consignId,String merdate){

		Map reqMap = new HashMap();
		reqMap.put("mer_id",merId);
		reqMap.put("order_id",consignId);
		reqMap.put("mer_date",merdate);
		Map map = getInstance().queryPaymentStatusMap(reqMap);
		Map<String,Map> reqMap1 = new HashMap();
		reqMap1.put("request",reqMap);
		reqMap1.put("response",map);
		return reqMap1;
	}

	/**
	 * 联动支付打款
	 * @param transAmount 打款金额
	 * @param receiverAccount 收款账户
	 * @param realName 收款人名称
	 * @param checkFlag 0：实时付款1：非实时付款
	 * @return
	 */
	public  Map<String,String> prepareTransferDirect(BigDecimal transAmount, String receiverAccount, String realName, Integer checkFlag, Long orderId){
		Integer amount = transAmount.multiply(new BigDecimal("100")).intValue();
		if(ObjectUtil.isNull(checkFlag)){
			checkFlag = 0;
		}
		Map reqMap = new HashMap();
		reqMap.put("mer_id", merId);
		reqMap.put("order_id", orderId);
		reqMap.put("mer_date",merdate);
		reqMap.put("amount", amount);//打款金额以分为单位
		reqMap.put("recv_account_type","00");//00:银行卡，02：U付账号
		reqMap.put("recv_bank_acc_pro","0");//0:对私，1：对公
//		reqMap.put("recv_account","6222032405001619698");//00:银行卡，02：U付账号
		reqMap.put("recv_account", receiverAccount);//00:银行卡，02：U付账号
		reqMap.put("recv_user_name", realName);
		reqMap.put("purpose","进货仓单收款");
		reqMap.put("checkFlag", checkFlag);//0：实时付款1：非实时付款
		return getInstance().paymentOrderMap(reqMap);
	}

	/**
	 * 收款链接生成
	 * @param transAmount 收款金额
	 * @param notifyUrl 通知链接
	 * @param goodsName 商品名称
	 * @param orderNo 订单号
	 * @return
	 */
	public Map<String, String> activeNewScanPayment(BigDecimal transAmount, String notifyUrl, String goodsName, String orderNo){
		Integer amount = transAmount.multiply(new BigDecimal("100")).intValue();
		Map reqMap = new HashMap();
		reqMap.put("mer_id", merId);
		reqMap.put("notify_url", notifyUrl);
		reqMap.put("goods_inf", goodsName);
		reqMap.put("order_id", orderNo);
		reqMap.put("mer_date",merdate);
		reqMap.put("amount", amount);
		reqMap.put("scancode_type","ALIPAY");
//		UmfService instance = new UmfServiceImpl("53463","/usr/local/liquor/cart/53463_.key.p8");
//		UmfService instance = new UmfServiceImpl("53463","D:\\IdeaProjects\\bladex-boot\\src\\main\\resources\\cert\\53463_.key.p8");
		return getInstance().activeNewScanPaymentMap(reqMap);

//		try {
//			return R.data(new String(Base64.getDecoder().decode(respMap.get("bank_payurl").toString()), "GBk"));
//		} catch (IOException e) {
//			e.printStackTrace();
//			return R.fail("付款失败请重新发起");
//		}
	}

	/**
	 * 快捷支付下单
	 * @param transAmount 付款金额
	 * @param notifyUrl 通知接口
	 * @param gateId 银行简称
	 * @param orderNo 订单id
	 * @return
	 */
	public Map<String, String> quickPayOrder(BigDecimal transAmount, String notifyUrl, String gateId, String orderNo){
		Integer amount = transAmount.multiply(new BigDecimal("100")).intValue();
		Map reqMap = new HashMap();
		reqMap.put("mer_id",merId);
		reqMap.put("notify_url", notifyUrl);
		reqMap.put("order_id", orderNo);
		reqMap.put("mer_date", merdate);
		reqMap.put("amount", amount);
		reqMap.put("gate_id", gateId);
		reqMap.put("pay_type", "DEBITCARD");
		Map map = getInstance().quickPayOrderMap(reqMap);
		map.put("reqMap",reqMap.toString());
		return map;
	}

	/**
	 * 获取支付验证码
	 * @param tradeNo 第三方订单号
	 * @param name 用户名称
	 * @param bankNo 银行卡号
	 * @param phone 电话
	 * @return
	 */
	public Map<String, String> quickGetMessage(String tradeNo, String name, String bankNo, String phone, String idCard){
		Map reqMap = new HashMap();
		reqMap.put("mer_id", merId);
		reqMap.put("trade_no", tradeNo);//真实的U付订单号
		reqMap.put("media_id", phone);
		reqMap.put("card_id", bankNo);
		reqMap.put("card_holder", name);
		reqMap.put("identity_type", "IDENTITY_CARD");
		reqMap.put("identity_code", idCard);
		return getInstance().quickGetMessageMap(reqMap);
	}

	/**
	 * 确认支付
	 * @param tradeNo 联动订单号
	 * @param verifyCode 验证码
	 * @param name 付款人姓名
	 * @param bankNo 银行卡号
	 * @param phone 电话
	 * @param idCard 身份证号
	 * @return
	 */
	public Map<String, String> quickPayConfirm(String tradeNo, String verifyCode, String name, String bankNo, String phone, String idCard){
		Map reqMap = new HashMap();
		reqMap.put("mer_id", merId);
		reqMap.put("trade_no", tradeNo);//真实的U付订单号
		reqMap.put("verify_code", verifyCode);
		reqMap.put("media_id", phone);
		reqMap.put("card_id", bankNo);
		reqMap.put("card_holder", name);
		reqMap.put("identity_type", "IDENTITY_CARD");
		reqMap.put("identity_code", idCard);
		return getInstance().quickPayConfirmMap(reqMap);
	}

	/**
	 * 快捷支付订单查询
	 * @param tradeNo 联动订单号
	 * @param orderNo 系统订单号
	 * @param orderDate 订单时间
	 * @return
	 */
	public Map<String, String> queryhistoryOrder(String tradeNo, String orderNo, Date orderDate){
		Map reqMap = new HashMap();
		reqMap.put("mer_id",merId);
		reqMap.put("mer_date",merdate);
		reqMap.put("trade_no", tradeNo);//真实的U付订单号
		reqMap.put("order_id", orderNo);
		reqMap.put("mer_date", sdf1.format(orderDate));
		getInstance().queryhistoryOrderMap(reqMap);
		return  getInstance().queryhistoryOrderMap(reqMap);
	}

	//准备查询订单信息
	public Map<String, String> prepareQueryhistoryOrder(String orderNo){
		Map reqMap = new HashMap();
		reqMap.put("mer_id", merId);
		reqMap.put("mer_date",merdate);
		reqMap.put("order_id", orderNo);
		return getInstance().queryhistoryOrderMap(reqMap);
	}
}
