package org.springblade.common.utils;

import cn.hutool.core.map.MapUtil;
import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSONObject;
import jdk.nashorn.internal.ir.annotations.Reference;
import lombok.Data;
import org.springblade.modules.platform.entity.UserBankCards;
import org.springblade.modules.system.dto.PayRepDTO;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;

import javax.annotation.Resource;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.security.KeyStore;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;
import java.util.*;

@Configuration
public class YsbPayUtil {

	private static String accountId;

	@Resource
	private RSAUtil rsaUtil;

	private final static String URL = "https://www.unspay.com/";

	@Value("${ysb.accountId}")
	public void setAccountId(String accountId) {
		YsbPayUtil.accountId = accountId;
	}

	/**
	 * 绑定银行卡操作
	 * @param userBankCards 用户银行卡信息
	 */
	public PayRepDTO bindBankCard(UserBankCards userBankCards){
		Map<String, Object> map = new HashMap<>();
		map.put("customerId", userBankCards.getCustomerIdmd());
		map.put("requestNo", userBankCards.getRequestNo());
		map.put("name", userBankCards.getName());
		map.put("idCardNo", userBankCards.getCardCode());
		map.put("cardNo", userBankCards.getBackNo());
		map.put("phoneNo", userBankCards.getMobile());
		map = getSendMap(map);
		String post = HttpUtil.post(URL + "quickpay-interface/walletPayApi/tieRequest", JSONUtil.toJsonStr(map));
		return JSONObject.parseObject(post, PayRepDTO.class);
	}

	/**
	 * 确认提交银行卡
	 * @param customerId 第三方用户id
	 * @param requestNo 绑卡请求号
	 * @param vericode 验证码
	 * @return
	 */
	public PayRepDTO confirmBankCard(String customerId, String requestNo, String vericode){
		Map<String, Object> map = new HashMap<>();
		map.put("customerId", customerId);
		map.put("requestNo", requestNo);
		map.put("vericode", vericode);
		map = getSendMap(map);
		String post = HttpUtil.post(URL + "quickpay-interface/walletPayApi/tieConfirm", JSONUtil.toJsonStr(map));
		return JSONObject.parseObject(post, PayRepDTO.class);
	}

	/**
	 * 绑定银行卡查询
	 * @param customerId 第三方用户id
	 * @param requestNo 绑卡请求号
	 * @return
	 */
	public PayRepDTO bindQuery(String customerId, String requestNo){
		Map<String, Object> map = new HashMap<>();
		map.put("customerId", customerId);
		map.put("requestNo", requestNo);
		map = getSendMap(map);
		String post = HttpUtil.post(URL + "quickpay-interface/walletPayApi/tieQuery", JSONUtil.toJsonStr(map));
		return JSONObject.parseObject(post, PayRepDTO.class);
	}



	/**
	 * 获取加密后的请求参数
	 * @param map
	 * @return
	 */
	public Map<String, Object> getSendMap(Map map){
		map.put("accountId", accountId);
		map.put("signType", "RSA");
		String rsaMacStr = rsaUtil.getRSAMacStr(map);
		map.put("mac", rsaMacStr);
		return map;
	}
}
