package org.springblade.modules.api.controller;

import cn.hutool.core.util.NumberUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.parser.Feature;
import com.alipay.api.*;
import com.alipay.api.domain.AlipayFundTransUniTransferModel;
import com.alipay.api.domain.AlipayTradeAppPayModel;
import com.alipay.api.domain.Participant;
import com.alipay.api.internal.util.AlipaySignature;
import com.alipay.api.request.*;
import com.alipay.api.response.*;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.umf.api.service.UmfService;
import com.umf.api.service.UmfServiceImpl;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.checkerframework.checker.units.qual.A;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.PaymentTypeEnum;
import org.springblade.common.utils.CommonUtil;
import org.springblade.common.utils.MerCallServiceSingleton;
import org.springblade.common.utils.NotifyUtils;
import org.springblade.common.utils.RSASignature;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.log.annotation.ApiLog;
import org.springblade.core.log.exception.ServiceException;
import org.springblade.core.log.logger.BladeLogger;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.StringUtil;
import org.springblade.modules.finance.entity.*;
import org.springblade.modules.finance.mapper.PlatformAuthorizationMapper;
import org.springblade.modules.finance.pay.entity.AlipayProperties;
import org.springblade.modules.finance.service.*;
import org.springblade.modules.platform.entity.UserBankCards;
import org.springblade.modules.platform.entity.UserCardInfo;
import org.springblade.modules.platform.service.IUserBankCardsService;
import org.springblade.modules.platform.service.IUserCardInfoService;
import org.springblade.modules.platform.wrapper.UserAppWrapper;
import org.springblade.modules.shopping.entity.Consign;
import org.springblade.modules.shopping.entity.PaymentRecord;
import org.springblade.modules.shopping.service.IConsignService;
import org.springblade.modules.shopping.service.IPaymentRecordService;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.entity.UserApp;
import org.springblade.modules.system.service.IUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import java.math.BigDecimal;
import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.*;

@RestController
@RequestMapping(CommonConstant.API_URL + "/aliPay/sdk")
@Api(value = "支付SDK", tags = "95.支付SDK")
public class AliPay01Controller extends BladeController {

	private static final Logger log = LoggerFactory.getLogger(AliPay01Controller.class);

	//渠道
	private static final String PAY_CODE = "aliPay";

	// H5签名
	private static String H5_SIGN = "https://pay.veyd.cn/xxpay/api/newsxf/sign/checkInfo";
	// H5请求url
	private static String H5_URL = "https://pay.veyd.cn/xxpay/api/create/NewSXFH5PayOrder?outTradeNo=";
	//私钥
	private static String PRIVATE_KEY;

	@Value("${alipay.sdk.private-key}")
	public void setPRIVATE_KEY(String PRIVATE_KEY) {
		this.PRIVATE_KEY = PRIVATE_KEY;
	}

	//预授权
	private static final String NOTIFY_URL = "/api/v1/aliPay/sdk/auth_notify_url";

	//预授权改付款
	private static final String NEW_NOTIFY_URL = "/api/v1/aliPay/sdk/new_auth_notify_url";

	//平台付款预授权
	private static final String PLATFORM_URL = "/api/v1/aliPay/sdk/platform_authorization_notify_url";

	//抢购
	private static final String TRADE_URL = "/api/v1/aliPay/sdk/trade_notify_url";

	//购买
	private static final String ORDER_URL = "/api/v1/aliPay/sdk/order_notify_url";

	//购物车购买
	private static final String CART_ORDER_URL = "/api/v1/aliPay/sdk/cart_order_notify_url";

	//充值订单
	@Resource
	private PlatformAuthorizationMapper paMapper;

	@Resource
	private IPaymentRecordService paymentRecordService;//付款记录

	@Resource(name = "alipayClient")
	private AlipayClient client;//支付宝请求sdk客户端

	@Resource
	private AlipayProperties properties;//支付宝sdk配置

	@Resource
	private IUserBankCardsService bankCardsService;//银行卡服务

	@Resource
	private IUserCardInfoService userCardInfoService;//身份证实名信息

	@Resource
	private MerCallServiceSingleton merCallServiceSingleton;//打款工具类

	@Resource
	private IOrderService orderService;
	@Resource
	private IOrderGrantService orderGrantService;
	@Resource
	private IUserService userService;
	@Resource
	private IOrderConsignService orderConsignService;
	@Resource
	private IConsignService consignService;
	@Resource
	private ITransactionFlowService transactionFlowService;
	@Resource
	private BladeLogger logger;

	@ApiLog("购物车发起")
	@PostMapping("/initiate")
	@ApiOperation(value = "统一收单线下交易查询", notes = "当面付")
	@ApiOperationSupport(order = 1)
	public R initiate(@ApiParam(value = "流水号", required = true) @RequestParam String transactionNo,
					@ApiParam(value = "支付渠道:aliPay支付宝，wechatPay微信支付，unionPay银联 ", required = true) @RequestParam String payFor) {
		TransactionFlow flow = transactionFlowService.lambdaQuery().eq(TransactionFlow::getTransactionNo, transactionNo).one();
		if (flow == null) {
			return R.fail("数据不存在");
		}
		if(StringUtil.isEmpty(payFor)){
			return R.fail("请选择支付方式！");
		}
		if("aliPay".equals(payFor)){
			AlipayTradeAppPayRequest request = new AlipayTradeAppPayRequest ();
			AlipayTradeAppPayModel model = new AlipayTradeAppPayModel ();
			model.setBody("中宏商城" );
			model.setSubject("中宏商城");
			model.setOutTradeNo(flow.getTransactionNo());
			model.setTimeoutExpress("30m");
			model.setTotalAmount(flow.getAmount().toString());
			model.setProductCode("QUICK_MSECURITY_PAY");
			request.setBizModel(model);
			request.setNotifyUrl(properties.getDomain() + CART_ORDER_URL);
			try  {
				AlipayTradeAppPayResponse response = client.sdkExecute(request);
				return R.data(response.getBody());
			}  catch (AlipayApiException e ) {
				e.printStackTrace();
				return R.fail("发起支付失败！");
			}
		}
		return R.fail("该支付方式暂不支持！");
	}

	@ApiLog("发起交易-证书")
	@PostMapping("/pay_001")
	@ApiOperation(value = "统一收单线下交易查询", notes = "当面付")
	@ApiOperationSupport(order = 1)
	public R pay001(@ApiParam(value = "订单号", required = true) @RequestParam String outTradeNo,
					@ApiParam(value = "支付渠道:aliPay支付宝，wechatPay微信支付，unionPay银联 ", required = true) @RequestParam String payFor) {
		Order order = orderService.getOne(Wrappers.<Order>lambdaQuery().eq(Order::getOutTradeNo, outTradeNo));
		if (order == null){
			return R.fail("请求参数错误！");
		}
		if(StringUtil.isEmpty(payFor)){
			return R.fail("请选择支付方式！");
		}
		if(order.getOrderType() == 3){
			//寄售订单而且寄售方式为寄售
			OrderConsign orderConsign = orderConsignService.getOne(Wrappers.<OrderConsign>lambdaQuery()
				.eq(OrderConsign::getOutTradeNo, outTradeNo));
			if (orderConsign != null){
				Consign consign = consignService.getById(orderConsign.getConsignId());
				if (consign != null && consign.getConsignType() == 2){
					return R.fail("该订单为抢购单，不能发起交易！");
				}
			}
		}
		if("aliPay".equals(payFor)){
			AlipayTradeAppPayRequest request = new AlipayTradeAppPayRequest ();
			AlipayTradeAppPayModel model = new AlipayTradeAppPayModel ();
			model.setBody("中宏商城" );
			model.setSubject("中宏商城");
			model.setOutTradeNo(outTradeNo);
			model.setTimeoutExpress("30m");
			model.setTotalAmount(order.getPayFee().toString());
			model.setProductCode("QUICK_MSECURITY_PAY");
			request.setBizModel(model);
			request.setNotifyUrl(properties.getDomain() + ORDER_URL);
			try  {
//				这里和普通的接口调用不同，使用的是sdkExecute
//				普通模式 使用 execute
//				证书使用 使用 sdkExecute
				AlipayTradeAppPayResponse response = client.sdkExecute(request);
				paymentRecordService.init(order, 0);
				return R.data(response.getBody());
			}  catch (AlipayApiException e ) {
				e.printStackTrace();
				return R.fail("发起支付失败！");
			}
		}
		return R.fail("该支付方式暂不支持！");
	}


	@ApiLog("绑定订单-预授权")
	@PostMapping("/pay_002")
	@ApiOperation(value = "统一收单交易支付接口", notes = "预授权")
	@ApiOperationSupport(order = 2)
	@Transactional(rollbackFor = Exception.class)
	public R pay002(@ApiParam(value = "抢购订单号", required = true) @RequestParam String outTradeNo,
					@ApiParam(value = "预授权订单号", required = true) @RequestParam String orderNo) {
		Order order = orderService.getOne(Wrappers.<Order>lambdaQuery().eq(Order::getOutTradeNo, outTradeNo));
		if (order == null){
			return R.fail("请求参数错误！");
		}
		OrderGrant orderGrant = orderGrantService.getOne(Wrappers.<OrderGrant>lambdaQuery().eq(OrderGrant::getOrderNo, orderNo));
		if (orderGrant == null) {
			return R.fail("请求参数错误！");
		}
		//获取数量
		Integer nowNum = orderGrant.getNowNum();
		UserApp userApp = new UserApp();
		UserApp query = userApp.selectOne(Wrappers.<UserApp>lambdaQuery().eq(UserApp::getUserId, orderGrant.getUserId()));
		if (query == null) {
			return R.fail("用户信息错误！");
		}
		if (StringUtil.isEmpty(query.getAlipayUserId())) {
			return R.fail("请绑定支付宝打款账号");
		}
		JSONObject data = new JSONObject();
		data.put("out_trade_no", outTradeNo);
		data.put("total_amount", orderGrant.getPrice());
		data.put("subject", "中宏酒业");
		data.put("product_code", "PRE_AUTH_ONLINE");
		data.put("auth_no", orderGrant.getAuthNo());
		data.put("body", orderGrant.getAuthNo());
		if (nowNum == 1){
			data.put("auth_confirm_mode", "COMPLETE"); //解冻
		}else{
			data.put("auth_confirm_mode", "NOT_COMPLETE");//不解冻
		}
		data.put("seller_id", properties.getPayeeUserId()); //收款方
		data.put("buyer_id", query.getAlipayUserId()); //买家ID //2088012801069195
		//APP支付
		AlipayTradePayRequest request = new AlipayTradePayRequest();
		request.setNotifyUrl(properties.getDomain() + TRADE_URL); //异步通知地址
		request.setBizContent(data.toJSONString()); //业务参数
		//APP支付
		try {
			Order update = new Order();
			update.setId(order.getId());
			update.setGrantNo(orderGrant.getAuthNo());
			boolean flg = orderService.updateById(update);
			if (!flg){
				logger.info("订单绑定失败",update.toString());
			}
			//普通模式 使用 execute
			//证书使用 使用 certificateExecute
			AlipayTradePayResponse response = client.certificateExecute(request);
			if (response.isSuccess()){
				return R.data(response.getBody());
			}else{
				orderGrantService.remove(Wrappers.<OrderGrant>lambdaQuery()
					.eq(OrderGrant::getId,orderGrant.getId())
					.eq(OrderGrant::getStatus, 0));
				logger.info("订单绑定失败","删除预授权数据");
			}
		} catch (AlipayApiException e) {
			e.printStackTrace();
		}
		return R.fail("发起支付失败！");
	}

	@ApiLog("第三方订单订单状态查询")
	@PostMapping("/queryOrderState")
	@ApiOperation(value = "第三方订单订单状态查询", notes = "第三方订单订单状态查询")
	@ApiOperationSupport(order = 4)
	public R queryOrderState(@ApiParam(value = "订单号", required = true) @RequestParam String orderNo){
		OrderGrant one = orderGrantService.getOne(Wrappers.lambdaQuery(OrderGrant.class).eq(OrderGrant::getOrderNo, orderNo));
		Map<String, String> stringStringMap = merCallServiceSingleton.queryhistoryOrder(one.getAuthNo(), one.getOrderNo(), one.getCreateTime());
		return R.data(stringStringMap);
	}

	@ApiLog("获取订单验证码")
	@PostMapping("/quickGetMessage")
	@ApiOperation(value = "获取订单验证码", notes = "获取订单验证码")
	@ApiOperationSupport(order = 4)
	public R quickGetMessage(@ApiParam(value = "订单号", required = true) @RequestParam String orderNo){
		OrderGrant one = orderGrantService.getOne(Wrappers.lambdaQuery(OrderGrant.class).eq(OrderGrant::getOrderNo, orderNo));
		UserBankCards bankCards = bankCardsService.getOne(Wrappers.lambdaQuery(UserBankCards.class)
			.eq(UserBankCards::getUserId, getUser().getUserId()));
		User user = userService.getById(getUser().getUserId());
		//获取身份证实名信息
		UserCardInfo userCard = userCardInfoService.getOne(Wrappers.lambdaQuery(UserCardInfo.class).eq(UserCardInfo::getUserId, getUser().getUserId()));
		if(StringUtil.isEmpty(bankCards.getMobile())){
			return R.fail("请完善银行卡预留手机信息");
		}
		Map<String, String> stringStringMap = merCallServiceSingleton.quickGetMessage(one.getAuthNo(),
			user.getRealName(), bankCards.getBackNo(), bankCards.getMobile(), userCard.getIdCard());
		Map<String, String> resMap = new HashMap<>();
		if("00060722".equals(stringStringMap.get("ret_code"))){
			resMap.put("code", "201");
			resMap.put("message", "银行卡信息有误请核实银行卡信息");
			return R.data(resMap);
		}
		if("0000".equals(stringStringMap.get("ret_code"))){
			resMap.put("code", "200");
			resMap.put("message", "验证码获取成功");
			return R.data(resMap);
		}
		if(ObjectUtil.isNotNull(stringStringMap)){
			return R.fail(stringStringMap.get("ret_msg"));
		}else{
			return R.fail("验证码获取失败，请检查银行卡信息是否正确");
		}
	}

	@ApiLog("联动确认支付")
	@PostMapping("/quickPayConfirm")
	@ApiOperation(value = "联动确认支付", notes = "联动确认支付")
	@ApiOperationSupport(order = 4)
	public R quickPayConfirm(@ApiParam(value = "订单号", required = true) @RequestParam String orderNo,
							 @ApiParam(value = "订单号", required = true) @RequestParam String verifyCode){
		OrderGrant one = orderGrantService.getOne(Wrappers.lambdaQuery(OrderGrant.class).eq(OrderGrant::getOrderNo, orderNo));
		User user = userService.getById(getUser().getUserId());
		UserBankCards bankCards = bankCardsService.getOne(Wrappers.lambdaQuery(UserBankCards.class)
			.eq(UserBankCards::getUserId, getUser().getUserId()));
		UserCardInfo userCard = userCardInfoService.getOne(Wrappers.lambdaQuery(UserCardInfo.class).eq(UserCardInfo::getUserId, getUser().getUserId()));
		Map<String, String> stringStringMap = merCallServiceSingleton.quickPayConfirm(one.getAuthNo(),
			verifyCode, user.getRealName(), bankCards.getBackNo(), bankCards.getMobile(), userCard.getIdCard());
		return R.data(stringStringMap);
	}


	/**
	 * 发起支付宝预授权
	 *
	 * 1、判断用户是否能抢购
	 * 2、查询是否有寄售/进货单
	 * 3、发起支付宝预支付
	 * 4、请求成功 创建预支付订单 默认为未授权
	 * @param batNo 批次ID
	 * @param price 金额
	 * @param num 预授数量
	 * @return R
	 * @throws AlipayApiException
	 */
	@ApiLog("发起支付宝预授权")
	@PostMapping("/pay_003")
	@ApiOperation(value = "线上资金授权冻结接口-调用支付宝预授权", notes = "支付请求")
	@ApiOperationSupport(order = 3)
	public R<Map<String, Object>> pay003(@ApiParam(value = "批次ID", required = true) @RequestParam Long batNo,
							@ApiParam(value = "金额", required = true) @RequestParam Double price,
							@ApiParam(value = "数量", required = true) @RequestParam Integer num,
							@ApiParam(value = "付款方式:0支付宝支付，1联动快捷支付", required = true) @RequestParam Integer type) throws AlipayApiException {
		UserApp userApp = new UserApp();
		Long userId = getUser().getUserId();
		UserApp query = userApp.selectOne(Wrappers.<UserApp>lambdaQuery().eq(UserApp::getUserId, userId));
		if (StringUtil.isEmpty(type)){
			return R.fail("交易类型不能为空！");
		}
		if (ObjectUtil.isNull(query)){
			return R.fail("该用户不存在！");
		}
		boolean flg = UserAppWrapper.build().isTicket(query.getTicket(), price);
		if (!flg){
			return R.fail("您的绿色积分不足！");
		}
		if (query.getEnableAuth() != 2){
			double k = (double)query.getCreditScore() / 100;
			int scoreCount = NumberUtil.roundDown(k, 2).intValue();
			int consignCount = Integer.parseInt(ParamCache.getValue(CommonConstant.DEFAULT_CONDIGN_COUNT));
			if (scoreCount > consignCount){
				scoreCount = consignCount;
			}
			if (scoreCount < num){
				return R.fail("预授数量不能大于单场可抢次数！");
			}
		}
		if(query.getState() != 1 ){
			return R.fail("该账号已冻结！");
		}
		Consign consign = consignService.queryConsign(batNo, userId);
		if (ObjectUtil.isNull(consign)){
			return R.fail("亲，好物已抢完欢迎再来！");
		}
		//判断用户是否在该场次下有预授权
		OrderGrant orderGrant = orderGrantService.getOne(Wrappers.<OrderGrant>lambdaQuery()
			.eq(OrderGrant::getBatNo, batNo)
			.eq(OrderGrant::getUserId, userId)
			.eq(OrderGrant::getStatus,1)
		);
		if(ObjectUtil.isNotNull(orderGrant)){
			return R.fail("您已发起预授权，无需再次发起！");
		}
		String orderNo = CommonUtil.genTimeID();
		PaymentRecord paymentRecord = new PaymentRecord();//付款记录
		paymentRecord.setPaymentType(type);
		paymentRecord.setOrderNo(orderNo);
		paymentRecord.setPaymentPrice(NumberUtil.mul(price, num));
		paymentRecord.setStatus(0);
		String dataDate = DateUtil.format(DateUtil.now(), DateUtil.PATTERN_DATE);
		OrderGrant grant = new OrderGrant();
		grant.setBatNo(batNo);
		grant.setUserId(userId);
		grant.setStatus(0);//未授权
		grant.setOrderNo(orderNo);
		grant.setNum(num);
		grant.setNowNum(num);
		grant.setPrice(price);
		grant.setDataDate(dataDate);
		grant.setCreateTime(DateUtil.now());//创建时间
		//APP支付
		//必须使用 sdkExecute
/************************************支付宝预授权开始*************************************/
		if(PaymentTypeEnum.ALIPAY.getValue().equals(type)){
			JSONObject data = new JSONObject();
			data.put("out_order_no", orderNo);
			data.put("out_request_no", orderNo);
			data.put("order_title","预授权冻结");
			data.put("amount", NumberUtil.mul(price, num));
			data.put("product_code","PRE_AUTH_ONLINE"); //销售产品码。支付宝预授权产品固定为 PRE_AUTH_ONLINE
			data.put("payee_user_id", properties.getPayeeUserId());
			data.put("timeout_express","30m");
			//APP支付
			AlipayFundAuthOrderAppFreezeRequest request = new AlipayFundAuthOrderAppFreezeRequest();
			request.setNotifyUrl(properties.getDomain() + NOTIFY_URL); //异步通知地址
			request.setBizContent(data.toJSONString()); //业务参数
				//必须使用 sdkExecute
			AlipayFundAuthOrderAppFreezeResponse response = client.sdkExecute(request);
			if(response.isSuccess()){
				paymentRecord.setRequestJson(request.toString());
				paymentRecordService.save(paymentRecord);//插入付款记录，去对应的回调方法中
				orderGrantService.save(grant);
				Map<String, Object> map = new HashMap<>();
				map.put("url", response.getBody());
				map.put("orderNo",orderNo);
				map.put("type", type);//0表示支付宝预授权
				return R.data(map);
			}
/************************************支付宝预授权结束*************************************/
		} else if(PaymentTypeEnum.LINKAGE_PAY.getValue().equals(type)){
/************************************第三方支付开始*************************************/
			UserBankCards bankCards = bankCardsService.getOne(Wrappers.lambdaQuery(UserBankCards.class)
				.eq(UserBankCards::getUserId, userId));
			if(ObjectUtil.isNull(bankCards) || StringUtil.isEmpty(bankCards.getBackNo()) || StringUtil.isEmpty(bankCards.getAreaCode())){
				return R.fail("银行卡信息不完整，请完善银行卡信息");
			}
			Map<String, String> activeNewScanPayment = merCallServiceSingleton.quickPayOrder(NumberUtil.mul(price, num),
				properties.getDomain() + NEW_NOTIFY_URL, bankCards.getAreaCode(), orderNo);
			if("0000".equals(activeNewScanPayment.get("ret_code"))){
				paymentRecord.setRequestJson(activeNewScanPayment.get("reqMap"));
				paymentRecordService.save(paymentRecord);//插入付款记录，去对应的回调方法中
				grant.setAuthNo(activeNewScanPayment.get("trade_no"));
				orderGrantService.save(grant);
				Map<String, Object> map = new HashMap<>();
				map.put("url", "");
				map.put("orderNo",orderNo);
				map.put("type", type);//1表示联动支付
				return R.data(map);
			} else{
				return R.fail(activeNewScanPayment.get("ret_msg"));
			}
/************************************第三方支付结束*************************************/
		}

		return R.fail("授权失败！");
	}

	@GetMapping("/pay_004")
	@ApiOperation(value = "资金授权操作查询接口", notes = "支付请求")
	@ApiOperationSupport(order = 3)
	public R pay004(@ApiParam(value = "订单号", required = true) @RequestParam String outTradeNo,
					@ApiParam(value = "查询明细，1查询冻结明细，2查询解冻明细,3查询支付明细时", required = true)
					@RequestParam Integer type) throws AlipayApiException {
		JSONObject data = new JSONObject();
		if(type == 1){ //查询冻结明细
			data.put("auth_no", outTradeNo);
			data.put("out_order_no", outTradeNo);
			data.put("operation_type","FREEZE");
		}else if(type == 2){ //查询解冻明细
			data.put("auth_no", outTradeNo);
			data.put("out_order_no", outTradeNo);
			data.put("operation_type","UNFREEZE");
		}else if(type == 3){ //查询支付明细时
			data.put("auth_no", outTradeNo);
			data.put("out_order_no", outTradeNo);
			data.put("operation_type","PAY");
		}else{
			return R.fail("参数错误！");
		}
		// 设置整体请求参数
		//APP支付
		AlipayFundAuthOperationDetailQueryRequest request = new AlipayFundAuthOperationDetailQueryRequest();
		request.setBizContent(data.toString());
		//APP支付
		AlipayFundAuthOperationDetailQueryResponse response = client.certificateExecute(request);
		if(response.isSuccess()){
			return R.data(response.getBody());
		}
		return R.fail("授权失败！");
	}

	@ApiLog("抢购打款-测试")
	@PostMapping("/pay_006")
	@ApiOperation(value = "单笔转账到支付宝账户", notes = "单笔转账到支付宝账户")
	@ApiOperationSupport(order = 5)
	public R pay006(@ApiParam(value = "id", required = true) @RequestParam String id,
					@ApiParam(value = "真实姓名", required = true) @RequestParam String name,
					@ApiParam(value = "金额", required = true) @RequestParam String amount) {
		transfer(id, amount, name);
		return R.fail("正在打款...");
	}

	@ApiLog("资金解冻")
	@GetMapping("/pay_unfreeze")
	@ApiOperation(value = "资金授权解冻", notes = "支付请求")
	@ApiOperationSupport(order = 3)
	public R payUnfreeze(@ApiParam(value = "支付宝资金授权订单号", required = true) @RequestParam String authNo,
						 @ApiParam(value = "解冻金额", required = true) @RequestParam Double amount) throws AlipayApiException {
		AlipayFundAuthOrderUnfreezeRequest request = new AlipayFundAuthOrderUnfreezeRequest();
		JSONObject bizContent = new JSONObject();
		bizContent.put("auth_no", authNo);
		bizContent.put("out_request_no","outRequestNo123");
		bizContent.put("amount", amount);
		bizContent.put("remark","解冻资金");
		JSONObject extraParam = new JSONObject();
		JSONObject unfreezeBizInfo = new JSONObject();
		unfreezeBizInfo.put("bizComplete",true);
		extraParam.put("unfreezeBizInfo",unfreezeBizInfo);
		bizContent.put("extra_param",extraParam);
		// 设置整体请求参数
		request.setBizContent(bizContent.toString());
		// 使用execute方法发起请求
		AlipayFundAuthOrderUnfreezeResponse response = client.certificateExecute(request);
		if(response.isSuccess()){
			logger.info("解冻资金成功", response.getBody());
			return R.fail("解冻资金成功！");
		}
		logger.info("解冻资金失败", response.getBody());
		return R.fail("解冻资金失败！");
	}

	@GetMapping("/getAlipay_sign")
	@ApiOperation(value = "获取签名", notes = "获取签名")
	@ApiOperationSupport(order = 97)
	public R getAlipaySign(@ApiParam(value = "scope", required = true) @RequestParam String scope,
						   @ApiParam(value = "verifyId", required = false) @RequestParam String verifyId) throws AlipayApiException, UnsupportedEncodingException {
		String content = "apiname=com.alipay.account.auth" +
			"&app_id=" + properties.getAppId() +
			"&app_name=mc" +
			"&auth_type=AUTHACCOUNT&biz_type=openservice" +
			"&method=alipay.open.auth.sdk.code.get" +
			"&pid=" + properties.getPayeeUserId() +
			"&product_id=APP_FAST_LOGIN" +
			"&scope=" +scope+
			"&sign_type=RSA2" +
			"&target_id=" + CommonUtil.genTimeID();
		if("id_verify".equals(scope)){
			content = content + "&cert_verify_id=" + verifyId;
		}
		String sign = AlipaySignature.rsaSign(content, properties.getPrivateKey(),"utf-8","RSA2");
		String urlencoder = URLEncoder.encode(sign,"UTF-8");
		return R.data(content + "&sign=" + urlencoder);
	}

	@ApiLog("获取支付宝用户信息")
	@GetMapping("/setAlipay_userInfo")
	@ApiOperation(value = "设置用户信息", notes = "设置用户信息")
	@ApiOperationSupport(order = 97)
	public R getAlipayUserinfo(@ApiParam(value = "用户ID", required = true) @RequestParam String userId,
							   @ApiParam(value = "支付宝用户ID", required = true) @RequestParam String aliPayUserId)  {
		UserApp userApp = new UserApp();
		UserApp query = userApp.selectOne(Wrappers.<UserApp>lambdaQuery().eq(UserApp::getUserId,userId));
		if (query == null){
			return R.fail("用户不存在");
		}
		UserApp param = new UserApp();
		param.setId(query.getId());
		param.setAlipayUserId(aliPayUserId);
		return R.status(param.updateById());
	}

	@ApiLog("平台付款预授权回调")
	@RequestMapping(value = "/platform_authorization_notify_url", method = {RequestMethod.GET, RequestMethod.POST})
	@ApiOperation(value = "异步通知相应-预授回调", notes = "异步通知相应")
	public void platformAuthorizationNotify(HttpServletRequest request){
		String errMsg = "预授回调";
		logger.info(errMsg, request.getParameterMap().toString());
		if (!NotifyUtils.rsaCheck(properties, request.getParameterMap())) {
			//这里处理验签失败
			log.info(errMsg + "-处理验签失败");
		}
		String status = request.getParameter("status");
		String auth_no = request.getParameter("auth_no");
		if (!"SUCCESS".equals(status)){
			log.info(errMsg + "-预授权失败");
		}
		String out_request_no = request.getParameter("out_request_no");
		LambdaQueryWrapper<PlatformAuthorization> query = Wrappers.lambdaQuery(PlatformAuthorization.class);
		query.eq(PlatformAuthorization::getOrderNo, out_request_no);
		PlatformAuthorization platformAuthorization = paMapper.selectOne(query);
		if(ObjectUtil.isNotNull(platformAuthorization)){
//			platformAuthorization.setAuthNo(auth_no);
			platformAuthorization.setState(1);
			paMapper.updateById(platformAuthorization);
		}

	}

	/**
	 * 发起支付宝预授权
	 *
	 * 1、判断用户是否能抢购
	 * 2、查询是否有寄售/进货单
	 * 3、发起支付宝预支付
	 * 4、请求成功 创建预支付订单 默认为未授权
	 * @param userId 用户id
	 * @param batNo 批次ID
	 * @param price 金额
	 * @param num 预授数量
	 * @return R
	 * @throws AlipayApiException
	 */
	@ApiLog("发起支付宝预授权")
	@PostMapping("/platfromAuth")
	@ApiOperation(value = "线上资金授权冻结接口-调用支付宝预授权", notes = "支付请求")
	@ApiOperationSupport(order = 3)
	public R<String> platfromAuth(@ApiParam(value = "用户号", required = true) @RequestParam Long userId,
								  @ApiParam(value = "批次ID", required = true) @RequestParam Long batNo,
								  @ApiParam(value = "金额", required = true) @RequestParam BigDecimal price,
								  @ApiParam(value = "数量", required = true) @RequestParam Integer num) throws AlipayApiException {
		UserApp userApp = new UserApp();
		UserApp query = userApp.selectOne(Wrappers.<UserApp>lambdaQuery().eq(UserApp::getUserId,userId));
		if (ObjectUtil.isNull(query)){
			return R.fail("该用户不存在！");
		}
		if (query.getEnableAuth() != 2){
			double k = (double)query.getCreditScore() / 100;
			int scoreCount = NumberUtil.roundDown(k, 2).intValue();
			int consignCount = Integer.parseInt(ParamCache.getValue(CommonConstant.DEFAULT_CONDIGN_COUNT));
			if (scoreCount > consignCount){
				scoreCount = consignCount;
			}
			if (scoreCount < num){
				return R.fail("预授数量不能大于单场可抢次数！");
			}
		}
		if(query.getState() != 1 ){
			return R.fail("该账号已冻结！");
		}

		JSONObject data = new JSONObject();
		String orderNo = CommonUtil.genTimeID();
		data.put("out_order_no", orderNo);
		data.put("out_request_no", orderNo);
		data.put("order_title","预授权冻结");
		data.put("amount", price.multiply(new BigDecimal(num)));
		data.put("product_code","PRE_AUTH_ONLINE"); //销售产品码。支付宝预授权产品固定为 PRE_AUTH_ONLINE
		data.put("payee_user_id", properties.getPayeeUserId());
		data.put("timeout_express","30m");
		//APP支付
		AlipayFundAuthOrderAppFreezeRequest request = new AlipayFundAuthOrderAppFreezeRequest();
		request.setNotifyUrl(properties.getDomain() + PLATFORM_URL); //异步通知地址
		request.setBizContent(data.toJSONString()); //业务参数
		//APP支付
		//必须使用 sdkExecute
		AlipayFundAuthOrderAppFreezeResponse response = client.sdkExecute(request);
		if(response.isSuccess()){
			PlatformAuthorization platformAuthorization = new PlatformAuthorization();
			platformAuthorization.setConsignConfigId(batNo);//场次id
//			platformAuthorization.setTotalNum(num);//授权数量
			platformAuthorization.setCreateUserId(getUser().getUserId());//创建用户id
			platformAuthorization.setState(0);//未授权
			platformAuthorization.setOrderNo(orderNo);//订单编号
			platformAuthorization.setAuthPrice(price.multiply(new BigDecimal(num)).setScale(2, BigDecimal.ROUND_DOWN));//订单金额
			platformAuthorization.setCreateTime(new Date());
			paMapper.insert(platformAuthorization);
			return R.data(response.getBody());
		}
		return R.fail("授权失败！");
	}

	@ApiLog("预授回调（新）")
	@RequestMapping(value = "/new_auth_notify_url", method = RequestMethod.GET)
	@ApiOperation(value = "异步通知相应-预授回调（新）", notes = "异步通知相应")
	@ApiOperationSupport(order = 99)
	public void authNotifyNew(HttpServletRequest request, HttpServletResponse response) {
		String errMsg = "预授回调";
		//获取联动发送请求的参数
		String requestParam =  request.getQueryString();
		System.out.println("请求参数 :" + requestParam);
		//调用异步通知解析方法
		UmfService service = merCallServiceSingleton.getInstance();
		Map respMap = null;
		try {
			respMap = service.notifyDataParserMap(requestParam);
			PaymentRecord paymentRecord = paymentRecordService.getOne(Wrappers.lambdaQuery(PaymentRecord.class).eq(PaymentRecord::getOrderNo, respMap.get("order_id").toString()));
			paymentRecord.setResponseJson(respMap.toString());
			if("TRADE_SUCCESS".equals(respMap.get("trade_state"))){
				OrderGrant grant = new OrderGrant();
				String out_request_no = respMap.get("order_id").toString();
				grant.setOrderNo(out_request_no);
				OrderGrant query = orderGrantService.getOne(Wrappers.<OrderGrant>lambdaQuery().eq(OrderGrant::getOrderNo,out_request_no));
				if (query == null){
					log.info(errMsg + "-查询预授权数据错误");
				}
				OrderGrant grantUpdate = new OrderGrant();
				grantUpdate.setId(query.getId());
				grantUpdate.setStatus(1);//已授权
				grantUpdate.setAuthNo(respMap.get("trade_no").toString());
				grantUpdate.setFreezeTime(DateUtil.now());
				boolean flg =  orderGrantService.updateById(grantUpdate);
				if (!flg){
					log.info(errMsg + "-更新数据失败");
				}
				paymentRecord.setStatus(1);
			}else{
				paymentRecord.setStatus(2);
			}
			paymentRecordService.updateById(paymentRecord);//更新付款记录为成功
		} catch (Exception e) {
			e.printStackTrace();
		}
		//调用SDK生成返回联动平台字符串，加到CONTENT中
		String resMetaData = service.responseUMFMap(respMap);
		response.setContentType("text/html;charset=utf-8");
		PrintWriter out = null;
		try {
			out = response.getWriter();
		} catch (IOException e) {
			e.printStackTrace();
		}
		out.println("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">");
			out.println("<HTML>");
			out.println("<HEAD><META NAME=\"MobilePayPlatform\" CONTENT=\"" + resMetaData + "\" /></HEAD>");
			out.println("<BODY>");
			out.println("</BODY>");
			out.println("</HTML>");
			out.flush();
			out.close();

	}

	@ApiLog("预授回调")
	@RequestMapping(value = "/auth_notify_url", method = {RequestMethod.GET, RequestMethod.POST})
	@ApiOperation(value = "异步通知相应-预授回调", notes = "异步通知相应")
	@ApiOperationSupport(order = 99)
	public String authNotify(HttpServletRequest request) throws AlipayApiException {
		String errMsg = "预授回调";
		logger.info(errMsg, request.getParameterMap().toString());
		log.info("预授回调参数[{}]", request.getParameterMap().toString());
		if (!NotifyUtils.rsaCheck(properties, request.getParameterMap(), true)) {
			//这里处理验签失败
			log.info(errMsg + "-处理验签失败");
			return "error";
		}
		String status = request.getParameter("status");
		String auth_no = request.getParameter("auth_no");
		if (!"SUCCESS".equals(status)){
			log.info(errMsg + "-预授权失败");
			return "error";
		}
		String out_request_no = request.getParameter("out_request_no");
		PaymentRecord paymentRecord = paymentRecordService.getOne(Wrappers.lambdaQuery(PaymentRecord.class).eq(PaymentRecord::getOrderNo, out_request_no));
		paymentRecord.setResponseJson(request.toString());
		if (out_request_no == null){
			log.info(errMsg + "-无法获取预授订单");
			return "error";
		}
		OrderGrant grant = new OrderGrant();
		grant.setOrderNo(out_request_no);
		OrderGrant query = orderGrantService.getOne(Wrappers.<OrderGrant>lambdaQuery().eq(OrderGrant::getOrderNo,out_request_no));
		if (query == null){
			log.info(errMsg + "-查询预授权数据错误");
			return "error";
		}
		paymentRecord.setStatus(1);
		paymentRecordService.updateById(paymentRecord);
		OrderGrant grantUpdate = new OrderGrant();
		grantUpdate.setId(query.getId());
		grantUpdate.setStatus(1);//已授权
		grantUpdate.setAuthNo(auth_no);
		grantUpdate.setFreezeTime(DateUtil.now());
		boolean flg =  orderGrantService.updateById(grantUpdate);
		if (!flg){
			log.info(errMsg + "-更新数据失败");
			return "error";
		}
		return "success";
	}

	@ApiLog("购物车购买支付宝回调")
	@RequestMapping(value = "/cart_order_notify_url", method = {RequestMethod.GET, RequestMethod.POST})
	@ApiOperation(value = "异步通知相应-购物车购买回调", notes = "异步通知相应,通知的间隔频率一般是：4m、10m、10m、1h、2h、6h、15h")
	@ApiOperationSupport(order = 100)
	public String cartOrderNotify(HttpServletRequest request) throws AlipayApiException {
		Order order = null;
		String outTradeNo = "";
		try {
			//获取支付宝POST过来反馈信息
			Map<String,String> params = new HashMap<>();
			Map requestParams = request.getParameterMap();
			for (Iterator iter = requestParams.keySet().iterator(); iter.hasNext ();) {
				String name =  ( String )iter.next();
				String[] values = (String[])requestParams.get(name);
				String valueStr="";
				for(int i = 0;i < values.length; i++){
					valueStr = (i== values.length-1)?valueStr+values[i]:valueStr+values[i] + ",";
				}
				//乱码解决，这段代码在出现乱码时使用。
				//valueStr = new String(valueStr.getBytes("ISO-8859-1"), "utf-8");
				params.put(name,valueStr);
			}
			log.info("params === " + params.toString());
			boolean flag = AlipaySignature.rsaCertCheckV1(params,properties.getAliPayCertPath(), AlipayConstants.CHARSET_UTF8,"RSA2");
			log.info("flag === " + flag);
			logger.info("购物车购买回调", "流水号: " + params.get("out_trade_no") + ",支付宝交易号:" + params.get("trade_no") + ",tradeStatus:" + params.get("trade_status"));
			if (!flag) {
				//这里处理验签失败
				log.info("处理验签失败");
				return "error";
			}
			outTradeNo = request.getParameter("out_trade_no");//获取请求参数中的商户订单号
			TransactionFlow flow = transactionFlowService.lambdaQuery().eq(TransactionFlow::getTransactionNo, outTradeNo).one();
			if (flow == null) {
				log.info("流水数据不存在[{}]", outTradeNo);
				return "error";
			}
			if (flow.getStatus() == 2) {
				log.info("该订单已支付[{}]", outTradeNo);
				return "error";
			}
			List<Order> list = orderService.lambdaQuery().eq(Order::getTransactionNo, outTradeNo).list();
			log.info("订单数量 [{}]", list.size());
			// 判断交易是否成功
			String tradeStatus = params.get("trade_status");
			// 交易成功
			if ("TRADE_SUCCESS".equals(tradeStatus)) {
				flow.setStatus(2);
				flow.setPaymentTime(new Date());
				flow.setPaymentType(PAY_CODE);
				transactionFlowService.updateById(flow);
				for (Order o : list) {
					order = o;
					log.info("当前处理订单号[{}], payFlag:[{}]", order.getOutTradeNo(), order.getPayFlag());
					orderService.payCommonSuccess(order, PAY_CODE);
				}
			}
			if ("TRADE_CLOSED".equals(tradeStatus)) { // 交易关闭
				flow.setStatus(3);
				flow.setCancelTime(new Date());
				transactionFlowService.updateById(flow);
				for (Order o : list) {
					orderService.lambdaUpdate().set(Order::getOrderState, 3).eq(Order::getId, o.getId()).update();
				}
			}
			return "success";
		} catch (Exception e) {
			log.error("支付宝支付回调异常, 订单号:" + outTradeNo + e.getMessage(), e);
			logger.error("支付宝支付回调异常", outTradeNo + e.getMessage());
			return "error";
		}
	}

	@ApiLog("支付宝购买回调")
	@RequestMapping(value = "/order_notify_url", method = {RequestMethod.GET, RequestMethod.POST})
	@ApiOperation(value = "异步通知相应-购买回调", notes = "异步通知相应,通知的间隔频率一般是：4m、10m、10m、1h、2h、6h、15h")
	@ApiOperationSupport(order = 100)
	public String orderNotify(HttpServletRequest request) throws AlipayApiException {
		Order order = null;
		String outTradeNo = "";
		try {
			String errMsg = "购买回调";
			//获取支付宝POST过来反馈信息
			Map<String,String> params = new HashMap<>();
			Map requestParams = request.getParameterMap();
			for (Iterator iter = requestParams.keySet().iterator(); iter.hasNext ();) {
				String name =  ( String )iter.next();
				String[] values = (String[])requestParams.get(name);
				String valueStr="";
				for(int i = 0;i < values.length; i++){
					valueStr = (i== values.length-1)?valueStr+values[i]:valueStr+values[i] + ",";
				}
				//乱码解决，这段代码在出现乱码时使用。
				//valueStr = new String(valueStr.getBytes("ISO-8859-1"), "utf-8");
				params.put(name,valueStr);
			}
			log.info("params === " + params.toString());
			//切记alipayPublicCertPath是支付宝公钥证书路径，请去open.alipay.com对应应用下载。
			//boolean AlipaySignature.rsaCertCheckV1(Map<String, String> params, String publicKeyCertPath, String charset,String signType)
			boolean flag = AlipaySignature.rsaCertCheckV1(params,properties.getAliPayCertPath(), AlipayConstants.CHARSET_UTF8,"RSA2");
			log.info("flag === " + flag);
			logger.info("支付宝购买回调", "订单号: " + params.get("out_trade_no") + ",支付宝交易号:" + params.get("trade_no") + ",tradeStatus:" + params.get("trade_status"));
			if (!flag) {
				//这里处理验签失败
				log.info(errMsg + "-处理验签失败");
				return "error";
			}
			outTradeNo = request.getParameter("out_trade_no");//获取请求参数中的商户订单号
			order = orderService.getOne(Wrappers.<Order>lambdaQuery().eq(Order::getOutTradeNo, outTradeNo));
			if (order == null){
				log.info(errMsg + "-订单无数据");
				return "error";
			}
			// 判断交易是否成功
			String tradeStatus = params.get("trade_status");
			// 交易成功
			if ("TRADE_SUCCESS".equals(tradeStatus)) {
				paymentRecordService.success(outTradeNo);
				//当等于充值订单时修改充值表的状态
				if(order.getOrderType() == 5){
					PlatformAuthorization platformAuthorization = new PlatformAuthorization();
					platformAuthorization.setState(1);
					paMapper.update(platformAuthorization, Wrappers.lambdaQuery(PlatformAuthorization.class)
						.eq(PlatformAuthorization::getOrderNo, order.getOutTradeNo()));
				}
				//寄售和购买
				orderService.payCommonSuccess(order, PAY_CODE);
			}
			if ("TRADE_CLOSED".equals(tradeStatus)) { // 交易关闭
				orderService.lambdaUpdate().set(Order::getOrderState, 3).eq(Order::getId, order.getId()).update();
			}
			return "success";
		} catch (Exception e) {
			log.error("支付宝支付回调异常, 订单号:" + outTradeNo + e.getMessage(), e);
			logger.error("支付宝支付回调异常", outTradeNo + e.getMessage());
			return "error";
		}
	}

	@ApiLog("进货回调")
	@RequestMapping(value = "/trade_notify_url", method = {RequestMethod.GET, RequestMethod.POST})
	@ApiOperation(value = "异步通知相应-进货回调", notes = "异步通知相应")
	@ApiOperationSupport(order = 100)
	public String tradeNotify(HttpServletRequest request) {
		String errMsg = "进货回调";//抢购改为进货
		log.info(errMsg, request.getParameterMap().toString());
		if (!NotifyUtils.rsaCheck(properties, request.getParameterMap())) {
			//这里处理验签失败
			log.info(errMsg + "-处理验签失败" + request.getParameterMap());
			//打款失败
			return "error";
		}
		String out_trade_no = request.getParameter("out_trade_no");//获取请求参数中的商户订单号
		log.info(errMsg, "out_trade_no == " + out_trade_no);
		Order order = orderService.getOne(Wrappers.<Order>lambdaQuery().eq(Order::getOutTradeNo, out_trade_no));
		if (ObjectUtil.isNull(order)){
			log.info(errMsg + "-订单无数据");
			return "error";
		}
		if(order.getOrderType() == 3){
			log.info(errMsg, "寄售订单 == " + order.getOrderType());
			//查询寄售订单信息
			OrderConsign orderConsign  = orderConsignService.getOne(Wrappers.<OrderConsign>lambdaQuery().eq(OrderConsign::getOutTradeNo, out_trade_no));
			log.info(errMsg, "寄售商品号", orderConsign);
			if (ObjectUtil.isNull(orderConsign)){
				log.info(errMsg + "-寄售订单无数据");
				return "error";
			}
			//寄售金额
			Double price = orderConsign.getConsignPrice();
			//查询寄售订单中的寄售人
			Consign consign  = consignService.getOne(Wrappers.<Consign>lambdaQuery().eq(Consign::getId, orderConsign.getConsignId()));
			if (ObjectUtil.isNull(consign)){
				log.info(errMsg + "-寄售无数据");
				return "error";
			}
			//授权号
			String body = request.getParameter("body");
			OrderGrant orderGrant = orderGrantService.getOne(Wrappers.<OrderGrant>lambdaQuery().eq(OrderGrant::getAuthNo, body));
			if (orderGrant != null){
				logger.info(errMsg + "-授权无数据", orderGrant.toString());
				//以单个授权金额为准
				if (!Objects.equals(price, orderGrant.getPrice())){
					price = orderGrant.getPrice();
				}
			}
			log.info(errMsg + "-body：" + body);
			//寄售来源为后台 不打款 订单的打款 2是订单
			if (consign.getConsignFor() == 2){
				//判断商品抢购价和进货价是否产生收益
				if(consign.getObtainPrice() < consign.getConsignPrice()){
					//收益金额 收益金额等于抢购价减去取得价
					BigDecimal bigDecimal = new BigDecimal(price).subtract(new BigDecimal(consign.getObtainPrice())).setScale(2, BigDecimal.ROUND_HALF_UP);
					//获取配置参数
					BigDecimal taxRatio = new BigDecimal(ParamCache.getValue(CommonConstant.PLATFORM_TAX_RATIO));
					//税费金额
					BigDecimal bigDecimal1 = bigDecimal.multiply(taxRatio).setScale(2, BigDecimal.ROUND_HALF_UP);
					//收款金额需扣除税费
					price = new BigDecimal(consign.getConsignPrice()).subtract(bigDecimal1).setScale(2, BigDecimal.ROUND_DOWN).doubleValue();
				}
				//获取寄售人信息
				UserApp userApp = new UserApp();
				UserApp query = userApp.selectOne(Wrappers.<UserApp>lambdaQuery().eq(UserApp::getUserId,consign.getConsignUserId()));
				//transfer(query, Double.toString(price), orderConsign.getId());
			}else{
				log.info(errMsg, "寄售来源为后台  == 无需打款" );
				OrderConsign updateConsign = new OrderConsign();
				updateConsign.setId(orderConsign.getId());
				updateConsign.setConfirmTime(DateUtil.now());
				updateConsign.setIsConfirm(4);
				updateConsign.setBody("平台无需打款");
				orderConsignService.updateById(updateConsign);
			}
		}else{
			log.info(errMsg + "-购买订单回调");
		}
		//修改订单状态
		orderService.payCommonSuccess(order,PAY_CODE);
		return "success";
	}

	/**
	 * 用户仓单收款
	 * 1、向用户打款
	 * 2、修改寄售订单金额
	 * @param name 用户
	 * @param transAmount 金额
	 */
	public void transfer(String identity, String transAmount, String name){
		try {
//			String privateKey = properties.getPrivateKey();
//			String alipayPublicKey = properties.getAlipayPublicKey();
//			AlipayConfig alipayConfig = new AlipayConfig();
//			alipayConfig.setServerUrl("https://openapi.alipay.com/gateway.do");
//			alipayConfig.setAppId("2021003125657245");
//			alipayConfig.setPrivateKey(privateKey);
//			alipayConfig.setFormat("json");
//			alipayConfig.setAlipayPublicKey(alipayPublicKey);
//			alipayConfig.setCharset("UTF8");
//			alipayConfig.setSignType("RSA2");
//			//设置应用公钥证书路径//appCertPublicKey_2021003125657245
//			alipayConfig.setAppCertPath(properties.getAppCertPath());
//			//设置支付宝公钥证书路径//alipayCertPublicKey_RSA2
//			alipayConfig.setAlipayPublicCertPath(properties.getAliPayCertPath());
//			//设置支付宝根证书路径
//			alipayConfig.setRootCertPath(properties.getAliPayRootCertPath());
//			AlipayClient alipayClient = new DefaultAlipayClient(alipayConfig);
			AlipayFundTransUniTransferModel model = new AlipayFundTransUniTransferModel();
			model.setOutBizNo(CommonUtil.genTimeID());
			model.setRemark("贵州中宏科技有限公司进货仓单收款");
			model.setBusinessParams("{\"payer_show_name_use_alias\":\"true\"}");
			model.setBizScene("DIRECT_TRANSFER");
			Participant payeeInfo = new Participant();
			payeeInfo.setIdentity(identity);
			payeeInfo.setIdentityType("ALIPAY_USER_ID");
			payeeInfo.setName(name);
			model.setPayeeInfo(payeeInfo);
			model.setTransAmount(transAmount);
			model.setProductCode("TRANS_ACCOUNT_NO_PWD");
			model.setOrderTitle("进货仓单收款");
			AlipayFundTransUniTransferRequest request = new AlipayFundTransUniTransferRequest();
			request.setBizModel(model);
			AlipayFundTransUniTransferResponse response = client.certificateExecute(request);
			if (!response.isSuccess()){
				log.info("向用户【" + name +"】打款失败，打款账号："  + identity);
				logger.info("打款失败", ",打款人：" + name + "支付宝账号：" + identity);
			}else{
				log.info("向用户【" + name +"】打款成功，打款账号："  + identity);
				logger.info("打款成功", ",打款人：" + name + "支付宝账号：" + identity);
			}
		} catch (AlipayApiException e) {
			e.printStackTrace();
			String msg = "打款失败, ,打款人：" + name + "支付宝账号：" + identity;
			logger.info(msg, e.getMessage());
			logger.info("打款失败", ",打款人：" + name + "支付宝账号：" + identity);
		}

	}

	/**
	 * 用户仓单收款
	 * 1、向用户打款
	 * 2、修改寄售订单金额
	 * @param user 用户
	 * @param transAmount 金额
	 * @param orderConsignId 寄售（进货）Id
	 */
	private void transfer(UserApp user, String transAmount, Long orderConsignId){
		OrderConsign orderConsign = new OrderConsign();
		orderConsign.setId(orderConsignId);
		orderConsign.setConfirmTime(DateUtil.now());
		if (user == null){
			orderConsign.setIsConfirm(3);//异常
			orderConsign.setBody("该用户不存在");
			orderConsignService.updateById(orderConsign);
			return;
		}
		if (StringUtil.isEmpty(user.getAlipayUserId())){
			orderConsign.setIsConfirm(3);//异常
			orderConsign.setBody("用户【" + user.getUserId() +" 】无支付宝账号数据");
			orderConsignService.updateById(orderConsign);
			return;
		}
		User u = userService.getById(user.getUserId());
		if (u == null){
			orderConsign.setIsConfirm(3);//异常
			orderConsign.setBody("该用户不存在,可能被删除或者冻结");
			orderConsignService.updateById(orderConsign);
			return;
		}
		if (StringUtil.isEmpty(u.getRealName())){
			orderConsign.setIsConfirm(3);//异常
			orderConsign.setBody("该用户无法获取真实名字");
			orderConsignService.updateById(orderConsign);
			return;
		}
		String identity = user.getAlipayUserId();
		String name = u.getRealName();
		try {
//			String privateKey = properties.getPrivateKey();
//			String alipayPublicKey = properties.getAlipayPublicKey();
//			AlipayConfig alipayConfig = new AlipayConfig();
//			alipayConfig.setServerUrl("https://openapi.alipay.com/gateway.do");
//			alipayConfig.setAppId("2021003125657245");
//			alipayConfig.setPrivateKey(privateKey);
//			alipayConfig.setFormat("json");
//			alipayConfig.setAlipayPublicKey(alipayPublicKey);
//			alipayConfig.setCharset("UTF8");
//			alipayConfig.setSignType("RSA2");
//			//设置应用公钥证书路径//appCertPublicKey_2021003125657245
//			alipayConfig.setAppCertPath(properties.getAppCertPath());
//			//设置支付宝公钥证书路径//alipayCertPublicKey_RSA2
//			alipayConfig.setAlipayPublicCertPath(properties.getAliPayCertPath());
//			//设置支付宝根证书路径
//			alipayConfig.setRootCertPath(properties.getAliPayRootCertPath());
//			AlipayClient alipayClient = new DefaultAlipayClient(alipayConfig);
			AlipayFundTransUniTransferModel model = new AlipayFundTransUniTransferModel();
			model.setOutBizNo(CommonUtil.genTimeID());
			model.setRemark("贵州中宏科技有限公司进货仓单收款");
			model.setBusinessParams("{\"payer_show_name_use_alias\":\"true\"}");
			model.setBizScene("DIRECT_TRANSFER");
			Participant payeeInfo = new Participant();
			payeeInfo.setIdentity(identity);
			payeeInfo.setIdentityType("ALIPAY_USER_ID");
			payeeInfo.setName(name);
			model.setPayeeInfo(payeeInfo);
			model.setTransAmount(transAmount);
			model.setProductCode("TRANS_ACCOUNT_NO_PWD");
			model.setOrderTitle("进货仓单收款");
			AlipayFundTransUniTransferRequest request = new AlipayFundTransUniTransferRequest();
			request.setBizModel(model);
			AlipayFundTransUniTransferResponse response = client.certificateExecute(request);
			if (!response.isSuccess()){
				log.info("向用户【" + name +" 】打款失败，打款账号："  + identity);
				logger.info("打款失败", ",打款人：" + name + "支付宝账号：" + identity);
				orderConsign.setBody("向用户【" + name +" 】打款失败，打款账号："  + identity);
				orderConsign.setIsConfirm(3);//异常
			}else{
				log.info("向用户【" + name +" 】打款成功，打款账号："  + identity);
				logger.info("打款成功", ",打款人：" + name + "支付宝账号：" + identity);
				orderConsign.setBody("向用户【" + name +" 】打款成功，打款账号："  + identity);
				orderConsign.setIsConfirm(2);//确认
			}
			orderConsignService.updateById(orderConsign);
		} catch (AlipayApiException e) {
			e.printStackTrace();
			logger.info("打款失败", ",打款人：" + name + "支付宝账号：" + identity);
			orderConsign.setIsConfirm(3);//异常
			orderConsign.setBody(e.getMessage());
			orderConsignService.updateById(orderConsign);
		}

	}
}
