/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.api.controller;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alipay.api.AlipayApiException;
import com.alipay.api.AlipayClient;
import com.alipay.api.request.AlipayTradePayRequest;
import com.alipay.api.response.AlipayTradePayResponse;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.constant.ConsignConstant;
import org.springblade.common.enums.*;
import org.springblade.common.utils.CommonUtil;
import org.springblade.common.utils.DateTimeUtil;
import org.springblade.common.utils.RedisTool;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.log.annotation.ApiLog;
import org.springblade.core.log.exception.ServiceException;
import org.springblade.core.log.logger.BladeLogger;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.redis.cache.BladeRedis;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.StringUtil;
import org.springblade.core.tool.utils.WebUtil;
import org.springblade.modules.api.param.StatisticsConsignParam;
import org.springblade.modules.api.request.*;
import org.springblade.modules.api.response.AliUserInfoResponse;
import org.springblade.modules.api.response.ConsignResponse;
import org.springblade.modules.api.service.AliFaceService;
import org.springblade.modules.api.service.IAliService;
import org.springblade.modules.api.service.ITradeService;
import org.springblade.modules.api.vo.LogisticVO;
import org.springblade.modules.api.vo.StatisticsConsignVO;
import org.springblade.modules.auth.utils.TokenUtil;
import org.springblade.modules.finance.entity.*;
import org.springblade.modules.finance.mapper.PlatformAuthorizationMapper;
import org.springblade.modules.finance.pay.entity.AlipayProperties;
import org.springblade.modules.finance.service.IOrderConsignService;
import org.springblade.modules.finance.service.IOrderGrantService;
import org.springblade.modules.finance.service.IOrderService;
import org.springblade.modules.finance.service.impl.OrderGoodsServiceImpl;
import org.springblade.modules.finance.vo.OrderGrantVO;
import org.springblade.modules.finance.vo.OrderVO;
import org.springblade.modules.finance.wrapper.OrderWrapper;
import org.springblade.modules.platform.entity.UserCardInfo;
import org.springblade.modules.platform.service.IUserCardInfoService;
import org.springblade.modules.platform.service.UserAppService;
import org.springblade.modules.redenvelopemall.entity.GoodsInfo;
import org.springblade.modules.redenvelopemall.entity.GoodsSpec;
import org.springblade.modules.redenvelopemall.service.IGoodsInfoService;
import org.springblade.modules.redenvelopemall.service.IGoodsSpecService;
import org.springblade.modules.redenvelopemall.service.ISupplyChainService;
import org.springblade.modules.redenvelopemall.service.IWeiPinShangService;
import org.springblade.modules.shopping.entity.Consign;
import org.springblade.modules.shopping.entity.PaymentRecord;
import org.springblade.modules.shopping.service.IConsignService;
import org.springblade.modules.shopping.service.IPaymentRecordService;
import org.springblade.modules.shopping.service.RemitRecordService;
import org.springblade.modules.shopping.vo.ConsignListVO;
import org.springblade.modules.shopping.vo.ConsignVO;
import org.springblade.modules.shopping.wrapper.ConsignWrapper;
import org.springblade.modules.system.entity.NowMoneyRecord;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.entity.UserApp;
import org.springblade.modules.system.entity.WithdrawalAccelerateRecord;
import org.springblade.modules.system.mapper.UserAppMapper;
import org.springblade.modules.system.mapper.WithdrawalAccelerateRecordMapper;
import org.springblade.modules.system.param.RecordParam;
import org.springblade.modules.system.service.INowMoneyRecordService;
import org.springblade.modules.system.service.IUserService;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 控制器
 *
 * @author xuwei
 * @since 2021-12-23
 */
@RestController
@RequestMapping(CommonConstant.API_URL)
@Api(value = "订单模块", tags = "05.订单模块")
public class AppOrderController extends BladeController {

	private static final Logger log = LoggerFactory.getLogger(AppOrderController.class);
	@Resource
	private IOrderService orderService;
	@Resource
	private IConsignService consignService;
	@Resource
	private IOrderConsignService orderConsignService;
	@Resource
	private IUserCardInfoService userCardInfoService;

	@Resource
	private ITradeService iTradeService;

	@Resource
	private RemitRecordService recordService;

	@Resource
	private IOrderGrantService orderGrantService;

	@Resource
	private PlatformAuthorizationMapper paMapper;

	@Resource
	private UserAppMapper userAppMapper;

	@Resource
	private IUserService userService;

	@Resource
	private AliFaceService aliFaceService;

	@Resource
	private BladeLogger logger;

	@Resource
	private OrderGoodsServiceImpl orderGoodsService;

	@Resource
	private IAliService aliService;

	@Resource
	private ISupplyChainService supplyChainService;

	@Resource
	private IGoodsSpecService goodsSpecService;
	@Resource
	private IGoodsInfoService goodsInfoService;
	@Resource
	private IWeiPinShangService weiPinShangService;

	@Resource
	private INowMoneyRecordService nowMoneyRecordService;

	@Resource
	private WithdrawalAccelerateRecordMapper accMapper;

	//抢购
	private static final String TRADE_URL = "/api/v1/aliPay/sdk/trade_notify_url";
	@Resource(name = "alipayClient")
	private AlipayClient client;//支付宝请求sdk客户端

	@Resource
	private AlipayProperties properties;//支付宝sdk配置

	@Resource
	private IPaymentRecordService paymentRecordService;//付款记录

	@Resource
	private BladeRedis bladeRedis;

	@Resource
	private UserAppService userAppService;

	@Resource
	private RedisTool redisTool;

	@PostMapping("/finance/order-commonSave")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "购买商品", notes = "传入用户ID")
	public R orderCommonSave(@Valid @RequestBody OrderCommonSaveRequest request) {
		//租户号
		String tenantId = WebUtil.getRequest().getHeader(TokenUtil.TENANT_HEADER_KEY);
		if (StringUtil.isEmpty(request.getDistributeMode())) {
			request.setDistributeMode(2); //物流配送
		}
		if (StringUtil.isEmpty(request.getUserId())) {
			return R.fail("请求参数错误！");
		}
		if (request.getGoodsList() == null || request.getGoodsList().size() == 0) {
			return R.fail("请选择购买的商品！");
		}
		return R.data(orderService.commonOrderInsert(request, tenantId));
	}

	@GetMapping("/fixData")
	public R fixData(@RequestParam Long configId) {
		List<Consign> consigns = consignService.getBaseMapper().selectList(Wrappers.<Consign>lambdaQuery()
			.eq(Consign::getConsignConfigId, configId)
			.eq(Consign::getConsignFor, 2));
		String str = "缓存最新场次用户单数据, 场次id：[" + configId + "], 用户单数量: [" + consigns.size() + "]";
		log.info("缓存最新场次用户单数据, 场次id：[{}], 用户单数量: [{}]", configId, consigns.size());
		if (CollUtil.isNotEmpty(consigns)) {
			for (Consign consign : consigns) {
				log.info("添加缓存数据 id [{}]", consign.getId());
				bladeRedis.lPush(ConsignConstant.CONSIGN_CACHE + configId, JSON.toJSONString(consign));
			}
		}
		return R.success(str);
	}

	@PostMapping("/finance/order-consignRandom")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "寄售抢购", notes = "抢购订单")
	@Transactional(rollbackFor = Exception.class)
	public R consignRandom(@RequestBody OrderConsignRandomRequest request) {
		String tenantId = WebUtil.getRequest().getHeader(TokenUtil.TENANT_HEADER_KEY);
		UserApp userApp = new UserApp();
		UserApp query = userApp.selectOne(Wrappers.<UserApp>lambdaQuery().eq(UserApp::getUserId, request.getUserId()));
		if (query == null) {
			return R.fail("该用户不存在");
		}
		if (query.getState() != 1) {
			return R.fail("登录账号已冻结");
		}
		if (query.getCreditScore() < 100) {
			return R.fail("您的信誉分不够");
		}
		if (StringUtil.isEmpty(query.getAlipayUserId())) {
			return R.fail("请绑定支付宝打款账号");
		}
		if (query.getTicket() < 100) {
			throw new ServiceException("您的绿色积分达不到要求！");
		}
		//判断用户授权
		ConsignResponse response = orderService.consignGrant(query, request.getConsignConfigId(), request.getOrderNo());
		if (response.getStatus() == 2) {
			//已授权则生成订单
			String outTradeNo = orderService.consignOrderInsert(request, query, tenantId);
			if (!StringUtil.isEmpty(outTradeNo)) {
				//通过订单号获取授权信息
				OrderGrant orderGrant = orderGrantService.getOne(Wrappers.<OrderGrant>lambdaQuery().eq(OrderGrant::getOrderNo, request.getOrderNo()));
				//重新查询返回是否授权
				response = orderService.consignGrant(query, request.getConsignConfigId(), request.getOrderNo());
				//返回订单号
				response.setOutTradeNo(outTradeNo);
				//获取当前订单信息
				OrderConsign orderConsign = orderConsignService.getOne(Wrappers.lambdaQuery(OrderConsign.class).eq(OrderConsign::getOutTradeNo, outTradeNo));

				//查询寄售商品
				Consign consign = consignService.getById(orderConsign.getConsignId());
				//收款金额 默认等于抢购金额
				BigDecimal collectionPrice = new BigDecimal(consign.getConsignPrice());

				//使用收款账户进行打款
				boolean flg = orderConsign(outTradeNo, request.getOrderNo(), collectionPrice.doubleValue());

				if (flg) {//是否发起统一收单
					//修改授权状态
					flg = orderGrantService.thaw(orderGrant);//flg = true
					if (!flg) {
						log.info("授权授权信息修改失败");
						throw new ServiceException("亲！请重新抢单");
					}
					return R.data(response);
				}
				throw new ServiceException("亲！请重新抢单");
			}
		}
		//判断用户授权
		return R.data(response);
	}

	@PostMapping("checkSystemPay")
	@ApiOperation(value = "系统特殊用户付款")
	public synchronized R checkSystemPay(@RequestBody SystemUserPayRequest payRequest) {
		if (ObjectUtil.isNull(payRequest)) {
			return R.fail("参数传递为null");
		}
		if (payRequest.getOrderConsignIds().size() < 1) {
			return R.fail("请选择打款订单");
		}
		List<OrderConsign> list = orderConsignService.list(Wrappers.lambdaQuery(OrderConsign.class)
			.in(OrderConsign::getId, payRequest.getOrderConsignIds())
			.eq(OrderConsign::getIsRemittance, 0));
		for (OrderConsign orderConsign : list) {
			Consign consign = consignService.getById(orderConsign.getConsignId());
			RecordParam recordParam = new RecordParam();
			recordParam.setChargeAmount(new BigDecimal(consign.getConsignPrice()).multiply(new BigDecimal(0.006)).setScale(2, BigDecimal.ROUND_UP));
			//特殊账号收款用户id
			recordParam.setUserId(payRequest.getPaymentUserId());
			//打款订单id
			recordParam.setDataId(orderConsign.getId());
			recordParam.setFluctuantAmount(new BigDecimal(consign.getConsignPrice()).setScale(2, BigDecimal.ROUND_UP));
			recordParam.setMoneySourceEnum(MoneySourceEnum.SPECIAL_REFUND);
			recordParam.setTaxAmount(new BigDecimal(0));
			Map<String, Object> map = nowMoneyRecordService.insertRecord(recordParam);
			if ((Boolean) map.get("flag")) {
				orderConsign.setIsRemittance(1);
				orderConsignService.updateById(orderConsign);
			}
		}
		return R.success("确认付款成功");
	}

	@PostMapping("checkConsignPay")
	@ApiOperation(value = "确认付款id")
	public synchronized R checkConsignPay(@RequestBody ConsignPayRequest payRequest) {
		try {
			if (payRequest.getPayType() == 1) {
				if (!redisTool.getRedisLock(payRequest.getConsignConfigId().toString(), AuthUtil.getUserId().toString())) {
					return R.fail("正在付款中请勿重复操作");
				}
			}
			if (ObjectUtil.isNull(payRequest)) {
				return R.fail("参数传递为null");
			}
			if (payRequest.getConsignId().size() < 1 && payRequest.getPayType() == 0) {
				return R.fail("请选择打款订单");
			}
			if (0 == payRequest.getPayType()) {//等于0时进行打款操作
				List<Consign> consigns = payRequest.getOrderConsignIds();
				consignService.checkConsignPay(consigns);
				return R.success("确认付款成功");
			} else if (1 == payRequest.getPayType()) {
				List<Consign> consigns = checkConsign(payRequest.getConsignConfigId(), false);
				consignService.checkConsignPay(consigns);
				redisTool.unRedisLock(payRequest.getConsignConfigId().toString());
				return R.success("确认付款成功");
			} else {
				return R.fail("当前不支持特殊用户打款");
			}
		} catch (Exception e) {
			return R.fail("一键打款失败请稍后再试!");
		} finally {//最后进行解锁
			if (payRequest.getPayType() == 1) {
				redisTool.unRedisLock(payRequest.getConsignConfigId().toString());
			}
		}
	}

	@PostMapping("countRecomAndTeamConsign")
	@ApiOperation(value = "购买人数统计")
	public R<List<Map<String, String>>> countRecomAndTeamConsign(@ApiParam(value = "寄售id", required = true) @RequestParam Long consignId) {
		Consign consign = consignService.getById(consignId);
		if (ObjectUtil.isNull(consign)) {
			return R.fail("查询有误");
		}
		List<Map<String, String>> maps = userService.countRecomAndTeamConsign(consign.getConsignUserId(), consign.getCreateTime(), consign.getConsignConfigId());
		return R.data(maps);
	}

	/**
	 * @return
	 */
	@PostMapping("getConsignListByConfigId")
	@ApiOperation(value = "查询场次付款记录")
	public R<List<Consign>> getConsignListByConfigId(@ApiParam(value = "批次ID", required = true) @RequestParam Long consignConfigId, @RequestParam(value = "isSearchAll", required = false, defaultValue = "true") Boolean isSearchAll) {
		return R.data(checkConsign(consignConfigId, isSearchAll));
	}

	/**
	 * 通过场次id筛选出需要付款的用户订单
	 *
	 * @param consignConfigId
	 * @param isSearchAll
	 * @return
	 */
	public List<Consign> checkConsign(Long consignConfigId, Boolean isSearchAll) {
		List<Consign> list = consignService.getConsignListByConfigId(consignConfigId);
		//获取用户id
		List<Long> collect = list.stream().map(Consign::getConsignUserId).collect(Collectors.toList());
		if (!isSearchAll) {
			collect = collect.stream().distinct().collect(Collectors.toList());
			Date consignDate = list.get(0).getCreateTime();
			int count = DateTimeUtil.diffDay(new Date(), consignDate);
			if (list.size() > 0 && count < 5) {
				List<Long> newList = new ArrayList<>();//符合活动的用户
				if (count >= 2) {//活动用户判断
					newList = userService.getNewList(collect);
					collect.removeAll(newList);
				}
				if (count == 4) {//T4  大于等于5个直推创客或者红色积分达到2万以上
					//查询出红色积分两万以上的客户
					List<UserApp> list1 = userAppService.list(Wrappers.lambdaQuery(UserApp.class).in(UserApp::getUserId, collect).ge(UserApp::getIntegral, 20000));
					List<Long> collect1 = list1.stream().map(UserApp::getUserId).collect(Collectors.toList());
					//将两万以上的客户先移除用户列表
					collect.removeAll(collect1);
					if(collect.size() > 0){
						//筛选满足直推创客的用户
						collect = userService.getMakerList(collect, 5);//满足直推创客人数的人员
						//再将两者进行合并
						collect.addAll(collect1);
					}
				}
				if (count == 3) {//T3  大于等于10个创客  团队实名注册20人  当天至少直推5人以上进货一单，团队当天8人以上进货一单，红色积分不低于1万。
					collect = checkUser(collect, 10, new BigDecimal(10000), 3, 8, consignDate);
				}
				if (count == 2) {//T2   大于等于20个创客  团队实名注册40人         直推当天进货8人进货一单，  团队当天15人进货一单，红色积分不低于2万。
					collect = checkUser(collect, 20, new BigDecimal(20000), 8, 15, consignDate);
				}
				if (count == 1) {//T1  大于等于30个创客，直推15人当天进货一单，团队当天30人以上进货，红色积分不低于3万。
					collect = checkUser(collect, 30, new BigDecimal(30000), 15, 30, consignDate);
				}
				if (newList.size() > 0) {//将满足活动的用户加入打款列表
					collect.addAll(newList);
				}
				List<Long> userIds = collect;
				list = list.stream().filter(t -> userIds.contains(t.getConsignUserId())).collect(Collectors.toList());
			}
		}
		if (ObjectUtil.isEmpty(list)) {
			return list;
		}
		List<User> users = userService.listByIds(collect);
		for (Consign consign : list) {
			List<User> first = users.stream().filter(s -> s.getId().equals(consign.getConsignUserId())).collect(Collectors.toList());
			if (CollUtil.isNotEmpty(first)) {
				User user = first.get(0);
				consign.setConsignUserName(user.getRealName());
				consign.setConsignUserPhone(user.getPhone());
			}
		}

		return list;
	}

	/**
	 * 筛选瞒住人员的名单id
	 *
	 * @param collect         用户id列表
	 * @param makerNum        满足创客人数
	 * @param integral        满足红色积分的数量
	 * @param teamConsingNum  满足团队购买人数
	 * @param recomConsignNum 满足直推购买人数
	 * @param consignDate     购买时间
	 * @return
	 */
	public List<Long> checkUser(List<Long> collect, Integer makerNum, BigDecimal integral, Integer recomConsignNum, Integer teamConsingNum, Date consignDate) {
		collect = userService.getMakerList(collect, 10);//满足直推创客人数的人员
		if (collect.size() > 0) {//每一步都需要判断是否有人员满足
			collect = userService.getTeamList(collect, makerNum);//满足团队实名注册的人员
		}
		if (collect.size() > 0) {
			collect = userService.getRecomConsignList(collect, recomConsignNum, consignDate);//判断满足直推购买人数的人员
		}
		if (collect.size() > 0) {
			collect = userService.getTeamConsignList(collect, teamConsingNum, consignDate);//判断满足团队购买人数的人员
		}
		if (collect.size() > 0) {
			//查询出红色积分两万以上的客户
			List<UserApp> list1 = userAppService.list(Wrappers.lambdaQuery(UserApp.class).in(UserApp::getUserId, collect).lt(UserApp::getIntegral, integral));
			if (list1.size() > 0) {
				List<Long> collect1 = list1.stream().map(UserApp::getUserId).collect(Collectors.toList());
				//将两万以下的客户先移除用户列表
				collect.removeAll(collect1);
			}

		}
		return collect;
	}

	/**
	 * @return
	 */
	@PostMapping("rollBackGrant")
	@ApiOperation(value = "通过用户id查询用户授权单号进行解冻，解冻今天之前的订单")
	public R rollBackGrant(@ApiParam(value = "用户ID", required = true) @RequestParam String userId) {
		List<OrderGrant> list = orderGrantService.list(Wrappers.<OrderGrant>lambdaQuery()
			.lt(OrderGrant::getCreateTime, new SimpleDateFormat("yyyy-MM-dd").format(new Date()).toString() + " 00:00:00")
			.eq(OrderGrant::getUserId, userId)
			.isNotNull(OrderGrant::getAuthNo)
		);
		log.info("已授权冻结的数据：" + list.size());
		if (list.size() > 0) {
			iTradeService.orderGrantNow(list);
		}
		return R.success("解冻成功");
	}

	/**
	 * @return
	 */
	@PostMapping("getConsignALLList")
	@ApiOperation(value = "查询付款授权场次")
	public R<List<ConsignListVO>> getConsignALLList(StatisticsConsignParam param) {
		return R.data(consignService.findOderConsignList(param));
	}


	@PostMapping("getConsignGrant")
	@ApiOperation(value = "查询预授权订单状态")
	public R<List<OrderGrantVO>> getConsignGrant(@ApiParam(value = "电话", required = false) @RequestParam(required = false) String account,
												 @ApiParam(value = "查询时间", required = false) @RequestParam(required = false) String searchDate,
												 @ApiParam(value = "退款列表查询", required = false) @RequestParam Integer returnStuts) {
		if (StringUtil.isEmpty(account) && returnStuts == 0) {
			return R.fail("电话号码不能为空");
		}
		if (StringUtil.isEmpty(searchDate) && returnStuts == 0) {
			return R.fail("查询时间不能为空不能为空");
		}
		return R.data(orderGrantService.getByAccount(account, searchDate, returnStuts));
	}

	@PostMapping("confirmRefund")
	@ApiOperation(value = "确认退款，修改预授权订单状态")
	public R confirmRefund(@ApiParam(value = "预授权订单id", required = true) @RequestParam Long id) {
		OrderGrant orderGrant = orderGrantService.getById(id);
		orderGrant.setStatus(2);
		boolean b = orderGrantService.updateById(orderGrant);
		if (b) {
			return R.success("确认退款成功");
		}
		return R.fail("确认退款失败，请联系管理员");
	}

	/**
	 * @return
	 */
	@PostMapping("getStatisticsConsign")
	@ApiOperation(value = "统计授权，完成数")
	public R<StatisticsConsignVO> getStatisticsConsign(StatisticsConsignParam param) {
		return R.data(consignService.getStatisticsConsign(param));
	}


	@GetMapping("/createAllPayOrder")
	@ApiOperation(value = "创建支付充值订单")
	@ApiOperationSupport(order = 13)
	public R createAllPayOrder(@ApiParam(value = "批次号", required = true) @RequestParam Long consignConfigId) {
		LambdaQueryWrapper<Consign> consignLambdaQueryWrapper = Wrappers.lambdaQuery(Consign.class);
		consignLambdaQueryWrapper.gt(Consign::getEndTime, new SimpleDateFormat("yyyy-MM-dd").format(new Date()) + " 23:59:59")
			.eq(Consign::getConsignFor, 2)
			.eq(Consign::getConsignConfigId, consignConfigId);
		List<Consign> list = consignService.list(consignLambdaQueryWrapper);
		//计算需总打款金额
		BigDecimal allPrice = new BigDecimal(list.get(0).getConsignPrice()).multiply(new BigDecimal(list.size()));
		//计算需充值金额，默认当前金额的
		BigDecimal payPrice = allPrice.multiply(new BigDecimal(0.06)).setScale(2, BigDecimal.ROUND_UP);
		LambdaQueryWrapper<Order> orderWrapper = new LambdaQueryWrapper<>();
		//创建打款订单
		Order order = new Order();
		order.setOutTradeNo(CommonUtil.genTimeID());//订单编号
		order.setUserId(AuthUtil.getUserId());//当前用户Id
		order.setOrderType(5);//5为充值订单
		order.setPayFlag(1); //待付款
		order.setPayFee(payPrice.doubleValue());//支付价格
		//记录打款信息
		PlatformAuthorization platformAuthorization = new PlatformAuthorization();
		platformAuthorization.setConsignConfigId(consignConfigId);
		platformAuthorization.setOrderNo(order.getOutTradeNo());
		platformAuthorization.setCreateTime(new Date());
		platformAuthorization.setAuthPrice(payPrice);
		platformAuthorization.setState(0);
		platformAuthorization.setCreateUserId(getUser().getUserId());
		paMapper.insert(platformAuthorization);
		orderService.save(order);
		return R.data(order);
	}


	/**
	 * @return
	 */
	@PostMapping("getConsignList")
	@ApiOperation(value = "查询付款授权场次")
	public R<List<ConsignListVO>> getConsignList() {
		LambdaQueryWrapper<Consign> consignLambdaQueryWrapper = Wrappers.lambdaQuery(Consign.class);
		consignLambdaQueryWrapper.gt(Consign::getEndTime, new SimpleDateFormat("yyyy-MM-dd").format(new Date()) + " 23:59:59")
			.eq(Consign::getConsignFor, 2);
		List<Consign> list = consignService.list(consignLambdaQueryWrapper);
		ConsignListVO consignListVO = null;
		List<ConsignListVO> consignListVOS = new ArrayList<>();
		Map<Long, List<Consign>> collect1 = list.stream().collect(Collectors.groupingBy(Consign::getConsignConfigId));
		for (Map.Entry<Long, List<Consign>> entry : collect1.entrySet()) {
			//取出之前授权的列表
//			List<PlatformAuthorization> platformAuthorizations1 = collect.get(entry.getKey());
			consignListVO = new ConsignListVO();
			Integer num = entry.getValue().size();
			if (num > 0) {
				//查询已授权表记录
				LambdaQueryWrapper<PlatformAuthorization> query = Wrappers.lambdaQuery(PlatformAuthorization.class);
				query.eq(PlatformAuthorization::getState, 1)
					.eq(PlatformAuthorization::getConsignConfigId, entry.getKey());
				List<PlatformAuthorization> platformAuthorizations = paMapper.selectList(query);
				//计算需总打款金额
				BigDecimal allPrice = new BigDecimal(entry.getValue().get(0).getConsignPrice()).multiply(new BigDecimal(num));
				//计算需充值金额，默认当前金额的
				BigDecimal payPrice = allPrice.multiply(new BigDecimal(0.06)).setScale(2, BigDecimal.ROUND_UP);
				consignListVO.setConsignConfigId(entry.getKey());
				consignListVO.setOrderNum(num);
				consignListVO.setEndTime(entry.getValue().get(0).getEndTime());
				consignListVO.setOrderPrice(new BigDecimal(entry.getValue().get(0).getConsignPrice()).setScale(2, BigDecimal.ROUND_DOWN));
				consignListVO.setPayPrice(payPrice);
				//判断是否存在付款该场次存在就不要再进行付款了
				if (ObjectUtil.isNull(platformAuthorizations) || platformAuthorizations.size() == 0) {
					consignListVOS.add(consignListVO);
				}
			}
		}
		return R.data(consignListVOS);
	}

	@GetMapping("/finance/order-page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "我的订单", notes = "传入用户ID，支付状态 0:全部，1待付款，2:待发货，3待收货，4已完成，5已取消")
	public R<List<OrderVO>> orderPage(@ApiParam(value = "用户ID", required = true) @RequestParam Long userId,
									  @ApiParam(value = "支付状态", required = false) @RequestParam(required = false) Integer payFlag,
									  Query query) {
		Order order = new Order();
		order.setUserId(userId);
		order.setOrderType(1);//普通订单
		if (!StringUtil.isEmpty(payFlag)) {
			if (payFlag != 0) {
				order.setPayFlag(payFlag); //订单状态
			}
		}
		QueryWrapper<Order> queryWrapper = Wrappers.query();
		queryWrapper.in("order_type", OrderTypeEnum.NORMAL.getValue(), OrderTypeEnum.RE_ORDER.getValue(), OrderTypeEnum.RE_EXCHANGE.getValue(), OrderTypeEnum.MAKE.getValue(), OrderTypeEnum.PARTNER.getValue(), OrderTypeEnum.LINKED.getValue())
			.eq("user_id", userId).orderByDesc("create_time");
		if (payFlag != 0) {
			queryWrapper.eq("pay_flag", payFlag);
		}
//		IPage<Order> pages = orderService.page(Condition.getPage(query), Condition.getQueryWrapper(order).orderByDesc("create_time"));
		IPage<Order> pages = orderService.page(Condition.getPage(query), queryWrapper);
		List<OrderVO> orderVOS = OrderWrapper.build().listVO(pages.getRecords());
		if (CollUtil.isNotEmpty(orderVOS)) {
			List<String> collect = orderVOS.stream().map(OrderVO::getOutTradeNo).collect(Collectors.toList());
			List<OrderGoods> list = orderGoodsService.lambdaQuery().in(OrderGoods::getOutTradeNo, collect).list();
			Map<String, List<OrderGoods>> listMap = list.stream().collect(Collectors.groupingBy(OrderGoods::getOutTradeNo));
			for (OrderVO orderVO : orderVOS) {
				List<OrderGoods> orderGoods = listMap.get(orderVO.getOutTradeNo());
				orderVO.setOrderGoods(orderGoods);
			}
		}
		return R.data(orderVOS);
	}

	/**
	 * 详情
	 */
	@GetMapping("/order/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "订单详情", notes = "传入order")
	public R<OrderVO> detail(@RequestParam("orderId") Long orderId) throws Exception {
		Order detail = orderService.getById(orderId);
		OrderVO orderVO = OrderWrapper.build().entityVO(detail);
		OrderGoods orderGoods = orderGoodsService.lambdaQuery().eq(OrderGoods::getOutTradeNo, detail.getOutTradeNo()).one();
		if (orderGoods != null) {
			GoodsInfo goodsInfo = goodsInfoService.getById(orderGoods.getGoodsId());
			GoodsSpec goodsSpec = goodsSpecService.getById(orderGoods.getGoodsSpecIds());
			orderVO.setGoodsInfo(goodsInfo);
			orderVO.setGoodsSpec(goodsSpec);
		}
		orderVO.setOrderGood(orderGoods);
		List<LogisticVO> logistic = orderService.logistic(detail.getOutTradeNo());
		orderVO.setLogisticList(logistic);
		return R.data(orderVO);
	}

	@GetMapping("/finance/consign-selfPage")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "我的仓单", notes = "传入用户ID，状态: 1寄售中，2:待收款，3:已收款, 不传或者传其他则查询全部")
	public R<List<ConsignVO>> consignPage(@ApiParam(value = "用户ID", required = true) @RequestParam(required = true) Long userId,
										  @ApiParam(value = "状态", required = false) @RequestParam(required = false) Integer status,
										  Query query) {
		Consign consign = new Consign();
		consign.setConsignUserId(userId);
		consign.setIsDelivery(1);
		if (status == 1) {
			consign.setConsignState(1); //寄售中
		} else if (status == 2) {
			consign.setConsignState(2); //待收款
		} else if (status == 3) {
			consign.setConsignState(3); //已收款
		} else if (status == 4) {
			consign.setIsDelivery(0); //已交割
		}//查询全部
		IPage<Consign> pages = consignService.page(Condition.getPage(query),
			Condition.getQueryWrapper(consign).orderByDesc("create_time"));
		return R.data(ConsignWrapper.build().listVO(pages.getRecords()));
	}

	@GetMapping("/finance/serch-selfPage")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "查询仓单", notes = "传入用户账号，状态: 0未打款，1已打款，2:打款中, 3已交割")
	public R<List<ConsignVO>> consignPageSearch(@ApiParam(value = "用户账号", required = true) @RequestParam(required = true) String account,
												@ApiParam(value = "状态", required = false) @RequestParam(required = false) Integer isPayment,
												Query query) {
		User one = userService.getOne(Wrappers.lambdaQuery(User.class).eq(User::getAccount, account));
		if (ObjectUtil.isNull(one)) {
			return R.fail("该账号不存在");
		}
		Consign consign = new Consign();
		consign.setConsignUserId(one.getId());
		consign.setIsDelivery(1);
		if (ObjectUtil.isNotNull(isPayment)) {
			consign.setIsPayment(isPayment);
			if (isPayment.equals(3)) {
				consign.setIsDelivery(0);
			}
		}
		IPage<Consign> pages = consignService.page(Condition.getPage(query),
			Condition.getQueryWrapper(consign).orderByDesc("create_time"));
		return R.data(ConsignWrapper.build().listVO(pages.getRecords()));
	}

	@PostMapping("/finance/searchPayLog")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "查询打款日志", notes = "寄售商品id")
	public R<List<NowMoneyRecord>> searchPayLog(@ApiParam(value = "仓单记录id", required = true) String id) {
		List<NowMoneyRecord> list = nowMoneyRecordService.list(Wrappers.lambdaQuery(NowMoneyRecord.class).eq(NowMoneyRecord::getDataId, id));
		return R.data(list);
	}

	@PostMapping("/finance/consign-selfTake")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "仓单提货", notes = "我的仓单提货")
	public R consignTake(@Valid @RequestBody OrderTakeRequest request) {
		return R.data(orderService.consignSelfTake(request));
	}

	@PostMapping("/finance/order-cancel")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "取消订单", notes = "传入订单号")
	public R orderCancel(@ApiParam(value = "订单ID", required = true) @RequestParam Long id) {
		Order record = orderService.getById(id);
		if (record == null) {
			return R.fail("订单数据不存在");
		}
		if (!PayFlagEnum.CANCEL.getValue().equals(record.getPayFlag())) {
			Order order = new Order();
			order.setId(id);
			order.setPayFlag(PayFlagEnum.CANCEL.getValue());
			List<OrderGoods> list = orderGoodsService.lambdaQuery().eq(OrderGoods::getOutTradeNo, record.getOutTradeNo()).list();
			if (CollUtil.isNotEmpty(list)) {
				GoodsInfo goodsInfo = goodsInfoService.getById(list.get(0).getGoodsId());
				if (BusinessTypeEnum.NONE_SELF_SUPPORT.getValue().equals(goodsInfo.getBusinessType())
					&& GoodsSourceEnum.WPS.getValue().equals(goodsInfo.getSource())) {
					// 调用唯品尚取消订单接口
					weiPinShangService.cancelOrder(record.getOutTradeNo(), "BUYER");
				}
			}
			return R.status(orderService.updateById(order));
		}
		return R.success("订单已取消");
	}

	@PostMapping("/finance/order-refund")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "申请退款", notes = "传入订单号")
	public R orderRefund(@ApiParam(value = "订单ID", required = true) @RequestParam Long id) {
		orderService.orderRefund(id);
		return R.success("退款成功");
	}

	@ApiLog("确认收货")
	@PostMapping("/finance/order-confirm")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "确认收货", notes = "待收货变为已完成")
	public R orderConfirm(@ApiParam(value = "订单ID", required = true) @RequestParam Long orderId,
						  @ApiParam(value = "支付密码", required = true) @RequestParam String payPassword,
						  @ApiParam(value = "用户id", required = true) @RequestParam(required = false) Long userId) {
		if (!userAppService.verifyPayPassword(payPassword, getUser().getUserId())) {
			return R.fail("支付密码不正确！");
		}
		return R.status(orderService.orderEnd(orderId, userId));
	}

	@ApiLog("人脸识别1、获取人脸认证Url")
	@PostMapping("/getAuthenticationUrl")
	@ApiOperation(value = "人脸识别1、获取人脸认证Url", notes = "设置用户信息")
	@ApiOperationSupport(order = 8)
	public R getAuthenticationUrl(@Valid @RequestBody AliUserAuthRequst request) {
		String url = aliFaceService.startCertify(request.getRealName(), request.getIdNum(), request.getReturnUrl(), request.getBizCode());
		return R.data(url);
	}

	@ApiLog("人脸识别2、获取人脸认证结果")
	@GetMapping("/getAuthenticationResult")
	@ApiOperation(value = "人脸识别2、获取人脸认证结果")
	@ApiOperationSupport(order = 9)
	public R getAuthenticationResult(@ApiParam(value = "verifyId", required = true) @RequestParam String verifyId,
									 @ApiParam(value = "授权码", required = true) @RequestParam String authCode) {
		Boolean b = aliFaceService.queryCertifyResult(verifyId, authCode);
		return R.data(b);
	}

	@ApiLog("实名认证信息对比1、录入用户实名信息")
	@PostMapping("/getVerifyid")
	@ApiOperation(value = "实名认证信息对比1、录入用户实名信息")
	@ApiOperationSupport(order = 10)
	public R getVerifyid(@Valid @RequestBody AliUserAuthRequst request) throws AlipayApiException {
		//根据用户Id查询当前有没有实名认证
		List<UserCardInfo> list = userCardInfoService.list(Wrappers.lambdaQuery(UserCardInfo.class)
			.eq(UserCardInfo::getUserId, getUser().getUserId())
			.eq(UserCardInfo::getIsAuth, 2));
		//如果没有实名认证,或者身份证不一致
		if (CollectionUtil.isEmpty(list) || !request.getIdNum().equals(list.get(0).getIdCard())) {
			//如果不一致
			//判断传过来的身份证是否已经认证过,如果认证过，则不可以重复认证
			List<UserCardInfo> userCardInfos = userCardInfoService.list(Wrappers.lambdaQuery(UserCardInfo.class).eq(UserCardInfo::getIdCard, request.getIdNum()));
			if (CollectionUtil.isNotEmpty(userCardInfos)) {
				User user = userService.getById(userCardInfos.get(0).getUserId());
				String account = Optional.ofNullable(user).map(User::getAccount).orElse("").replaceAll("(\\d{3})\\d{4}(\\d{4})", "$1****$2");
				throw new ServiceException("该身份证号已经被" + account + "实名认证!!!");
			}
		}

		User user = userService.getById(getUser().getUserId());
		log.info("【实名认证信息对比】真实姓名:{},身份证号:{},手机号:{}", request.getRealName(), request.getIdNum(), user.getPhone());
		String verifyid = aliService.getVerifyid(request.getRealName(), request.getIdNum(), user.getPhone());
		return R.data(verifyid);
	}

	@ApiLog("实名认证信息对比2、实名信息校验")
	@GetMapping("/realNameCheck")
	@ApiOperation(value = "实名认证信息对比2、实名信息校验")
	@ApiOperationSupport(order = 11)
	public R realNameCheck(@ApiParam(value = "verifyId", required = true) @RequestParam String verifyId,
						   @ApiParam(value = "授权码", required = true) @RequestParam String authCode) throws AlipayApiException {
		Boolean b = aliService.realNameCheck(verifyId, authCode);
		return R.data(b);
	}

	@GetMapping("/getAliUserInfo")
	@ApiOperation(value = "获取支付宝用户详细信息")
	@ApiOperationSupport(order = 12)
	public R getAliUserInfo(@ApiParam(value = "authCode", required = true) @RequestParam String authCode) throws AlipayApiException {
		AliUserInfoResponse d = aliService.getAliUserInfo(authCode);
		return R.data(d);
	}


	@GetMapping("/createAliFaceOrder")
	@ApiOperation(value = "创建支付宝人脸识别订单")
	@ApiOperationSupport(order = 13)
	public R createAliFaceOrder() {
		Order order = aliFaceService.createAliFaceOrder();
		return R.data(order);
	}

	@ApiOperation(value = "查询物流信息")
	@GetMapping("/order/logistic")
	public R<List<LogisticVO>> createAliFaceOrder(@RequestParam("orderNo") String orderNo) throws Exception {
		List<LogisticVO> logistic = orderService.logistic(orderNo);
		return R.data(logistic);
	}

	/**
	 * 预支付统一收单
	 *
	 * @param outTradeNo 订单号
	 * @param orderNo    授权
	 * @param price      打款金额
	 * @return R
	 */
	public boolean orderConsign(String outTradeNo, String orderNo, Double price) {
		//查询抢购订单数据
		Order order = orderService.getOne(Wrappers.<Order>lambdaQuery().eq(Order::getOutTradeNo, outTradeNo));

		if (ObjectUtil.isNull(order)) {
			return false;
		}
		//通过授权号查询用户授权信息
		OrderGrant orderGrant = orderGrantService.getOne(Wrappers.<OrderGrant>lambdaQuery().eq(OrderGrant::getOrderNo, orderNo));
		if (ObjectUtil.isNull(orderGrant)) {
			return false;
		}
		//获取剩余预售授权数量
		Integer nowNum = orderGrant.getNowNum();
		UserApp userApp = new UserApp();
		UserApp query = userApp.selectOne(Wrappers.<UserApp>lambdaQuery().eq(UserApp::getUserId, orderGrant.getUserId()));
		JSONObject data = new JSONObject();
		data.put("out_trade_no", outTradeNo);
		data.put("total_amount", price);
		data.put("subject", "中宏酒业");
		data.put("product_code", "PRE_AUTH_ONLINE");
		data.put("auth_no", orderGrant.getAuthNo());
		data.put("body", orderGrant.getAuthNo());
		if (nowNum == 1) {//判断剩余授权数量是否为1
			//授权数量为1是进行解冻
			data.put("auth_confirm_mode", "COMPLETE"); //解冻
		} else {
			//授权数量不为1时，交易继续，只进行收单操作
			data.put("auth_confirm_mode", "NOT_COMPLETE");//不解冻
		}
		data.put("seller_id", properties.getPayeeUserId()); //收款方
//		data.put("seller_id", properties.getPayeeUserId()); //收款方
		data.put("buyer_id", query.getAlipayUserId()); //买家ID //2088012801069195
		//APP支付
		AlipayTradePayRequest request = new AlipayTradePayRequest();
		request.setNotifyUrl(properties.getDomain() + TRADE_URL); //异步通知地址
		request.setBizContent(data.toJSONString()); //业务参数
		//APP支付
		try {

			PaymentRecord record = paymentRecordService.getOne(Wrappers.lambdaQuery(PaymentRecord.class).eq(PaymentRecord::getOrderNo, orderNo));
			if (PaymentTypeEnum.ALIPAY.getValue().equals(record.getPaymentType())) {//支付宝支付
				//订单绑定授权号
				Order update = new Order();
				update.setId(order.getId());
				update.setGrantNo(orderGrant.getAuthNo());
				boolean flg = orderService.updateById(update);
				if (!flg) {
					log.info("订单绑定失败 + update.toString()");
				}
				//普通模式 使用 execute
				//证书使用 使用 certificateExecute
				AlipayTradePayResponse response = client.certificateExecute(request);
				if (response.isSuccess()) {
					orderService.payConsignSuccess(order);
					WithdrawalAccelerateRecord accRecord = new WithdrawalAccelerateRecord();
					User user1 = userService.getById(query.getUserId());
					UserApp puserApp = userAppService.getByUserId(query.getParentId());
					//计算加速提现金额
					accRecord.setRemark("进货余额加速");
					BigDecimal amount = new BigDecimal(price).multiply(new BigDecimal(ParamCache.getValue(CommonConstant.ACCELERATE_WITHDRAWAL_RATIO)));
					if (puserApp.getAccBalance().compareTo(new BigDecimal(ParamCache.getValue(CommonConstant.ACCELERATE_WITHDRAWAL_CAPS))) >= 0) {//判断余额是否大于封顶值
						amount = new BigDecimal(0);
						accRecord.setRemark("加速封顶");
					}
					accRecord.setAccelerateAmount(new BigDecimal(price));
					accRecord.setRatio(new BigDecimal(ParamCache.getValue(CommonConstant.ACCELERATE_WITHDRAWAL_RATIO)));
					accRecord.setDataId(order.getId());
					accRecord.setAccelerateUserId(order.getUserId());
					accRecord.setAccelerateUserName(user1.getRealName());
					accRecord.setBeforeAmout(puserApp.getAccBalance());
					BigDecimal add = puserApp.getAccBalance().add(amount);
					if (add.compareTo(new BigDecimal(ParamCache.getValue(CommonConstant.ACCELERATE_WITHDRAWAL_CAPS))) >= 0) {//判断金额是否超过封顶了
						add = new BigDecimal(ParamCache.getValue(CommonConstant.ACCELERATE_WITHDRAWAL_CAPS));
						amount = add.subtract(puserApp.getAccBalance());
						accRecord.setRemark("加速封顶");
					}
					accRecord.setAfterAmout(add);
					accRecord.setAmount(amount);
					accRecord.setBenefitUserId(puserApp.getUserId());
					accRecord.setType(0);
					accRecord.setSrc(0);
					puserApp.setAccBalance(add);
					userAppMapper.updateById(puserApp);
					accMapper.insert(accRecord);
					return true;
				} else {
					orderGrantService.remove(Wrappers.<OrderGrant>lambdaQuery()
						.eq(OrderGrant::getId, orderGrant.getId())
						.eq(OrderGrant::getStatus, 0));
					log.info("订单绑定失败 + 删除预授权数据," + JSON.toJSONString(response));
				}
			} else if (PaymentTypeEnum.LINKAGE_PAY.getValue().equals(record.getPaymentType())) {//联动快捷支付
				//订单绑定授权号
				Order update = new Order();
				update.setId(order.getId());
				update.setGrantNo(orderGrant.getAuthNo());
				boolean flg = orderService.updateById(update);
				if (!flg) {
					log.info("订单绑定失败 + update.toString()");
				}
				orderService.payConsignSuccess(order);
//				orderService.payCommonSuccess(order, "联动银行卡支付");
				return true;
			} else if (PaymentTypeEnum.BALANCE_PAY.getValue().equals(record.getPaymentType())) {
				orderService.payConsignSuccess(order);
//				orderService.payCommonSuccess(order, "余额支付");
				return true;
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return false;
	}


}
