package org.springblade.modules.api.controller;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.NumberUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alipay.api.AlipayApiException;
import com.alipay.api.AlipayClient;
import com.alipay.api.AlipayConstants;
import com.alipay.api.domain.AlipayTradeAppPayModel;
import com.alipay.api.internal.util.AlipaySignature;
import com.alipay.api.request.AlipayTradeAppPayRequest;
import com.alipay.api.response.AlipayTradeAppPayResponse;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.MoneySourceEnum;
import org.springblade.common.enums.PaymentTypeEnum;
import org.springblade.common.enums.WithdrawalStatusEnum;
import org.springblade.common.utils.CommonUtil;
import org.springblade.common.utils.DateUtils;
import org.springblade.common.utils.StringUtils;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.log.logger.BladeLogger;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.modules.api.request.AuditRequest;
import org.springblade.modules.finance.entity.OrderGrant;
import org.springblade.modules.finance.pay.entity.AlipayProperties;
import org.springblade.modules.finance.service.IOrderGrantService;
import org.springblade.modules.platform.service.UserAppService;
import org.springblade.modules.platform.wrapper.UserAppWrapper;
import org.springblade.modules.shopping.entity.Consign;
import org.springblade.modules.shopping.entity.PaymentRecord;
import org.springblade.modules.shopping.service.IConsignService;
import org.springblade.modules.shopping.service.IPaymentRecordService;
import org.springblade.modules.system.dto.NowMoneyRecordDTO;
import org.springblade.modules.system.dto.WithdrawalRecordDTO;
import org.springblade.modules.system.entity.*;
import org.springblade.modules.system.param.RecordParam;
import org.springblade.modules.system.service.*;
import org.springblade.modules.system.vo.NowMoneyRecordVO;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

@RestController
@RequestMapping(CommonConstant.API_URL + "/balance")
@Api(value = "余额交易", tags = "10.余额交易相关")
public class BalancePayController extends BladeController {

	private static final Logger log = LoggerFactory.getLogger(BalancePayController.class);

	//预授权
	private static final String RECHARGE_URL = "/api/v1/balance/recharge_url";
	@Resource
	private IOrderGrantService orderGrantService;
	@Resource
	private IUserService userService;
	@Resource
	private IConsignService consignService;

	@Resource
	private IRechargeRecordService rechargeRecordService;//充值记录
	@Resource
	private IWithdrawalAccelerateRecordService accelerateRecordService;
	@Resource
	private IPaymentRecordService paymentRecordService;//付款记录
	@Resource
	private INowMoneyRecordService nowMoneyRecordService;
	@Resource(name = "alipayClient")
	private AlipayClient client;//支付宝请求sdk客户端
	@Resource
	private AlipayProperties properties;//支付宝sdk配置
	@Resource
	private IWithdrawalRecordService withdrawalRecordService;//提现记录
	@Resource
	private UserAppService userAppService;
	@Resource
	private BladeLogger logger;

	/**
	 * 余额进货预授权
	 *
	 * @param batNo 批次id
	 * @param price 预授权单价
	 * @param num   预授权数量
	 * @return
	 */
	@PostMapping("restock")
	@ApiOperation(value = "余额进货预授权", notes = "传入批次金额以及数量")
	public R restock(@ApiParam(value = "批次ID", required = true) @RequestParam Long batNo,
					 @ApiParam(value = "金额", required = true) @RequestParam Double price,
					 @ApiParam(value = "数量", required = true) @RequestParam Integer num,
					 @ApiParam(value = "支付密码", required = true) @RequestParam String payPassword) {
		UserApp userApp = new UserApp();
		Long userId = getUser().getUserId();
		if (num < 1) {
			return R.fail("请选择授权数量");
		}
		UserApp query = userApp.selectOne(Wrappers.<UserApp>lambdaQuery().eq(UserApp::getUserId, userId));
		BigDecimal mul = NumberUtil.mul(price, num);//计算预售总金额
		if (mul.compareTo(query.getNowMoney()) == 1) {
			return R.fail("用户余额不足");
		}
//		query.getNowMoney().
		if (ObjectUtil.isNull(query)) {
			return R.fail("该用户不存在！");
		}
		if (!userAppService.verifyPayPassword(payPassword, userId)) {
			return R.fail("支付密码不正确！");
		}
		boolean flg = UserAppWrapper.build().isTicket(query.getTicket(), price);
		if (!flg) {
			return R.fail("您的绿色积分不足！");
		}
		if (query.getEnableAuth() != 2) {
			double k = (double) query.getCreditScore() / 100;
			int scoreCount = NumberUtil.roundDown(k, 2).intValue();
			int consignCount = Integer.parseInt(ParamCache.getValue(CommonConstant.DEFAULT_CONDIGN_COUNT));
			if (scoreCount > consignCount) {
				scoreCount = consignCount;
			}
			if (scoreCount < num) {
				return R.fail("预授数量不能大于单场可抢次数！");
			}
		}
		if (query.getState() != 1) {
			return R.fail("该账号已冻结！");
		}
		Consign consign = consignService.queryConsign(batNo, userId);
		if (ObjectUtil.isNull(consign)) {
			return R.fail("亲，好物已抢完欢迎再来！");
		}
		//判断用户是否在该场次下有预授权
		OrderGrant orderGrant = orderGrantService.getOne(Wrappers.<OrderGrant>lambdaQuery()
			.eq(OrderGrant::getBatNo, batNo)
			.eq(OrderGrant::getUserId, userId)
			.eq(OrderGrant::getStatus, 1)
		);
		if (ObjectUtil.isNotNull(orderGrant)) {
			return R.fail("您已发起预授权，无需再次发起！");
		}
		String orderNo = CommonUtil.genTimeID();
		PaymentRecord paymentRecord = new PaymentRecord();//付款记录
		paymentRecord.setPaymentType(PaymentTypeEnum.BALANCE_PAY.getValue());
		paymentRecord.setOrderNo(orderNo);
		paymentRecord.setPaymentPrice(mul);
		paymentRecord.setStatus(0);
		String dataDate = DateUtil.format(DateUtil.now(), DateUtil.PATTERN_DATE);
		OrderGrant grant = new OrderGrant();
		grant.setBatNo(batNo);
		grant.setUserId(userId);
		grant.setStatus(0);//余额支付默认是金额足够就能已授权
		grant.setOrderNo(orderNo);
		grant.setNum(num);
		grant.setNowNum(num);
		grant.setFreezeTime(DateUtil.now());
		grant.setPrice(price);
		grant.setDataDate(dataDate);
		grant.setCreateTime(DateUtil.now());//创建时间
		orderGrantService.save(grant);
		//todo 调用余额额扣款
		RecordParam recordParam = new RecordParam();
		recordParam.setFluctuantAmount(mul);
		recordParam.setMoneySourceEnum(MoneySourceEnum.PRE_AUTHORIZED_CHARGE);
		recordParam.setUserId(getUser().getUserId());
		recordParam.setDataId(grant.getId());
		Map<String, Object> res = nowMoneyRecordService.insertRecord(recordParam);
		Boolean flag = (Boolean) res.get("flag");
		if (flag) {
			paymentRecord.setStatus(1);
			paymentRecordService.save(paymentRecord);//插入付款记录，去对应的回调方法中
			grant.setStatus(1);
			orderGrantService.updateById(grant);
			Map<String, Object> map = new HashMap<>();
			map.put("url", "");
			map.put("orderNo", orderNo);
			map.put("type", PaymentTypeEnum.BALANCE_PAY.getValue());//0表示支付宝预授权
			return R.data(map);
		} else {
			return R.fail(res.get("msg").toString());
		}
	}

	@PostMapping("/rechargeBalanceOrder")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "余额充值订单创建", notes = "余额充值订单创建")
	public R rechargeBalanceOrder(@ApiParam(value = "充值金额", required = true) @RequestParam BigDecimal amount,
								  @ApiParam(value = "充值方式0：支付宝，3：微信支付", required = true) @RequestParam Integer type) {
		RechargeRecord rechargeRecord = new RechargeRecord();
		String orderNo = CommonUtil.genTimeID();
		rechargeRecord.setStatus(0);
		rechargeRecord.setOrderNo(orderNo);
		rechargeRecord.setPaymentPrice(amount);
		rechargeRecord.setCreateTime(new Date());
		rechargeRecord.setCreateUserId(AuthUtil.getUserId());
		rechargeRecord.setPaymentType(type);
		if (PaymentTypeEnum.ALIPAY.getValue().equals(type)) {
			AlipayTradeAppPayRequest request = new AlipayTradeAppPayRequest();
			AlipayTradeAppPayModel model = new AlipayTradeAppPayModel();
			model.setBody("余额充值");
			model.setSubject("中宏商城");
			model.setOutTradeNo(orderNo);
			model.setTimeoutExpress("30m");
			model.setTotalAmount(amount.toString());
			model.setProductCode("QUICK_MSECURITY_PAY");
			request.setBizModel(model);
			request.setNotifyUrl(properties.getDomain() + RECHARGE_URL);
			try {
//				这里和普通的接口调用不同，使用的是sdkExecute
//				普通模式 使用 execute
//				证书使用 使用 sdkExecute
				AlipayTradeAppPayResponse response = client.sdkExecute(request);
				if (response.isSuccess()) {
					Map<String, Object> map = new HashMap<>();
					rechargeRecordService.save(rechargeRecord);
					map.put("url", response.getBody());
					map.put("orderNo", orderNo);
					map.put("type", type);//0表示支付宝预授权
					return R.data(map);
				}
			} catch (AlipayApiException e) {
				e.printStackTrace();
				return R.fail("发起支付失败！");
			}

		}
		return R.fail("创建订单失败");
	}

	@PostMapping("/recharge_url")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "余额充值订单回调", notes = "余额充值订单回调")
	public String rechargeReturn(HttpServletRequest request) throws AlipayApiException {
		String errMsg = "充值回调";
		//获取支付宝POST过来反馈信息
		Map<String, String> params = new HashMap<>();
		Map requestParams = request.getParameterMap();
		for (Iterator iter = requestParams.keySet().iterator(); iter.hasNext(); ) {
			String name = (String) iter.next();
			String[] values = (String[]) requestParams.get(name);
			String valueStr = "";
			for (int i = 0; i < values.length; i++) {
				valueStr = (i == values.length - 1) ? valueStr + values[i] : valueStr + values[i] + ",";
			}
			//乱码解决，这段代码在出现乱码时使用。
			//valueStr = new String(valueStr.getBytes("ISO-8859-1"), "utf-8");
			params.put(name, valueStr);
		}
		log.info("params === " + params.toString());
		//切记alipayPublicCertPath是支付宝公钥证书路径，请去open.alipay.com对应应用下载。
		//boolean AlipaySignature.rsaCertCheckV1(Map<String, String> params, String publicKeyCertPath, String charset,String signType)
		boolean flag = AlipaySignature.rsaCertCheckV1(params, properties.getAliPayCertPath(), AlipayConstants.CHARSET_UTF8, "RSA2");
		log.info("flag === " + flag);
		logger.info("支付宝充值回调", "订单号: " + params.get("out_trade_no") + ",支付宝交易号:" + params.get("trade_no") + ",tradeStatus:" + params.get("trade_status"));
		if (!flag) {
			//这里处理验签失败
			log.info(errMsg + "-处理验签失败");
			return "error";
		}
		// 判断交易是否成功
		String tradeStatus = params.get("trade_status");
		if ("TRADE_SUCCESS".equals(tradeStatus)) {// 交易成功
			String orderNo = request.getParameter("out_trade_no");
			RechargeRecord rechargeRecord = rechargeRecordService.getOne(Wrappers.lambdaQuery(RechargeRecord.class).eq(RechargeRecord::getOrderNo, orderNo));
			if (ObjectUtil.isNull(rechargeRecord)) {
				log.info(errMsg + "-充值订单无数据");
				return "error";
			}
			rechargeRecord.setStatus(1);
			rechargeRecord.setUpdateTime(new Date());
			rechargeRecordService.updateById(rechargeRecord);
			RecordParam recordParam = new RecordParam();
			recordParam.setChargeAmount(new BigDecimal(0));
			recordParam.setUserId(rechargeRecord.getCreateUserId());
			recordParam.setDataId(rechargeRecord.getId());
			recordParam.setFluctuantAmount(rechargeRecord.getPaymentPrice());
			recordParam.setMoneySourceEnum(MoneySourceEnum.RECHARGE);
			recordParam.setTaxAmount(new BigDecimal(0));
			nowMoneyRecordService.insertRecord(recordParam);
			return "success";
		}
		if ("TRADE_CLOSED".equals(tradeStatus)) { // 交易关闭
			String orderNo = request.getParameter("out_request_no");
			RechargeRecord rechargeRecord = rechargeRecordService.getOne(Wrappers.lambdaQuery(RechargeRecord.class).eq(RechargeRecord::getOrderNo, orderNo));
			if(ObjectUtil.isNotNull(rechargeRecord)){
				rechargeRecord.setStatus(2);
				rechargeRecord.setUpdateTime(new Date());
				rechargeRecordService.updateById(rechargeRecord);
			}
		}
		return "error";
	}

	@PostMapping("/page")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "余额变动记录分页-查询自己", notes = "传入nowMoneyRecord")
	public R<List<NowMoneyRecord>> list(NowMoneyRecord nowMoneyRecord, Query query) {

		BladeUser user = getUser();
		LambdaQueryWrapper<UserApp> queryWrapper = new LambdaQueryWrapper<>();
		queryWrapper.eq(UserApp::getUserId, user.getUserId());
		UserApp userApp = userAppService.getOne(queryWrapper);
		nowMoneyRecord.setUserAppId(userApp.getId());
		QueryWrapper<NowMoneyRecord> queryWrapper1 = Condition.getQueryWrapper(nowMoneyRecord);
		queryWrapper1.orderByDesc("create_time");
		queryWrapper1.orderByDesc("after_money");
		IPage<NowMoneyRecord> pages = nowMoneyRecordService.page(Condition.getPage(query), queryWrapper1);
		return R.data(pages.getRecords());
	}

	@PostMapping("deduction")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "封坛酒余额扣除", notes = "传入nowMoneyRecord")
	public R deduction(@ApiParam(value = "扣除金额", required = true) @RequestParam BigDecimal amount,
					   @ApiParam(value = "用户id", required = true) @RequestParam Long userId){
		NowMoneyRecord nowMoneyRecord = new NowMoneyRecord();
		UserApp userApp = userAppService.getByUserId(userId);
		if(ObjectUtil.isNull(userApp)){
			return R.fail("用户异常请联系管理员");
		}
		if(userApp.getNowMoney().compareTo(amount) == -1){
			return R.fail("余额不足");
		}
		nowMoneyRecord.setUserAppId(userApp.getId());
		nowMoneyRecord.setBeforeMoney(userApp.getNowMoney());
		nowMoneyRecord.setAfterMoney(userApp.getNowMoney().subtract(amount));
		nowMoneyRecord.setFluctuantAmount(amount);
		nowMoneyRecord.setUserId(userId);
		nowMoneyRecord.setSource("封坛酒扣款");
		nowMoneyRecord.setCreateTime(new Date());
		nowMoneyRecord.setCreateUserId(AuthUtil.getUserId());
		nowMoneyRecord.setUpdateTime(new Date());
		nowMoneyRecord.setUpdateUserId(AuthUtil.getUserId());
		nowMoneyRecord.setType(2);
		nowMoneyRecord.setChargeAmount(new BigDecimal(0));
		nowMoneyRecord.setTaxAmount(new BigDecimal(0));
		nowMoneyRecord.setSourceCode(11);
		nowMoneyRecord.setParamStr("");
		nowMoneyRecordService.save(nowMoneyRecord);
		userApp.setNowMoney(userApp.getNowMoney().subtract(amount));
		userAppService.updateById(userApp);
		return R.success("封坛酒扣款成功");
	}

	/**
	 * 分页
	 */
	@PostMapping("/balanceAllList")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "余额变动记录分页", notes = "传入nowMoneyRecord")
	public R<List<NowMoneyRecordVO>> balanceAllList(NowMoneyRecordDTO nowMoneyRecord, Query query) {
		User user = null;
		if (StringUtils.isNotEmpty(nowMoneyRecord.getAccount())) {
			user = userService.getOne(Wrappers.lambdaQuery(User.class).eq(User::getAccount, nowMoneyRecord.getAccount()));
			if (ObjectUtil.isNull(user)) {
				return R.fail("无法查询到该用户");
			}
//			nowMoneyRecord.setUserId(user.getId());
			LambdaQueryWrapper<UserApp> queryWrapper = new LambdaQueryWrapper<>();
			queryWrapper.eq(UserApp::getUserId, user.getId());
			UserApp userApp = userAppService.getOne(queryWrapper);
			nowMoneyRecord.setUserAppId(userApp.getId());
		}
		QueryWrapper<NowMoneyRecord> queryWrapper = Condition.getQueryWrapper(nowMoneyRecord);
		queryWrapper.orderByDesc("create_time");
		queryWrapper.orderByDesc("after_money");
		IPage<NowMoneyRecord> pages = nowMoneyRecordService.page(Condition.getPage(query), queryWrapper);
		List<NowMoneyRecordVO> nowMoneyRecordVOS = new ArrayList<NowMoneyRecordVO>();
		for (NowMoneyRecord record : pages.getRecords()) {
			NowMoneyRecordVO nowMoneyRecordVO = new NowMoneyRecordVO();
			BeanUtil.copyProperties(record, nowMoneyRecordVO, "");
			nowMoneyRecordVO.setUserName(user.getRealName());
			nowMoneyRecordVOS.add(nowMoneyRecordVO);
		}
		return R.data(nowMoneyRecordVOS);
	}


	/**
	 * 分页
	 */
	@PostMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "提现记录分页--查自己", notes = "传入withdrawalRecord")
	public R<List<WithdrawalRecord>> list(WithdrawalRecord withdrawalRecord, Query query) {
		BladeUser user = getUser();
		withdrawalRecord.setCreateUserId(user.getUserId());
		query.setDescs("create_time");

		IPage<WithdrawalRecord> pages = withdrawalRecordService.page(Condition.getPage(query), Condition.getQueryWrapper(withdrawalRecord));
		List<WithdrawalRecord> records = pages.getRecords();
		return R.data(records);
	}

	@PostMapping("/auditList")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "提现记录分页--查所有", notes = "传入withdrawalRecord")
	public R<List<WithdrawalRecord>> auditList(WithdrawalRecordDTO withdrawalRecord, Query query) {
		if(ObjectUtil.isNull(withdrawalRecord.getStatus())){
			return R.fail("请传入查询类型");
		}
		if (StringUtils.isNotEmpty(withdrawalRecord.getAccount())) {
			User user = userService.getOne(Wrappers.lambdaQuery(User.class).eq(User::getAccount, withdrawalRecord.getAccount()));
			if(ObjectUtil.isNull(user)){
				return R.fail("未查询到该用户");
			}
			withdrawalRecord.setCreateUserId(user.getId());
		}
		if (withdrawalRecord.getStatus() == 0) {
			query.setDescs("create_time");
		} else {
			query.setDescs("audit_time");
		}
		IPage<WithdrawalRecord> pages = withdrawalRecordService.page(Condition.getPage(query), Condition.getQueryWrapper(withdrawalRecord));
		List<WithdrawalRecord> records = pages.getRecords();
		return R.data(records);
	}


	/**
	 * 提现申请
	 */
	@PostMapping("/createWithdrawal")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "提现申请", notes = "传入提现金额以及支付密码")
	public R createWithdrawal(@ApiParam(value = "提现金额", required = true) @RequestParam BigDecimal amount,
							  @ApiParam(value = "支付密码", required = true) @RequestParam String payPassword,
							  @ApiParam(value = "支付密码", required = true) @RequestParam Integer isAccelerate) throws ParseException {
//		return R.fail("功能调试升级中，稍后再试");
		if (!userAppService.verifyPayPassword(payPassword, getUser().getUserId())) {
			return R.fail("支付密码不正确！");
		}
		Consign consign = consignService.getNewestByUserId(getUser().getUserId());
		if (Objects.isNull(consign) && isAccelerate == 0) {
			return R.fail("新人购买寄售订单之后15天才能提现");
		}
		//查询最新的提现成功记录
		WithdrawalRecord withdrawal = withdrawalRecordService.getNewestByUserId(getUser().getUserId());

		if(isAccelerate == 0){
			SimpleDateFormat simp = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
			Date parse = simp.parse("2022-10-17 00:00:00");
			if (Objects.nonNull(withdrawal)) {
				//距离上次提现30后才能提现
				Date date = parse.compareTo(withdrawal.getCreateTime())<0?withdrawal.getCreateTime():parse;
				int i = DateUtils.daysBetween(date, new Date());
				//isAccelerate --0:普通提现，1：加速提现，2：新人提现
				isAccelerate = 3;
				if (i < 30) {
					if (parse.compareTo(withdrawal.getCreateTime())<0){
						return R.fail("距上一次提现" + i + "天，还有" + (30 - i) + "天才能提现");
					}else {
						return R.fail("距2022年10月17号" + i + "天，还有" + (30 - i) + "天才能提现");
					}

				}
			} else {
				//新人购买寄售订单之后15天才能提现
				Date date = parse.compareTo(consign.getCreateTime())<0?consign.getCreateTime():parse;
				int i = DateUtils.daysBetween(date, new Date());
				//isAccelerate --0:普通提现，1：加速提现，2：新人提现
				isAccelerate = 2;
				if (i < 15) {
					if (parse.compareTo(consign.getCreateTime())<0){
						return R.fail("购买寄售订单之后15天才能提现，还有" + (15 - i) + "天才能提现");
					}else {
						return R.fail("距2022年10月17号" + i + "天，还有" + (15 - i) + "天才能提现");
					}

				}
			}
		}

		if (Objects.isNull(amount)) {
			return R.fail("提现金额不能为空！");
		}
		if (amount.compareTo(new BigDecimal(1)) == -1) {
			return R.fail("提现金额必须大于1！");
		}
		BigDecimal bigDecimal = new BigDecimal(ParamCache.getValue(CommonConstant.NORMAL_WITHDRAWAL_CAPS));
		if (amount.compareTo(bigDecimal) == 1 && (isAccelerate == 2 || isAccelerate == 3 )) {
			return R.fail("提现金额不能超过"+bigDecimal+"！");
		}
		UserApp userApp = userAppService.getByUserId(getUser().getUserId());
		if(isAccelerate == 1 && amount.compareTo(userApp.getAccBalance()) ==1){
			return R.fail("加速提现金额不足！");
		}

		Map<String, Object> withdrawalRecord = withdrawalRecordService.createWithdrawalRecord(amount, isAccelerate);
		if (!(Boolean) withdrawalRecord.get("flag")) {
			return R.fail((String) withdrawalRecord.get("msg"));
		}
		return R.success("提现申请已提交，请等待审核！");
	}

	@PostMapping("confirmAudit")
	@ApiOperation(value = "确认审核", notes = "传入id进行审核")
	public R confirmAudit(@RequestBody AuditRequest auditRequest) {
		if (ObjectUtil.isNull(auditRequest.getIds()) || auditRequest.getIds().size() < 1) {
			return R.fail("请选择id传入");
		}
//		auditRequest.getIds().add(1589239045109649410L);
		for (Long id : auditRequest.getIds()) {
			withdrawalRecordService.updataWithdrawalRecord(id, WithdrawalStatusEnum.PASS, "审核同意");
		}
		return R.success("审核成功");
	}

	@PostMapping("/rejectAudit")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "驳回申请", notes = "传入提现申请id以及驳回意见")
	public R rejectAudit(@ApiParam(value = "驳回id", required = true) @RequestParam Long id,
						 @ApiParam(value = "支付密码", required = true) @RequestParam String auditMsg) {
		Map<String, Object> map = withdrawalRecordService.updataWithdrawalRecord(id, WithdrawalStatusEnum.REJECT, auditMsg);
		if ((Boolean) map.get("flag")) {
			return R.success("驳回成功");
		} else {
			return R.fail(map.get("msg").toString());
		}
	}

	@PostMapping("/backoutAudit")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "撤销申请", notes = "传入撤销申请id")
	public R backoutAudit(@ApiParam(value = "撤销id", required = true) @RequestParam Long id) {
		Map<String, Object> map  = withdrawalRecordService.backoutAudit(id);
		if ((Boolean) map.get("flag")) {
			return R.success("撤销成功");
		} else {
			return R.fail(map.get("msg").toString());
		}
	}

	/**
	 * 分页 余额加速提现
	 */
	@PostMapping("/accelerateRecordlist")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "加速记录分页", notes = "传入withdrawalAccelerateRecord")
	public R list(WithdrawalAccelerateRecord withdrawalAccelerateRecord, Query query) {
		query.setDescs("create_time");
		IPage<WithdrawalAccelerateRecord> pages = accelerateRecordService.page(Condition.getPage(query), Condition.getQueryWrapper(withdrawalAccelerateRecord));
		return R.data(pages.getRecords());
	}


}
