package org.springblade.modules.api.controller;


import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springblade.common.base.BaseEntity;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.LinkedEarningsTypeEnum;
import org.springblade.common.enums.ZoneTypeEnum;
import org.springblade.common.utils.DateTimeUtil;
import org.springblade.common.utils.StringUtils;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.StringUtil;
import org.springblade.modules.linked.entity.LinkedBindLog;
import org.springblade.modules.linked.entity.LinkedEarnings;
import org.springblade.modules.linked.entity.LinkedOrder;
import org.springblade.modules.linked.entity.LinkedUserInfo;
import org.springblade.modules.linked.service.ILinkedBindLogService;
import org.springblade.modules.linked.service.ILinkedEarningsService;
import org.springblade.modules.linked.service.ILinkedOrderService;
import org.springblade.modules.linked.service.ILinkedUserInfoService;
import org.springblade.modules.linked.vo.LinkedStatisticsVO;
import org.springblade.modules.linked.vo.UserInfoVO;
import org.springblade.modules.platform.service.UserAppService;
import org.springblade.modules.redenvelopemall.entity.GoodsInfo;
import org.springblade.modules.redenvelopemall.service.IGoodsInfoService;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.entity.UserApp;
import org.springblade.modules.system.service.IUserService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Objects;


@RestController
@RequestMapping(CommonConstant.API_URL + "/linked")
@Api(value = "共富1580", tags = "共富1580")
public class LinkedController extends BladeController {


	@Value("${linkedUrl.url}")
	private String linkedUrl;

	@Resource
	private ILinkedEarningsService linkedEarningsService;

	@Resource
	private ILinkedOrderService linkedOrderService;

	@Resource
	private IUserService userService;

	@Resource
	private ILinkedUserInfoService linkedUserInfoService;

	@Resource
	private ILinkedBindLogService linkedBindLogService;

	@Resource
	private IGoodsInfoService goodsInfoService;

	@Resource
	private UserAppService userAppService;


	/**
	 * 分页 联动模式用户信息表
	 */
	@GetMapping("/getUserByPromotionNo")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "根据推广码获取用户信息", notes = "传入promotionNo")
	public R<LinkedUserInfo> getUserByPromotionNo(String promotionNo) {

		if (StringUtil.isBlank(promotionNo)) {
			UserApp userApp = userAppService.getByUserId(AuthUtil.getUserId());
			if (Objects.isNull(userApp.getParentId())) {
				return R.data(new LinkedUserInfo());
			}
			LinkedUserInfo linkedUserInfo = linkedUserInfoService.getByUserId(userApp.getParentId());
			if (Objects.isNull(linkedUserInfo)) {
				return R.data(new LinkedUserInfo());
			}
			if ("ADMIN".equals(linkedUserInfo.getPromotionNo())) {
				return R.data(new LinkedUserInfo());
			}
			return R.data(linkedUserInfo);
		}

		LinkedUserInfo linkedUserInfo = linkedUserInfoService.getLinkUserByCode(promotionNo);
		if (Objects.isNull(linkedUserInfo)) {
			return R.data(new LinkedUserInfo());
		}
		if (linkedUserInfo.getIsWeed() == 1) {
			return R.data(new LinkedUserInfo());
		}
		return R.data(linkedUserInfo);
	}

	@PostMapping("/getLinkedUrl")
	@ApiOperation(value = "获取共富分享地址")
	public R<String> getLinkedUrl() {

		List<GoodsInfo> list = goodsInfoService.lambdaQuery().eq(GoodsInfo::getZoneType, ZoneTypeEnum.LINKED.getValue()).list();
		if (CollectionUtil.isEmpty(list)) {
			return R.fail("商品信息不存在");
		}
		GoodsInfo goodsInfo = list.get(0);

		LinkedUserInfo linkedUser = linkedUserInfoService.getByUserId(getUser().getUserId());
		if (Objects.isNull(linkedUser)) {
			return R.fail("请先购买共富1580商品");
		}
		User user = userService.getById(getUser().getUserId());
		String url = linkedUrl + "#/?userName=" + linkedUser.getUserName() + "&promotioncode=" + linkedUser.getPromotionNo() +
			"&goodsId=" + goodsInfo.getId() + "&code=" + user.getCode();
		return R.data(url);
	}

	@PostMapping("/getContributionUsers")
	@ApiOperation(value = "获取贡献人列表")
	public R<List<UserInfoVO>> getContributionUsers(@ApiParam(value = "用户id") @RequestParam Long userId) {
		User user = userService.getById(userId);
		if(ObjectUtil.isNull(user)){
			return R.fail("未查询到该用户");
		}
		LambdaQueryWrapper<LinkedUserInfo> queryWrapper = Wrappers.lambdaQuery(LinkedUserInfo.class)
			.eq(LinkedUserInfo::getRecommendId, userId)
			.orderByAsc(BaseEntity::getCreateTime)
			.last("limit 2");
		List<UserInfoVO> vo = new ArrayList<>();
		List<LinkedUserInfo> list = linkedUserInfoService.list(queryWrapper);
		if (list.size() == 2) {
			for (LinkedUserInfo record : list) {
				UserInfoVO userInfoVO = new UserInfoVO();
				BeanUtils.copyProperties(record, userInfoVO);
				User nowUser = userService.getById(record.getUserId());
				userInfoVO.setAccount(nowUser.getAccount());
				userInfoVO.setAvatar(nowUser.getAvatar());
				vo.add(userInfoVO);
			}
		}
		return R.data(vo);
	}

	@PostMapping("/getStatistics")
	@ApiOperation(value = "获取共富1580统计数据")
	public R<LinkedStatisticsVO> getStatistics(@ApiParam(value = "用户id") @RequestParam Long userId) {
		User user = userService.getById(userId);
		if(ObjectUtil.isNull(user)){
			return R.fail("未查询到该用户");
		}

		LinkedStatisticsVO linked = new LinkedStatisticsVO();

		//收益
		LinkedUserInfo linkedUser = linkedUserInfoService.getByUserId(userId);

		if (Objects.isNull(linkedUser)) {
			return R.data(linked);
		}
		//累计人数
		linked.setCountLinkedUser(linkedUserInfoService.count(Wrappers.lambdaQuery(LinkedUserInfo.class).eq(LinkedUserInfo::getIsOut, 0)));
		//今日购买人数
		linked.setCountTodayLinkedUser(linkedUserInfoService.count(Wrappers.lambdaQuery(LinkedUserInfo.class).gt(BaseEntity::getCreateTime, DateTimeUtil.earliestTime(new Date()))));
		//获取用户的所有收益
		List<LinkedEarnings> list = linkedEarningsService.list(Wrappers.lambdaQuery(LinkedEarnings.class)
			.eq(LinkedEarnings::getBenefitUserId, userId)
			.ne(LinkedEarnings::getType, LinkedEarningsTypeEnum.SUBTRACT.getValue()));
		BigDecimal earningsCount = new BigDecimal(0);
		for (LinkedEarnings linkedEarnings : list) {
			earningsCount = earningsCount.add(linkedEarnings.getAmount());
		}

		//用户累计收益
		linked.setEarningsCount(earningsCount);

		//用户当前收益
		linked.setNowEarnings(ObjectUtil.isNotNull(linkedUser.getEarnings()) ? linkedUser.getEarnings() : new BigDecimal(0));

		//计算今日收益
		BigDecimal todayEarnings = new BigDecimal(0);
		for (LinkedEarnings linkedEarnings : list) {
			if (linkedEarnings.getCreateTime().compareTo(DateTimeUtil.earliestTime(new Date())) >= 0) {
				todayEarnings = todayEarnings.add(linkedEarnings.getAmount());
			}

		}
		//用户今日收益
		linked.setTodayEarnings(todayEarnings);

		//用户邀请码
		linked.setPromotionNo(linkedUser.getPromotionNo());

		//直推人数
		List<LinkedUserInfo> oneLiset = linkedUserInfoService.getOneByUserId(userId);
		linked.setOneCount(oneLiset.size());

		//间推人数
		List<LinkedUserInfo> twoList = linkedUserInfoService.getTwoByUserId(userId);
		linked.setTwoCount(twoList.size());

		linked.setIsPartner(linkedUser.getIsPartner());
		if (linkedUser.getIsPartner() == 1) {
			linked.setPartnerStr("合伙人");
		} else {
			linked.setPartnerStr("消费商");
		}

		//上级信息
		LinkedUserInfo linkedUserInfo = linkedUserInfoService.getByUserId(linkedUser.getParentId());
		linked.setLinkedPaeentUser(linkedUserInfo);


		//推广连接
		String url = null;
		List<GoodsInfo> goodsList = goodsInfoService.lambdaQuery().eq(GoodsInfo::getZoneType, ZoneTypeEnum.LINKED.getValue()).list();
		if (CollectionUtil.isNotEmpty(goodsList)) {
			GoodsInfo goodsInfo = goodsList.get(0);
			url = linkedUrl + "#/?userName=" + linkedUser.getUserName() + "&promotioncode=" + linkedUser.getPromotionNo() +
				"&goodsId=" + goodsInfo.getId() + "&code=" + user.getCode();
		}
		linked.setSheraUrl(url);

		//当前位置
		LinkedOrder linkedOrder = linkedOrderService.getLastOrderByUserId(userId);
		if (Objects.nonNull(linkedOrder)) {
			LambdaQueryWrapper<LinkedOrder> query = Wrappers.lambdaQuery(LinkedOrder.class)
				.eq(LinkedOrder::getIsDelete, 0)
				.le(LinkedOrder::getSort, linkedOrder.getSort());
			int count = linkedOrderService.count(query);
			linked.setSort(count);
		} else {
			linked.setSort(0);
		}


		//出局位置

		LambdaQueryWrapper<LinkedOrder> query = Wrappers.lambdaQuery(LinkedOrder.class)
			.eq(LinkedOrder::getIsDelete, 0)
			.eq(LinkedOrder::getIsOut, 1);
		int count = linkedOrderService.count(query);
		linked.setOutSort(count);

		return R.data(linked);
	}


	@PostMapping("/getLinkedUser")
	@ApiOperation(value = "查询自己是否购买过1580")
	public R<LinkedUserInfo> getLinkedUser() {
		LinkedUserInfo linkedUser = linkedUserInfoService.getByUserId(getUser().getUserId());
		return R.data(linkedUser);
	}

	/**
	 * 分页 联动模式用户信息表
	 */
	@GetMapping("/linkedUserList")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "一级分页", notes = "传入userInfo")
	public R<List<UserInfoVO>> listOne(Query query, @ApiParam(value = "用户id") @RequestParam Long userId) {
		User user = userService.getById(userId);
		if(ObjectUtil.isNull(user)){
			return R.fail("未查询到该用户");
		}
		IPage<LinkedUserInfo> pages = linkedUserInfoService.page(Condition.getPage(query),
			Wrappers.lambdaQuery(LinkedUserInfo.class).eq(LinkedUserInfo::getParentId,userId));
		List<LinkedUserInfo> records = pages.getRecords();
		List<UserInfoVO> vo = new ArrayList<>();
		for (LinkedUserInfo record : records) {
			UserInfoVO userInfoVO = new UserInfoVO();
			BeanUtils.copyProperties(record, userInfoVO);
			User nowUser = userService.getById(record.getUserId());
			userInfoVO.setAccount(nowUser.getAccount());
			userInfoVO.setAvatar(nowUser.getAvatar());
			vo.add(userInfoVO);
		}
		return R.data(vo);
	}


	/**
	 * 分页 用户收益明细表
	 */
	@GetMapping("/earningsList")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "收益分页", notes = "传入linkedEarnings")
	public R<List<LinkedEarnings>> list(@ApiParam(value = "用户id") @RequestParam Long userId, Query query) {
		LambdaQueryWrapper<LinkedEarnings> queryWrapper = Wrappers.lambdaQuery(LinkedEarnings.class)
			.eq(LinkedEarnings::getBenefitUserId, userId)
			.orderByDesc(BaseEntity::getCreateTime);
		IPage<LinkedEarnings> pages = linkedEarningsService.page(Condition.getPage(query), queryWrapper);
		return R.data(pages.getRecords());
	}


	/**
	 * 分页 绑定记录表
	 */
	@GetMapping("/linkedBindLogList")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "绑定记录分页", notes = "传入bindLog")
	public R<List<LinkedBindLog>> list(Query query, @ApiParam(value = "用户id") @RequestParam Long userId) {
		User user = userService.getById(userId);
		if(ObjectUtil.isNull(user)){
			return R.fail("未查询到该用户");
		}
		LambdaQueryWrapper<LinkedBindLog> queryWrapper = new LambdaQueryWrapper<>();
		queryWrapper.eq(LinkedBindLog::getBeforeParentId, userId).or()
			.eq(LinkedBindLog::getAfterParentId, userId).or()
			.eq(LinkedBindLog::getUserId, userId)
			.orderByDesc(LinkedBindLog::getCreateTime)
			.orderByAsc(LinkedBindLog::getSort);

		IPage<LinkedBindLog> pages = linkedBindLogService.page(Condition.getPage(query), queryWrapper);
		return R.data(pages.getRecords());
	}


}
