package org.springblade.modules.api.controller;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springblade.common.base.BaseEntity;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.utils.DateTimeUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.modules.redenvelopemall.entity.RedEnvelopeReceiveLog;
import org.springblade.modules.redenvelopemall.entity.RedIntegral;
import org.springblade.modules.redenvelopemall.mapper.RedAccelerateRecordMapper;
import org.springblade.modules.redenvelopemall.service.IRedEnvelopeManagerService;
import org.springblade.modules.redenvelopemall.service.IRedEnvelopeReceiveLogService;
import org.springblade.modules.redenvelopemall.service.IRedEnvelopeService;
import org.springblade.modules.redenvelopemall.service.IRedIntegralService;
import org.springblade.modules.redenvelopemall.vo.RedAccelerateRecordExclusiveVo;
import org.springblade.modules.redenvelopemall.vo.RedEnvelopeReceiveLogVo;
import org.springblade.modules.redenvelopemall.vo.RedEnvelopeStatisticsVO;
import org.springblade.modules.redenvelopemall.vo.RedIntegralVO;
import org.springblade.modules.redenvelopemall.wrapper.RedIntegralWrapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

@RestController
@Api(value = "红包商城", tags = "100.红包商城")
@RequestMapping(CommonConstant.API_URL + "/re")
public class RedEnvelopeController {
	private static final Logger log = LoggerFactory.getLogger(RedEnvelopeController.class);
	@Autowired
	private IRedEnvelopeService redEnvelopeService;

	@Autowired
	private IRedEnvelopeReceiveLogService redEnvelopeReceiveLogService;

	@Autowired
	private IRedEnvelopeManagerService redEnvelopeManagerService;

	@Resource
	private RedAccelerateRecordMapper redAccelerateRecordMapper;

	@Resource
	private IRedIntegralService redIntegralService;


	@GetMapping("/grab")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "抢红包")
	public R<RedEnvelopeReceiveLog> grab(@ApiParam(value = "标识:0随机红包,1专属红包", required = true) @RequestParam(required = true) Integer type) {
		try {
			RedEnvelopeReceiveLog log = null;
			if (0 == type) {
				//如果是0则抢专属红包
				log = redEnvelopeService.grab();
			} else if (1 == type) {
				//如果是1则领专属红包
				log = redEnvelopeService.grabBelong();
			} else if(2 == type){
				log = redEnvelopeService.grabLinked();
			}
			return R.data(log);
		} catch (Exception e) {
			return R.fail(e.getMessage());
		}
	}

	/**
	 * 获取红包领取情况
	 */
	@GetMapping("/logByRedEnvelopeId")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "获取指定红包领取情况", notes = "传入红包id")
	public R<List<RedEnvelopeReceiveLogVo>> list(@ApiParam(value = "主键", required = true) @RequestParam String redEnvelopeId,
												 @ApiParam(value = "用户名", required = false) @RequestParam(required = false) String userName,
												 Query query) {
		IPage<RedEnvelopeReceiveLogVo> page = redEnvelopeReceiveLogService.logByRedEnvelopeId(redEnvelopeId, userName, query);
		return R.data(page.getRecords());
	}

	@GetMapping("/logListByUserId")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "查询当前登录人领取的红包金额记录", notes = "查询当前登录人领取的红包金额记录")
	public R<List<RedEnvelopeReceiveLog>> logListByUserId(@ApiParam(value = "开始时间", required = false) @RequestParam(required = false) Date startTime,
														  @ApiParam(value = "结束时间", required = false) @RequestParam(required = false) Date endTime, Query query) {
		IPage page = Condition.getPage(query);
		LambdaQueryWrapper<RedEnvelopeReceiveLog> queryWrapper = new LambdaQueryWrapper<>();
		queryWrapper.eq(BaseEntity::getCreateUserId, AuthUtil.getUserId());
		queryWrapper.gt(ObjectUtil.isNotNull(startTime), BaseEntity::getCreateTime, startTime);
		queryWrapper.lt(ObjectUtil.isNotNull(endTime), BaseEntity::getCreateTime, endTime);
		queryWrapper.orderByDesc(BaseEntity::getCreateTime);
		List list = redEnvelopeReceiveLogService.page(page, queryWrapper).getRecords();
		return R.data(list);
	}

	/**
	 * 分页 红色积分变更记录表
	 */
	@GetMapping("/integralList")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "红色积分变更记录表分页", notes = "传入redIntegral")
	public R list(Query query) {
		RedIntegral redIntegral = new RedIntegral();
		redIntegral.setUserId(AuthUtil.getUserId());
		query.setDescs("create_time");
		IPage<RedIntegral> pages = redIntegralService.page(Condition.getPage(query), Condition.getQueryWrapper(redIntegral));
		return R.data(pages.getRecords());
	}


	@GetMapping("/todayStatistics")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "红包首页数据-统计", notes = "今日统计")
	public R<RedEnvelopeStatisticsVO> todayStatistics() {
		RedEnvelopeStatisticsVO vo = redEnvelopeManagerService.todayAppStatistics();
		return R.data(vo);
	}

	@GetMapping("/leaderboard")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "红包排行榜", notes = "红包排行榜")
	public R<List<RedEnvelopeReceiveLogVo>> leaderboard(
		@ApiParam(value = "查询标识 0查全部 1查当天", required = true) @RequestParam Integer flag,
		@ApiParam(value = "红包类型 0:红包商城随机红包,1:个人专属红包(来自下级团队收益),2:1580收益红包") @RequestParam(required = false) Integer type,
		Query query) {
		IPage<RedEnvelopeReceiveLogVo> page;
		if (flag == 0) {
			page = redEnvelopeReceiveLogService.leaderboard(null, null, query, type);
		} else {
			page = redEnvelopeReceiveLogService.leaderboard(DateTimeUtil.earliestTime(new Date()), DateTimeUtil.lastestTime(new Date()), query, type);
		}

		return R.data(page.getRecords());
	}


	@GetMapping("/grabFlag")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "判断当前用户是否可以抢红包", notes = "1可以抢0不可以")
	public R<Map<String, Object>> grabFlag(@ApiParam(value = "标识:0随机红包,1专属红包,2联动收益红包", required = true) @RequestParam(required = true) Integer type) {
		Map<String, Object> map = redEnvelopeManagerService.grabFlag(type);
		return R.data(map);
	}

	@GetMapping("/grabFlagList")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "判断当前用户是否可以抢红包", notes = "1可以抢0不可以")
	public R<List<Map<String, Object>>> grabFlagList() {
		List<Map<String, Object>> maps = new ArrayList<>();
		for(int i = 0; i < 3; i++){
			Map<String, Object> map = redEnvelopeManagerService.grabFlag(i);
			map.put("type", i);
			maps.add(map);
		}
		return R.data(maps);
	}

	@GetMapping("/exclusivePage")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "分页查询错失红包记录列表", notes = "分页查询错失红包记录列表")
	public R<List<RedAccelerateRecordExclusiveVo>> getExclusivePage(Query query) {
		IPage page = Condition.getPage(query);
		IPage<RedAccelerateRecordExclusiveVo> mapIPage = redAccelerateRecordMapper.getExclusivePage(page, AuthUtil.getUserId());
		return R.data(mapIPage.getRecords());
	}

}
