package org.springblade.modules.api.controller.redenvelopemall;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.BusinessTypeEnum;
import org.springblade.common.enums.GoodsStateEnum;
import org.springblade.common.enums.YesOrNoEnum;
import org.springblade.common.enums.ZoneTypeEnum;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.modules.api.request.GoodsListRequest;
import org.springblade.modules.api.service.impl.ReOrderServiceImpl;
import org.springblade.modules.api.vo.FullReductionVO;
import org.springblade.modules.redenvelopemall.entity.CategoryInfo;
import org.springblade.modules.redenvelopemall.entity.GoodsInfo;
import org.springblade.modules.redenvelopemall.entity.GoodsParams;
import org.springblade.modules.redenvelopemall.entity.GoodsSpec;
import org.springblade.modules.redenvelopemall.service.IGoodsInfoService;
import org.springblade.modules.redenvelopemall.service.IGoodsParamsService;
import org.springblade.modules.redenvelopemall.service.IGoodsSpecService;
import org.springblade.modules.redenvelopemall.service.ISupplyChainService;
import org.springblade.modules.redenvelopemall.service.impl.CategoryInfoServiceImpl;
import org.springblade.modules.redenvelopemall.vo.GoodsInfoVO;
import org.springblade.modules.redenvelopemall.wrapper.GoodsInfoWrapper;
import org.springblade.modules.system.entity.DictBiz;
import org.springblade.modules.system.service.IDictBizService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@Api(value = "红包商城",tags = "100.红包商城")
@RequestMapping(CommonConstant.API_URL+"/re/goodsInfo")
public class AppGoodsInfoController {

	@Resource
	private IGoodsInfoService goodsInfoService;
	@Resource
	private IGoodsParamsService goodsParamsService;
	@Resource
	private IGoodsSpecService goodsSpecService;
	@Resource
	private ISupplyChainService supplyChainService;
	@Resource
	private ReOrderServiceImpl reOrderService;
	@Resource
	private CategoryInfoServiceImpl categoryInfoService;
	@Resource
	private IDictBizService dictService;


	@GetMapping("/page")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "商品分页接口", notes = "传入goodsInfo")
	public R<List<GoodsInfoVO>> list(GoodsListRequest request, Query query) {
		LambdaQueryWrapper<GoodsInfo> wrapper = Wrappers.lambdaQuery(GoodsInfo.class);
		if (request.getZoneType() != null) {
			wrapper.eq(GoodsInfo::getZoneType, request.getZoneType());
		}
		if (StrUtil.isNotBlank(request.getGoodsCategoryId())) {
			CategoryInfo categoryInfo = categoryInfoService.getById(request.getGoodsCategoryId());
			if (categoryInfo.getParentId() == 0) {
				wrapper.likeRight(GoodsInfo::getGoodsCategoryId, request.getGoodsCategoryId() + "-");
			} else {
				wrapper.likeRight(GoodsInfo::getGoodsCategoryId, categoryInfo.getParentId() + "-" + request.getGoodsCategoryId() + "-");
			}
		}
		if (StrUtil.isNotBlank(request.getGoodsName())) {
			wrapper.like(GoodsInfo::getGoodsName, request.getGoodsName());
		}
		wrapper.orderByAsc(GoodsInfo::getSort);
		if (request.getIsRecom() != null) {
			wrapper.eq(GoodsInfo::getIsRecom, 1).orderByDesc(GoodsInfo::getTotalViews).orderByDesc(GoodsInfo::getTotalSales);
		} else {
			wrapper.orderByAsc(GoodsInfo::getSalePrice);
		}
		wrapper.eq(GoodsInfo::getIsSale, GoodsStateEnum.ON_SALE.getValue());
		wrapper.ge(GoodsInfo::getTotalStock, 1);
		IPage<GoodsInfo> pages = goodsInfoService.page(Condition.getPage(query), wrapper);
		List<GoodsInfoVO> goodsInfoVOS = GoodsInfoWrapper.build().listVO(pages.getRecords());
		if (CollUtil.isNotEmpty(goodsInfoVOS)) {
			String exchangeRedIntegralMul = ParamCache.getValueDefault(CommonConstant.EXCHANGE_RED_INTEGRAL_MULTIPLE, "3");
			String buyRedIntegralMul = ParamCache.getValueDefault(CommonConstant.BUY_RED_INTEGRAL_MULTIPLE, "2");
			for (GoodsInfoVO goodsInfoVO : goodsInfoVOS) {
				// 设置积分兑换所需要的积分和需要付款的金额
				if (ZoneTypeEnum.INTEGRAL_CONVERT.getValue().equals(goodsInfoVO.getZoneType())) {
					BigDecimal salePrice = goodsInfoVO.getSalePrice();
					BigDecimal needExchangeIntegral = reOrderService.calNeedExchangeIntegral(salePrice, goodsInfoVO.getAgreementPrice());
					goodsInfoVO.setNeedAmount(salePrice.subtract(needExchangeIntegral));
					goodsInfoVO.setNeedIntegral(needExchangeIntegral);
				}

				// 积分兑换专区获得价格的三倍的积分，红色积分专区获取两倍的积分
				if (ZoneTypeEnum.INTEGRAL_CONVERT.getValue().equals(goodsInfoVO.getZoneType()) || ZoneTypeEnum.CITY_PARTNER.getValue().equals(goodsInfoVO.getZoneType())) {
					goodsInfoVO.setObtainIntegral(goodsInfoVO.getSalePrice().multiply(new BigDecimal(exchangeRedIntegralMul)).setScale(2, BigDecimal.ROUND_HALF_UP));
				} else if (ZoneTypeEnum.RED_INTEGRAL.getValue().equals(goodsInfoVO.getZoneType()) || ZoneTypeEnum.GUEST.getValue().equals(goodsInfoVO.getZoneType()) || ZoneTypeEnum.HOT_STYLE.getValue().equals(goodsInfoVO.getZoneType())
					|| ZoneTypeEnum.LINKED.getValue().equals(goodsInfoVO.getZoneType())) {
					goodsInfoVO.setObtainIntegral(goodsInfoVO.getSalePrice().multiply(new BigDecimal(buyRedIntegralMul)).setScale(2, BigDecimal.ROUND_HALF_UP));
				} else if (ZoneTypeEnum.GREEN_INTEGRAL.getValue().equals(goodsInfoVO.getZoneType())) {
					List<GoodsSpec> list = goodsSpecService.lambdaQuery().eq(GoodsSpec::getGoodsId, goodsInfoVO.getId()).eq(GoodsSpec::getIsSale, GoodsStateEnum.ON_SALE.getValue()).eq(GoodsSpec::getIsDefault, 1).list();
					goodsInfoVO.setObtainIntegral(list.get(0).getObtainIntegral());
				} else {
					goodsInfoVO.setObtainIntegral(goodsInfoVO.getSalePrice().setScale(2, BigDecimal.ROUND_HALF_UP));
				}

				// 没有轮播图，取封面展示
				if (CollUtil.isEmpty(goodsInfoVO.getSlideshowList())) {
					goodsInfoVO.setSlideshowList(CollUtil.newArrayList(goodsInfoVO.getGoodsCover()));
				}
			}
		}
		return R.data(goodsInfoVOS);
	}

	@GetMapping("/detail")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "商品详情接口", notes = "传入goodsInfo")
	public R<GoodsInfoVO> detail(@RequestParam("id") Long id) {
		GoodsInfo detail = goodsInfoService.detail(id);
		GoodsInfoVO goodsInfoVO = GoodsInfoWrapper.build().entityVO(detail);
		List<GoodsParams> goodsParamsList = goodsParamsService.getByGoodsId(id);
		goodsInfoVO.setGoodsParamsList(goodsParamsList);
		List<GoodsSpec> goodsSpecList = goodsSpecService.lambdaQuery().eq(GoodsSpec::getGoodsId, id).eq(GoodsSpec::getIsSale, GoodsStateEnum.ON_SALE.getValue()).orderByAsc(GoodsSpec::getSalePrice).list();

		for (GoodsSpec goodsSpec : goodsSpecList) {
			// 设置积分兑换所需要的积分和需要付款的金额
			if (ZoneTypeEnum.INTEGRAL_CONVERT.getValue().equals(detail.getZoneType())) {
				BigDecimal salePrice = goodsSpec.getSalePrice();
				BigDecimal needExchangeIntegral = reOrderService.calNeedExchangeIntegral(salePrice, goodsSpec.getAgreementPrice());
				goodsSpec.setNeedAmount(salePrice.subtract(needExchangeIntegral));
				goodsSpec.setNeedIntegral(needExchangeIntegral);
			}
			if (YesOrNoEnum.NO.getValue().equals(detail.getIsActivity())) {
				String exchangeRedIntegralMul = ParamCache.getValueDefault(CommonConstant.EXCHANGE_RED_INTEGRAL_MULTIPLE, "3");
				String buyRedIntegralMul = ParamCache.getValueDefault(CommonConstant.BUY_RED_INTEGRAL_MULTIPLE, "2");
				if (ZoneTypeEnum.INTEGRAL_CONVERT.getValue().equals(goodsInfoVO.getZoneType()) || ZoneTypeEnum.CITY_PARTNER.getValue().equals(goodsInfoVO.getZoneType())) {
					goodsSpec.setObtainIntegral(goodsSpec.getSalePrice().multiply(new BigDecimal(exchangeRedIntegralMul)).setScale(2, BigDecimal.ROUND_HALF_UP));
				} else if (ZoneTypeEnum.RED_INTEGRAL.getValue().equals(goodsInfoVO.getZoneType()) || ZoneTypeEnum.GUEST.getValue().equals(goodsInfoVO.getZoneType()) || ZoneTypeEnum.HOT_STYLE.getValue().equals(goodsInfoVO.getZoneType())
					|| ZoneTypeEnum.LINKED.getValue().equals(goodsInfoVO.getZoneType())) {
					goodsSpec.setObtainIntegral(goodsSpec.getSalePrice().multiply(new BigDecimal(buyRedIntegralMul)).setScale(2, BigDecimal.ROUND_HALF_UP));
				} else if (ZoneTypeEnum.GREEN_INTEGRAL.getValue().equals(goodsInfoVO.getZoneType())) {
					goodsInfoVO.setObtainIntegral(goodsSpec.getObtainIntegral());
				} else {
					goodsSpec.setObtainIntegral(goodsSpec.getSalePrice().setScale(2, BigDecimal.ROUND_HALF_UP));
				}
			} else {
				if (goodsSpec.getSalePrice().doubleValue() > 3000) {
					goodsSpec.setObtainIntegral(BigDecimal.valueOf(goodsSpec.getSalePrice().doubleValue() * 5));
				} else {
					goodsSpec.setObtainIntegral(BigDecimal.valueOf(goodsSpec.getSalePrice().doubleValue() * 4));
				}
			}

			// 规格没有封面，取商品封面展示
			if (StrUtil.isBlank(goodsSpec.getCover())) {
				goodsSpec.setCover(detail.getGoodsCover());
			}
		}
		goodsInfoVO.setGoodsSpecList(goodsSpecList);
		// 增加浏览量
		detail.setTotalViews(detail.getTotalViews() + 1);
		goodsInfoService.updateById(detail);
		return R.data(goodsInfoVO);
	}

	@GetMapping("/activityGoods/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "活动商品分页接口", notes = "传入goodsInfo")
	public R<List<GoodsInfoVO>> activityGoods(GoodsListRequest request, Query query) {
		List<GoodsInfo> pages = goodsInfoService.activityGoods(Condition.getPage(query), request.getActivityDate());
		List<GoodsInfoVO> goodsInfoVOS = GoodsInfoWrapper.build().listVO(pages);
		if (CollUtil.isNotEmpty(goodsInfoVOS)) {
			for (GoodsInfoVO goodsInfoVO : goodsInfoVOS) {
				goodsInfoVO.setObtainGreenIntegral(goodsInfoVO.getSalePrice());
				// 没有轮播图，取封面展示
				if (CollUtil.isEmpty(goodsInfoVO.getSlideshowList())) {
					goodsInfoVO.setSlideshowList(CollUtil.newArrayList(goodsInfoVO.getGoodsCover()));
				}
				if (goodsInfoVO.getSalePrice().doubleValue() < 3000) {
					goodsInfoVO.setObtainIntegral(goodsInfoVO.getSalePrice().multiply(new BigDecimal(4)).setScale(2, BigDecimal.ROUND_HALF_UP));
				} else {
					goodsInfoVO.setObtainIntegral(goodsInfoVO.getSalePrice().multiply(new BigDecimal(5)).setScale(2, BigDecimal.ROUND_HALF_UP));
				}
			}

		}
		return R.data(goodsInfoVOS);
	}


	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "双十一活动状态")
	@GetMapping("/doubleEleven/status")
	public R<Map<String, Object>> doubleElevenStatus() {
		String value = ParamCache.getValue(CommonConstant.DOUBLE_ELEVEN_STATUS);
		Map<String, Object> map = new HashMap<>();
		String[] split = value.split(",");
		map.put("isDoubleEleven", split[0]);
		map.put("isBlack", split[1]);
		return R.data(map);
	}

	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "双十一优惠")
	@GetMapping("/doubleEleven/discounts")
	public R<List<FullReductionVO>> doubleElevenDiscount() {
		List<FullReductionVO> list = new ArrayList<>();
		List<DictBiz> dictBizs = dictService.getList(CommonConstant.DOUBLE_ELEVEN_DISCOUNTS);
		if (CollUtil.isNotEmpty(dictBizs)) {
			for (DictBiz dictBiz : dictBizs) {
				FullReductionVO vo = new FullReductionVO();
				vo.setReduction(Double.parseDouble(dictBiz.getDictKey()));
				vo.setFull(Double.parseDouble(dictBiz.getDictValue()));
				list.add(vo);
			}
		}
		return R.data(list);
	}

}
