package org.springblade.modules.api.controller.redenvelopemall;

import cn.hutool.core.collection.CollUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.*;
import org.springblade.core.log.annotation.ApiLog;
import org.springblade.core.log.exception.ServiceException;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.core.tool.utils.StringUtil;
import org.springblade.core.tool.utils.WebUtil;
import org.springblade.modules.api.request.BeforeCheckRequest;
import org.springblade.modules.api.request.OrderGoodsSaveRequest;
import org.springblade.modules.api.request.ReOrderSaveRequest;
import org.springblade.modules.api.request.SubmitOrderRequest;
import org.springblade.modules.api.response.BeforeCheckResponse;
import org.springblade.modules.api.response.SubmitOrderResponse;
import org.springblade.modules.api.service.IReOrderService;
import org.springblade.modules.api.vo.FullReductionDetailVO;
import org.springblade.modules.auth.utils.TokenUtil;
import org.springblade.modules.redenvelopemall.entity.GoodsInfo;
import org.springblade.modules.redenvelopemall.entity.GoodsSpec;
import org.springblade.modules.redenvelopemall.service.IGoodsInfoService;
import org.springblade.modules.redenvelopemall.service.IGoodsSpecService;
import org.springblade.modules.redenvelopemall.service.ISupplyChainService;
import org.springblade.modules.redenvelopemall.service.IWeiPinShangService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.stream.Collectors;

@RestController
@Api(value = "红包商城", tags = "100.红包商城")
@RequestMapping(CommonConstant.API_URL + "/re/order")
public class ReOrderController {

	@Resource
	private IReOrderService reOrderService;
	@Resource
	private ISupplyChainService supplyChainService;
	@Resource
	private IGoodsInfoService goodsInfoService;
	@Resource
	private IGoodsSpecService goodsSpecService;
	@Resource
	private IWeiPinShangService weiPinShangService;

	@PostMapping("/beforeCheck")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "前置校验", notes = "他营的商品需调用此接口，此接口一般常应用于客户付款之前确认订单页面，该接口会返回当下订单传入的商品是否有不可售的商品，以保证商品下单后都能流转到供应链中台。")
	public R<BeforeCheckResponse> beforeCheck(@Valid @RequestBody BeforeCheckRequest request) {
		if (request.getUserAddressId() == null) {
			return R.fail("请选择收货地址");
		}
		BeforeCheckResponse beforeCheckResponse = new BeforeCheckResponse();
		GoodsSpec goodsSpec = goodsSpecService.getById(request.getGoodsSpecId());
		GoodsInfo goodsInfo = goodsInfoService.getById(goodsSpec.getGoodsId());
		if (BusinessTypeEnum.NONE_SELF_SUPPORT.getValue().equals(goodsInfo.getBusinessType())) {
			int num = request.getNum();
			// 是否为套装规格，调用第三方的购买数=用户购买数*套装商品数量
			if (YesOrNoEnum.YES.getValue().equals(goodsSpec.getIsPackage())) {
				num = request.getNum() * goodsSpec.getPackageNum();
			}
			if (GoodsSourceEnum.STBZ.getValue().equals(goodsInfo.getSource())) {
				// 他营的商品调用第三方前置校验接口
				JSONObject jsonObject = supplyChainService.beforeCheck(goodsSpec.getOptionId(), num, request.getUserAddressId());
				JSONArray data = jsonObject.getJSONArray("data");
				List<BeforeCheckResponse> beforeCheckResponses = data.toJavaList(BeforeCheckResponse.class);
				beforeCheckResponse = beforeCheckResponses.get(0);
				if (beforeCheckResponse.getFreight() != null) {
					// 第三方返回的邮费
					beforeCheckResponse.setFreight(beforeCheckResponse.getFreight().divide(new BigDecimal(100), 2, BigDecimal.ROUND_HALF_UP));
				}
				return R.data(beforeCheckResponse);
			} else if (GoodsSourceEnum.WPS.getValue().equals(goodsInfo.getSource())) {
				JSONObject postage = weiPinShangService.getPostage(goodsInfo.getThirdId(), goodsSpec.getOptionId(), num, request.getUserAddressId());
				beforeCheckResponse.setFreight(postage.getJSONObject("data").getBigDecimal("freight"));
			} else {
				throw new ServiceException("商品来源属性错误");
			}
		} else if (BusinessTypeEnum.SELF_SUPPORT.getValue().equals(goodsInfo.getBusinessType())) {
			// 商品不包邮则获取设置的邮费
			if (goodsInfo.getIsFreeShipping() == 0) {
				beforeCheckResponse.setFreight(goodsInfo.getFreePrice().setScale(2, BigDecimal.ROUND_HALF_UP));
			}
		} else {
			return R.fail("营业类型错误");
		}
		return R.data(beforeCheckResponse);
	}

	@GetMapping("/availableCheck")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "可售检测", notes = "此接口一般常应用于进入商品详情页后调取，以防个别商品部分规格不可售或无货导致用户无法下单")
	public R list(@ApiParam(value = "商品id") @RequestParam Long goodsInfoId,
							 @ApiParam(value = "用户地址id") @RequestParam(required = false) Long userAddressId) {
		if (userAddressId == null) {
			return R.fail("请先到设置后货地址");
		}
		GoodsInfo goodsInfo = goodsInfoService.getById(goodsInfoId);
		if(BusinessTypeEnum.NONE_SELF_SUPPORT.getValue().equals(goodsInfo.getBusinessType())
			&& GoodsSourceEnum.STBZ.getValue().equals(goodsInfo.getSource())) {
			JSONObject jsonObject = supplyChainService.availableCheck(goodsInfoId, userAddressId);
			return R.data(jsonObject.getJSONObject("data").getJSONObject("data"));
		} else if(BusinessTypeEnum.NONE_SELF_SUPPORT.getValue().equals(goodsInfo.getBusinessType())
			&& GoodsSourceEnum.WPS.getValue().equals(goodsInfo.getSource())) {
			HashMap<String, List<Long>> map = new HashMap<>();
			ArrayList<Long> arrayList = new ArrayList<>();
			boolean result = weiPinShangService.availableCheck(goodsInfo, userAddressId);
			List<GoodsSpec> list = goodsSpecService.lambdaQuery().eq(GoodsSpec::getGoodsId, goodsInfoId).eq(GoodsSpec::getIsSale, GoodsStateEnum.ON_SALE.getValue()).list();
			List<Long> collect = list.stream().map(GoodsSpec::getId).collect(Collectors.toList());
			if (result) {
				map.put("ban", arrayList);
				map.put("available", collect);
			} else {
				map.put("ban", collect);
				map.put("available", arrayList);
			}
			return R.data(map);
		}
		else {
			// 自营商品暂时返回空的数据
			HashMap<String, List<Long>> map = new HashMap<>();
			ArrayList<Long> arrayList = new ArrayList<>();
			map.put("ban", arrayList);
			List<GoodsSpec> list = goodsSpecService.lambdaQuery().eq(GoodsSpec::getGoodsId, goodsInfoId).eq(GoodsSpec::getIsSale, GoodsStateEnum.ON_SALE.getValue()).list();
			List<Long> collect = list.stream().map(GoodsSpec::getId).collect(Collectors.toList());
			map.put("available", collect);
			return R.data(map);
		}
	}

	@ApiLog("提交下单")
	@PostMapping("/submit")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "提交下单")
	public R<SubmitOrderResponse> submitOrder(@Valid @RequestBody ReOrderSaveRequest request) {
		if (request.getUserAddressId() == null) {
			return R.fail("请选择收货地址");
		}
		String tenantId = WebUtil.getRequest().getHeader(TokenUtil.TENANT_HEADER_KEY);
		if (StringUtil.isEmpty(request.getDistributeMode())) {
			request.setDistributeMode(2);
		}
		if (CollUtil.isEmpty(request.getGoodsList())) {
			return R.fail("请选择购买的商品！");
		}
		// 默认及时到账
		if (request.getSettleType() == null) {
			request.setSettleType(SettleTypeEnum.SELF_SUPPORT.getValue());
		}
		if (OrderTypeEnum.PARTNER.getValue().equals(request.getOrderType())) {
			if (request.getPayType() == null) {
				return R.fail("请选择支付方式！");
			}
		}
		request.setUserId(AuthUtil.getUserId());
		return R.data(reOrderService.submitOrder(request, tenantId));
	}

	@ApiLog("购物车提交下单")
	@PostMapping("/cart/submit")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "购物车提交下单")
	public R<SubmitOrderResponse> cartSubmitOrder(@Valid @RequestBody SubmitOrderRequest request) {
		if (CollUtil.isEmpty(request.getGoodsList())) {
			return R.fail("请选择购买的商品！");
		}
		String tenantId = WebUtil.getRequest().getHeader(TokenUtil.TENANT_HEADER_KEY);
		return R.data(reOrderService.cartSubmitOrder(request, tenantId));
	}

	@PostMapping("/fullReduction")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "获取商品满减详情", notes = "传入商品id集合 ids")
	public R<FullReductionDetailVO> fullReductionDetail(@RequestBody SubmitOrderRequest request) {
		return R.data(reOrderService.fullReductionDetail(request));
	}


}
