package org.springblade.modules.api.controller.redenvelopemall;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springblade.common.base.BaseEntity;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.WithdrawalStatusEnum;
import org.springblade.common.utils.DateTimeUtil;
import org.springblade.common.utils.RedisTool;
import org.springblade.common.utils.StringUtils;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.modules.platform.service.UserAppService;
import org.springblade.modules.system.entity.RedMoneyRecord;
import org.springblade.modules.system.dto.MallWithdrawalRecordDTO;
import org.springblade.modules.system.entity.MallWithdrawalRecord;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.entity.UserApp;
import org.springblade.modules.system.service.IMallWithdrawalRecordService;
import org.springblade.modules.system.service.IRedMoneyRecordService;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springblade.modules.system.service.IUserService;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Objects;

@RestController
@Api(value = "红包余额相关",tags = "红包余额相关")
@RequestMapping(CommonConstant.API_URL+"/re/money")
public class RedMoneyController {

	@Resource
	private IMallWithdrawalRecordService mallWithdrawalRecordService;

	@Resource
	private UserAppService userAppService;
	@Resource
	private IRedMoneyRecordService redMoneyRecordService;
	@Resource
	private RedisTool redisTool;
	@Resource
	private IUserService userService;

	@PostMapping("createMallWithdrawal")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "红包余额提现申请", notes = "传入提现金额以及支付密码")
	public R createMallWithdrawal(@ApiParam(value = "提现金额", required = true) @RequestParam BigDecimal amount,
								  @ApiParam(value = "支付密码", required = true) @RequestParam String payPassword){
		MallWithdrawalRecord one = mallWithdrawalRecordService.getOne(Wrappers.lambdaQuery(MallWithdrawalRecord.class)
			.eq(BaseEntity::getCreateUserId, AuthUtil.getUserId())
			.orderByDesc(BaseEntity::getCreateTime)
			.last("limit 1"));
		if(ObjectUtil.isNotNull(one)){
			if(one.getStatus() == 0){
				return R.fail("你有一笔提现正在审核中");
			}
			if(one.getCreateTime().compareTo(DateTimeUtil.earliestTime(new Date())) == 1 && one.getStatus() == 2){
				return R.fail("一天只能提现一次");
			}
		}
		if (!userAppService.verifyPayPassword(payPassword, AuthUtil.getUserId())) {
			return R.fail("支付密码不正确！");
		}
		if (Objects.isNull(amount)) {
			return R.fail("提现金额不能为空！");
		}
		if (amount.compareTo(new BigDecimal(1)) == -1) {
			return R.fail("提现金额必须大于1！");
		}
		BigDecimal bigDecimal = new BigDecimal(ParamCache.getValue(CommonConstant.NORMAL_WITHDRAWAL_CAPS));
		if (amount.compareTo(bigDecimal) == 1) {
			return R.fail("提现金额不能超过" + bigDecimal + "！");
		}
		UserApp userApp = userAppService.getByUserId(AuthUtil.getUserId());
		if (amount.compareTo(userApp.getRedMoney()) == 1) {
			return R.fail("红包余额不足！");
		}
		mallWithdrawalRecordService.createMallWithdrawalRecord(amount);
		return R.success("提现成功");
	}

	@PostMapping("confirmAuditAll")
	@ApiOperation(value = "一键审核")
	public R confirmAuditAll() {
		try {
			if (!redisTool.getRedisLock("confirmAuditAll:"+ AuthUtil.getUserId(),"confirmAuditAll")) {
				return R.fail("打款处理中，请不要重复点击");
			}
			List<MallWithdrawalRecord> list = mallWithdrawalRecordService.list(Wrappers.lambdaQuery(MallWithdrawalRecord.class).eq(MallWithdrawalRecord::getStatus, 0));
			for (MallWithdrawalRecord mallWithdrawalRecord : list) {
				mallWithdrawalRecordService.updateMallWithdrawalRecord(mallWithdrawalRecord.getId(), WithdrawalStatusEnum.PASS, "已通过");
			}
			redisTool.unRedisLock("confirmAuditAll:"+ AuthUtil.getUserId());
		} catch (Exception e) {
			e.printStackTrace();
		}finally {
			redisTool.unRedisLock("confirmAuditAll:"+ AuthUtil.getUserId());
		}
		return R.success("审核成功");
	}

	@PostMapping("confirmAudit")
	@ApiOperation(value = "确认审核", notes = "传入id进行审核")
	public R confirmAudit(@ApiParam(value = "提现金额", required = true) @RequestParam Long id) {
		mallWithdrawalRecordService.updateMallWithdrawalRecord(id, WithdrawalStatusEnum.PASS, "已通过");
		return R.success("审核成功");
	}

	@PostMapping("/rejectAudit")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "驳回申请", notes = "传入提现申请id以及驳回意见")
	public R rejectAudit(@ApiParam(value = "驳回id", required = true) @RequestParam Long id,
						 @ApiParam(value = "支付密码", required = true) @RequestParam String auditMsg) {
		mallWithdrawalRecordService.updateMallWithdrawalRecord(id, WithdrawalStatusEnum.REJECT, auditMsg);
		return R.success("驳回成功");
	}

	@PostMapping("/backoutAudit")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "撤销申请", notes = "传入撤销申请id")
	public R backoutAudit(@ApiParam(value = "撤销id", required = true) @RequestParam Long id) {
		mallWithdrawalRecordService.updateMallWithdrawalRecord(id, WithdrawalStatusEnum.BACKOUT, "已撤回");
		return R.success("撤销成功");
	}

	/**
	 * 红包余额变动分页
	 */
	@PostMapping("/redMoneyRecordList")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "红包余额变动分页", notes = "传入redMoneyRecord")
	public R<List<RedMoneyRecord>> redMoneyRecordList(@ApiParam(value = "账号") @RequestParam(required = false) String account, Query query) {
		Long userId = AuthUtil.getUser().getUserId();
		if(StringUtils.isNotEmpty(account)){
			User queryUser = userService.getByAccount(account);
			if(ObjectUtil.isNull(queryUser)){
				return R.fail("未查询到该用户");
			}
			userId = queryUser.getId();
		}
		LambdaQueryWrapper<RedMoneyRecord> queryWrapper = new LambdaQueryWrapper<>();
		queryWrapper.eq(RedMoneyRecord::getUserId, userId);
		queryWrapper.eq(RedMoneyRecord::getIsDelete, 0);
		queryWrapper.orderByDesc(RedMoneyRecord::getCreateTime);
		IPage<RedMoneyRecord> pages = redMoneyRecordService.page(Condition.getPage(query), queryWrapper);
		return R.data(pages.getRecords());
	}



	@PostMapping("/auditList")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "审核提现记录分页", notes = "传入withdrawalRecord")
	public R<List<MallWithdrawalRecord>> auditList(MallWithdrawalRecordDTO withdrawalRecord, Query query) {
		if(ObjectUtil.isNull(withdrawalRecord.getStatus())){
			return R.fail("请传入查询类型");
		}
		if (StringUtils.isNotEmpty(withdrawalRecord.getAccount())) {
			User user = userService.getOne(Wrappers.lambdaQuery(User.class).eq(User::getAccount, withdrawalRecord.getAccount()));
			if(ObjectUtil.isNull(user)){
				return R.fail("未查询到该用户");
			}
			withdrawalRecord.setCreateUserId(user.getId());
		}
		if (withdrawalRecord.getStatus() == 0) {
			query.setAscs("create_time");
		} else {
			query.setDescs("audit_time");
		}
		IPage<MallWithdrawalRecord> pages = mallWithdrawalRecordService.page(Condition.getPage(query), Condition.getQueryWrapper(withdrawalRecord));
		List<MallWithdrawalRecord> records = pages.getRecords();
		return R.data(records);
	}

	/**
	 * 分页
	 */
	@PostMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "提现记录分页--查自己", notes = "传入withdrawalRecord")
	public R<List<MallWithdrawalRecord>> list(MallWithdrawalRecord withdrawalRecord, Query query) {
		withdrawalRecord.setCreateUserId(AuthUtil.getUserId());
		query.setDescs("create_time");
		IPage<MallWithdrawalRecord> pages = mallWithdrawalRecordService.page(Condition.getPage(query), Condition.getQueryWrapper(withdrawalRecord));
		List<MallWithdrawalRecord> records = pages.getRecords();
		return R.data(records);
	}
}
