/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.api.request;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

/**
 * 请求实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@ApiModel(value = "新增订单实体对象", description = "请求实体类")
public class ReOrderSaveRequest implements Serializable {

	private static final long serialVersionUID = 1L;

	@NotNull(message = "用户收货地址id不能为空")
	@ApiModelProperty(value = "用户收货地址id")
	private Long userAddressId;

	@ApiModelProperty(value = "配送方式，1物流配送，2到店自取")
	private Integer distributeMode;

	@ApiModelProperty(value = "运费")
	private Double wlPrice;

	@ApiModelProperty(value = "配送信息")
	private String deliveryStaff;

	@ApiModelProperty(value = "订单类型 1-绿色积分 6-红色积分 7-积分兑换订单 8-创客  9-城市合伙人")
	private Integer orderType;

	@ApiModelProperty(value = "到账类型 0-及时到账 1-确认收货后到账")
	private Integer settleType;

	@ApiModelProperty(value = "备注")
	private String remark;

	@ApiModelProperty(value = "支付方式 1-纯现金 2-现金加积分 3-纯积分")
	private Integer payType;

	@ApiModelProperty(value = "现金")
	private BigDecimal amount;

	@ApiModelProperty(value = "积分")
	private BigDecimal integral;

	@ApiModelProperty(value = "推广码")
	private String promotionCode;

	@ApiModelProperty(value = "用户手机号")
	private String phone;

	@ApiModelProperty(value = "用户名称")
	private String username;

	@ApiModelProperty(value = "推荐人手机号")
	private String recommendPhone;

	private Long userId;

	@NotEmpty(message = "商品信息不能为空")
	@ApiModelProperty(value = "商品信息")
	private List<OrderGoodsSaveRequest> goodsList;

}
