package org.springblade.modules.api.service;

import com.alipay.api.AlipayApiException;
import org.springblade.modules.api.response.AliUserInfoResponse;
import org.springblade.modules.finance.entity.Order;
import org.springblade.modules.finance.entity.TransactionFlow;
import org.springblade.modules.system.entity.PayLog;

import java.math.BigDecimal;
import java.util.Map;

public interface IZhzxAliService {
	/**
	 * 获取verifyid
	 * @param realName
	 * @param idNum
	 * @param mobile
	 * @return
	 * @throws AlipayApiException
	 */
	 String getVerifyid(String realName, String idNum, String mobile) throws AlipayApiException;

	/**
	 * 真是名字检验
	 * @param verifyid verifyid
	 * @param authCode
	 * @return
	 * @throws AlipayApiException
	 */
	Boolean realNameCheck(String verifyid, String authCode) throws AlipayApiException;

	/**
	 * 获取阿里用户信息
	 * @param authCode
	 * @return
	 * @throws AlipayApiException
	 */
    AliUserInfoResponse getAliUserInfo(String authCode) throws AlipayApiException;


	/**
	 *
	 * 向指定阿里用户付款
	 * @param type 类型默认0 余额提现 1 特殊账号打款 2 红包提现
	 * @param userId 系统用户Id
	 * @param aliUserId 阿里用户Id
	 * @param name 用户真实名字
	 * @param transAmount 金额
	 * @param orderTitle 标题
	 * @param remarks 备注
	 * @return PayLog
	 */
	PayLog pay(Integer type, Long userId, String aliUserId, String name, BigDecimal transAmount, String orderTitle, String remarks);

	/**
	 * 退款
	 * @param order
	 */
	void refund(Order order);

	/**
	 * 交易初始化
	 * @param outTradeNo 订单号
	 * @param amount 金额
	 * @param callbackUrl 回调地址
	 * @return
	 */
	String init(String outTradeNo, String amount, String callbackUrl);

	/**
	 * 证书验证
	 * @param params
	 * @return
	 * @throws AlipayApiException
	 */
	boolean rsaCertCheck(Map<String,String> params) throws AlipayApiException;

	/**
	 * 1、商户需要验证该通知数据中的out_trade_no是否为商户系统中创建的订单号，
	 * 2、判断total_amount是否确实为该订单的实际金额（即商户订单创建时的金额），
	 * 3、验证app_id是否为该商户本身。上述1、2、3有任何一个验证不通过，则表明本次通知是异常通知，务必忽略。
	 * @param params
	 */
	void check(Map<String,String> params, Order order);

	void check(Map<String,String> params, TransactionFlow flow);

	/**
	 * 获取商户支付宝账号
	 * @return
	 */
	String getPayeeUserId();
}
