package org.springblade.modules.api.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.NumberUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.*;
import org.springblade.common.utils.CommonUtil;
import org.springblade.core.log.exception.ServiceException;
import org.springblade.core.log.logger.BladeLogger;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.modules.api.request.OrderGoodsSaveRequest;
import org.springblade.modules.api.request.ReOrderSaveRequest;
import org.springblade.modules.api.request.SubmitOrderRequest;
import org.springblade.modules.api.response.SubmitOrderResponse;
import org.springblade.modules.api.service.IReOrderService;
import org.springblade.modules.api.vo.FullReductionDetailVO;
import org.springblade.modules.finance.entity.Order;
import org.springblade.modules.finance.entity.OrderGoods;
import org.springblade.modules.finance.entity.TransactionFlow;
import org.springblade.modules.finance.mapper.OrderMapper;
import org.springblade.modules.finance.service.IOrderService;
import org.springblade.modules.finance.service.ITransactionFlowService;
import org.springblade.modules.linked.service.ILinkedOrderService;
import org.springblade.modules.platform.entity.UserAddress;
import org.springblade.modules.platform.entity.UserTicket;
import org.springblade.modules.platform.service.IUserAddressService;
import org.springblade.modules.platform.service.IUserTicketService;
import org.springblade.modules.redenvelopemall.entity.GoodsInfo;
import org.springblade.modules.redenvelopemall.entity.GoodsSpec;
import org.springblade.modules.redenvelopemall.service.IRedIntegralService;
import org.springblade.modules.redenvelopemall.service.IShoppingCartService;
import org.springblade.modules.redenvelopemall.service.ISupplyChainService;
import org.springblade.modules.redenvelopemall.service.IWeiPinShangService;
import org.springblade.modules.redenvelopemall.service.impl.GoodsInfoServiceImpl;
import org.springblade.modules.redenvelopemall.service.impl.GoodsSpecServiceImpl;
import org.springblade.modules.system.entity.DictBiz;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.entity.UserApp;
import org.springblade.modules.system.mapper.UserAppMapper;
import org.springblade.modules.system.mapper.UserMapper;
import org.springblade.modules.system.service.IDictBizService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.Assert;

import javax.annotation.Resource;
import javax.validation.constraints.NotEmpty;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

@Service
public class ReOrderServiceImpl implements IReOrderService {

	@Resource
	private IUserAddressService userAddressService;
	@Resource
	private UserMapper userMapper;
	@Resource
	private GoodsInfoServiceImpl goodsInfoService;
	@Resource
	private GoodsSpecServiceImpl goodsSpecService;
	@Resource
	private UserAppMapper userAppMapper;
	@Resource
	private ISupplyChainService supplyChainService;
	@Resource
	private BladeLogger bladeLogger;
	@Resource
	private OrderMapper orderMapper;
	@Resource
	private IUserTicketService userTicketService;
	@Resource
	private IRedIntegralService redIntegralService;
	@Resource
	private IOrderService orderService;
	@Resource
	private IWeiPinShangService weiPinShangService;
	@Resource
	private ITransactionFlowService transactionFlowService;
	@Resource
	private IShoppingCartService shoppingCartService;
	@Resource
	private IDictBizService dictService;
	@Resource
	private ILinkedOrderService linkedOrderService;


	@Transactional(rollbackFor = Exception.class)
	@Override
	public SubmitOrderResponse submitOrder(ReOrderSaveRequest request, String tenantId) {
		// 双十一启动标识
		String status = ParamCache.getValueDefault(CommonConstant.DOUBLE_ELEVEN_STATUS, Boolean.FALSE.toString());
		Integer orderType = this.getOrderType(request.getGoodsList().get(0).getGoodsId());
		//生成订单号
		String orderNo = CommonUtil.genTimeID();
		User user = userMapper.selectById(request.getUserId());
		Order order = new Order();
		order.setSettleType(request.getSettleType());
		order.setUserAddressId(request.getUserAddressId());
		order.setTenantId(tenantId);
		order.setUserName(user.getRealName());
		order.setOutTradeNo(orderNo);
		order.setOrderType(orderType);
		order.setUserId(user.getId());
		order.setRemark(request.getRemark());
		order.setPayFlag(PayFlagEnum.WAIT_PAY.getValue()); //待付款
		order.setPromotionCode(request.getPromotionCode());

		UserAddress userAddress = userAddressService.getById(request.getUserAddressId());
		if (userAddress == null) {
			throw new ServiceException("请填写用户地址");
		}
		order.setUserAddress(this.getAddress(userAddress));
		order.setTelPhone(userAddress.getPhone());
		order.setDistributeMode(request.getDistributeMode());
		order.setDeliveryStaff(request.getDeliveryStaff());
		order.setReceivingName(userAddress.getRealName());
		order.setWlPrice(request.getWlPrice());

		// 商品总金额
		Double totalFee = 0.0;
		// 总积分
		Double totalTicket = 0.0;
		// 实付金额
		Double payFee = 0.0;

		Map<Long, GoodsInfo> goodsInfoMap = new HashMap<>();
		Map<Long, GoodsSpec> specMap = new HashMap<>();
		for (OrderGoodsSaveRequest item : request.getGoodsList()) {
			GoodsInfo goodsInfo = goodsInfoService.getById(item.getGoodsId());
			goodsInfoMap.put(goodsInfo.getId(), goodsInfo);
			if (OrderTypeEnum.RE_EXCHANGE.getValue().equals(orderType) && !ZoneTypeEnum.INTEGRAL_CONVERT.getValue().equals(goodsInfo.getZoneType())) {
				throw new ServiceException("该商品不能兑换");
			}
			// 校验商品状态
			this.checkGoodsState(goodsInfo);
			GoodsSpec goodsSpec = goodsSpecService.getById(item.getGoodsSpecIds());
			specMap.put(goodsInfo.getId(), goodsSpec);
			// 校验规格状态
			this.checkGoodsSpecState(goodsSpec);
			// 创建orderGoods
			this.createOrderGoods(goodsInfo, goodsSpec, item.getGoodsNum(), orderNo);
			Double specPrice = NumberUtil.toDouble(NumberUtil.mul(goodsSpec.getSalePrice(), item.getGoodsNum()));
			totalFee = NumberUtil.add(totalFee, specPrice);
			payFee = totalFee;
			if (Boolean.parseBoolean(status) && YesOrNoEnum.YES.getValue().equals(goodsInfo.getIsActivity())) {
				// 双十一活动优惠金额
				BigDecimal discountAmount = this.fullReduction(totalFee);
				order.setDiscountAmount(discountAmount);
				payFee = payFee - discountAmount.doubleValue();
				// 获得的绿色积分
				order.setActivityIntegral(specPrice);
			}

			Double specTicket = this.calIntegral(goodsInfo, goodsSpec, item.getGoodsNum(), totalFee);
			totalTicket = NumberUtil.add(totalTicket, specTicket);
		}

		order.setTotalFee(totalFee);
		order.setPayFee(payFee + request.getWlPrice());
		order.setTotalTicket(totalTicket);


		// 积分兑换
		if (OrderTypeEnum.RE_EXCHANGE.getValue().equals(orderType)) {
			this.exchange(order, request);
		}

		// 城市合伙人校验
		if (OrderTypeEnum.PARTNER.getValue().equals(orderType)) {
			this.cityPartnerCheck(order, request);
		}

		// 共富1580
//		if (OrderTypeEnum.LINKED.getValue().equals(orderType)) {
//			Boolean linkedResult = linkedOrderService.checkLinkedOrder(order);
//			order.setLinkedResult(linkedResult);
//		}


		// 唯品尚供应链需先调用下单接口，支付完成之后调用确认订单接口
		for (OrderGoodsSaveRequest item : request.getGoodsList()) {
			GoodsInfo goodsInfo = goodsInfoMap.get(item.getGoodsId());
			if (BusinessTypeEnum.NONE_SELF_SUPPORT.getValue().equals(goodsInfo.getBusinessType())
				&& GoodsSourceEnum.WPS.getValue().equals(goodsInfo.getSource())) {
				GoodsSpec goodsSpec = specMap.get(goodsInfo.getId());
				int num = item.getGoodsNum();
				// 是否为套装规格，调用第三方的购买数=用户购买数*套装商品数量
				if (YesOrNoEnum.YES.getValue().equals(goodsSpec.getIsPackage())) {
					num = item.getGoodsNum() * goodsSpec.getPackageNum();
				}
				String thirdOrderNo = weiPinShangService.createOrder(orderNo, goodsSpec.getOptionId(), goodsInfo.getThirdId(), num, request.getUserAddressId());
				order.setThirdOrderNo(thirdOrderNo);
			}
		}

		orderMapper.insert(order);

		// 城市合伙人订单，当支付类型为纯积分支付时，直接调用支付成功接口
		if (OrderTypeEnum.PARTNER.getValue().equals(orderType) && request.getPayType() == 3) {
			orderService.payCommonSuccess(order, "");
		}

		SubmitOrderResponse response = new SubmitOrderResponse();
		response.setOrderNo(orderNo);
		return response;
	}

	/**
	 * 计算满减
	 * @param price
	 * @return
	 */
	private BigDecimal fullReduction(Double price) {
		// 获取满减业务参数，key:500,1000  value: 30 表示金额大于等于500，小于1000区间内的优惠为满500减30，5000,-1表示没有上限
		if (price >= 500 && price <1000) {
			return BigDecimal.valueOf(30);
		} else if (price >= 1000 && price < 3000) {
			return BigDecimal.valueOf(80);
		} else if (price >= 3000 && price < 5000) {
			return BigDecimal.valueOf(100);
		} else if (price >= 5000) {
			int m = (int) (price / 5000);
			return new BigDecimal(150).multiply(new BigDecimal(m));
		}
		return BigDecimal.valueOf(0.0);
	}

	@Transactional(rollbackFor = Exception.class)
	@Override
	public SubmitOrderResponse cartSubmitOrder(SubmitOrderRequest request, String tenantId) {
		boolean activityStatus = Boolean.parseBoolean(ParamCache.getValueDefault(CommonConstant.DOUBLE_ELEVEN_STATUS, Boolean.FALSE.toString()));
		// 交易流水号
		String transactionNo = CommonUtil.genTimeID();
		TransactionFlow flow = new TransactionFlow();
		flow.setStatus(1);// 未支付
		flow.setTransactionNo(transactionNo);
		// 查询用户
		User user = userMapper.selectById(AuthUtil.getUserId());
		Assert.notNull(user, "用户信息不存在");
		// 用户地址
		UserAddress userAddress = userAddressService.getById(request.getUserAddressId());
		Assert.notNull(userAddress, "用户地址不存在");
		List<Long> goodsIds = request.getGoodsList().stream().map(OrderGoodsSaveRequest::getGoodsId).collect(Collectors.toList());
		List<String> goodsSpecIds = request.getGoodsList().stream().map(OrderGoodsSaveRequest::getGoodsSpecIds).collect(Collectors.toList());
		List<GoodsInfo> goodsInfoList = goodsInfoService.lambdaQuery().in(GoodsInfo::getId, goodsIds).list();
		List<GoodsSpec> goodsSpecList = goodsSpecService.lambdaQuery().in(GoodsSpec::getId, goodsSpecIds).list();
		Map<Long, GoodsInfo> goodsInfoMap = goodsInfoList.stream().collect(Collectors.toMap(GoodsInfo::getId, Function.identity()));
		Map<Long, GoodsSpec> goodsSpecMap = goodsSpecList.stream().collect(Collectors.toMap(GoodsSpec::getId, Function.identity()));
		// 先校验所有商品和规格的状态
		for (GoodsInfo goodsInfo : goodsInfoList) {
			// 校验商品状态
			this.checkGoodsState(goodsInfo);
		}
		for (GoodsSpec goodsSpec : goodsSpecList) {
			// 校验规格状态
			this.checkGoodsSpecState(goodsSpec);
		}
//		List<GoodsInfo> activityGoods = new ArrayList<>();
		Map<Long, BigDecimal> activityGoodsMap = new HashMap<>();
		// 兑换需要的总积分
		BigDecimal exchangeNeedTotalIntegral = new BigDecimal(0);
		// 活动商品总金额
		double activityGoodsTotalAmount = 0.0;
		for (OrderGoodsSaveRequest req : request.getGoodsList()) {
			GoodsInfo goodsInfo = goodsInfoMap.get(req.getGoodsId());
			GoodsSpec goodsSpec = goodsSpecMap.get(Long.parseLong(req.getGoodsSpecIds()));
			if (ZoneTypeEnum.INTEGRAL_CONVERT.getValue().equals(goodsInfo.getZoneType())) {
				BigDecimal salePrice = goodsSpec.getSalePrice();
				// 计算兑换需要的积分
				BigDecimal needExchangeIntegral = this.calNeedExchangeIntegral(salePrice, goodsSpec.getAgreementPrice()).multiply(new BigDecimal(req.getGoodsNum()));
				exchangeNeedTotalIntegral = exchangeNeedTotalIntegral.add(needExchangeIntegral);
			}
			if (activityStatus && YesOrNoEnum.YES.getValue().equals(goodsInfo.getIsActivity())) {
				// 商品金额
				double goodsTotalAmount = NumberUtil.toDouble(NumberUtil.mul(goodsSpec.getSalePrice(), req.getGoodsNum()));
				activityGoodsMap.put(goodsInfo.getId(), BigDecimal.valueOf(goodsTotalAmount));
				activityGoodsTotalAmount = goodsTotalAmount + activityGoodsTotalAmount;
			}
		}
		// 计算满减
		Map<Long, BigDecimal> goodsDiscountMap = cartFullReduction(activityGoodsMap, activityGoodsTotalAmount);
		// 大于0表示有兑换的商品，需要判断用户积分是否足够
		if (exchangeNeedTotalIntegral.doubleValue() > 0) {
			// 判断用户积分是否足够
			UserApp userApp = userAppMapper.selectOne(Wrappers.lambdaQuery(UserApp.class).eq(UserApp::getUserId, AuthUtil.getUserId()));
			if (userApp.getTicket() < exchangeNeedTotalIntegral.doubleValue()) {
				throw new ServiceException("用户积分不足");
			}
		}

		BigDecimal cartTotalAmount = new BigDecimal(0);
		for (OrderGoodsSaveRequest req : request.getGoodsList()) {
			Order order = new Order();
			// 订单类型
			Integer orderType = this.getOrderType(req.getGoodsId());
			// 生成订单号
			String orderNo = CommonUtil.genTimeID();
			order.setTransactionNo(transactionNo);
			order.setOrderType(orderType);
			order.setSettleType(req.getSettleType());
			order.setUserAddressId(request.getUserAddressId());
			order.setTenantId(tenantId);
			order.setUserName(user.getRealName());
			order.setOutTradeNo(orderNo);
			order.setUserId(user.getId());
			order.setRemark(req.getRemark());
			order.setPayFlag(PayFlagEnum.WAIT_PAY.getValue()); //待付款
			order.setUserAddress(this.getAddress(userAddress));
			order.setTelPhone(userAddress.getPhone());
			order.setDistributeMode(req.getDistributeMode() == null ? 2 : req.getDistributeMode());
			order.setReceivingName(userAddress.getRealName());
			order.setWlPrice(req.getWlPrice());
			// 查询商品信息
			GoodsInfo goodsInfo = goodsInfoMap.get(req.getGoodsId());
			// 查询规格信息
			GoodsSpec goodsSpec = goodsSpecMap.get(Long.parseLong(req.getGoodsSpecIds()));
			// 唯品尚供应链需先调用下单接口，支付完成之后调用确认订单接口
			if (BusinessTypeEnum.NONE_SELF_SUPPORT.getValue().equals(goodsInfo.getBusinessType())
				&& GoodsSourceEnum.WPS.getValue().equals(goodsInfo.getSource())) {
				int num = req.getGoodsNum();
				// 是否为套装规格，调用第三方的购买数=用户购买数*套装商品数量
				if (YesOrNoEnum.YES.getValue().equals(goodsSpec.getIsPackage())) {
					num = req.getGoodsNum() * goodsSpec.getPackageNum();
				}
				String thirdOrderNo = weiPinShangService.createOrder(orderNo, goodsSpec.getOptionId(), goodsInfo.getThirdId(), num, request.getUserAddressId());
				order.setThirdOrderNo(thirdOrderNo);
			}
			// 商品总价
			Double totalFee = NumberUtil.toDouble(NumberUtil.mul(goodsSpec.getSalePrice(), req.getGoodsNum()));
			// 支付总价
			Double payFee = NumberUtil.add(totalFee, req.getWlPrice());
			// 获得积分数
			Double totalTicket = this.calIntegral(goodsInfo, goodsSpec, req.getGoodsNum(), activityGoodsTotalAmount);
			order.setTotalFee(totalFee);
			order.setPayFee(payFee);
			if (activityStatus && CollUtil.isNotEmpty(goodsDiscountMap) && goodsDiscountMap.get(goodsInfo.getId()) != null) {
				order.setDiscountAmount(goodsDiscountMap.get(goodsInfo.getId()));
				order.setPayFee(order.getPayFee() - order.getDiscountAmount().doubleValue());
				order.setActivityIntegral(totalFee);
			}
			order.setTotalTicket(totalTicket);

			// 积分兑换
			if (OrderTypeEnum.RE_EXCHANGE.getValue().equals(orderType)) {
				BigDecimal salePrice = goodsSpec.getSalePrice();
				// 计算兑换需要的积分
				BigDecimal needExchangeIntegral = this.calNeedExchangeIntegral(salePrice, goodsSpec.getAgreementPrice());
				// 兑换所需的金额
				BigDecimal totalAmount = salePrice.subtract(needExchangeIntegral).multiply(new BigDecimal(req.getGoodsNum()));
				order.setTotalFee(totalAmount.doubleValue());
				order.setPayFee(NumberUtil.toDouble(NumberUtil.add(totalAmount, req.getWlPrice())));
				order.setNeedIntegral(needExchangeIntegral.multiply(new BigDecimal(req.getGoodsNum())).doubleValue());
			}

			this.createOrderGoods(goodsInfo, goodsSpec, req.getGoodsNum(), orderNo);
			orderMapper.insert(order);
			cartTotalAmount = cartTotalAmount.add(BigDecimal.valueOf(order.getPayFee()));
			flow.setAmount(cartTotalAmount);
			shoppingCartService.removeById(req.getShoppingCartId());
		}
		transactionFlowService.save(flow);
		SubmitOrderResponse response = new SubmitOrderResponse();
		response.setOrderNo(transactionNo);
		return response;
	}

	@Override
	public FullReductionDetailVO fullReductionDetail(SubmitOrderRequest request) {
		FullReductionDetailVO vo = new FullReductionDetailVO();
		boolean activityStatus = Boolean.parseBoolean(ParamCache.getValueDefault(CommonConstant.DOUBLE_ELEVEN_STATUS, Boolean.FALSE.toString()));
		Map<Long, BigDecimal> activityGoodsMap = new HashMap<>();
//		if (activityStatus) {
			double activityGoodsTotalAmount = 0.0;
			double noActivityGoodsTotalAmount = 0.0;
			double discountAmount = 0.0;

			for (OrderGoodsSaveRequest req : request.getGoodsList()) {
				GoodsInfo goodsInfo = goodsInfoService.getById(req.getGoodsInfoId());
				GoodsSpec goodsSpec = goodsSpecService.getById(Long.parseLong(req.getGoodsSpecId()));
				double goodsTotalAmount = NumberUtil.toDouble(NumberUtil.mul(goodsSpec.getSalePrice(), req.getGoodsNum()));
				if (activityStatus && YesOrNoEnum.YES.getValue().equals(goodsInfo.getIsActivity())) {
					// 商品金额
					activityGoodsMap.put(goodsInfo.getId(), BigDecimal.valueOf(goodsTotalAmount));
					activityGoodsTotalAmount = goodsTotalAmount + activityGoodsTotalAmount;
				} else {
					noActivityGoodsTotalAmount = noActivityGoodsTotalAmount + goodsTotalAmount;
				}
			}
			Map<Long, BigDecimal> map = this.cartFullReduction(activityGoodsMap, activityGoodsTotalAmount);
			if (CollUtil.isNotEmpty(map)) {
				for (Map.Entry<Long, BigDecimal> entry : map.entrySet()) {
					discountAmount = discountAmount + entry.getValue().doubleValue();
				}
			}
			vo.setMultiple(activityGoodsTotalAmount > 3000 ? 5.0 : 4.0);
			vo.setRedIntegral(activityGoodsTotalAmount * 4);
			if (activityGoodsTotalAmount > 3000) {
				vo.setRedIntegralTwo(activityGoodsTotalAmount * 5);
			}
			vo.setDiscountAmount(discountAmount);
			vo.setGreenIntegral(activityGoodsTotalAmount);
			vo.setTotalAmount(activityGoodsTotalAmount + noActivityGoodsTotalAmount - discountAmount);
//		}
		return vo;
	}

	/**
	 * 计算购物车满减
	 * @param activityGoodsMap 活动商品
	 * @param activityGoodsTotalAmount 活动商品总金额
	 */
	private Map<Long, BigDecimal> cartFullReduction(Map<Long, BigDecimal> activityGoodsMap, double activityGoodsTotalAmount) {
		if (CollUtil.isEmpty(activityGoodsMap)) {
			return null;
		}
		// 记录商品优惠金额
		Map<Long, BigDecimal> goodsDiscountMap = new HashMap<>();
		// 先计算优惠的总金额
		// 获取满减业务参数，key:500,1000  value: 30 表示金额大于等于500，小于1000区间内的优惠为满500减30，5000,-1表示没有上限
//		List<DictBiz> dictBizs = dictService.getList(CommonConstant.DOUBLE_ELEVEN_DISCOUNTS);
		// 满减优惠金额
		double fullReductionAmount = 0.0;
//		for (DictBiz dictBiz : dictBizs) {
//			String[] split = dictBiz.getDictValue().split(",");
//			double min = Double.parseDouble(split[0]);
//			double max = Double.parseDouble(split[1]);
//			if (max != -1) {
//				if (activityGoodsTotalAmount >= min && activityGoodsTotalAmount < max) {
//					int m = (int) (activityGoodsTotalAmount / min);
//					fullReductionAmount = Double.parseDouble(dictBiz.getDictKey()) * m;
//				}
//			} else {
//				if (activityGoodsTotalAmount >= min) {
//					int m = (int) (activityGoodsTotalAmount / min);
//					fullReductionAmount = Double.parseDouble(dictBiz.getDictKey()) * m;
//				}
//			}
//		}
		BigDecimal bigDecimal = this.fullReduction(activityGoodsTotalAmount);
		fullReductionAmount = bigDecimal.doubleValue();
		int size = activityGoodsMap.size();
		// 剩余优惠金额
		double remainFullReductionAmount = fullReductionAmount;
		int idx = 1;
		// 计算每个商品的满减优惠金额
		for (Map.Entry<Long, BigDecimal> entry : activityGoodsMap.entrySet()) {
			if (idx == size) {
				goodsDiscountMap.put(entry.getKey(), BigDecimal.valueOf(remainFullReductionAmount));
			} else {
				// 先计算商品优惠金额的比例，然后用比例乘以优惠金额
				BigDecimal divide = entry.getValue().divide(BigDecimal.valueOf(activityGoodsTotalAmount), 4, BigDecimal.ROUND_DOWN);
				BigDecimal multiply = divide.multiply(BigDecimal.valueOf(fullReductionAmount));
				remainFullReductionAmount = remainFullReductionAmount - multiply.doubleValue();
				goodsDiscountMap.put(entry.getKey(), multiply);
				idx++;
			}
		}
		return goodsDiscountMap;
	}

	/**
	 * 计算积分
	 * @param goodsInfo 商品信息
	 * @param goodsSpec 规格信息
	 * @param goodsNum 商品购买数量
	 * @return
	 */
	private Double calIntegral(GoodsInfo goodsInfo, GoodsSpec goodsSpec, Integer goodsNum, Double totalFee) {
		double integral = 0.0;
		if (YesOrNoEnum.NO.getValue().equals(goodsInfo.getIsActivity())) {
			// 兑换获得红色积分倍数
			String exchangeRedIntegralMul = ParamCache.getValueDefault(CommonConstant.EXCHANGE_RED_INTEGRAL_MULTIPLE, "3");
			// 购买获得红色积分倍数
			String buyRedIntegralMul = ParamCache.getValueDefault(CommonConstant.BUY_RED_INTEGRAL_MULTIPLE, "2");
			// 计算积分，不同专区类型比例
			if (ZoneTypeEnum.INTEGRAL_CONVERT.getValue().equals(goodsInfo.getZoneType()) || ZoneTypeEnum.CITY_PARTNER.getValue().equals(goodsInfo.getZoneType())) {
				integral =  NumberUtil.toDouble(NumberUtil.mul(goodsSpec.getSalePrice().multiply(new BigDecimal(exchangeRedIntegralMul)), goodsNum));
			} else if (ZoneTypeEnum.RED_INTEGRAL.getValue().equals(goodsInfo.getZoneType()) || ZoneTypeEnum.GUEST.getValue().equals(goodsInfo.getZoneType())
				|| ZoneTypeEnum.HOT_STYLE.getValue().equals(goodsInfo.getZoneType()) || ZoneTypeEnum.LINKED.getValue().equals(goodsInfo.getZoneType())) {
				integral =  NumberUtil.toDouble(NumberUtil.mul(goodsSpec.getSalePrice().multiply(new BigDecimal(buyRedIntegralMul)), goodsNum));
			} else {
				integral =  NumberUtil.toDouble(NumberUtil.mul(goodsSpec.getObtainIntegral(), goodsNum));
			}
		} else {
			String exchangeRedIntegralMul = ParamCache.getValueDefault(CommonConstant.DOUBLE_ELEVEN_INTEGRAL_MULTIPLE, "4");
			// 参加双十一活动商品，四倍积分，金额大于3000五倍积分
			if (totalFee < 3000) {
				integral = NumberUtil.toDouble(NumberUtil.mul(goodsSpec.getSalePrice().multiply(new BigDecimal(exchangeRedIntegralMul)), goodsNum));
			} else {
				integral =  NumberUtil.toDouble(NumberUtil.mul(goodsSpec.getSalePrice().multiply(new BigDecimal(exchangeRedIntegralMul).add(new BigDecimal("1"))), goodsNum));
			}
		}


		return integral;
	}

	/**
	 * 创建 OrderGoods
	 * @param goodsInfo
	 * @param goodsSpec
	 * @param goodsNum
	 * @param orderNo
	 */
	private void createOrderGoods(GoodsInfo goodsInfo, GoodsSpec goodsSpec, Integer goodsNum, String orderNo) {
		OrderGoods orderGoods = new OrderGoods();
		orderGoods.setAgreementPrice(goodsSpec.getAgreementPrice());
		orderGoods.setSalePrice(goodsSpec.getSalePrice());
		orderGoods.setBusinessType(goodsInfo.getBusinessType());
		orderGoods.setGoodsImg(goodsInfo.getGoodsCover());
		orderGoods.setGoodsId(goodsInfo.getId());
		orderGoods.setGoodsPrice(goodsSpec.getSalePrice().doubleValue());
		orderGoods.setGoodsSpecNames(goodsSpec.getSpceName());
		orderGoods.setGoodsNum(goodsNum);
		orderGoods.setOutTradeNo(orderNo);
		orderGoods.setGoodsName(goodsInfo.getGoodsName());
		orderGoods.setGoodsSpecIds(goodsSpec.getId().toString());
		orderGoods.setTicketVal(goodsSpec.getObtainIntegral().doubleValue());
		orderGoods.setGoodsType(goodsInfo.getZoneType());
		orderGoods.setIsPackage(goodsSpec.getIsPackage());
		orderGoods.setPackageNum(goodsSpec.getPackageNum());
		orderGoods.setIsActivity(goodsInfo.getIsActivity());
		orderGoods.insert();
	}


	/**
	 * 城市合伙人校验
	 * @param order
	 * @param request
	 */
	private void cityPartnerCheck(Order order, ReOrderSaveRequest request) {
		// 一人只能购买一个城市合伙人订单
		Integer count = orderService.lambdaQuery()
			.in(Order::getPayFlag, CollUtil.newArrayList(PayFlagEnum.WAIT_PAY.getValue(), PayFlagEnum.WAIT_DELIVERY.getValue(),
				PayFlagEnum.WAIT_RECEIVE.getValue(), PayFlagEnum.COMPLETED.getValue()))
			.eq(Order::getOrderType, OrderTypeEnum.PARTNER.getValue()).eq(Order::getUserId, AuthUtil.getUserId()).count();
		if (count > 0) {
			throw new ServiceException("一人只能购买一个城市合伙人订单");
		}
		// 积分兑换时判断用户积分是否足够
		UserApp userApp = userAppMapper.selectOne(Wrappers.lambdaQuery(UserApp.class).eq(UserApp::getUserId, AuthUtil.getUserId()));
		if (request.getPayType() == 2) {// 混合支付
			if (userApp.getTicket() < request.getIntegral().doubleValue()) {
				throw new ServiceException("积分不足");
			}
			BigDecimal add = request.getAmount().add(request.getIntegral());
			if (add.doubleValue() != order.getTotalFee()) {
				throw new ServiceException("金额积分总数错误");
			}
			order.setPayFee(request.getAmount().doubleValue() + request.getWlPrice());
			order.setNeedIntegral(request.getIntegral().doubleValue());
		}
		if (request.getPayType() == 3) {// 积分支付
			if (userApp.getTicket() < order.getTotalFee()) {
				throw new ServiceException("积分不足");
			}
			order.setPayFee(request.getWlPrice());
			order.setNeedIntegral(order.getTotalFee());
		}
	}

	/**
	 * 根据商品获取对应的订单类型
	 * @param goodsId
	 * @return
	 */
	private Integer getOrderType(Long goodsId) {
		GoodsInfo goodsInfo = goodsInfoService.getById(goodsId);
		if (ZoneTypeEnum.GREEN_INTEGRAL.getValue().equals(goodsInfo.getZoneType())) {
			return OrderTypeEnum.NORMAL.getValue();
		} else if (ZoneTypeEnum.INTEGRAL_CONVERT.getValue().equals(goodsInfo.getZoneType())) {
			return OrderTypeEnum.RE_EXCHANGE.getValue();
		} else if (ZoneTypeEnum.RED_INTEGRAL.getValue().equals(goodsInfo.getZoneType()) || ZoneTypeEnum.HOT_STYLE.getValue().equals(goodsInfo.getZoneType())) {
			return OrderTypeEnum.RE_ORDER.getValue();
		} else if (ZoneTypeEnum.GUEST.getValue().equals(goodsInfo.getZoneType())) {
			return OrderTypeEnum.MAKE.getValue();
		} else if (ZoneTypeEnum.CITY_PARTNER.getValue().equals(goodsInfo.getZoneType())) {
			return OrderTypeEnum.PARTNER.getValue();
		} else if (ZoneTypeEnum.LINKED.getValue().equals(goodsInfo.getZoneType())) {
			return OrderTypeEnum.LINKED.getValue();
		} else {
			throw new ServiceException("参数错误");
		}
	}

	/**
	 * 积分兑换
	 */
	private void exchange(Order order, ReOrderSaveRequest request) {
		BigDecimal totalAmount = new BigDecimal(0);
		BigDecimal totalIntegral = new BigDecimal(0);
		for (OrderGoodsSaveRequest item : request.getGoodsList()) {
			GoodsInfo goodsInfo = goodsInfoService.getById(item.getGoodsId());
			if (!ZoneTypeEnum.INTEGRAL_CONVERT.getValue().equals(goodsInfo.getZoneType())) {
				throw new ServiceException("该商品不能兑换");
			}
			GoodsSpec goodsSpec = goodsSpecService.getById(item.getGoodsSpecIds());
			BigDecimal salePrice = goodsSpec.getSalePrice();
			// 计算兑换需要的积分
			BigDecimal needExchangeIntegral = this.calNeedExchangeIntegral(salePrice, goodsSpec.getAgreementPrice());
			// 兑换所需的金额
			totalAmount = salePrice.subtract(needExchangeIntegral).multiply(new BigDecimal(item.getGoodsNum()));
			totalIntegral = totalIntegral.add(needExchangeIntegral.multiply(new BigDecimal(item.getGoodsNum())));
		}
		order.setTotalFee(totalAmount.doubleValue());
		order.setPayFee(NumberUtil.toDouble(NumberUtil.add(totalAmount, order.getWlPrice())));
		order.setNeedIntegral(totalIntegral.doubleValue());

		// 积分兑换时判断用户积分是否足够
		UserApp userApp = userAppMapper.selectOne(Wrappers.lambdaQuery(UserApp.class).eq(UserApp::getUserId, AuthUtil.getUserId()));
		if (userApp.getTicket() < totalIntegral.doubleValue()) {
			throw new ServiceException("用户积分不足");
		}
	}

	/**
	 * 计算积分兑换所需要的积分
	 * @param salePrice 售价
	 * @param agreementPrice 协议价
	 * @return 所需要的积分
	 */
	public BigDecimal calNeedExchangeIntegral(BigDecimal salePrice, BigDecimal agreementPrice) {
//		// 售价红包比例
//		String rate = ParamCache.getValueDefault(CommonConstant.SALE_PRICE_RED_ENVELOPE_RATE, "0.2");
//		// 兑换比例
//		String exchangeRate = ParamCache.getValueDefault(CommonConstant.EXCHANGE_RATE, "0.1");
//		BigDecimal subtract = salePrice.subtract(agreementPrice);
//		BigDecimal red = subtract.multiply(new BigDecimal(rate));
//		BigDecimal exchange = subtract.multiply(new BigDecimal(exchangeRate));
//		return subtract.subtract(red).subtract(exchange);
		BigDecimal amount = salePrice.multiply(new BigDecimal("0.3")).add(agreementPrice);
		return salePrice.subtract(amount);
	}


	/**
	 * 校验商品状态
	 */
	private void checkGoodsState(GoodsInfo goodsInfo) {
		if (goodsInfo == null) {
			throw new ServiceException("商品不存在！");
		}
		if (GoodsStateEnum.UNDERCARRIAGE.getValue().equals(goodsInfo.getIsSale())) {
			throw new ServiceException("商品[" + goodsInfo.getGoodsName() + "]已下架！");
		}
		if (goodsInfo.getTotalStock() < 1) {
			throw new ServiceException("商品[" + goodsInfo.getGoodsName() + "]库存不足！");
		}
	}

	/**
	 * 校验规格状态
	 */
	private void checkGoodsSpecState(GoodsSpec goodsSpec) {
		if (goodsSpec == null) {
			throw new ServiceException("规格不存在！");
		}
		if (GoodsStateEnum.UNDERCARRIAGE.getValue().equals(goodsSpec.getIsSale())) {
			throw new ServiceException("规格[" + goodsSpec.getSpceName() + "]已下架！");
		}
		if (goodsSpec.getStock() < 1) {
			throw new ServiceException("规格[" + goodsSpec.getSpceName() + "]库存不足！");
		}
	}

	private String getAddress(UserAddress userAddress) {
		return userAddress.getProvince() + userAddress.getCity() + userAddress.getDistrict() + userAddress.getDetail();
	}
}
