package org.springblade.modules.api.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alipay.api.AlipayApiException;
import com.alipay.api.AlipayClient;
import com.alipay.api.AlipayConstants;
import com.alipay.api.domain.AlipayFundTransUniTransferModel;
import com.alipay.api.domain.AlipayTradeAppPayModel;
import com.alipay.api.domain.Participant;
import com.alipay.api.internal.util.AlipaySignature;
import com.alipay.api.request.*;
import com.alipay.api.response.*;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.PayFlagEnum;
import org.springblade.common.enums.YesOrNoEnum;
import org.springblade.common.utils.CommonUtil;
import org.springblade.common.utils.StringUtils;
import org.springblade.core.log.exception.ServiceException;
import org.springblade.core.log.logger.BladeLogger;
import org.springblade.modules.api.response.AliUserInfoResponse;
import org.springblade.modules.api.service.IAliService;
import org.springblade.modules.api.service.IZhzxAliService;
import org.springblade.modules.finance.entity.Order;
import org.springblade.modules.finance.entity.OrderRefund;
import org.springblade.modules.finance.entity.TransactionFlow;
import org.springblade.modules.finance.pay.entity.ZhzxAlipayProperties;
import org.springblade.modules.finance.service.IOrderRefundService;
import org.springblade.modules.finance.service.IOrderService;
import org.springblade.modules.finance.service.ITransactionFlowService;
import org.springblade.modules.platform.service.UserAppService;
import org.springblade.modules.system.entity.PayLog;
import org.springblade.modules.system.entity.UserApp;
import org.springblade.modules.system.service.IPayLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.Assert;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

@Service
public class ZhzxAliServiceImpl implements IZhzxAliService {

	private static final Logger log = LoggerFactory.getLogger(IAliService.class);

	@Resource
	private ZhzxAlipayProperties properties;
	@Resource(name = "zhzxAlipayClient")
	private AlipayClient alipayClient;
	@Resource
	private BladeLogger bladeLogger;
	@Resource
	private IPayLogService payLogService;
	@Autowired
	private UserAppService userAppService;
	@Resource
	private IOrderRefundService orderRefundService;
	@Resource
	private IOrderService orderService;
	@Resource
	private ITransactionFlowService transactionFlowService;

	@Override
	public String getVerifyid(String realName, String idNum, String mobile) throws AlipayApiException {
		AlipayUserCertdocCertverifyPreconsultRequest request = new AlipayUserCertdocCertverifyPreconsultRequest();
		//构造身份信息json对象  JSONObject 阿里的fastjson
		JSONObject identityObj = new JSONObject();
		//真实姓名，必填
		identityObj.put("user_name", realName);
		//证件类型，必填
		identityObj.put("cert_type", "IDENTITY_CARD");
		//证件号码,必填
		identityObj.put("cert_no", idNum);
		//手机号
		identityObj.put("mobile", mobile);
		request.setBizContent(identityObj.toString());
		AlipayUserCertdocCertverifyPreconsultResponse response = alipayClient.certificateExecute(request);
		if (response.isSuccess()) {
			return response.getVerifyId();
		} else {
			bladeLogger.error("录入实名信息获取Verifyid", JSONObject.toJSONString(response));
			throw new RuntimeException("获取Verifyid失败,请重试");
		}
	}

	@Override
	public Boolean realNameCheck(String verifyid, String authCode) throws AlipayApiException {
		String accessToken = this.getAccessTokenByAuthCode(authCode);
		if (StringUtils.isBlank(accessToken)) {
			throw new RuntimeException("获取令牌失败");
		}
		AlipayUserCertdocCertverifyConsultRequest request = new AlipayUserCertdocCertverifyConsultRequest();
		JSONObject jsonObject = new JSONObject();
		jsonObject.put("verify_id", verifyid);
		request.setBizContent(jsonObject.toString());
		AlipayUserCertdocCertverifyConsultResponse response = alipayClient.certificateExecute(request, accessToken);
		if (response.isSuccess()) {
			String passed = response.getPassed();
			if ("T".equalsIgnoreCase(passed)) {
				return true;
			} else {
				bladeLogger.error("【支付宝真实信息验证】失败", JSONObject.toJSONString(response));
				log.info("【支付宝真实信息验证】失败参数:{}", response.getFailParams());
				log.info("【支付宝真实信息验证】失败原因:{}", response.getFailReason());
				throw new RuntimeException(response.getFailReason());
			}
		} else {
			bladeLogger.error("【支付宝真实信息验证】失败", JSONObject.toJSONString(response));
			log.info("【支付宝真实信息验证】失败参数:{}", response.getSubMsg());
			throw new RuntimeException(response.getSubMsg());
		}
	}

	@Override
	public AliUserInfoResponse getAliUserInfo(String authCode) throws AlipayApiException {
		String accessToken = this.getAccessTokenByAuthCode(authCode);
		if (StringUtils.isBlank(accessToken)) {
			throw new ServiceException("获取令牌失败");
		}
		AlipayUserInfoShareRequest request = new AlipayUserInfoShareRequest();
		AlipayUserInfoShareResponse response = alipayClient.certificateExecute(request, accessToken);
		AliUserInfoResponse aliUserInfoResponse = new AliUserInfoResponse();
		if (response.isSuccess()) {
			aliUserInfoResponse.setUserId(response.getUserId())
				.setAvatar(response.getAvatar())
				.setCity(response.getCity())
				.setProvince(response.getProvince())
				.setNickName(response.getNickName())
				.setGender(response.getGender());
		} else {

			log.info("【支付宝】获取用户信息失败:{}", response.getSubMsg());
		}
		return aliUserInfoResponse;
	}

	/**
	 *
	 * 向指定阿里用户付款
	 * @param type 类型默认0 余额提现 1 特殊账号打款 2 红包提现
	 * @param userId 系统用户Id
	 * @param aliUserId 阿里用户Id
	 * @param name 用户真实名字
	 * @param transAmount 金额
	 * @param orderTitle 标题
	 * @param remarks 备注
	 * @return PayLog
	 */
	@Override
	@Transactional(rollbackFor = Exception.class,propagation = Propagation.REQUIRES_NEW)
	public PayLog pay(Integer type,Long userId,String aliUserId, String name, BigDecimal transAmount, String orderTitle,String remarks) {

		PayLog payLog = new PayLog();
		payLog.setType(type);
		payLog.setAmount(transAmount);
		payLog.setReceiverUserId(userId);
		payLog.setReceiverAccount(aliUserId);
		payLog.setReceiverType(0);
		payLog.setRemarks(remarks);
		LambdaQueryWrapper<UserApp> wrapper = new LambdaQueryWrapper<>();
		wrapper.eq(UserApp::getUserId, userId);
		UserApp userApp = userAppService.getOne(wrapper);
		payLog.setBeforeAmount(userApp.getRedMoney()==null?new BigDecimal(0):userApp.getRedMoney());
		try {
			AlipayFundTransUniTransferModel model = new AlipayFundTransUniTransferModel();
			model.setOutBizNo(CommonUtil.genTimeID());
			model.setRemark(remarks);
			model.setBusinessParams("{\"payer_show_name_use_alias\":\"true\"}");
			model.setBizScene("DIRECT_TRANSFER");
			Participant payeeInfo = new Participant();
			payeeInfo.setIdentity(aliUserId);
			payeeInfo.setIdentityType("ALIPAY_USER_ID");
			payeeInfo.setName(name);
			model.setPayeeInfo(payeeInfo);
			if(type == 2){//红包提现
				payLog.setRealAmount(transAmount);
				model.setTransAmount(transAmount.toString());
			}else {
				payLog.setRealAmount(transAmount);
				model.setTransAmount(transAmount.toString());
			}


			model.setProductCode("TRANS_ACCOUNT_NO_PWD");
			model.setOrderTitle(orderTitle);
			AlipayFundTransUniTransferRequest request = new AlipayFundTransUniTransferRequest();
			request.setBizModel(model);
			AlipayFundTransUniTransferResponse response = alipayClient.certificateExecute(request);

			if (!response.isSuccess()) {
				log.info("向用户【" + name + " 】打款失败，打款账号：" + aliUserId);
				bladeLogger.info("打款失败", ",打款人：" + name + "支付宝账号：" + aliUserId + "，支付宝返回数据:" + JSON.toJSONString(response));
				payLog.setIsSuccess(0);
				payLog.setFailureReason(response.getSubMsg());
			} else {
				log.info("向用户【" + name + " 】打款成功，打款账号：" + aliUserId);
				bladeLogger.info("打款成功", ",打款人：" + name + "支付宝账号：" + aliUserId + "，支付宝返回数据:" + JSON.toJSONString(response));
				//如果是红包提现
//				if (type==2){
//
//					//更新用户余额
//					UpdateWrapper wrapper1 = new UpdateWrapper();
//					wrapper1.eq("user_id",userId);
//					wrapper1.setSql(" red_money = ( CASE WHEN IFNULL( red_money, '' ) = '' THEN '' ELSE red_money END) - "+transAmount);
//					userAppService.update(wrapper1);
//					payLog.setAfterAmount(userApp.getRedMoney().subtract(transAmount));
//				}
				payLog.setIsSuccess(1);

			}
		} catch (AlipayApiException e) {
			e.printStackTrace();
			log.info("打款失败", ",打款人：" + name + "支付宝账号：" + aliUserId + ", " + e.getMessage());
			bladeLogger.info("打款失败", ",打款人：" + name + "支付宝账号：" + aliUserId + "，支付宝返回数据:" + e.getMessage());
			payLog.setIsSuccess(0);
			payLog.setFailureReason(e.getMessage());
		}
		//保存打款日志
		payLogService.save(payLog);
		return payLog;

	}

	@Override
	public boolean rsaCertCheck(Map<String, String> params) throws AlipayApiException {
		return AlipaySignature.rsaCertCheckV1(params, properties.getAliPayCertPath(), AlipayConstants.CHARSET_UTF8, "RSA2");
	}

	@Override
	public String getPayeeUserId() {
		return properties.getPayeeUserId();
	}

	@Override
	public void check(Map<String, String> params, TransactionFlow flow) {
		if (flow == null) {
			throw new ServiceException("out_trade_no错误");
		}

		Integer count = orderService.lambdaQuery().eq(Order::getTransactionNo, flow.getTransactionNo()).count();
		if (count < 1) {
			throw new ServiceException("购物车订单数据为空");
		}

		// 2、判断total_amount是否确实为该订单的实际金额（即商户订单创建时的金额），
		double total_amount = new BigDecimal(params.get("total_amount")).doubleValue();
		if (total_amount != flow.getAmount().doubleValue()) {
			throw new ServiceException("金额不一致");
		}

		// 4、验证app_id是否为该商户本身。
		if (!params.get("app_id").equals(properties.getAppId())) {
			throw new ServiceException("app_id不一致");
		}
	}

	@Override
	public void check(Map<String, String> params, Order order) {
		if (order == null) {
			throw new ServiceException("out_trade_no错误");
		}

		// 2、判断total_amount是否确实为该订单的实际金额（即商户订单创建时的金额），
		double total_amount = new BigDecimal(params.get("total_amount")).doubleValue();
		if (total_amount != order.getPayFee()) {
			throw new ServiceException("金额不一致");
		}

		// 4、验证app_id是否为该商户本身。
		if (!params.get("app_id").equals(properties.getAppId())) {
			throw new ServiceException("app_id不一致");
		}
	}

	@Override
	public String init(String outTradeNo, String amount, String callbackUrl) {
		// 构建支付宝支付参数
		AlipayTradeAppPayRequest request = new AlipayTradeAppPayRequest ();
		AlipayTradeAppPayModel model = new AlipayTradeAppPayModel ();
		model.setBody("中宏商城" );
		model.setSubject("中宏商城");
		model.setOutTradeNo(outTradeNo);
		model.setTimeoutExpress("30m");
		model.setTotalAmount(amount);
		model.setProductCode("QUICK_MSECURITY_PAY");
		request.setBizModel(model);
		request.setNotifyUrl(properties.getDomain() + callbackUrl);
		try  {
			// 证书方式调用
			AlipayTradeAppPayResponse response = alipayClient.sdkExecute(request);
			return response.getBody();
		}  catch (AlipayApiException e ) {
			log.error("发起支付失败—" + e.getMessage(), e);
			throw new ServiceException("发起支付失败");
		}
	}

	@Override
	public void refund(Order order) {
		Assert.notNull(order.getId(), "订单id参数错误");
		// 记录退款信息
		List<OrderRefund> list = orderRefundService.lambdaQuery().eq(OrderRefund::getOrderId, order.getId()).orderByDesc(OrderRefund::getCreateTime).list();
		OrderRefund orderRefund;
		if (CollUtil.isNotEmpty(list)) {
			orderRefund = list.get(0);
		} else {
			orderRefund = OrderRefund.build(order.getId());
		}
		// 构建支付宝退款请求参数
		AlipayTradeRefundRequest request = new AlipayTradeRefundRequest();
		JSONObject bizContent = new JSONObject();
		bizContent.put("refund_amount", order.getPayFee());
		if (StrUtil.isNotBlank(order.getTransactionNo())) {
			TransactionFlow flow = transactionFlowService.getByNo(order.getTransactionNo());
			bizContent.put("out_trade_no", new Integer(2).equals(flow.getStatus()) ? order.getTransactionNo() : order.getOutTradeNo());
			bizContent.put("out_request_no", orderRefund.getRefundNo());
		} else {
			bizContent.put("out_trade_no", order.getOutTradeNo());
		}
		request.setBizContent(bizContent.toString());
		try {
			AlipayTradeRefundResponse response = alipayClient.certificateExecute(request);
			if(response.isSuccess()){
				log.info("退款成功, 订单号[{}]", order.getOutTradeNo() + ",支付宝返回数据:" + JSON.toJSONString(response));
				bladeLogger.info("退款成功", "订单号:" + order.getOutTradeNo() + ",支付宝返回数据:" + JSON.toJSONString(response));
				order.setIsRefund(YesOrNoEnum.YES.getValue());
				order.setPayFlag(PayFlagEnum.REFUNDED.getValue());
				orderRefundService.success(orderRefund);
				orderService.updateById(order);
			} else {
				log.info("退款失败, 订单号[{}], 支付宝返回数据[{}]", order.getOutTradeNo(), JSON.toJSONString(response));
				bladeLogger.info("退款失败", "订单号:" + order.getOutTradeNo() + ",支付宝返回数据:" + JSON.toJSONString(response));
				orderRefundService.failure(orderRefund, response.getSubMsg());
				throw new ServiceException("退款失败, " + response.getCode() + ":" + response.getSubMsg());
			}
		} catch (AlipayApiException e) {
			log.error("退款异常," + e.getMessage(), e);
			bladeLogger.error("退款异常", "订单号:" + order.getOutTradeNo() + ",errorMessage:" + e.getMessage());
			orderRefundService.failure(orderRefund, e.getErrMsg());
			throw new ServiceException(e.getMessage());
		}
	}


	//根据authCode授权码获取accessToken令牌
	public String getAccessTokenByAuthCode(String authCode) {

		AlipaySystemOauthTokenRequest request = new AlipaySystemOauthTokenRequest();
		request.setCode(authCode);
		request.setGrantType("authorization_code");
		try {
			AlipaySystemOauthTokenResponse response = alipayClient.certificateExecute(request);
			if (response.isSuccess()) {
				String accessToken = response.getAccessToken();
				return accessToken;
			} else {
				throw new AlipayApiException(response.getSubMsg());
			}
		} catch (AlipayApiException e) {
			//处理异常
			e.printStackTrace();
			log.info("获取令牌失败:{}", e.getMessage());
		}
		return null;
	}
}
