package org.springblade.modules.api.task;

import lombok.extern.slf4j.Slf4j;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.YesOrNoEnum;
import org.springblade.core.cache.utils.CacheUtil;
import org.springblade.modules.redenvelopemall.entity.GoodsInfo;
import org.springblade.modules.redenvelopemall.service.IActivitiesGoodsService;
import org.springblade.modules.redenvelopemall.service.IGoodsInfoService;
import org.springblade.modules.system.entity.Param;
import org.springblade.modules.system.service.IParamService;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

import java.util.List;

import static org.springblade.core.cache.constant.CacheConstant.PARAM_CACHE;

/**
 * Author pangqijun
 * Date 2022/11/3
 * Description 双十一活动关闭定时任务
 */
@Slf4j
@Component
@EnableScheduling
public class DoubleElevenCloseTask {

	@Resource
	private IGoodsInfoService goodsInfoService;
	@Resource
	private IParamService paramService;


	@Scheduled(cron = "0 30 17 14 11 ?")
	public void task() {
		log.info("双十一活动关闭定时任务执行...");
		CacheUtil.clear(PARAM_CACHE);
		CacheUtil.clear(PARAM_CACHE, Boolean.FALSE);
		paramService.lambdaUpdate().set(Param::getParamValue, "false").eq(Param::getParamKey, CommonConstant.DOUBLE_ELEVEN_STATUS).update();
		goodsInfoService.lambdaUpdate().set(GoodsInfo::getActivityPrice, YesOrNoEnum.NO.getValue())
			.eq(GoodsInfo::getActivityPrice, YesOrNoEnum.YES.getValue()).update();
		List<GoodsInfo> list = goodsInfoService.lambdaQuery().eq(GoodsInfo::getIsActivity, YesOrNoEnum.YES.getValue()).list();
		for (GoodsInfo goodsInfo : list) {
			goodsInfo.setIsActivity(YesOrNoEnum.NO.getValue());
		}
		goodsInfoService.updateBatchById(list);
	}
}
