package org.springblade.modules.api.task;


import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springblade.common.utils.MerCallServiceSingleton;
import org.springblade.common.utils.StringUtils;
import org.springblade.core.log.model.LogUsual;
import org.springblade.modules.shopping.entity.Consign;
import org.springblade.modules.shopping.service.IConsignService;
import org.springblade.modules.system.entity.PayqueryRecord;
import org.springblade.modules.system.service.ILogUsualService;
import org.springblade.modules.system.service.PayqueryRecordService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.Trigger;
import org.springframework.scheduling.annotation.SchedulingConfigurer;
import org.springframework.scheduling.config.ScheduledTaskRegistrar;
import org.springframework.scheduling.support.CronTrigger;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.Date;
import java.util.List;
import java.util.Map;


@Component
public class PayqueryRecordTask implements SchedulingConfigurer {


	private static final Logger log = LoggerFactory.getLogger(PayqueryRecordTask.class);
	private static final String TASK_NAME = "【定时查询打款状态】";
	@Autowired
	private PayqueryRecordService payqueryRecordService;
	@Autowired
	private ILogUsualService logUsualService;
	@Autowired
	private IConsignService consignService;
	@Resource
	private MerCallServiceSingleton merCallServiceSingleton;//打款工具类

	@Override
	public void configureTasks(ScheduledTaskRegistrar scheduledTaskRegistrar) {


		Runnable task = () -> {
			log.info(TASK_NAME + "定时查询打款状态开始: " + LocalDateTime.now());
			payqueryRecord();
			log.info(TASK_NAME + "定时查询打款状态结束: " + LocalDateTime.now());
		};

		Trigger trigger = triggerContext -> {

			String cron = "0 0/30 * * * ?";
			CronTrigger trigger1 = new CronTrigger(cron);
			return trigger1.nextExecutionTime(triggerContext);
		};
		scheduledTaskRegistrar.addTriggerTask(task, trigger);

	}


	private void payqueryRecord() {

		LambdaQueryWrapper<Consign> query = new LambdaQueryWrapper<>();
		query.eq(Consign::getIsPayment, 2);
		query.eq(Consign::getIsDeleted, 0);
		List<Consign> consigns = consignService.list(query);
		if (consigns.size() <= 0) {
			return;
		}
		for (Consign consign : consigns) {
			LambdaQueryWrapper<PayqueryRecord> queryRecord = new LambdaQueryWrapper<>();
			queryRecord.eq(PayqueryRecord::getConsigId, consign.getId());
			queryRecord.eq(PayqueryRecord::getIsDelete, 0);
			List<PayqueryRecord> list = payqueryRecordService.list(queryRecord);
			if (list.size() == 5) {
				continue;
			}

			LambdaQueryWrapper<LogUsual> queryLogUsual = new LambdaQueryWrapper<>();
			queryLogUsual.eq(LogUsual::getLogId, "打款中");
			queryLogUsual.like(LogUsual::getLogData, consign.getId());
			queryLogUsual.orderByDesc(LogUsual::getCreateTime);
			List<LogUsual> logUsuals = logUsualService.list(queryLogUsual);
			if (logUsuals.size() <= 0) {
				continue;
			}
			LogUsual logUsual = logUsuals.get(0);
			String logData = logUsual.getLogData().split("返回数据：")[1];
			Map<String,String> parse = (Map<String,String>) JSON.parse(logData);
			String merDate = parse.get("mer_date");

			//查询第三方
			Map<String, Map> statusMap = merCallServiceSingleton.queryPaymentStatus(consign.getId() + "", merDate);
			Map request = statusMap.get("request");
			Map response = statusMap.get("response");
			String tradeState = (String) response.get("trade_state");
			if (StringUtils.isNotEmpty(tradeState)) {
				if ("4".equals(tradeState)) {
					consign.setIsPayment(1);
					consignService.saveOrUpdate(consign);
				}
			}

			PayqueryRecord payqueryRecord = new PayqueryRecord();
			payqueryRecord.setConsigId(consign.getId());
			payqueryRecord.setRequestJson(request.toString());
			payqueryRecord.setResponseJson(response.toString());
			payqueryRecord.setStatus(StringUtils.isNotEmpty(tradeState) ? Integer.parseInt(tradeState) : null);
			Date date = new Date();
			payqueryRecord.setIsDelete(0);
			payqueryRecord.setCreateTime(date);
			payqueryRecord.setCreateUserId(0L);
			payqueryRecord.setUpdateTime(date);
			payqueryRecord.setUpdateUserId(0L);
			payqueryRecordService.save(payqueryRecord);
		}


	}
}
