package org.springblade.modules.api.task;

import org.springblade.common.utils.AliyunSmsUtil;
import org.springblade.modules.linked.service.ILinkedUserInfoService;
import org.springblade.modules.linked.vo.LinkedVerifyVO;
import org.springblade.modules.system.service.INowMoneyRecordService;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 数据检验定时任务。
 */

@Component
@EnableScheduling
public class SysErrorTask {

	@Value("${sms.message-phone}")
	private String phone;

	@Value("${spring.profiles.active}")
	private String env;

	@Resource
	private AliyunSmsUtil aliyunSmsUtil;
	@Resource
	private ILinkedUserInfoService linkedUserInfoService;
	@Resource
	private INowMoneyRecordService nowMoneyRecordService;

	/**
	 * 检验1580收益和红包领取是否异常
	 */
	@Scheduled(cron = "0 0 * * * ?")
	public void redMoneyUnlikenessEarnings() {
		if (env.equals("prod")){
			List<LinkedVerifyVO> list = linkedUserInfoService.redMoneyUnlikenessEarnings();
			if (list.size() > 0) {
				// 发送短信
				Map<String, String> param = new HashMap<>();
				param.put("code", "1580");
				aliyunSmsUtil.send("贵州中宏科技", AliyunSmsUtil.DATA_EXCEPTION, phone, param);
			}
		}
	}

	/**
	 * 检验用户现金和余额记录是否异常
	 */
//	@Scheduled(cron = "0 0 * * * ?")
	public void nowMoneyUnlikenessRecord() {
		List<LinkedVerifyVO> list = nowMoneyRecordService.getnowMoneyUnlikenessRecord();
		if (list.size() > 0) {
			//todo 发送短信
		}
	}


}
