package org.springblade.modules.api.task;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.ijpay.core.IJPayHttpResponse;
import com.ijpay.core.enums.RequestMethod;
import com.ijpay.core.kit.WxPayKit;
import com.ijpay.wxpay.WxPayApi;
import com.ijpay.wxpay.enums.WxApiType;
import com.ijpay.wxpay.enums.WxDomain;
import lombok.extern.slf4j.Slf4j;
import org.springblade.core.tool.api.R;
import org.springblade.modules.api.service.IWxPayService;
import org.springblade.modules.finance.pay.entity.WxPayV3Bean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;


/**
 * 定时刷新微信平台证书
 */
@Slf4j
@Component
@EnableScheduling
public class WxPlatformCertMngTask {

	@Resource
	WxPayV3Bean wxPayV3Bean;
	@Resource
	private IWxPayService wxPayService;
	@Value("${spring.profiles.active}")
	private String env;


	@Scheduled(cron = "0 0 */8 * * ?")
	public void task() {
		log.info("同步微信平台证书:[{}]", env);
		if ("dev".equals(env)) {
			return;
		}
		try {
			IJPayHttpResponse response = WxPayApi.v3(
				RequestMethod.GET,
				WxDomain.CHINA.toString(),
				WxApiType.GET_CERTIFICATES.toString(),
				wxPayV3Bean.getMchId(),
				wxPayService.getSerialNumber(),
				null,
				wxPayV3Bean.getKeyPath(),
				""
			);

			String serialNumber = response.getHeader("Wechatpay-Serial");

			String body = response.getBody();
			int status = response.getStatus();

			log.info("serialNumber: {}", serialNumber);
			log.info("status: {}", status);
			log.info("body: {}", body);
			int isOk = 200;
			if (status == isOk) {
				JSONObject jsonObject = JSONUtil.parseObj(body);
				JSONArray dataArray = jsonObject.getJSONArray("data");
				// 默认认为只有一个平台证书
				JSONObject encryptObject = dataArray.getJSONObject(0);
				JSONObject encryptCertificate = encryptObject.getJSONObject("encrypt_certificate");
				String associatedData = encryptCertificate.getStr("associated_data");
				String cipherText = encryptCertificate.getStr("ciphertext");
				String nonce = encryptCertificate.getStr("nonce");
				String serialNo = encryptObject.getStr("serial_no");
				final String platSerialNo = wxPayService.savePlatformCert(associatedData, nonce, cipherText, wxPayV3Bean.getPlatformCertPath());
				log.info("平台证书序列号: {} serialNo: {}", platSerialNo, serialNo);
			}
			// 根据证书序列号查询对应的证书来验证签名结果
			boolean verifySignature = WxPayKit.verifySignature(response, wxPayV3Bean.getPlatformCertPath());
			System.out.println("verifySignature:" + verifySignature);
		} catch (Exception e) {
			log.error("同步微信平台证书失败_" + e.getMessage(), e);
		}
	}
}
