package org.springblade.modules.courier.controller;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.google.gson.Gson;
import com.kuaidi100.sdk.response.SubscribePushParamResp;
import com.kuaidi100.sdk.response.SubscribeResp;
import com.kuaidi100.sdk.utils.SignUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springblade.common.param.SingleParam;
import org.springblade.common.utils.StringUtils;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.tool.api.R;
import org.springblade.modules.courier.entity.CourierData;
import org.springblade.modules.courier.entity.Delivery;
import org.springblade.modules.courier.param.CourierNumberParam;
import org.springblade.modules.courier.param.CourierNumberParamList;
import org.springblade.modules.courier.service.CourierNumberService;
import org.springblade.modules.shopping.entity.Attributes;
import org.springblade.modules.shopping.entity.CatBrands;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.validation.Valid;
import java.util.List;

@RestController
@AllArgsConstructor
@RequestMapping("delivery")
@Api(value = "快递相关接口", tags = "快递相关接口")
public class DeliveryController extends BladeController {

	@Resource
	private CourierNumberService courierNumberService;


	@PostMapping("/insertCourierNumber")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "快递单号录入", notes = "快递单号录入")
	public R insertCourierNumber(@Valid @RequestBody CourierNumberParamList param) {

		BladeUser user = getUser();
		String msg = courierNumberService.insertCourierNumber(param.getList(),user);
		return R.data(msg);
	}



	@PostMapping("/selectCourierData")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "快递信息查询", notes = "快递信息查询")
	public R selectCourierData(@RequestBody SingleParam<String> param) throws Exception {
		if (StringUtils.isEmpty(param.getKey())){
			return R.fail("参数不能为空！");
		}

		List<CourierData> courierDataList = courierNumberService.selectCourierData(param.getKey());
		return R.data(courierDataList);
	}


	@PostMapping("/pageDelivery")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "快递公司信息查询", notes = "快递公司信息查询")
	public R<IPage<Delivery>>  pageDelivery(@RequestBody  SingleParam<String> param,@RequestBody Query query) throws Exception {
		IPage<Delivery> pages= courierNumberService.pageDelivery(param.getKey(), query);
		return R.data(pages);
	}

	@PostMapping("/callback")
	@ApiOperation(value = "快递100订阅回调")
	public SubscribeResp callback(HttpServletRequest request) {
		String orderNo = request.getParameter("orderNo");
		String param = request.getParameter("param");
		String sign = request.getParameter("sign");
		String ourSign = SignUtils.sign(param);

		SubscribeResp subscribeResp = new SubscribeResp();
		subscribeResp.setResult(Boolean.TRUE);
		subscribeResp.setReturnCode("200");
		subscribeResp.setMessage("成功");

		//加密如果相等，属于快递100推送；否则可以忽略掉当前请求
		if (ourSign.equals(sign)) {
			//TODO 业务处理
			SubscribePushParamResp subscribePushParamResp = new Gson().fromJson(param, SubscribePushParamResp.class);
			return subscribeResp;
		}
		return null;
	}

}
