package org.springblade.modules.courier.service.impl;
import com.google.common.collect.Lists;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.google.gson.Gson;
import com.kuaidi100.sdk.api.QueryTrack;
import com.kuaidi100.sdk.core.IBaseClient;
import com.kuaidi100.sdk.pojo.HttpResult;
import com.kuaidi100.sdk.request.*;
import com.kuaidi100.sdk.response.SubscribeResp;
import com.kuaidi100.sdk.utils.SignUtils;
import org.apache.http.HttpStatus;
import org.springblade.common.utils.StringUtils;
import org.springblade.core.log.exception.ServiceException;
import org.springblade.modules.courier.entity.CourierData;
import org.springblade.modules.courier.entity.CourierNumber;
import org.springblade.modules.courier.mapper.CourierDataMapper;
import org.springblade.modules.courier.mapper.CourierNumberMapper;
import org.springblade.modules.courier.service.CourierDataService;
import org.springblade.modules.courier.service.CourierNumberService;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;


@Service
public class CourierDataServiceImpl extends ServiceImpl<CourierDataMapper, CourierData> implements CourierDataService {

	//快递100配置
	@Value("${kuaidi100.key}")
	private String key;
	//快递100配置
	@Value("${kuaidi100.customer}")
	private String customer;
	@Value("${kuaidi100.callbackurl}")
	private String callbackurl;


	@Resource
	private CourierNumberMapper courierNumberMapper;



	@Override
	public List<CourierData> selectByOrderId(CourierNumber courierNumber) {

		LambdaQueryWrapper<CourierData> query = new LambdaQueryWrapper<>();
		query.eq(CourierData::getCourierNumberId,courierNumber.getId());
		query.orderByDesc(CourierData::getTime);
		return this.list(query);
	}

	@Override
	public List<CourierData> queryCourierData(CourierNumber courierNumber) throws Exception {

		QueryTrackReq queryTrackReq = new QueryTrackReq();
		QueryTrackParam queryTrackParam = new QueryTrackParam();
		queryTrackParam.setCom(courierNumber.getDeliveryCode());
		queryTrackParam.setNum(courierNumber.getCourierNumber());
		queryTrackParam.setResultv2("4");
		String param = new Gson().toJson(queryTrackParam);
		queryTrackReq.setParam(param);
		queryTrackReq.setCustomer(customer);
		queryTrackReq.setSign(SignUtils.querySign(param ,key,customer));

		IBaseClient baseClient = new QueryTrack();
		HttpResult execute = baseClient.execute(queryTrackReq);
		courierNumber.setQueryTime(new Date());
		courierNumber.setResponseJson(execute.toString());
		courierNumberMapper.updateById(courierNumber);
		List<CourierData> courierDataList ;
		Map<String,Object> map = (Map<String,Object>) JSON.parse(execute.getBody());
		String status = (String) map.get("status");
		if ("200".equals(status)){
			//删除原来的快递详情
			LambdaQueryWrapper<CourierData> query = new LambdaQueryWrapper<>();
			query.eq(CourierData::getCourierNumberId,courierNumber.getId());
			this.remove(query);

			//创建新的快递详情
			List<Map<String,String>> data =(List<Map<String,String>>) JSON.parse(map.get("data").toString());

			 courierDataList = transition(data,courierNumber);

			this.saveBatch(courierDataList);
		} else{
			//快递100查询报错，直接返回现有详情
			LambdaQueryWrapper<CourierData> query = new LambdaQueryWrapper<>();
			query.eq(CourierData::getCourierNumberId,courierNumber.getId());
			query.orderByDesc(CourierData::getTime);
			return this.list(query);
		}
		return courierDataList;
	}

	private List<CourierData> transition(List<Map<String,String>> data,CourierNumber courierNumber) throws ParseException {
	    List<CourierData> courierDatalist= new ArrayList<>();
		SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
		for (Map<String, String> datum : data) {
			CourierData courierData = new CourierData();
			courierData.setCourierNumberId(courierNumber.getId());
			courierData.setTime(format.parse(datum.get("time")));
			courierData.setContext(datum.get("context"));
			courierData.setFtime(format.parse(datum.get("ftime")));
			courierData.setAreaCode(datum.get("areaCode"));
			courierData.setAreaName(datum.get("areaName"));
			courierData.setStatus(datum.get("status"));
			courierData.setLocation(datum.get("location"));
			courierData.setAreaCenter(datum.get("areaCenter"));
			courierData.setAreaPinYin(datum.get("areaPinYin"));
			courierData.setStatusCode(datum.get("statusCode"));
			courierDatalist.add(courierData);
		}
	    return courierDatalist;
	}

	@Override
	public List<CourierData> createCourierData(CourierNumber courierNumber) throws Exception {

		QueryTrackReq queryTrackReq = new QueryTrackReq();
		QueryTrackParam queryTrackParam = new QueryTrackParam();
		queryTrackParam.setCom(courierNumber.getDeliveryCode());
		queryTrackParam.setNum(courierNumber.getCourierNumber());
		queryTrackParam.setResultv2("4");
		String param = new Gson().toJson(queryTrackParam);
		queryTrackReq.setParam(param);
		queryTrackReq.setCustomer(customer);
		queryTrackReq.setSign(SignUtils.querySign(param ,key,customer));

		IBaseClient baseClient = new QueryTrack();
		HttpResult execute = baseClient.execute(queryTrackReq);

		courierNumber.setQueryTime(new Date());
		courierNumber.setResponseJson(execute.toString());
		courierNumberMapper.updateById(courierNumber);

		Map<String,Object> map = (Map<String,Object>) JSON.parse(execute.getBody());
		String status = (String) map.get("status");

		List<CourierData> courierDataList = new ArrayList<>();

		if ("200".equals(status)){
			List<Map<String,String>> data =(List<Map<String,String>>) JSON.parse(map.get("data").toString());

			courierDataList = transition(data,courierNumber);
			this.saveBatch(courierDataList);
		}

		return courierDataList;
	}

	@Override
	public SubscribeResp subscribe(String orderNo, String number, String company) throws Exception {

		SubscribeParameters parameters = new SubscribeParameters();
		parameters.setCallbackurl(callbackurl + orderNo);

		SubscribeParam param = new SubscribeParam();
		param.setKey(key);
		param.setCompany(company);
		param.setNumber(number);
		param.setParameters(parameters);

		SubscribeReq req = new SubscribeReq();
		req.setSchema("json");
		req.setParam(new Gson().toJson(param));
		IBaseClient baseClient = new QueryTrack();
		HttpResult httpResult = baseClient.execute(req);
		if (httpResult.getStatus() == HttpStatus.SC_OK && StringUtils.isNotBlank(httpResult.getBody())) {
			SubscribeResp subscribeResp = new Gson().fromJson(httpResult.getBody(), SubscribeResp.class);
			if (!"200".equals(subscribeResp.getReturnCode())) {
				throw new ServiceException("订阅失败_" + subscribeResp.getMessage());
			}
			return subscribeResp;
		}
		throw new ServiceException("订阅失败");
	}
}
