package org.springblade.modules.courier.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.modules.courier.entity.CourierData;
import org.springblade.modules.courier.entity.CourierNumber;
import org.springblade.modules.courier.entity.Delivery;
import org.springblade.modules.courier.mapper.CourierNumberMapper;
import org.springblade.modules.courier.param.CourierNumberParam;
import org.springblade.modules.courier.service.CourierDataService;
import org.springblade.modules.courier.service.CourierNumberService;
import org.springblade.modules.courier.service.DeliveryService;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;


@Service
public class CourierNumberServiceImpl extends ServiceImpl<CourierNumberMapper, CourierNumber> implements CourierNumberService {

//	@Autowired
//	private IUserService userService;

	@Resource
	private CourierDataService courierDataService;

	@Resource
	private DeliveryService deliveryService;


	@Value("${kuaidi100.intervalTime}")
	private Integer intervalTime;



	@Override
	public String insertCourierNumber(List<CourierNumberParam> key, BladeUser user) {
		List<CourierNumber> courierNumberList = new ArrayList<>();


		for (CourierNumberParam courierNumberParam : key) {

			//删除原来的快递单号信息
			LambdaQueryWrapper<CourierNumber> query = new LambdaQueryWrapper<>();
			query.eq(CourierNumber::getOrderId,courierNumberParam.getOrderNo());
			this.remove(query);

			//新建快递单号信息
			CourierNumber courierNumber = new CourierNumber();
			courierNumber.setOrderId(courierNumberParam.getOrderNo());
			courierNumber.setOrderType(courierNumberParam.getOrderType());
			courierNumber.setCourierNumber(courierNumberParam.getCourierNumber());
			courierNumber.setDeliveryName(courierNumberParam.getDeliveryName());
			courierNumber.setDeliveryCode(courierNumberParam.getDeliveryCode());
			courierNumber.setStatus(0);
//			User user1 = userService.getById(user.getUserId());
//			courierNumber.setCreateUserName(user1.getRealName());
			courierNumber.setCreateUserId(user.getUserId());
			courierNumber.setUpdateUserId(user.getUserId());
			Date date = new Date();
			courierNumber.setCreateTime(date);
			courierNumber.setUpdateTime(date);
			courierNumber.setIsDelete(0);
			courierNumberList.add(courierNumber);
		}

		this.saveBatch(courierNumberList);
		return "快递单号录入成功！";
	}

	@Override
	public List<CourierData> selectCourierData(String orderId) throws Exception {

		LambdaQueryWrapper<CourierNumber> query = new LambdaQueryWrapper<>();
		query.eq(CourierNumber::getOrderId,orderId).or()
			.eq(CourierNumber::getCourierNumber,orderId);
		query.eq(CourierNumber::getIsDelete,0);
		CourierNumber courierNumber = this.getOne(query);
		if (Objects.isNull(courierNumber)){
			return new ArrayList<>();
		}

		if (Objects.isNull(courierNumber.getQueryTime())){
			//最新查询时间为空，则去查询快递100
			return courierDataService.createCourierData(courierNumber);
		}
		Date nowdate = new Date();
		if ((nowdate.getTime() - courierNumber.getQueryTime().getTime()) /(1000*60) >= intervalTime ){
			//最新查询时间为已经超过半小时，则去查询快递100
			return courierDataService.queryCourierData(courierNumber);
		}

		return courierDataService.selectByOrderId(courierNumber);
	}

	@Override
	public IPage<Delivery> pageDelivery(String key, Query query) {

		return deliveryService.pageDelivery(key,query);

	}

	@Override
	public CourierNumber getByOrderNo(String orderNo) {

		LambdaQueryWrapper<CourierNumber> query = new LambdaQueryWrapper<>();
		query.eq(CourierNumber::getIsDelete,0);
		query.eq(CourierNumber::getOrderId,orderNo);
		return this.getOne(query);
	}


}
