/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.io.IoUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.poi.excel.ExcelReader;
import cn.hutool.poi.excel.ExcelUtil;
import cn.hutool.poi.excel.ExcelWriter;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.annotation.Resource;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import org.apache.poi.ss.usermodel.*;
import org.springblade.common.cache.DictBizCache;
import org.springblade.common.cache.DictCache;
import org.springblade.common.enums.*;
import org.springblade.core.log.logger.BladeLogger;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.api.request.OrderGoodsSaveRequest;
import org.springblade.modules.api.service.IWxPayService;
import org.springblade.modules.api.request.ReOrderSaveRequest;
import org.springblade.modules.api.request.SubmitOrderRequest;
import org.springblade.modules.api.response.SubmitOrderResponse;
import org.springblade.modules.api.service.IReOrderService;
import org.springblade.modules.api.vo.LogisticVO;
import org.springblade.modules.courier.param.CourierNumberParam;
import org.springblade.modules.courier.service.CourierNumberService;
import org.springblade.modules.finance.dto.GoodsOrderExportDTO;
import org.springblade.modules.finance.entity.OrderGoods;
import org.springblade.modules.finance.entity.OrderRefund;
import org.springblade.modules.finance.service.IOrderGoodsService;
import org.springblade.modules.finance.service.IOrderRefundService;
import org.springblade.modules.finance.wrapper.OrderWrapper;
import org.springblade.modules.linked.service.ILinkedUserInfoService;
import org.springblade.modules.platform.entity.Express;
import org.springblade.modules.platform.entity.UserAddress;
import org.springblade.modules.platform.service.IExpressService;
import org.springblade.modules.platform.service.IUserAddressService;
import org.springblade.modules.redenvelopemall.entity.GoodsInfo;
import org.springblade.modules.redenvelopemall.entity.GoodsSpec;
import org.springblade.modules.redenvelopemall.service.IGoodsInfoService;
import org.springblade.modules.redenvelopemall.service.IGoodsSpecService;
import org.springblade.modules.redenvelopemall.service.ISupplyChainService;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.service.IUserService;
import org.springframework.util.Assert;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.Order;
import org.springblade.modules.finance.vo.OrderVO;
import org.springblade.modules.finance.service.IOrderService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.math.BigDecimal;
import java.net.URLEncoder;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 订单表 控制器
 *
 * @author BladeX
 * @since 2022-02-13
 */
@RestController
@RequestMapping("finance/order")
@Api(value = "订单表", tags = "订单表接口")
public class OrderController extends BladeController {

	@Resource
	private IOrderService orderService;
	@Resource
	private IExpressService expressService;
	@Resource
	private ISupplyChainService supplyChainService;
	@Resource
	private IOrderGoodsService orderGoodsService;
	@Resource
	private IGoodsSpecService goodsSpecService;
	@Resource
	private CourierNumberService courierNumberService;
	@Resource
	private IGoodsInfoService goodsInfoService;
	@Resource
	private IUserService userService;
	@Resource
	private IUserAddressService userAddressService;
	@Resource
	private IReOrderService reOrderService;
	@Resource
	private ILinkedUserInfoService linkedUserInfoService;
	@Resource
	private BladeLogger bladeLogger;
	@Resource
	private IOrderRefundService orderRefundService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入order")
	public R<OrderVO> detail(Order order) throws Exception {
		Order detail = orderService.getOne(Condition.getQueryWrapper(order));
		OrderVO orderVO = OrderWrapper.build().entityVO(detail);
		OrderGoods orderGoods = orderGoodsService.lambdaQuery().eq(OrderGoods::getOutTradeNo, detail.getOutTradeNo()).one();
		if (orderGoods != null) {
			GoodsInfo goodsInfo = goodsInfoService.get(orderGoods.getGoodsId());
			GoodsSpec goodsSpec = goodsSpecService.getById(orderGoods.getGoodsSpecIds());
			orderVO.setGoodsInfo(goodsInfo);
			orderVO.setGoodsSpec(goodsSpec);
		}
		orderVO.setOrderGood(orderGoods);
		List<LogisticVO> logistic = new ArrayList<>();
		try {
			logistic = orderService.logistic(detail.getOutTradeNo());
		} catch (Exception ignored) {}
		orderVO.setLogisticList(logistic);

		if (PayFlagEnum.REFUNDING.getValue().equals(detail.getPayFlag()) || PayFlagEnum.REFUNDED.getValue().equals(detail.getPayFlag())) {
			List<OrderRefund> list = orderRefundService.lambdaQuery().eq(OrderRefund::getOrderId, detail.getId()).orderByDesc(OrderRefund::getCreateTime).list();
			if (CollUtil.isNotEmpty(list)) {
				OrderRefund orderRefund = list.get(0);
				orderVO.setRefundApplyTime(orderRefund.getCreateTime());
				orderVO.setRefundTime(orderRefund.getRefundTime());
			}
		}
		return R.data(orderVO);
	}

	/**
	 * 分页 订单表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入order")
	public R<IPage<OrderVO>> list(Order order, Query query) {
		IPage<Order> pages = orderService.selectOrderPage(Condition.getPage(query), order);
		return R.data(OrderWrapper.build().pageVO(pages));
	}

	/**
	 * 商品订单表
	 */
	@GetMapping("/goodsOrder/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入order")
	public R<IPage<OrderVO>> goodsOrder(OrderVO order, Query query, String integralType) {
		IPage<OrderVO> pages = orderService.goodsOrder(Condition.getPage(query), order, integralType);
		for (OrderVO record : pages.getRecords()) {
			// 唯尚品的订单需要恢复成原始的协议价(进价)，方便财务对账
			if (BusinessTypeEnum.NONE_SELF_SUPPORT.getValue().equals(record.getBusinessType())
				&& GoodsSourceEnum.WPS.getValue().equals(record.getSource())) {
				BigDecimal divide = record.getAgreementPrice().divide(new BigDecimal("1.05"), 2, BigDecimal.ROUND_HALF_UP);
				record.setAgreementPrice(divide);
			}
			record.setSourceDesc(GoodsSourceEnum.getNameByValue(record.getSource()));
		}
		return R.data(pages);
	}

	/**
	 * 自定义分页 订单表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入order")
	public R<IPage<OrderVO>> page(OrderVO order, Query query) {
		IPage<Order> pages = orderService.selectOrderPage(Condition.getPage(query), order);
		return R.data(OrderWrapper.build().pageVO(pages));
	}

	/**
	 * 新增 订单表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入order")
	public R save(@Valid @RequestBody Order order) {
		return R.status(orderService.save(order));
	}

	/**
	 * 修改 订单表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入order")
	public R update(@Valid @RequestBody Order order) {
		return R.status(orderService.updateById(order));
	}

	/**
	 * 新增或修改 订单表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入order")
	public R submit(@Valid @RequestBody Order order) {
		return R.status(orderService.saveOrUpdate(order));
	}

	/**
	 * 删除 订单表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(orderService.removeByIds(Func.toLongList(ids)));
	}

	/**
	 * 发货
	 */
	@PostMapping("/deliver")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "发货", notes = "传入order")
	public R deliver(@Valid @RequestBody Order order) {
		Express express = expressService.getOne(Wrappers.<Express>lambdaQuery().eq(Express::getExpressCode, order.getWlCode()));
		Order query = orderService.getById(order.getId());
		order.setSendTime(DateUtil.now());//发货时间
		if (express != null){
			order.setWlName(express.getExpressName());
		}
		if(query.getPayFlag() == 2){
			order.setPayFlag(3);
		}
		return R.status(orderService.updateById(order));
	}

	@PostMapping("export")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "导出")
	public void export(@RequestBody GoodsOrderExportDTO dto, HttpServletResponse response) throws IOException {
		ExcelWriter writer = ExcelUtil.getWriter(true);
		this.writeBillingDetailSheet(writer, dto);
		this.writeOrderDetailSheet(writer, dto);
		this.writeCollInfo(writer, dto);
		//response为HttpServletResponse对象
		response.setContentType("application/vnd.ms-excel;charset=utf-8");
		//test.xls是弹出下载对话框的文件名，不能为中文，中文请自行编码
		response.setHeader("Content-Disposition","attachment;filename=" + URLEncoder.encode("订单数据", "utf-8") + ".xls");
		ServletOutputStream out = response.getOutputStream();

		writer.flush(out, true);

		// 关闭writer，释放内存
		writer.close();
		//此处记得关闭输出Servlet流
		IoUtil.close(out);
	}

	@PostMapping("/refund")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "指定金额退款")
	public R refund(@RequestParam String orderNo, @RequestParam BigDecimal amount,@RequestParam BigDecimal deductIntegral) {
		orderService.refund(orderNo, amount, deductIntegral);
		return R.success("操作成功");
	}

	@PostMapping("/refund/cart")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "购物车退款")
	public R refundCart(@RequestParam String orderNo, @RequestParam BigDecimal amount,@RequestParam BigDecimal deductIntegral) {
		orderService.refundCart(orderNo, amount, deductIntegral);
		return R.success("操作成功");
	}

	@Resource
	private IWxPayService wxPayService;

	@PostMapping("/refundByFlow")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "refundByFlow")
	public R refundByFlow(@RequestParam String trNO, @RequestParam Double amount, @RequestParam Double refundAmount) throws Exception {
		wxPayService.refundByFlow(trNO, amount, refundAmount);
		return R.success("操作成功");
	}

	@PostMapping("/cityPartnerRefund")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "城市合伙人订单退款")
	public R cityPartnerRefund(@RequestParam String orderNo) {
		orderService.cityPartnerRefund(orderNo, null);
		return R.success("操作成功");
	}

	@ApiOperation(value = "绑定物流单号")
	@PostMapping("/bindLogisticsInfo")
	public R bindLogisticsInfo(String orderNo, String wlNo, String wlCompany, String wlCompanyNo) {
		Order order = orderService.getOne(Wrappers.<Order>lambdaQuery().eq(Order::getOutTradeNo, orderNo));
		if (PayFlagEnum.REFUNDING.getValue().equals(order.getPayFlag()) || PayFlagEnum.REFUNDED.getValue().equals(order.getPayFlag()) ||
			PayFlagEnum.COMPLETED.getValue().equals(order.getPayFlag())) {
			return R.fail("当前状态不支持绑定");
		}

		order.setWlCode(wlCompanyNo);
		order.setWlNum(wlNo);
		order.setWlName(wlCompany);
		order.setPayFlag(PayFlagEnum.WAIT_RECEIVE.getValue());
		orderService.updateById(order);

		List<CourierNumberParam> key = new ArrayList<>();
		CourierNumberParam param = new CourierNumberParam();
		param.setOrderNo(orderNo);
		param.setOrderType(order.getOrderType());
		param.setDeliveryCode(wlCompanyNo);
		param.setDeliveryName(wlCompany);
		param.setCourierNumber(wlNo);
		key.add(param);
		courierNumberService.insertCourierNumber(key, AuthUtil.getUser());
		return R.success("绑定成功！");
	}

	@ApiOperation(value = "数据报表")
	@GetMapping("/dataReport")
	public R dataReport() {
		return R.data(orderService.dataReport());
	}

	@ApiOperation(value = "数据报表")
	@GetMapping("/dataReportByDate")
	public R dataReportByDate(String queryType) {
		return R.data(orderService.dataReportByDate(queryType));
	}

	@ApiOperation(value = "数据报表")
	@GetMapping("/orderGoodsProportion")
	public R orderGoodsProportion(String queryType) {
		return R.data(orderService.orderGoodsProportion(queryType));
	}

	@ApiOperation(value = "录入共富1580订单")
	@PostMapping("/linkedOrder/add")
	public R linkedOrderAdd(MultipartFile file) throws IOException {
		ExcelReader reader = ExcelUtil.getReader(file.getInputStream());
		List<Map<String, Object>> maps = reader.readAll();
		for (Map<String, Object> map : maps) {
			Object username = map.get("名字");
			Object phone = map.get("电话");
			Object tj = map.get("推荐人名字");
			Object tjPhone = map.get("推荐人电话");
			Object seq = map.get("顺位排序");

			ReOrderSaveRequest request = new ReOrderSaveRequest();
			request.setPhone(phone.toString());
			request.setUsername(username.toString());
			request.setRecommendPhone(tjPhone.toString());

			if (StrUtil.isBlank(request.getPhone())) {
				return R.fail("请输入电话号码");
			}
			if (StrUtil.isBlank(request.getUsername())) {
				return R.fail("请输入用户名称");
			}
			// 根据电话号码查询用户信息和用户地址信息
			User user = userService.lambdaQuery().eq(User::getAccount, request.getPhone()).one();
			Assert.notNull(user, "用户不存在");
			if (!user.getRealName().equals(request.getUsername())) {
				return R.fail("手机号与用户姓名不匹配");
			}

			List<Order> orders = orderService.lambdaQuery().eq(Order::getOrderType, OrderTypeEnum.LINKED.getValue()).eq(Order::getUserId, user.getId()).list();
			if (CollUtil.isNotEmpty(orders)) {
				continue;
			}

			if (StrUtil.isNotBlank(request.getRecommendPhone())) {
				// 查询推荐人
				User recommendUser = userService.lambdaQuery().eq(User::getAccount, request.getRecommendPhone()).one();
				Assert.notNull(recommendUser, "推荐用户不存在");
				// 根据推荐人手机号查询推荐码
				String promotionCode = linkedUserInfoService.getPromotionNoByPhone(recommendUser.getAccount());
				request.setPromotionCode(promotionCode);
			}

			List<UserAddress> userAddress = userAddressService.lambdaQuery().eq(UserAddress::getUserId, user.getId()).list();
			Assert.notEmpty(userAddress, "用户没有设置地址");
			request.setUserAddressId(userAddress.get(0).getId());
			request.setDistributeMode(1);
			request.setWlPrice(0.00);
			request.setSettleType(SettleTypeEnum.NONE_SELF_SUPPORT.getValue());
			request.setUserId(user.getId());

			// 查询共富1580商品
			List<GoodsInfo> list = goodsInfoService.lambdaQuery().eq(GoodsInfo::getZoneType, ZoneTypeEnum.LINKED.getValue()).eq(GoodsInfo::getIsSale, YesOrNoEnum.YES.getValue()).list();
			Assert.notEmpty(list, "没有有效的共富1580商品");
			GoodsInfo goodsInfo = list.get(0);

			List<GoodsSpec> goodsSpecs = goodsSpecService.lambdaQuery().eq(GoodsSpec::getGoodsId, goodsInfo.getId()).list();
			Assert.notEmpty(list, "没有有效的共富1580商品规格");
			GoodsSpec goodsSpec = goodsSpecs.get(0);

			// 设置商品信息
			List<OrderGoodsSaveRequest> goodsList = new ArrayList<>();
			OrderGoodsSaveRequest orderGoodsSaveRequest = new OrderGoodsSaveRequest();
			orderGoodsSaveRequest.setGoodsId(goodsInfo.getId());
			orderGoodsSaveRequest.setGoodsNum(1);
			orderGoodsSaveRequest.setGoodsSpecIds(goodsSpec.getId().toString());
			goodsList.add(orderGoodsSaveRequest);
			request.setGoodsList(goodsList);

			// 调用下单接口
			SubmitOrderResponse submitOrderResponse = reOrderService.submitOrder(request, "000000");
			Order order = orderService.lambdaQuery().eq(Order::getOutTradeNo, submitOrderResponse.getOrderNo()).one();
			// 调用支付成功接口
			orderService.payCommonSuccess(order, "");
			bladeLogger.info("共富1580订单录入", "排位:" + seq + ",用户名:" + user.getRealName() + ",电话:" + user.getPhone() + ",推荐人手机号:"
				+ request.getRecommendPhone() + ",推荐码:" + request.getPromotionCode());
		}


		return R.success("绑定成功！");
	}

	@PostMapping("/linkedOrder/addByExcel")
	public R linkedOrderAddByExcel(MultipartFile file) throws IOException {
		List<String> noRegister = new ArrayList<>();
		List<String> noRealName = new ArrayList<>();
		List<String> noAddress = new ArrayList<>();
		List<String> tjNoRegister = new ArrayList<>();
		List<String> tjNoRealName = new ArrayList<>();
		List<String> tjNoAddress = new ArrayList<>();
		List<String> usernameError = new ArrayList<>();
		List<String> tjUsernameError = new ArrayList<>();


		ExcelReader reader = ExcelUtil.getReader(file.getInputStream());
		List<Map<String, Object>> maps = reader.readAll();
		for (Map<String, Object> map : maps) {
			Object username = map.get("名字");
			Object phone = map.get("电话");
			Object tj = map.get("推荐人名字");
			Object tjPhone = map.get("推荐人电话");
			Object seq = map.get("顺位排序");
			User user = userService.lambdaQuery().eq(User::getAccount, phone).one();
			if (user == null) {
				noRegister.add(username + " - " + phone);
			} else {
				if (StrUtil.isBlank(user.getRealName())) {
					noRealName.add(username + " - " + phone);
				} else {
					if (!username.equals(user.getRealName())) {
						String s = "账号 " + phone + "与姓名 " + username + "不匹配 realName:" + user.getRealName();
						usernameError.add(s);
					}
				}
				List<UserAddress> userAddress = userAddressService.lambdaQuery().eq(UserAddress::getUserId, user.getId()).list();
				if (CollUtil.isEmpty(userAddress)) {
					noAddress.add(username + " - " + phone);
				}
			}

			User tjuser = userService.lambdaQuery().eq(User::getAccount, tjPhone).one();
			if (tjuser == null) {
				tjNoRegister.add(tj + " - " + tjPhone);
			} else {
				if (StrUtil.isBlank(tjuser.getRealName())) {
					tjNoRealName.add(tj + " - " + tjPhone);
				} else {
					if (!tj.equals(tjuser.getRealName())) {
						String s = "账号 " + tjPhone + "与姓名 " + tj + "不匹配 realName:" + tjuser.getRealName();
						tjUsernameError.add(s);
					}
				}
				UserAddress userAddress = userAddressService.lambdaQuery().eq(UserAddress::getUserId, tjuser.getId()).eq(UserAddress::getDefaultState, 2).one();
				if (userAddress == null) {
					tjNoAddress.add(tj + " - " + tjPhone);
				}
			}
		}

		Map<String, List<String>> res = new HashMap<>();
		res.put("noRegister", noRegister);
		res.put("noRealName", noRealName);
		res.put("tjNoRegister", tjNoRegister);
		res.put("tjNoRealName", tjNoRealName);
		res.put("noAddress", noAddress);
		res.put("tjNoAddress", tjNoAddress);
		res.put("usernameError", usernameError);
		res.put("tjUsernameError", tjUsernameError);

		return R.data(res);
	}

	/**
	 * 写入账单明细sheet页
	 * @param writer
	 * @param dto
	 */
	private void writeBillingDetailSheet(ExcelWriter writer, GoodsOrderExportDTO dto) {
		writer.renameSheet("账单信息");
		// 列名集合
		List<String> headers = CollUtil.newArrayList("结算方", "产品ID", "专区类型", "账单日期", "账单金额", "物流状态", "结算卡号");
		writer.merge(headers.size() - 1 ,"【注】账单明细：商城维度按日汇总的结算数据，当天数据需次日下载查看；订单明细：订单维度详细的结算数据；汇总信息：各项费用累计汇总信息。");
		writer.setRowHeight(0, 70);
		// 写入表头
		this.writeHeader(writer, headers, 1);
		// 切换到下一行
		writer.setCurrentRow(writer.getCurrentRow() + 1);
		// 设置列宽
		for (int i = 0; i < headers.size(); i++) {
			if (i == headers.size() - 1) {
				writer.setColumnWidth(i, 30);
			} else if (i == 1) {
				writer.setColumnWidth(i, 20);
			} else if (i == 3) {
				writer.setColumnWidth(i, 20);
			}
			else {
				writer.setColumnWidth(i, 15);
			}
		}
		List<List<Object>> rows = new ArrayList<>();
		for (OrderVO vo : dto.getOrderList()) {
			List<Object> row = CollUtil.newArrayList(BusinessTypeEnum.SELF_SUPPORT.getValue().equals(vo.getBusinessType()) ? "中宏自营" : "聚合供应链",
				vo.getGoodsId(), ZoneTypeEnum.getNameByValue(vo.getZoneType()), DateUtil.format(vo.getCreateTime(), "yyyy年MM月dd日"),
				vo.getTotalFee(), PayFlagEnum.getNameByValue(vo.getPayFlag()), vo.getSettlementAccount());
			rows.add(row);
		}
		writer.write(rows, true);
	}

	/**
	 * 写入订单明细sheet页
	 * @param writer
	 * @param dto
	 */
	private void writeOrderDetailSheet(ExcelWriter writer, GoodsOrderExportDTO dto) {
		// 列名集合
		List<String> headers = CollUtil.newArrayList("订单号", "商品名称", "订单类型", "收货人", "支付总价", "商品购买总价", "数量", "邮费", "协议价",
			"商品售价", "抵扣积分", "支付状态", "收件人电话", "收货地址", "物流公司", "物流单号", "下单时间", "支付时间", "发货时间", "收货时间");
		writer.setSheet("订单明细");
		// 写入表头
		this.writeHeader(writer, headers, 0);
		// 切换到下一行
		writer.setCurrentRow(writer.getCurrentRow() + 1);
		// 设置列宽
		for (int i = 0; i < headers.size(); i++) {
			if (i == 0) {
				writer.setColumnWidth(i, 20);
			} else if (i == 1) {
				writer.setColumnWidth(i, 50);
			} else {
				writer.setColumnWidth(i, 15);
			}
		}
		List<List<Object>> rows = new ArrayList<>();
		for (OrderVO vo : dto.getOrderList()) {
			List<Object> row = CollUtil.newArrayList(vo.getOutTradeNo(), vo.getGoodsName(), OrderTypeEnum.getNameByValue(vo.getOrderType()),
				vo.getReceivingName(), vo.getPayFee(), vo.getTotalFee(), vo.getGoodsNum(), vo.getWlPrice(), vo.getAgreementPrice(), vo.getSalePrice(), vo.getNeedIntegral(),
				PayFlagEnum.getNameByValue(vo.getPayFlag()), vo.getTelPhone(), vo.getUserAddress(), vo.getWlName(), vo.getWlNum(), vo.getCreateTime(), vo.getSendTime(), vo.getRecordTime());
			rows.add(row);
		}
		writer.write(rows, true);
	}

	/**
	 * 写入信息汇总sheet页
	 * @param writer
	 * @param dto
	 */
	private void writeCollInfo(ExcelWriter writer, GoodsOrderExportDTO dto) {
		writer.setSheet("信息汇总");
		// 列名集合
		List<String> headers = CollUtil.newArrayList("订单日期", "订单数", "订单退款", "合计");
		// 写入表头
		this.writeHeader(writer, headers, 0);
		// 设置列宽
		for (int i = 0; i < headers.size(); i++) {
			if (i == 0) {
				writer.setColumnWidth(i, 30);
			} else {
				writer.setColumnWidth(i, 15);
			}
		}
		// 切换到下一行
		writer.setCurrentRow(writer.getCurrentRow() + 1);
		String dateStr;
		List<OrderVO> orderList = dto.getOrderList();
		if (dto.getOrderStartTime() != null && dto.getOrderEndTime() != null) {
			dateStr = DateUtil.format(dto.getOrderStartTime(), "yyyy年MM月dd日") + "-" + DateUtil.format(dto.getOrderEndTime(), "yyyy年MM月dd日");
		} else {
			dateStr = DateUtil.format(orderList.get(0).getCreateTime(), "yyyy年MM月dd日") + "-" + DateUtil.format(orderList.get(orderList.size() - 1).getCreateTime(), "yyyy年MM月dd日");
		}
		List<OrderVO> collect = orderList.stream().filter(e -> PayFlagEnum.REFUNDING.getValue().equals(e.getPayFlag()) || PayFlagEnum.REFUNDED.getValue().equals(e.getPayFlag())).collect(Collectors.toList());
		List<Object> row = CollUtil.newArrayList(dateStr, orderList.size(), collect.size(), orderList.size() + collect.size());
		List<List<Object>> rows = CollUtil.newArrayList(Collections.singleton(row));
		writer.write(rows, true);
	}

	private void writeHeader(ExcelWriter writer, List<String> headers, int rowIndex) {
		for (int i = 0; i < headers.size(); i++) {
			System.out.println(headers.get(i));
			writer.writeCellValue(i, rowIndex, headers.get(i));
			// 根据x,y轴获取当前单元格样式
			CellStyle cellStyle = writer.createCellStyle(i, rowIndex);
			// 内容水平居中
			cellStyle.setAlignment(HorizontalAlignment.CENTER);
			// 内容垂直居中
			cellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
			// 设置边框
			cellStyle.setBorderBottom(BorderStyle.THIN);
			cellStyle.setBorderLeft(BorderStyle.THIN);
			cellStyle.setBorderRight(BorderStyle.THIN);
			cellStyle.setFillForegroundColor(IndexedColors.LIGHT_YELLOW.getIndex());
			cellStyle.setFillPattern(FillPatternType.SOLID_FOREGROUND);
		}
	}
}
