/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.OrderException;
import org.springblade.modules.finance.vo.OrderExceptionVO;
import org.springblade.modules.finance.service.IOrderExceptionService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 异常订单表 控制器
 *
 * @author BladeX
 * @since 2022-11-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/orderexception")
@Api(value = "异常订单表", tags = "异常订单表接口")
public class OrderExceptionController extends BladeController {

	private final IOrderExceptionService orderExceptionService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入orderException")
	public R<OrderException> detail(OrderException orderException) {
		OrderException detail = orderExceptionService.getOne(Condition.getQueryWrapper(orderException));
		return R.data(detail);
	}

	/**
	 * 分页 异常订单表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入orderException")
	public R<IPage<OrderException>> list(OrderException orderException, Query query) {
		IPage<OrderException> pages = orderExceptionService.page(Condition.getPage(query), Condition.getQueryWrapper(orderException));
		return R.data(pages);
	}

	/**
	 * 自定义分页 异常订单表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入orderException")
	public R<IPage<OrderExceptionVO>> page(OrderExceptionVO orderException, Query query) {
		IPage<OrderExceptionVO> pages = orderExceptionService.selectOrderExceptionPage(Condition.getPage(query), orderException);
		return R.data(pages);
	}

	/**
	 * 新增 异常订单表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入orderException")
	public R save(@Valid @RequestBody OrderException orderException) {
		return R.status(orderExceptionService.save(orderException));
	}

	/**
	 * 修改 异常订单表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入orderException")
	public R update(@Valid @RequestBody OrderException orderException) {
		return R.status(orderExceptionService.updateById(orderException));
	}

	/**
	 * 新增或修改 异常订单表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入orderException")
	public R submit(@Valid @RequestBody OrderException orderException) {
		return R.status(orderExceptionService.saveOrUpdate(orderException));
	}


	@PostMapping("/replacementOrder")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "补单")
	public R replacementOrder(String orderNo, String payCode) {
		orderExceptionService.replacementOrder(orderNo, payCode);
		return R.status(true);
	}

	@PostMapping("/reSubmitOrder")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "重新下单")
	public R reSubmitOrder(String oldOrderNo, String payCode) {
		orderExceptionService.reSubmitOrder(oldOrderNo, payCode);
		return R.status(true);
	}
}
