/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.math.BigDecimal;

/**
 * 订单商品表实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@TableName("t_order_goods")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "OrderGoods对象", description = "订单商品表")
public class OrderGoods extends Model<OrderGoods> {

	private static final long serialVersionUID = 1L;

	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "id", type = IdType.ASSIGN_ID)
	@ApiModelProperty(value = "主键ID")
	private Long id;

	@ApiModelProperty(value = "商品id")
	private Long goodsId;

	@ApiModelProperty(value = "订单号")
	private String outTradeNo;

	@ApiModelProperty(value = "商品数量")
	private Integer goodsNum;

	@ApiModelProperty(value = "商品价格")
	private Double goodsPrice;

	@ApiModelProperty(value = "商品规格ID")
	private String goodsSpecIds;

	@ApiModelProperty(value = "商品规格名")
	private String goodsSpecNames;

	@ApiModelProperty(value = "商品名称")
	private String goodsName;

	@ApiModelProperty(value = "商品图片")
	private String goodsImg;

	@ApiModelProperty(value = "商品类型")
	private Integer goodsType;

	@ApiModelProperty(value = "酒票值")
	private Double ticketVal;

	@ApiModelProperty(value = "商品营业类型")
	private Integer businessType;

	@ApiModelProperty(value = "协议价")
	private BigDecimal agreementPrice;

	@ApiModelProperty(value = "销售价")
	private BigDecimal salePrice;

	@ApiModelProperty(value = "是否为套装 1-是 0-否")
	private Integer isPackage;

	@ApiModelProperty(value = "套装商品数量")
	private Integer packageNum;

	@ApiModelProperty(value = "是否参加活动;1-是  0-否")
	private Integer isActivity;
}
