/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import org.springblade.common.constant.CommonConstant;
import org.springblade.modules.api.vo.LogisticVO;
import org.springblade.modules.finance.entity.Order;
import lombok.Data;
import lombok.EqualsAndHashCode;
import io.swagger.annotations.ApiModel;
import org.springblade.modules.finance.entity.OrderGoods;
import org.springblade.modules.redenvelopemall.entity.GoodsInfo;
import org.springblade.modules.redenvelopemall.entity.GoodsSpec;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 订单表视图实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "OrderVO对象", description = "订单表")
public class OrderVO extends Order {

	private static final long serialVersionUID = 1L;

	@ApiModelProperty(value = "订单状态")
	private String payFlagDisplayName;


	@ApiModelProperty(value = "订单类型：1酒票订单，2寄售订单,3普通订单")
	private String orderTypeDisplayName;

	@ApiModelProperty(value = "配送方式")
	private String distributeModeDisplayName;

	@ApiModelProperty(value = "是否退款")
	private String isRefundDisplayName;

	@ApiModelProperty(value = "状态（预留）")
	private String orderStateDisplayName;

	@ApiModelProperty(value = "到账类型")
	private String settleTypeDisplayName;

	@ApiModelProperty(value = "商品信息")
	private List<OrderGoods> orderGoods;

	@ApiModelProperty(value = "商品名称")
	private String goodsName;

	@ApiModelProperty(value = "商品Id")
	private String goodsId;

	@ApiModelProperty(value = "商品价格")
	private Double salePrice;

	@ApiModelProperty(value = "商品协议价")
	private BigDecimal agreementPrice;

	@ApiModelProperty(value = "规格名称")
	private String specName;

	@ApiModelProperty(value = "数量")
	private Integer goodsNum;

	@ApiModelProperty(value = "营业类型;1-自营 2-他营")
	private Integer businessType;

	@ApiModelProperty(value = "专区类型;1-绿色积分专区 2-积分兑换专区 3-红色积分专区")
	private Integer zoneType;

	@ApiModelProperty(value = "商品来源")
	private String source;

	@ApiModelProperty(value = "商品来源描述")
	private String sourceDesc;

	@JsonFormat(pattern = "yyyyMMdd hh:mm:ss")
	@ApiModelProperty(value = "订单开始时间")
	private Date orderStartTime;

	@JsonFormat(pattern = "yyyy-MM-dd hh:mm:ss")
	@ApiModelProperty(value = "退款申请时间")
	private Date refundApplyTime;

	@JsonFormat(pattern = "yyyy-MM-dd hh:mm:ss")
	@ApiModelProperty(value = "退款时间")
	private Date refundTime;

	@JsonFormat(pattern = "yyyyMMdd hh:mm:ss")
	@ApiModelProperty(value = "订单结束时间")
	private Date orderEndTime;

	@ApiModelProperty(value = "物流信息")
	private List<LogisticVO> logisticList;

	@ApiModelProperty(value = "商品信息")
	private GoodsInfo goodsInfo;

	@ApiModelProperty(value = "商品规格信息")
	private GoodsSpec goodsSpec;

	private OrderGoods orderGood;

	private String payCodeDesc;

	public String getPayCodeDesc() {
		if (CommonConstant.ALI_PAY.equals(this.getPayCode())) {
			return "支付宝";
		} else if(CommonConstant.WX_PAY.equals(this.getPayCode())) {
			return "微信";
		} else {
			return "暂无";
		}
	}
}
