/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.linked.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.linked.entity.LinkedUserInfo;
import org.springblade.modules.linked.vo.UserInfoVO;
import org.springblade.modules.linked.service.ILinkedUserInfoService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 联动模式用户信息表 控制器
 *
 * @author BladeX
 * @since 2022-11-08
 */
@RestController
@AllArgsConstructor
@RequestMapping("linked/userinfo")
@Api(value = "联动模式用户信息表", tags = "联动模式用户信息表接口")
public class LinkedUserInfoController extends BladeController {

	private final ILinkedUserInfoService userInfoService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入userInfo")
	public R<LinkedUserInfo> detail(LinkedUserInfo LUserInfo) {
		LinkedUserInfo detail = userInfoService.getOne(Condition.getQueryWrapper(LUserInfo));
		return R.data(detail);
	}

	/**
	 * 分页 联动模式用户信息表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入userInfo")
	public R<IPage<LinkedUserInfo>> list(LinkedUserInfo LUserInfo, Query query) {
		IPage<LinkedUserInfo> pages = userInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(LUserInfo));
		return R.data(pages);
	}

	/**
	 * 自定义分页 联动模式用户信息表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入userInfo")
	public R<IPage<UserInfoVO>> page(UserInfoVO userInfo, Query query) {
		IPage<UserInfoVO> pages = userInfoService.selectUserInfoPage(Condition.getPage(query), userInfo);
		return R.data(pages);
	}

	/**
	 * 新增 联动模式用户信息表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入userInfo")
	public R save(@Valid @RequestBody LinkedUserInfo LUserInfo) {
		return R.status(userInfoService.save(LUserInfo));
	}

	/**
	 * 修改 联动模式用户信息表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入userInfo")
	public R update(@Valid @RequestBody LinkedUserInfo LUserInfo) {
		return R.status(userInfoService.updateById(LUserInfo));
	}

	/**
	 * 新增或修改 联动模式用户信息表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入userInfo")
	public R submit(@Valid @RequestBody LinkedUserInfo LUserInfo) {
		return R.status(userInfoService.saveOrUpdate(LUserInfo));
	}


	/**
	 * 删除 联动模式用户信息表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(userInfoService.removeByIds(Func.toLongList(ids)));
	}


}
