/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.linked.entity;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springblade.common.base.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 联动模式用户信息表实体类
 *
 * @author BladeX
 * @since 2022-11-08
 */
@Data
@TableName("linked_user_info")
@ApiModel(value = "UserInfo对象", description = "联动模式用户信息表")
public class LinkedUserInfo extends BaseEntity<LinkedUserInfo> implements Cloneable {

	/**
	 * 贡献时间
	 */
	@TableField(value = "contribute_time", fill = FieldFill.INSERT)
	@ApiModelProperty(value = "贡献时间")
	@JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
	private Date contributeTime;
	/**
	 * 用户id
	 */
	@ApiModelProperty(value = "用户id")
	private Long userId;
	/**
	 * 用户名称
	 */
	@ApiModelProperty(value = "用户名称")
	private String userName;
	/**
	 * 是否出局
	 */
	@ApiModelProperty(value = "是否出局")
	private Integer isOut;
	/**
	 * 是否淘汰
	 */
	@ApiModelProperty(value = "是否淘汰")
	private Integer isWeed;
	/**
	 * 推广码
	 */
	@ApiModelProperty(value = "推广码")
	private String promotionNo;
	/**
	 * 收益金额
	 */
	@ApiModelProperty(value = "收益金额")
	private BigDecimal earnings;
	/**
	 * 当前上级id
	 */
	@ApiModelProperty(value = "当前上级id")
	private Long parentId;
	/**
	 * 上级名称
	 */
	@ApiModelProperty(value = "上级名称")
	private String parentName;
	/**
	 * 推荐人id
	 */
	@ApiModelProperty(value = "推荐人id")
	private Long recommendId;
	/**
	 * 推荐人名称
	 */
	@ApiModelProperty(value = "推荐人名称")
	private String recommendName;
	/**
	 * 是否合伙人
	 */
	@ApiModelProperty(value = "是否合伙人")
	private Integer isPartner;

	@Override
	public LinkedUserInfo clone() {
		LinkedUserInfo newParan = null;
		try {
			newParan = (LinkedUserInfo) super.clone();
		} catch (CloneNotSupportedException e) {
			e.printStackTrace();
		}
		return newParan;
	}
}
