/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.linked.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.common.enums.LinkedBindLogEnum;
import org.springblade.modules.linked.entity.LinkedUserInfo;
import org.springblade.modules.linked.entity.LinkedBindLog;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springblade.modules.linked.entity.LinkedOrder;
import org.springblade.modules.linked.vo.LinkedBindLogVO;

import java.util.List;

/**
 * 绑定记录表 服务类
 *
 * @author BladeX
 * @since 2022-11-07
 */
public interface ILinkedBindLogService extends IService<LinkedBindLog> {

	/**
	 * 创建变更绑定记录
	 * @param parentUser 接收上级
	 * @param list 需要变更绑定的人
	 */
	List<LinkedBindLog> createChangeLog(LinkedUserInfo parentUser, List<LinkedUserInfo> list,Integer sort);
	/**
	 * 创建购买商变为合伙人的记录
	 * @param userInfo
	 */
	void createPartnerLog(LinkedUserInfo userInfo,Integer sort);

	/**
	 * 创建入局记录
	 * @param linkedOrder  订单
	 * @param befUser 此订单之前的绑定关系
	 * @param aftUser 此订单之后的绑定关系
	 *
	 */
	void createOrderBindLog(LinkedOrder linkedOrder, LinkedUserInfo befUser,
							LinkedUserInfo aftUser, LinkedBindLogEnum linkedBindLogEnum,Integer sort);

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param bindLog
	 * @return
	 */
	IPage<LinkedBindLogVO> selectBindLogPage(IPage<LinkedBindLogVO> page, LinkedBindLogVO bindLog);


	/**
	 * 创建无效的推荐记录
	 * @param linkedOrder 订单
	 * @param promotion 推荐人
	 * @param parentUser 实际绑定人
	 * @param invalidLog 无效枚举
	 */
	void createInvalidLog(LinkedOrder linkedOrder, LinkedUserInfo promotion,LinkedUserInfo parentUser,
						  LinkedBindLogEnum invalidLog,Integer sort);
}
