/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.linked.service;

import org.springblade.common.enums.LinkedEarningsTypeEnum;
import org.springblade.modules.linked.entity.LinkedUserInfo;
import org.springblade.modules.linked.entity.LinkedOrder;
import org.springblade.modules.linked.vo.LinkedVerifyVO;
import org.springblade.modules.linked.vo.UserInfoVO;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * 联动模式用户信息表 服务类
 *
 * @author BladeX
 * @since 2022-11-08
 */
public interface ILinkedUserInfoService extends IService<LinkedUserInfo> {

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param userInfo
	 * @return
	 */
	IPage<UserInfoVO> selectUserInfoPage(IPage<UserInfoVO> page, UserInfoVO userInfo);


	/**
	 * 绑定用户关系
	 * @param linkedOrder 订单
	 * @return
	 */
	LinkedUserInfo createUser(LinkedOrder linkedOrder);


	/**
	 * 根据推用户id查询用户
	 * @param userId 用户id
	 * @return
	 */
	LinkedUserInfo getByUserId(Long userId);

	/**
	 * 根据推广码查询用户
	 * @param promotionNo 推广码
	 * @return
	 */
	LinkedUserInfo getLinkUserByCode(String promotionNo);

	/**
	 * 查询一级用户信息
	 * @param userId
	 * @return
	 */
	List<LinkedUserInfo> getOneByUserId(Long userId);

	/**
	 * 查询二级用户信息
	 * @param userId
	 * @return
	 */
	List<LinkedUserInfo> getTwoByUserId(Long userId);

	/**
	 *
	 * @param userId 用户id
	 * @param subNumber 扣减/增加收益
	 * @param earningsTypeEnum 枚举
	 */
	Map<String,Object> changeEarnings(Long userId, BigDecimal subNumber, LinkedEarningsTypeEnum earningsTypeEnum);


	/**
	 * 变更上级为合伙人，同时贡献两个人给上级
	 * @param userInfo
	 */
	void changeUserBind(LinkedUserInfo userInfo);


	/**
	 * 通过电话查询推荐码
	 * @param phone
	 */
	String getPromotionNoByPhone(String phone);

	/**
	 * 查询红包领取数额与收益扣减不相等的人员
	 */
	List<LinkedVerifyVO> redMoneyUnlikenessEarnings();
}
