package org.springblade.modules.linked.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.common.base.BaseEntity;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.LinkedEarningsTypeEnum;
import org.springblade.common.utils.RedisTool;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.modules.finance.entity.Order;
import org.springblade.modules.linked.entity.LinkedEarnings;
import org.springblade.modules.linked.entity.LinkedOrder;
import org.springblade.modules.linked.entity.LinkedUserInfo;
import org.springblade.modules.linked.mapper.LinkedOrderMapper;
import org.springblade.modules.linked.service.ILinkedEarningsService;
import org.springblade.modules.linked.service.ILinkedOrderService;
import org.springblade.modules.linked.service.ILinkedUserInfoService;
import org.springblade.modules.linked.vo.OrderVO;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.support.atomic.RedisAtomicLong;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;


@Service
public class ILinkedOrderServiceImpl extends ServiceImpl<LinkedOrderMapper, LinkedOrder> implements ILinkedOrderService {

	@Resource
	private ILinkedUserInfoService linkedUserInfoService;

	private final static String LINKED_ORDER_NO = "linked:order:no:test";

	@Resource
	private ILinkedEarningsService earningsService;

	@Resource
	private RedisTemplate redisTemplate;

	@Resource
	private RedisTool redisTool;

	@Override
	public IPage<OrderVO> selectOrderPage(IPage<OrderVO> page, OrderVO order) {
		return page.setRecords(baseMapper.selectOrderPage(page, order));
	}

	@Override
	public Boolean checkLinkedOrder(Order order) {
		List<LinkedOrder> list = list(Wrappers.lambdaQuery(LinkedOrder.class)
			.eq(LinkedOrder::getUserId, order.getUserId())
			.eq(LinkedOrder::getIsOut, 0));
		if(list.size() > 0){
			return false;
		}
		return true;
	}

	@Override
	public Boolean updateLinkedOrder(Order order) {
		List<LinkedOrder> list = list(Wrappers.lambdaQuery(LinkedOrder.class)
			.eq(LinkedOrder::getUserId, order.getUserId())
			.eq(LinkedOrder::getIsOut, 0));
		if(list.size() > 0){
			return false;
		}

		//通过推广码获取上级用户
		LinkedOrder linkedOrder = new LinkedOrder();
		/*********************创建联动模式订单开始**********************************/
		linkedOrder.setPromotionNo(order.getPromotionCode());
		linkedOrder.setOrderId(order.getId());
		linkedOrder.setUserId(order.getUserId());
		linkedOrder.setUserName(order.getUserName());
		linkedOrder.setIsOut(0);
		/*********************创建联动模式订单结束*****************************/
		/************************收益计算开始********************************/
			//创建绑定关系
			LinkedUserInfo user = linkedUserInfoService.createUser(linkedOrder);
			//获取上级用户
			LinkedUserInfo fuser = linkedUserInfoService.getByUserId(user.getParentId());
			/***************************消费收益*******************************/
			if(fuser.getIsPartner() == 0){//上级为消费商时进行消费收益计算
				LinkedEarnings linkedEarnings = new LinkedEarnings();
				linkedEarnings.setAmount(new BigDecimal(ParamCache.getValue(CommonConstant.LINKED_EARNINGS_CONSUMPTION)));
				linkedEarnings.setBuyUserId(user.getUserId());
				linkedEarnings.setBuyUserName(user.getUserName());
				linkedEarnings.setBenefitUserId(fuser.getUserId());
				linkedEarnings.setOrderId(order.getId());
				linkedEarnings.setType(LinkedEarningsTypeEnum.CONSUMPTION.getValue());
				linkedEarnings.setRemake(LinkedEarningsTypeEnum.CONSUMPTION.getName());
				saveEarnings(linkedEarnings, fuser);
				/****************************间推收益*******************************/
				if(!"ADMIN".equals(fuser.getPromotionNo())){//上级不等于默认用户的时候进行间推收益
					LinkedUserInfo puser = linkedUserInfoService.getByUserId(fuser.getParentId());
					if(puser.getIsPartner() == 1){//只有满足合伙人才进行间推收益计算
						LinkedEarnings flinkedEarnings = new LinkedEarnings();
						flinkedEarnings.setAmount(new BigDecimal(ParamCache.getValue(CommonConstant.LINKED_EARNINGS_INDIRECT)));
						flinkedEarnings.setBuyUserId(user.getUserId());
						flinkedEarnings.setBuyUserName(user.getUserName());
						flinkedEarnings.setBenefitUserId(puser.getUserId());
						flinkedEarnings.setOrderId(order.getId());
						flinkedEarnings.setType(LinkedEarningsTypeEnum.INDIRECT.getValue());
						flinkedEarnings.setRemake(LinkedEarningsTypeEnum.INDIRECT.getName());
						saveEarnings(flinkedEarnings, puser);
						if(!"ADMIN".equals(puser.getPromotionNo()) && !puser.getParentId().equals(puser.getRecommendId())){
							/****************************贡献收益*******************************/
							LinkedEarnings fflinkedEarnings = new LinkedEarnings();
							fflinkedEarnings.setAmount(new BigDecimal(ParamCache.getValue(CommonConstant.LINKED_EARNINGS_INDIRECT))
								.multiply(new BigDecimal(ParamCache.getValue(CommonConstant.LINKED_EARNINGS_RATIO))));
							fflinkedEarnings.setBuyUserId(puser.getUserId());
							fflinkedEarnings.setBuyUserName(puser.getUserName());
							fflinkedEarnings.setBenefitUserId(puser.getRecommendId());
							fflinkedEarnings.setOrderId(order.getId());
							fflinkedEarnings.setType(LinkedEarningsTypeEnum.CONTRIBUTION.getValue());
							fflinkedEarnings.setRemake(LinkedEarningsTypeEnum.CONTRIBUTION.getName());
							saveEarnings(fflinkedEarnings, linkedUserInfoService.getByUserId(puser.getRecommendId()));
						}
					}
				}
			}
			/****************************直推收益*******************************/
			if(fuser.getIsPartner() == 1) {//上级为合伙人时进行直推收益计算
				LinkedEarnings linkedEarnings = new LinkedEarnings();
				linkedEarnings.setAmount(new BigDecimal(ParamCache.getValue(CommonConstant.LINKED_EARNINGS_DIRECT)));
				linkedEarnings.setBuyUserId(user.getUserId());
				linkedEarnings.setBuyUserName(user.getUserName());
				linkedEarnings.setBenefitUserId(fuser.getUserId());
				linkedEarnings.setOrderId(order.getId());
				linkedEarnings.setType(LinkedEarningsTypeEnum.DIRECT.getValue());
				linkedEarnings.setRemake(LinkedEarningsTypeEnum.DIRECT.getName());
				saveEarnings(linkedEarnings, fuser);
				if(!"ADMIN".equals(fuser.getPromotionNo()) && !fuser.getParentId().equals(fuser.getRecommendId())){
					/****************************贡献收益*******************************/
					LinkedEarnings fflinkedEarnings = new LinkedEarnings();
					fflinkedEarnings.setAmount(new BigDecimal(ParamCache.getValue(CommonConstant.LINKED_EARNINGS_DIRECT))
						.multiply(new BigDecimal(ParamCache.getValue(CommonConstant.LINKED_EARNINGS_RATIO))));
					fflinkedEarnings.setBuyUserId(fuser.getUserId());
					fflinkedEarnings.setBuyUserName(fuser.getUserName());
					fflinkedEarnings.setBenefitUserId(fuser.getRecommendId());
					fflinkedEarnings.setOrderId(order.getId());
					fflinkedEarnings.setType(LinkedEarningsTypeEnum.CONTRIBUTION.getValue());
					fflinkedEarnings.setRemake(LinkedEarningsTypeEnum.CONTRIBUTION.getName());
					saveEarnings(fflinkedEarnings, linkedUserInfoService.getByUserId(fuser.getRecommendId()));
				}
			}
		/************************收益计算结束********************************/
		linkedOrder.setSort(generateGoodsSpecNo());
		linkedOrder.setRecommendId(user.getRecommendId());
		linkedOrder.setRecommendName(user.getRecommendName());
		if(save(linkedOrder)){//保存成功后进行出局判断和奖励计算
			linkedOrderOut(linkedOrder.getSort());
		}
		//修改用户状态，已经处理贡献人
		linkedUserInfoService.changeUserBind(user);
		return true;
	}

	/**
	 * 处理出局已经奖励
	 * @param nowSort 当前排序
	 */
	public void linkedOrderOut(Integer nowSort){
		//统计当前购买人数
		int count = count(Wrappers.lambdaQuery(LinkedOrder.class).le(LinkedOrder::getSort, nowSort));
		//统计出局人数
		int oustCount = count(Wrappers.lambdaQuery(LinkedOrder.class).eq(LinkedOrder::getIsOut, 1).lt(LinkedOrder::getSort, nowSort));
		int num = Integer.parseInt(ParamCache.getValue(CommonConstant.LINKED_OUT_NUM));
		if((num*(oustCount+1)) < count){//判断当前位置是否需要进行出局奖励的操作
			//获取当前处在第一位未出局的用户给以出局奖励
			LambdaQueryWrapper<LinkedOrder> query = new LambdaQueryWrapper<>();
			query.eq(LinkedOrder::getIsDelete,0);
			query.eq(LinkedOrder::getIsOut,0);
			query.orderByAsc(LinkedOrder::getSort);
			query.last("limit 1");
			LinkedOrder one = this.getOne(query);
			one.setIsOut(1);
			one.setUpdateTime(new Date());
			updateById(one);
			try {
				if(redisTool.getRedisLock(String.valueOf(oustCount), "linked")){
					//计算出局奖励
					LinkedEarnings linkedEarnings = new LinkedEarnings();
					linkedEarnings.setAmount(new BigDecimal(1580));
					linkedEarnings.setBuyUserId(one.getUserId());
					linkedEarnings.setBuyUserName(one.getUserName());
					linkedEarnings.setBenefitUserId(one.getUserId());
					linkedEarnings.setOrderId(one.getOrderId());
					linkedEarnings.setType(LinkedEarningsTypeEnum.AWARD.getValue());
					linkedEarnings.setRemake(LinkedEarningsTypeEnum.AWARD.getName());
					LinkedUserInfo userInfo = linkedUserInfoService.getByUserId(one.getUserId());
					saveEarnings(linkedEarnings, userInfo);
				}
			} catch (Exception e){
				e.printStackTrace();
			}finally {//最后进行解锁
				redisTool.unRedisLock("linkedSort" + one.getSort());
			}

		}
	}

	/**
	 * 查询用户最近的一笔订单
	 * @param userId
	 * @return
	 */
	@Override
	public LinkedOrder getLastOrderByUserId(Long userId) {
		LambdaQueryWrapper<LinkedOrder> query = new LambdaQueryWrapper<>();
		query.eq(LinkedOrder::getIsDelete,0);
		query.eq(LinkedOrder::getUserId,userId);
		query.orderByDesc(LinkedOrder::getSort);
		query.last("limit 1");
		return this.getOne(query);
	}

	/**
	 * 查询最后一个出局的订单
	 * @return
	 */
	@Override
	public LinkedOrder getLastOutOrder() {
		LambdaQueryWrapper<LinkedOrder> query = new LambdaQueryWrapper<>();
		query.eq(LinkedOrder::getIsDelete,0);
		query.eq(LinkedOrder::getIsOut,1);
		query.orderByDesc(LinkedOrder::getSort);
		query.last("limit 1");
		return this.getOne(query);

	}

	/**
	 * 收益计算
	 * @param linkedEarnings
	 */
	public void saveEarnings(LinkedEarnings linkedEarnings, LinkedUserInfo user){
		//保存收益
		linkedEarnings.setBeforeAmount(user.getEarnings());
		linkedEarnings.setAfterAmount(user.getEarnings().add(linkedEarnings.getAmount()));
		earningsService.save(linkedEarnings);
		user.setEarnings(linkedEarnings.getAfterAmount());
		linkedUserInfoService.updateById(user);
	}

	/**
	 * 获取排序
	 * @return
	 */
	public int generateGoodsSpecNo() {
		RedisAtomicLong redisAtomicLong = new RedisAtomicLong(LINKED_ORDER_NO, redisTemplate.getConnectionFactory());
		return (int)redisAtomicLong.incrementAndGet();
	}
}
