package org.springblade.modules.linked.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.common.enums.LinkedBindLogEnum;
import org.springblade.modules.linked.entity.LinkedBindLog;
import org.springblade.modules.linked.entity.LinkedOrder;
import org.springblade.modules.linked.entity.LinkedUserInfo;
import org.springblade.modules.linked.mapper.LinkedBindLogMapper;
import org.springblade.modules.linked.service.ILinkedBindLogService;
import org.springblade.modules.linked.vo.LinkedBindLogVO;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.service.IUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 绑定记录表 服务实现类
 *
 * @author BladeX
 * @since 2022-11-07
 */
@Service
public class LinkedBindLogServiceImpl extends ServiceImpl<LinkedBindLogMapper, LinkedBindLog> implements ILinkedBindLogService {

	@Lazy
	@Autowired
	private IUserService userService;

	@Override
	public IPage<LinkedBindLogVO> selectBindLogPage(IPage<LinkedBindLogVO> page, LinkedBindLogVO bindLog) {
		return page.setRecords(baseMapper.selectBindLogPage(page, bindLog));
	}

	/***
	 *
	 * @param linkedOrder 订单
	 * @param promotion 推荐人
	 * @param parentUser 实际绑定人
	 * @param invalidLog 无效枚举
	 */
	@Override
	public void createInvalidLog(LinkedOrder linkedOrder, LinkedUserInfo promotion,
								 LinkedUserInfo parentUser, LinkedBindLogEnum invalidLog,Integer sort) {
		User user = userService.getById(linkedOrder.getUserId());
		LinkedBindLog linkedBindLog = new LinkedBindLog();
		linkedBindLog.setUserId(user.getId());
		linkedBindLog.setUserName(user.getRealName());
		linkedBindLog.setBeforeParentId(promotion.getUserId());
		linkedBindLog.setBeforeParentName(promotion.getUserName());
		linkedBindLog.setAfterParentId(parentUser.getUserId());
		linkedBindLog.setAfterParentName(parentUser.getUserName());
		linkedBindLog.setType(invalidLog.getValue());
		linkedBindLog.setTypeMsg(invalidLog.getName());
		linkedBindLog.setOrderId(linkedOrder.getOrderId());
		linkedBindLog.setCreateUserId(user.getId());
		linkedBindLog.setUpdateUserId(user.getId());
		Date date = new Date();
		linkedBindLog.setCreateTime(date);
		linkedBindLog.setUpdateTime(date);
		linkedBindLog.setIsDelete(0);
		linkedBindLog.setSort(sort);
		this.save(linkedBindLog);
	}


	/**
	 * 创建变更绑定记录
	 *
	 * @param parentUser 接收上级
	 * @param list       需要变更绑定的人
	 */
	@Override
	public List<LinkedBindLog> createChangeLog(LinkedUserInfo parentUser, List<LinkedUserInfo> list,Integer sort) {
		Date date = new Date();
		List<LinkedBindLog> logList = new ArrayList<>();

		for (LinkedUserInfo lUserInfo : list) {
			LinkedBindLog linkedBindLog = new LinkedBindLog();
			linkedBindLog.setUserId(lUserInfo.getUserId());
			linkedBindLog.setUserName(lUserInfo.getUserName());
			linkedBindLog.setCreateTime(date);
			linkedBindLog.setCreateUserId(parentUser.getUserId());
			linkedBindLog.setIsDelete(0);
			linkedBindLog.setUpdateUserId(parentUser.getUserId());
			linkedBindLog.setUpdateTime(date);
			linkedBindLog.setBeforeParentId(lUserInfo.getParentId());
			linkedBindLog.setBeforeParentName(lUserInfo.getParentName());
			linkedBindLog.setAfterParentId(parentUser.getUserId());
			linkedBindLog.setAfterParentName(parentUser.getUserName());
			linkedBindLog.setType(LinkedBindLogEnum.SUPERIOR_CHANGE.getValue());
			linkedBindLog.setTypeMsg(LinkedBindLogEnum.SUPERIOR_CHANGE.getName());
			linkedBindLog.setSort(sort);
			logList.add(linkedBindLog);
		}
		this.saveBatch(logList);
		return logList;
	}


	@Override
	public void createPartnerLog(LinkedUserInfo userInfo,Integer sort) {
		Date date = new Date();
		LinkedBindLog linkedBindLog = new LinkedBindLog();
		linkedBindLog.setUserId(userInfo.getUserId());
		linkedBindLog.setUserName(userInfo.getUserName());
		linkedBindLog.setCreateTime(date);
		linkedBindLog.setCreateUserId(userInfo.getUserId());
		linkedBindLog.setIsDelete(0);
		linkedBindLog.setUpdateUserId(userInfo.getUserId());
		linkedBindLog.setUpdateTime(date);
		linkedBindLog.setBeforeParentId(userInfo.getParentId());
		linkedBindLog.setBeforeParentName(userInfo.getParentName());
		linkedBindLog.setAfterParentId(userInfo.getParentId());
		linkedBindLog.setAfterParentName(userInfo.getParentName());
		linkedBindLog.setType(LinkedBindLogEnum.PROMOTION.getValue());
		linkedBindLog.setTypeMsg(LinkedBindLogEnum.PROMOTION.getName());
		linkedBindLog.setSort(sort);
		this.save(linkedBindLog);

	}

	/**
	 * 购买时创建绑定记录
	 * @param linkedOrder 订单
	 * @param befUser	 用户
	 * @param aftUser	 用户
	 * @param linkedBindLogEnum
	 */
	@Override
	public void createOrderBindLog(LinkedOrder linkedOrder, LinkedUserInfo befUser,LinkedUserInfo aftUser,
								   LinkedBindLogEnum linkedBindLogEnum,Integer sort) {
		Date date = new Date();
		LinkedBindLog linkedBindLog = new LinkedBindLog();
		linkedBindLog.setUserId(aftUser.getUserId());
		linkedBindLog.setUserName(aftUser.getUserName());
		linkedBindLog.setCreateTime(date);
		linkedBindLog.setCreateUserId(aftUser.getUserId());
		linkedBindLog.setIsDelete(0);
		linkedBindLog.setUpdateUserId(aftUser.getUserId());
		linkedBindLog.setUpdateTime(date);
		linkedBindLog.setBeforeParentId(befUser.getParentId());
		linkedBindLog.setBeforeParentName(befUser.getParentName());
		linkedBindLog.setAfterParentId(aftUser.getParentId());
		linkedBindLog.setAfterParentName(aftUser.getParentName());
		linkedBindLog.setType(linkedBindLogEnum.getValue());
		linkedBindLog.setTypeMsg(linkedBindLogEnum.getName());
		linkedBindLog.setOrderId(linkedOrder.getOrderId());
		linkedBindLog.setSort(sort);
		this.save(linkedBindLog);
	}
}
