/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.linked.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springblade.common.enums.LinkedEarningsTypeEnum;
import org.springblade.modules.linked.entity.LinkedEarnings;
import org.springblade.modules.linked.entity.LinkedUserInfo;
import org.springblade.modules.linked.service.ILinkedUserInfoService;
import org.springblade.modules.linked.vo.LinkedEarningsVO;
import org.springblade.modules.linked.mapper.LinkedEarningsMapper;
import org.springblade.modules.linked.service.ILinkedEarningsService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.metadata.IPage;

import javax.annotation.Resource;
import javax.xml.crypto.Data;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

/**
 * 用户收益明细表 服务实现类
 *
 * @author BladeX
 * @since 2022-11-10
 */
@Service
public class LinkedEarningsServiceImpl extends ServiceImpl<LinkedEarningsMapper, LinkedEarnings> implements ILinkedEarningsService {

	@Override
	public IPage<LinkedEarningsVO> selectLinkedEarningsPage(IPage<LinkedEarningsVO> page, LinkedEarningsVO linkedEarnings) {
		return page.setRecords(baseMapper.selectLinkedEarningsPage(page, linkedEarnings));
	}

	@Override
	public LinkedEarnings getLastEarnings(Long userId){
		LambdaQueryWrapper<LinkedEarnings> query = new LambdaQueryWrapper<>();
		query.eq(LinkedEarnings::getBenefitUserId,userId);
		query.orderByDesc(LinkedEarnings::getCreateTime);
		query.orderByDesc(LinkedEarnings::getAfterAmount);
		query.last("LIMIT 1");
		return this.getOne(query);
	}


	@Override
	public LinkedEarnings getLastEarningsBeforeToday(Long userId){
		Date date = new Date();
		date.setHours(0);
		date.setMinutes(0);
		date.setSeconds(0);
		LambdaQueryWrapper<LinkedEarnings> query = new LambdaQueryWrapper<>();
		query.eq(LinkedEarnings::getBenefitUserId,userId);
		query.lt(LinkedEarnings::getCreateTime,date);
		query.orderByDesc(LinkedEarnings::getCreateTime);
		query.orderByDesc(LinkedEarnings::getAfterAmount);
		query.last("LIMIT 1");
		return this.getOne(query);
	}



}
