/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.linked.service.impl;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.LinkedBindLogEnum;
import org.springblade.common.enums.LinkedEarningsTypeEnum;
import org.springblade.core.tool.utils.RandomType;
import org.springblade.core.tool.utils.StringUtil;
import org.springblade.modules.linked.entity.LinkedBindLog;
import org.springblade.modules.linked.entity.LinkedEarnings;
import org.springblade.modules.linked.entity.LinkedOrder;
import org.springblade.modules.linked.entity.LinkedUserInfo;
import org.springblade.modules.linked.mapper.UserInfoMapper;
import org.springblade.modules.linked.service.ILinkedBindLogService;
import org.springblade.modules.linked.service.ILinkedContributeLogService;
import org.springblade.modules.linked.service.ILinkedEarningsService;
import org.springblade.modules.linked.service.ILinkedUserInfoService;
import org.springblade.modules.linked.vo.LinkedVerifyVO;
import org.springblade.modules.linked.vo.UserInfoVO;
import org.springblade.modules.platform.service.UserAppService;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.entity.UserApp;
import org.springblade.modules.system.service.IUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.*;

/**
 * 联动模式用户信息表 服务实现类
 *
 * @author BladeX
 * @since 2022-11-08
 */
@Service
public class LinkedUserInfoServiceImpl extends ServiceImpl<UserInfoMapper, LinkedUserInfo> implements ILinkedUserInfoService {


	@Resource
	private ILinkedBindLogService linkedBindLogService;
	@Resource
	private UserAppService userAppService;
	@Resource
	private ILinkedContributeLogService linkedContributeLogService;
	@Autowired
	@Lazy
	private IUserService userService;
	@Resource
	private ILinkedEarningsService linkedEarningsService;

	@Override
	public IPage<UserInfoVO> selectUserInfoPage(IPage<UserInfoVO> page, UserInfoVO userInfo) {
		return page.setRecords(baseMapper.selectUserInfoPage(page, userInfo));
	}

	public LinkedUserInfo createUser(LinkedOrder linkedOrder) {

		LinkedUserInfo user = getByUserId(linkedOrder.getUserId());
		if (Objects.isNull(user)) {
			//用户第一次购买，创建关系
			LinkedUserInfo userInfo = firstBind(linkedOrder);
			this.save(userInfo);
			//创建入局记录
			linkedBindLogService.createOrderBindLog(linkedOrder, new LinkedUserInfo(), userInfo, LinkedBindLogEnum.BUY_ORDER, 2);
			//变更上级为合伙人，同时贡献两个人给上级
//			changeUserBind(userInfo);
			return userInfo;
		} else {
			//用户不是第一次购买，激活邀请权限
			LinkedUserInfo linkedUserInfo = noFirstBind(linkedOrder, user);
			if (!linkedUserInfo.getParentId().equals(user.getParentId())) {
				LinkedUserInfo parentUser = getByUserId(linkedUserInfo.getParentId());
				List<LinkedUserInfo> list = new ArrayList<>();
				list.add(user);
				linkedBindLogService.createChangeLog(parentUser, list, 2);
			}

			this.saveOrUpdate(linkedUserInfo);
			//变更上级为合伙人，同时贡献两个人给上级
//			changeUserBind(linkedUserInfo);
			//创建入局记录
			linkedBindLogService.createOrderBindLog(linkedOrder, user, linkedUserInfo, LinkedBindLogEnum.BUY_ORDER, 3);
			user = linkedUserInfo;
		}

		return user;
	}

	private LinkedUserInfo noFirstBind(LinkedOrder linkedOrder, LinkedUserInfo user) {

		LinkedUserInfo clone = user.clone();

		clone.setIsOut(0);
		clone.setIsWeed(0);
		clone.setUpdateTime(new Date());
		clone.setUpdateUserId(linkedOrder.getUserId());

		if (clone.getIsPartner() == 1) {
			//如果购买人是合伙人。则关系不做变动
			return clone;
		}

		LinkedUserInfo promotionUser = null;//推荐人

		LinkedUserInfo newPromotion = null;//有效上级

		//用户被淘汰,建立新的关系
		if (clone.getIsWeed() == 1) {
			//判断邀请码不为空时取为上级用户
			if (StrUtil.isNotBlank(linkedOrder.getPromotionNo())) {

				newPromotion = getOne(Wrappers.lambdaQuery(LinkedUserInfo.class)
					.eq(LinkedUserInfo::getIsWeed, 0)
					.eq(LinkedUserInfo::getPromotionNo, linkedOrder.getPromotionNo()));

				promotionUser = getOne(Wrappers.lambdaQuery(LinkedUserInfo.class)
					.eq(LinkedUserInfo::getPromotionNo, linkedOrder.getPromotionNo()));

			}
			if (ObjectUtil.isEmpty(newPromotion)) {//为空时默认上级，判断上级是否有效
				UserApp userApp = userAppService.getByUserId(linkedOrder.getUserId());
				newPromotion = getOne(Wrappers.lambdaQuery(LinkedUserInfo.class)
					.eq(LinkedUserInfo::getIsWeed, 0)
					.eq(LinkedUserInfo::getUserId, userApp.getParentId()));
			}
			//判断上级邀请码和上级筛选过后的用户是否为空，为空直接取系统配置账号，如果系统没有配置账号取admin
			if (ObjectUtil.isEmpty(newPromotion)) {

				String code = ParamCache.getValue(CommonConstant.LINKED_CONTRIBUTE_CODE);
				if (StringUtil.isNotBlank(code)) {
					newPromotion = getLinkUserByCode(code);
				} else {
					newPromotion = getLinkUserByCode("ADMIN");
				}
			}
		} else {
			//用户未淘汰,维持原的关系
			newPromotion = getByUserId(clone.getParentId());
		}

		//如果新的推荐人和有效推荐人不一致。添加一条无效的记录。
		if (Objects.nonNull(promotionUser) && !newPromotion.getUserId().equals(promotionUser.getUserId())) {
			linkedBindLogService.createInvalidLog(linkedOrder, promotionUser, newPromotion, LinkedBindLogEnum.INVALID_LOG, 1);
		}


		clone.setParentId(newPromotion.getUserId());
		clone.setParentName(newPromotion.getUserName());
		clone.setRecommendId(newPromotion.getUserId());
		clone.setRecommendName(newPromotion.getUserName());
		return clone;
	}

	/**
	 * 用户第一次绑定关系，判断他的上级是否需要转换为合伙人
	 *
	 * @param userInfo
	 */
	@Override
	public void changeUserBind(LinkedUserInfo userInfo) {
		Date date = new Date();
		LambdaQueryWrapper<LinkedUserInfo> query = new LambdaQueryWrapper<>();
		query.eq(LinkedUserInfo::getUserId, userInfo.getParentId());
		query.eq(LinkedUserInfo::getIsDelete, 0);
		LinkedUserInfo puser = this.getOne(query);
		if (puser.getIsPartner() == 1) {
			//上级是合伙人，不用改变
			return;
		}
		//上级不是合伙人。
		LambdaQueryWrapper<LinkedUserInfo> query1 = new LambdaQueryWrapper<>();
		query1.eq(LinkedUserInfo::getRecommendId, userInfo.getParentId());
		query1.eq(LinkedUserInfo::getIsDelete, 0);
		query1.orderByAsc(LinkedUserInfo::getCreateTime);
		query1.last("limit 2");
		List<LinkedUserInfo> list = this.list(query1);
		if (list.size() < 2) {
			//上级不满足条件，不用转换成合伙人
			return;
		}
		//转换为合伙人
		puser.setIsPartner(1);
		puser.setUpdateUserId(userInfo.getUserId());
		puser.setUpdateTime(date);
		this.saveOrUpdate(puser);
		//创建转换为合伙人记录
		linkedBindLogService.createPartnerLog(puser, 4);

		LinkedUserInfo ppuser = getByUserId(puser.getParentId());
		if (ppuser.getIsPartner() == 1) {
			//创建绑定变更记录
			List<LinkedBindLog> changeLog = linkedBindLogService.createChangeLog(ppuser, list, 5);
			//将最早的两人贡献给上级。
			for (LinkedUserInfo lUserInfo : list) {
				lUserInfo.setParentId(ppuser.getUserId());
				lUserInfo.setParentName(ppuser.getUserName());
				lUserInfo.setUpdateTime(date);
				lUserInfo.setContributeTime(date);
				lUserInfo.setUpdateUserId(userInfo.getUserId());
			}
			this.saveOrUpdateBatch(list);
			//创建贡献记录
			linkedContributeLogService.creatContributeLog(puser, ppuser, list, changeLog, "正常贡献");
		} else {
			//查询系统的配置的接收贡献人员的账号的推荐码
			LinkedUserInfo admin = null;
			String code = ParamCache.getValue(CommonConstant.LINKED_CONTRIBUTE_CODE);
			if (StringUtil.isNotBlank(code)) {
				admin = getLinkUserByCode(code);
			} else {
				admin = getLinkUserByCode("ADMIN");
			}
			//创建绑定变更记录
			List<LinkedBindLog> changeLog = linkedBindLogService.createChangeLog(admin, list, 5);
			//上级不是合伙人，将最早的两人贡献给系统。
			for (LinkedUserInfo lUserInfo : list) {
				lUserInfo.setParentId(admin.getUserId());
				lUserInfo.setParentName(admin.getUserName());
				lUserInfo.setUpdateTime(date);
				lUserInfo.setUpdateUserId(userInfo.getUserId());
			}
			this.saveOrUpdateBatch(list);

			//创建贡献记录
			linkedContributeLogService.creatContributeLog(puser, admin, list, changeLog,
				puser.getUserName() + "的上级" + ppuser.getUserName() + "不是合伙人，将人员贡献给" + admin.getUserName());
		}

	}

	/**
	 * 通过电话查询推荐码
	 *
	 * @param phone
	 */
	@Override
	public String getPromotionNoByPhone(String phone) {

		User user = userService.getOne(Wrappers.lambdaQuery(User.class).eq(User::getAccount, phone));
		if (Objects.isNull(user)){
			return "";
		}
		LinkedUserInfo linkedUserInfo = getByUserId(user.getId());
		if (Objects.isNull(linkedUserInfo)) {
			return "";
		}
		return linkedUserInfo.getPromotionNo();
	}

	@Override
	public List<LinkedVerifyVO> redMoneyUnlikenessEarnings() {
		return getBaseMapper().redMoneyUnlikenessEarnings();
	}

	private LinkedUserInfo firstBind(LinkedOrder linkedOrder) {
		//有效上级用户
		LinkedUserInfo parentUser = null;
		//推荐用户
		LinkedUserInfo promotion = null;
		//判断邀请码不为空时取为上级用户
		if (StrUtil.isNotBlank(linkedOrder.getPromotionNo())) {

			parentUser = getOne(Wrappers.lambdaQuery(LinkedUserInfo.class)
				.eq(LinkedUserInfo::getIsWeed, 0)
				.eq(LinkedUserInfo::getPromotionNo, linkedOrder.getPromotionNo()));
			//推荐人
			promotion = getOne(Wrappers.lambdaQuery(LinkedUserInfo.class)
				.eq(LinkedUserInfo::getPromotionNo, linkedOrder.getPromotionNo()));

		}
		if (ObjectUtil.isEmpty(parentUser)) {//为空时默认上级，判断上级是否有效
			UserApp userApp = userAppService.getByUserId(linkedOrder.getUserId());
			parentUser = getOne(Wrappers.lambdaQuery(LinkedUserInfo.class)
				.eq(LinkedUserInfo::getIsWeed, 0)
				.eq(LinkedUserInfo::getUserId, userApp.getParentId()));
		}
		//判断上级邀请码和上级筛选过后的用户是否为空，为空直接取系统配置账号，如果系统没有配置账号取admin
		if (ObjectUtil.isEmpty(parentUser)) {
			String code = ParamCache.getValue(CommonConstant.LINKED_CONTRIBUTE_CODE);
			if (StringUtil.isNotBlank(code)) {
				parentUser = getLinkUserByCode(code);
			} else {
				parentUser = getLinkUserByCode("ADMIN");
			}

		}

		//判断当前推荐用户和有效上级用户是否为同一个用户，如果不为同一个则产生一条无效记录
		if (ObjectUtil.isNotEmpty(promotion) && !promotion.getUserId().equals(parentUser.getUserId())) {
			linkedBindLogService.createInvalidLog(linkedOrder, promotion, parentUser, LinkedBindLogEnum.INVALID_LOG, 1);
		}

		User user = userService.getById(linkedOrder.getUserId());
		Date date = new Date();
		LinkedUserInfo userInfo = new LinkedUserInfo();
		userInfo.setUserId(linkedOrder.getUserId());
		userInfo.setUserName(user.getRealName());
		userInfo.setIsOut(0);
		userInfo.setIsWeed(0);
		userInfo.setPromotionNo(getCode());
		userInfo.setEarnings(new BigDecimal(0));
		userInfo.setIsPartner(0);
		userInfo.setCreateTime(date);
		userInfo.setCreateUserId(linkedOrder.getUserId());
		userInfo.setIsDelete(0);
		userInfo.setUpdateUserId(linkedOrder.getUserId());
		userInfo.setUpdateTime(date);

		userInfo.setParentId(parentUser.getUserId());
		userInfo.setParentName(parentUser.getUserName());
		userInfo.setRecommendId(parentUser.getUserId());
		userInfo.setRecommendName(parentUser.getUserName());

		return userInfo;
	}

	@Override
	public LinkedUserInfo getByUserId(Long userId) {
		LambdaQueryWrapper<LinkedUserInfo> query = new LambdaQueryWrapper<>();
		query.eq(LinkedUserInfo::getIsDelete, 0);
		query.eq(LinkedUserInfo::getUserId, userId);
		return this.getOne(query);
	}

	@Override
	public LinkedUserInfo getLinkUserByCode(String promotionNo) {
		LambdaQueryWrapper<LinkedUserInfo> query = new LambdaQueryWrapper<>();
		query.eq(LinkedUserInfo::getIsDelete, 0);
		query.eq(LinkedUserInfo::getPromotionNo, promotionNo);
		return this.getOne(query);
	}

	@Override
	public List<LinkedUserInfo> getOneByUserId(Long userId) {
		LambdaQueryWrapper<LinkedUserInfo> query = new LambdaQueryWrapper<>();
		query.eq(LinkedUserInfo::getIsDelete, 0);
		query.eq(LinkedUserInfo::getParentId, userId);
		return this.list(query);
	}

	@Override
	public List<LinkedUserInfo> getTwoByUserId(Long userId) {
		return this.getBaseMapper().getTwoByUserId(userId);
	}

	@Override
	public Map<String,Object> changeEarnings(Long userId, BigDecimal subNumber, LinkedEarningsTypeEnum earningsTypeEnum) {

		Map<String,Object> map = new HashMap<>();

		if (!(earningsTypeEnum.equals(LinkedEarningsTypeEnum.SUBTRACT)
			|| earningsTypeEnum.equals(LinkedEarningsTypeEnum.INCREASE))){
			map.put("flag",false);
			map.put("msg","操作无效！");
			return map;
		}

		LinkedUserInfo linkedUser = getByUserId(userId);
		if (earningsTypeEnum.equals(LinkedEarningsTypeEnum.SUBTRACT)
			&& linkedUser.getEarnings().compareTo(subNumber) < 0 ){
			map.put("flag",false);
			map.put("msg","收益不足！");
			return map;
		}

		LinkedEarnings lastEarnings = linkedEarningsService.getLastEarnings(userId);
		if (lastEarnings.getAfterAmount().compareTo(linkedUser.getEarnings()) !=0){
			map.put("flag",false);
			map.put("msg","收益数据异常！");
			return map;
		}

		BigDecimal afterAmount;
		if (earningsTypeEnum.equals(LinkedEarningsTypeEnum.SUBTRACT)){
			afterAmount = lastEarnings.getAfterAmount().subtract(subNumber);
		}else {
			afterAmount = lastEarnings.getAfterAmount().add(subNumber);
		}

		//创建收益变动记录
		LinkedEarnings newLinkedEarnings = new LinkedEarnings();
		newLinkedEarnings.setBuyUserId(userId);
		newLinkedEarnings.setBenefitUserId(userId);
		newLinkedEarnings.setType(earningsTypeEnum.getValue());
		newLinkedEarnings.setRemake(earningsTypeEnum.getName());
		newLinkedEarnings.setAmount(subNumber);
		newLinkedEarnings.setBeforeAmount(lastEarnings.getAfterAmount());
		newLinkedEarnings.setAfterAmount(afterAmount);
		newLinkedEarnings.setCreateTime(new Date());
		newLinkedEarnings.setUpdateTime(new Date());

		linkedEarningsService.save(newLinkedEarnings);

		//修改用户收益
		linkedUser.setEarnings(afterAmount);
		this.saveOrUpdate(linkedUser);

		map.put("flag",true);
		map.put("msg","操作成功！");
		return map;

	}


	/**
	 * 生成不重复的Code
	 */
	private String getCode() {
		String code = StringUtil.random(6, RandomType.ALL).toUpperCase();
		Integer codeCount = baseMapper.selectCount(Wrappers.<LinkedUserInfo>query()
			.lambda().eq(LinkedUserInfo::getPromotionNo, code));
		if (codeCount > 0) {
			return getCode();
		}
		return code;
	}

}
