/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.annotation.Resource;
import javax.validation.Valid;

import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.sms.model.SmsCode;
import org.springblade.core.sms.model.SmsData;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.platform.dto.AddUserTicketDTO;
import org.springblade.modules.platform.vo.EarningsTicketStatisVO;
import org.springblade.modules.platform.vo.IntegralInfoVO;
import org.springblade.modules.resource.builder.sms.SmsBuilder;
import org.springblade.modules.resource.utils.SmsUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.platform.entity.UserTicket;
import org.springblade.modules.platform.vo.UserTicketVO;
import org.springblade.modules.platform.service.IUserTicketService;
import org.springblade.core.boot.ctrl.BladeController;

import java.util.List;
import java.util.Map;

import static org.springblade.modules.resource.utils.SmsUtil.*;

/**
 * 用户酒票表 控制器
 *
 * @author BladeX
 * @since 2022-02-13
 */
@RestController
@RequestMapping("platform/userticket")
@Api(value = "用户酒票表", tags = "用户酒票表接口")
public class UserTicketController extends BladeController {

	@Resource
	private IUserTicketService userTicketService;

	@Value("${ticket.check.phone}")
	private String ticketCheckPhone;
	@Autowired
	private SmsBuilder smsBuilder;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入userTicket")
	public R<UserTicket> detail(UserTicket userTicket) {
		UserTicket detail = userTicketService.getOne(Condition.getQueryWrapper(userTicket));
		return R.data(detail);
	}

	/**
	 * 分页 用户酒票表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入userTicket")
	public R<IPage<UserTicket>> list(UserTicket userTicket, Query query) {
		IPage<UserTicket> pages = userTicketService.page(Condition.getPage(query), Condition.getQueryWrapper(userTicket));
		return R.data(pages);
	}

	/**
	 * 自定义分页 用户酒票表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入userTicket")
	public R<IPage<UserTicketVO>> page(UserTicketVO userTicket, Query query) {
		IPage<UserTicketVO> pages = userTicketService.selectUserTicketPage(Condition.getPage(query), userTicket);
		return R.data(pages);
	}

	/**
	 * 新增 用户酒票表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入userTicket")
	public R save(@Valid @RequestBody UserTicket userTicket) {
		return R.status(userTicketService.save(userTicket));
	}

	/**
	 * 修改 用户酒票表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入userTicket")
	public R update(@Valid @RequestBody UserTicket userTicket) {
		return R.status(userTicketService.updateById(userTicket));
	}

	/**
	 * 新增或修改 用户酒票表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入userTicket")
	public R submit(@Valid @RequestBody UserTicket userTicket) {
		return R.status(userTicketService.saveOrUpdate(userTicket));
	}


	/**
	 * 删除 用户酒票表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(userTicketService.removeByIds(Func.toLongList(ids)));
	}

	@PostMapping("addUserScore")
	@ApiOperation(value = "添加用户积分", notes = "传入ids")
	public R addUserScore(@RequestBody AddUserTicketDTO addUserTicketDTO) {
		if (addUserTicketDTO.getScore() < 1) {
			return R.fail("积分数不能小于1");
		}
		SmsCode smsCode = new SmsCode();
		smsCode.setId(addUserTicketDTO.getCodeId());
		smsCode.setPhone(ticketCheckPhone);
		smsCode.setValue(addUserTicketDTO.getCode());
//		boolean b = smsBuilder.noAuthTemplate().validateMessage(smsCode);
//		if (!b) {
//			return R.fail("验证码不正确");
//		}
		addUserTicketDTO.setDataSrc(5);
		userTicketService.addUserScore(addUserTicketDTO);
		return R.success("添加成功");
	}

	@PostMapping("subUserScore")
	@ApiOperation(value = "扣除用户积分")
	public R subUserScore(@RequestBody AddUserTicketDTO addUserTicketDTO) {
		if (addUserTicketDTO.getScore() < 1) {
			return R.fail("积分数不能小于1");
		}
		userTicketService.subUserScore(addUserTicketDTO);
		return R.success("添加成功");
	}

	@ApiOperation(value = "收益积分统计", tags = "传入类型 6-直推 7-团队")
	@GetMapping("/earningsTicketStatic")
	public R<EarningsTicketStatisVO> earningsTicketStatic(@RequestParam("type") Integer type) {
		return R.data(userTicketService.earningsTicketStatic(AuthUtil.getUserId(), type));
	}

	@GetMapping("/send-validate")
	@ApiOperation(value = "短信发送")
	public R sendValidate() {
		Map<String, String> params = SmsUtil.getValidateParams();
		SmsCode smsCode = smsBuilder.noAuthTemplate().sendValidate(new SmsData(params).setKey(PARAM_KEY), ticketCheckPhone);
		return smsCode.isSuccess() ? R.data(smsCode, SEND_SUCCESS) : R.fail(SEND_FAIL);
	}

	@GetMapping("info")
	@ApiOperation(value = "积分信息")
	public R<IPage<IntegralInfoVO>> info(@RequestParam(value = "userName", required = false) String userName, @RequestParam(value = "type") Integer type, Query query) {
		IPage<IntegralInfoVO> info = userTicketService.info(Condition.getPage(query), userName, type);
		return R.data(info);
	}
}
