/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.platform.service;

import org.apache.poi.ss.formula.functions.T;
import org.springblade.common.enums.TicketTypeEnum;
import org.springblade.modules.platform.dto.AddUserTicketDTO;
import org.springblade.modules.platform.entity.UserTicket;
import org.springblade.modules.platform.vo.EarningsTicketDetailVO;
import org.springblade.modules.platform.vo.EarningsTicketStatisVO;
import org.springblade.modules.platform.vo.IntegralInfoVO;
import org.springblade.modules.platform.vo.UserTicketVO;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.system.entity.User;

import java.math.BigDecimal;
import java.util.List;

/**
 * 用户酒票表 服务类
 *
 * @author BladeX
 * @since 2022-02-13
 */
public interface IUserTicketService extends IService<UserTicket> {

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param userTicket
	 * @return
	 */
	IPage<UserTicketVO> selectUserTicketPage(IPage<UserTicketVO> page, UserTicketVO userTicket);

	/**
	 * 添加用户积分
	 * @param addUserTicketDTO
	 */
	void addUserScore(AddUserTicketDTO addUserTicketDTO);

	/**
	 * 扣除用户积分
	 * @param addUserTicketDTO
	 */
	void subUserScore(AddUserTicketDTO addUserTicketDTO);

	void addScoreBySrc2Data(Long userId, BigDecimal score, Integer src, String remake, TicketTypeEnum ticketType, Long dataId);

	/**
	 * 积分变更
	 * @param userId 用户id
	 * @param score 积分
	 * @param src 来源
	 * @param remake 备注
	 * @param ticketType 插入类型，1:收入 2：支出
	 */
	void addScoreBySrc(Long userId, BigDecimal score, Integer src, String remake, TicketTypeEnum ticketType);

	EarningsTicketStatisVO earningsTicketStatic(Long userId, Integer type);

	EarningsTicketDetailVO earningsTicketDetail(Long userId, Integer type);

	/**
	 * 查询积分信息
	 * @param name 用户名称
	 * @param type 类型 1-绿色积分 2-红色积分 3-抢红包 4-分红型红包
	 * @return
	 */
	IPage<IntegralInfoVO> info(IPage<User> page, String name, Integer type);

}
