package org.springblade.modules.platform.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.comparator.CompareUtil;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.OrderTypeEnum;
import org.springblade.core.log.model.LogUsual;
import org.springblade.modules.finance.entity.Order;
import org.springblade.modules.finance.service.impl.OrderServiceImpl;
import org.springblade.modules.platform.service.IDataChartService;
import org.springblade.modules.platform.vo.DayStatisVO;
import org.springblade.modules.platform.vo.StatisticsVO;
import org.springblade.modules.shopping.entity.Consign;
import org.springblade.modules.shopping.service.impl.ConsignServiceImpl;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.service.impl.LogUsualServiceImpl;
import org.springblade.modules.system.service.impl.UserServiceImpl;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.*;

@Service
public class DataChartServiceImpl implements IDataChartService {

	@Resource
	private OrderServiceImpl orderService;
	@Resource
	private LogUsualServiceImpl logUsualService;
	@Resource
	private ConsignServiceImpl consignService;
	@Resource
	private UserServiceImpl userService;

	@Override
	public StatisticsVO statistics() {
		StatisticsVO vo = new StatisticsVO();
		DayStatisVO todayStatis = getDayStatis(DateUtil.date());
		DayStatisVO yesterdayStatis = getDayStatis(DateUtil.yesterday());
		vo.setToday(todayStatis);
		vo.setYesterday(yesterdayStatis);

		int dataChartDayNum = Integer.parseInt(ParamCache.getValueDefault(CommonConstant.DATA_CHART_DAY_NUM, "6"));
		// 进货数据
		List<Map<String, Object>> stockMap = consignService.getBaseMapper().selectMaps(Wrappers.<Consign>query()
			.ge("create_time", DateUtil.beginOfDay(DateUtil.offsetDay(new Date(), -dataChartDayNum)))
			.le("create_time", DateUtil.date()).eq("consign_for", 2)
			.select("count(0) total", "DATE_FORMAT(create_time, '%Y/%m/%d') date").groupBy("date").orderByAsc("date"));
		// 用户数据
		Integer integer = userService.getBaseMapper().selectCount(Wrappers.<User>query()
			.le("create_time", DateUtil.beginOfDay(DateUtil.offsetDay(new Date(), -dataChartDayNum))).eq("user_type", 2));
		List<Map<String, Object>> peopleMap = userService.getBaseMapper().selectMaps(Wrappers.<User>query()
			.ge("create_time", DateUtil.beginOfDay(DateUtil.offsetDay(new Date(), -dataChartDayNum)))
			.le("create_time", DateUtil.date()).eq("user_type", 2)
			.select("count(0) total", "DATE_FORMAT(create_time, '%Y/%m/%d') date").groupBy("date").orderByAsc("date"));


		for (Map<String, Object> map : peopleMap) {
			Long total = (Long) map.get("total");
			map.put("total", total + integer);
			total = (Long) map.get("total");
			integer = total.intValue();
		}
		// 打款数据
		List<LogUsual> logUsuals = logUsualService.getBaseMapper().selectList(Wrappers.<LogUsual>query()
			.ge("create_time", DateUtil.beginOfDay(DateUtil.offsetDay(new Date(), -dataChartDayNum)))
			.le("create_time", DateUtil.date()).eq("log_id", "打款成功").select("log_data", "create_time").orderByAsc("create_time"));
		Map<String, BigDecimal> flag = new HashMap<>();
		List<Map<String, Object>> remitData = new ArrayList<>();
		if (CollUtil.isNotEmpty(logUsuals)) {
			for (LogUsual logUsual : logUsuals) {
				double amount = this.parseAmountRemit(logUsual.getLogData());
				String key = DateUtil.format(logUsual.getCreateTime(), "yyyy/MM/dd");
				flag.merge(key, BigDecimal.valueOf(amount), BigDecimal::add);
			}
		}
		flag.forEach((s, aDouble) -> {
			Map<String, Object> map = new HashMap<>();
			map.put("date", s);
			map.put("total", aDouble);
			remitData.add(map);
		});
		remitData.sort((o1, o2) -> CompareUtil.compare(o1.entrySet().toArray()[0].toString(), o2.entrySet().toArray()[0].toString()));
		vo.setRemitData(remitData);
		vo.setStockData(stockMap);
		vo.setPeopleData(peopleMap);
		return vo;
	}

	@Override
	public List<User> snapUpPeopleToday() {
		return userService.getBaseMapper().snapUpPeopleToday(DateUtil.beginOfDay(DateUtil.date()));
	}

	@Override
	public List<User> snapUpPeopleYesterday() {
		DateTime yesterday = DateUtil.yesterday();
		return userService.getBaseMapper().snapUpPeopleYesterday(DateUtil.beginOfDay(yesterday), DateUtil.endOfDay(yesterday));
	}


	/**
	 * 获取日统计数据
	 * @param date
	 * @return
	 */
	private DayStatisVO getDayStatis(Date date) {
		List<Order> orders = orderService.getBaseMapper().selectList(Wrappers.<Order>lambdaQuery().ge(Order::getCreateTime, DateUtil.beginOfDay(date))
			.le(Order::getCreateTime, DateUtil.endOfDay(date)).eq(Order::getOrderType, OrderTypeEnum.CONSIGN.getValue()));
		DayStatisVO dayStatisVO = new DayStatisVO();
		// 抢购人数
		long snapUpPeopleCount = orders.stream().mapToLong(Order::getUserId).distinct().count();
		dayStatisVO.setSnapUpPeopleCount(snapUpPeopleCount);
		// 订单数
		dayStatisVO.setOrderCount(orders.size());
		// 收款金额
		double amountCollected = orders.stream().mapToDouble(Order::getPayFee).sum();
		dayStatisVO.setAmountCollected(amountCollected);
		// 打款金额
		double amountRemit = 0;
		List<LogUsual> logUsualList = logUsualService.getBaseMapper().selectList(Wrappers.<LogUsual>lambdaQuery().ge(LogUsual::getCreateTime, DateUtil.beginOfDay(date))
			.le(LogUsual::getCreateTime, DateUtil.endOfDay(date))
			.eq(LogUsual::getLogId, "打款成功"));
		if (CollUtil.isNotEmpty(logUsualList)) {
			for (LogUsual logUsual : logUsualList) {
				double v = this.parseAmountRemit(logUsual.getLogData());
				amountRemit = amountRemit + v;
			}
		}
		dayStatisVO.setAmountRemit(amountRemit);
		return dayStatisVO;
	}

	/**
	 * 解析打款成功日志里的打款金额
	 * @param logData
	 * @return
	 */
	private double parseAmountRemit(String logData) {
		int index = logData.indexOf("支付宝返回数据:");
		if (index > 0) {
			logData = logData.substring(index + "支付宝返回数据:".length());
			return JSON.parseObject(logData).getJSONObject("params").getJSONObject("biz_content").getDoubleValue("trans_amount");
		}
		return 0;
	}




}


