package org.springblade.modules.platform.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.utils.DigestUtil;
import org.springblade.core.tool.utils.StringUtil;
import org.springblade.modules.platform.service.UserAppService;
import org.springblade.modules.shopping.entity.Consign;
import org.springblade.modules.shopping.entity.ConsignConfig;
import org.springblade.modules.shopping.service.impl.ConsignConfigServiceImpl;
import org.springblade.modules.shopping.service.impl.ConsignServiceImpl;
import org.springblade.modules.system.entity.UserApp;
import org.springblade.modules.system.mapper.UserAppMapper;
import org.springblade.modules.system.vo.UserAppVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.DecimalFormat;
import java.util.List;


@Service
public class UserAppServiceImpl extends ServiceImpl<UserAppMapper, UserApp> implements UserAppService {

	@Resource
	private ConsignServiceImpl consignService;
	@Resource
	private ConsignConfigServiceImpl consignConfigService;


	@Override
	public IPage<UserAppVO> pageList(IPage<UserAppVO> page, UserAppVO vo) {
		IPage<UserAppVO> pageList = this.getBaseMapper().getPageList(page, vo);
		if (CollUtil.isNotEmpty(page.getRecords())) {
			for (UserAppVO record : page.getRecords()) {
				// 查询用户进入系统之后的场次
				Integer afterConfigNum = consignConfigService.getBaseMapper().selectCount(Wrappers.<ConsignConfig>lambdaQuery().ge(ConsignConfig::getStartTime, record.getCreateTime()));
				// 查询用户参与的场次
				List<Consign> consigns = consignService.getBaseMapper().selectList(Wrappers.<Consign>lambdaQuery().eq(Consign::getConsignUserId, record.getUserId()).groupBy(Consign::getConsignConfigId).select(Consign::getConsignConfigId));
				int consignCount = 0;
				if (CollUtil.isNotEmpty(consigns)) {
					consignCount = consigns.size();
				}
				float active = (float) consignCount / afterConfigNum;
				DecimalFormat df = new DecimalFormat("0.00");
				record.setUserActive(df.format(active * 100) + "%");
			}
		}
		return pageList;
	}

	@Override
	public Boolean verifyPayPassword(String payPassword, Long userId){
		UserApp userApp = this.getBaseMapper().selectOne(Wrappers.lambdaQuery(UserApp.class).eq(UserApp::getUserId, userId));
		if(ObjectUtil.isNull(userApp) || StringUtil.isEmpty(userApp.getPayPassword())){
			throw new RuntimeException("未查询到该用户支付信息");
		}
		String encrypt = DigestUtil.encrypt(userApp.getOffsetCode() + payPassword);
		return userApp.getPayPassword().equals(encrypt);
	}

	@Override
	public UserApp getByUserId(Long userId) {
		return getOne(Wrappers.lambdaQuery(UserApp.class).eq(UserApp::getUserId, userId));
	}
}
