package org.springblade.modules.redenvelopemall.controller;

import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.modules.redenvelopemall.service.IFinanceService;
import org.springblade.modules.redenvelopemall.vo.CostBreakdownVO;
import org.springblade.modules.redenvelopemall.vo.GrossProfitVO;
import org.springblade.modules.redenvelopemall.vo.SalesVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.List;

@RestController
@AllArgsConstructor
@RequestMapping("redenvelopemall/finance")
@Api(value = "财务统计", tags = "财务统计")
public class FinanceController {

	@Autowired
	private IFinanceService financeService;

	/**
	 * 销售日报明细
	 */
	@GetMapping("/salesOfTheDay")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "销售日报明细", notes = "")
	public R<IPage<SalesVO>> salesOfTheDay(@ApiParam(value = "供应商类型") @RequestParam(required = false) String source,
										   @ApiParam(value = "折扣类型") @RequestParam(required = false) Integer zoneType,
										   @ApiParam(value = "日期") @RequestParam(required = false) Date time,
										   Query query) {
		Date startTime = null;
		Date endTime = null;
		if (time != null) {
			startTime = DateUtil.beginOfDay(time);
			endTime = DateUtil.endOfDay(time);
		}
		IPage<SalesVO> page = financeService.salesOfTheDay(source, zoneType, startTime, endTime, query);
		return R.data(page);
	}
	/**
	 * 销售日报汇总
	 */
	@GetMapping("/salesOfTheDayStatistics")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "销售日报汇总", notes = "")
	public R<IPage<SalesVO>> salesOfTheDayStatistics(@ApiParam(value = "供应商类型") @RequestParam(required = false) String source,
										   @ApiParam(value = "日期") @RequestParam(required = false) Date time,
										   Query query) {
		Date startTime = null;
		Date endTime = null;
		if (time != null) {
			startTime = DateUtil.beginOfDay(time);
			endTime = DateUtil.endOfDay(time);
		}
		IPage<SalesVO> page = financeService.salesOfTheDayStatistics(source, startTime, endTime, query);
		return R.data(page);
	}

	/**
	 * 成本明细
	 */
	@GetMapping("/costBreakdownPage")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "成本明细", notes = "")
	public R<IPage<CostBreakdownVO>> costBreakdownPage(@ApiParam(value = "供应商", required = false) @RequestParam(required = false) String source,
													   @ApiParam(value = "商品名称", required = false) @RequestParam(required = false) String goodsName,
													   @ApiParam(value = "开始时间", required = false) @RequestParam(required = false) Date startTime,
													   @ApiParam(value = "结束时间", required = false) @RequestParam(required = false) Date endTime,
													   Query query) {

		IPage<CostBreakdownVO> page = financeService.costBreakdown(source, goodsName, startTime, endTime, query);
		return R.data(page);
	}

	/**
	 * 成本明细
	 */
	@GetMapping("/costBreakdownStatistics")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "成本明细汇总", notes = "")
	public R<IPage<CostBreakdownVO>> costBreakdownStatistics(@ApiParam(value = "供应商", required = false) @RequestParam(required = false) String source,
															 Query query) {

		IPage<CostBreakdownVO> page = financeService.costBreakdownStatistics(source, query);
		return R.data(page);
	}
	/**
	 * 毛利统计
	 */
	@GetMapping("/grossProfitStatistics")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "毛利统计", notes = "")
	public R<List<GrossProfitVO>> grossProfitStatistics() {
		List<GrossProfitVO> list = financeService.grossProfitStatistics();
		return R.data(list);
	}
}
