/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.redenvelopemall.controller;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.annotation.Resource;
import javax.validation.Valid;

import org.springblade.common.enums.YesOrNoEnum;
import org.springblade.common.enums.ZoneTypeEnum;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.api.service.impl.ReOrderServiceImpl;
import org.springblade.modules.redenvelopemall.entity.GoodsInfo;
import org.springblade.modules.redenvelopemall.service.impl.GoodsInfoServiceImpl;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.redenvelopemall.entity.GoodsSpec;
import org.springblade.modules.redenvelopemall.vo.GoodsSpecVO;
import org.springblade.modules.redenvelopemall.wrapper.GoodsSpecWrapper;
import org.springblade.modules.redenvelopemall.service.IGoodsSpecService;
import org.springblade.core.boot.ctrl.BladeController;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 商品规格表 控制器
 *
 * @author BladeX
 * @since 2022-05-07
 */
@RestController
@AllArgsConstructor
@RequestMapping("redenvelopemall/goodsspec")
@Api(value = "商品规格表", tags = "商品规格表接口")
public class GoodsSpecController extends BladeController {

	@Resource
	private IGoodsSpecService goodsSpecService;
	@Resource
	private GoodsInfoServiceImpl goodsInfoService;
	@Resource
	private ReOrderServiceImpl reOrderService;


	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入goodsSpec")
	public R<GoodsSpecVO> detail(GoodsSpec goodsSpec) {
		GoodsSpec detail = goodsSpecService.getOne(Condition.getQueryWrapper(goodsSpec));
		if (detail == null) {
			return R.fail("规格数据不存在，请刷新后重试");
		}
		GoodsInfo goodsInfo = goodsInfoService.getById(detail.getGoodsId());
		if (goodsInfo == null) {
			return R.fail("商品数据不存在，请刷新后重试");
		}
		detail.setGoodsNo(goodsInfo.getGoodsNo());
		return R.data(GoodsSpecWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 商品规格表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入goodsSpec")
	public R<IPage<GoodsSpecVO>> list(GoodsSpec goodsSpec, Query query) {
		IPage<GoodsSpecVO> goodsSpecVOIPage = goodsSpecService.selectGoodsSpecPage(Condition.getPage(query), goodsSpec);
		for (GoodsSpecVO record : goodsSpecVOIPage.getRecords()) {
			if (ZoneTypeEnum.INTEGRAL_CONVERT.getValue().equals(record.getZoneType())) {
				BigDecimal salePrice = record.getSalePrice();
				BigDecimal needExchangeIntegral = reOrderService.calNeedExchangeIntegral(salePrice, record.getAgreementPrice());
				record.setNeedAmount(salePrice.subtract(needExchangeIntegral).setScale(2, BigDecimal.ROUND_HALF_UP));
				record.setExchangeNeedIntegral(needExchangeIntegral.setScale(2, BigDecimal.ROUND_HALF_UP));
			}
		}
		return R.data(goodsSpecVOIPage);
	}


	/**
	 * 自定义分页 商品规格表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入goodsSpec")
	public R<IPage<GoodsSpecVO>> page(GoodsSpecVO goodsSpec, Query query) {
		IPage<GoodsSpecVO> pages = goodsSpecService.selectGoodsSpecPage(Condition.getPage(query), goodsSpec);
		return R.data(pages);
	}

	/**
	 * 新增 商品规格表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入goodsSpec")
	public R save(@Valid @RequestBody GoodsSpec goodsSpec) {
		if (YesOrNoEnum.YES.getValue().equals(goodsSpec.getIsPackage())) {
			if (goodsSpec.getPackageNum() == null) {
				return R.fail("套装数不能为空");
			}
			if (goodsSpec.getPackageNum() < 0) {
				return R.fail("套装数不能小于0");
			}
		}
		return R.status(goodsSpecService.save(goodsSpec));
	}

	/**
	 * 修改 商品规格表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入goodsSpec")
	public R update(@Valid @RequestBody GoodsSpec goodsSpec) {
		if (YesOrNoEnum.YES.getValue().equals(goodsSpec.getIsPackage())) {
			if (goodsSpec.getPackageNum() == null) {
				return R.fail("套装数不能为空");
			}
			if (goodsSpec.getPackageNum() < 0) {
				return R.fail("套装数不能小于0");
			}
		}
		return R.status(goodsSpecService.updateById(goodsSpec));
	}

	/**
	 * 新增或修改 商品规格表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入goodsSpec")
	public R submit(@Valid @RequestBody GoodsSpec goodsSpec) {
		if (YesOrNoEnum.YES.getValue().equals(goodsSpec.getIsPackage())) {
			if (goodsSpec.getPackageNum() == null) {
				return R.fail("套装数不能为空");
			}
			if (goodsSpec.getPackageNum() < 0) {
				return R.fail("套装数不能小于0");
			}
		}
		goodsSpecService.submit(goodsSpec);
		return R.success("操作成功");
	}


	/**
	 * 删除 商品规格表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(goodsSpecService.removeByIds(Func.toLongList(ids)));
	}


	/**
	 * 上下架
	 */
	@PostMapping("/updateStatus")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "上下架", notes = "传入ids")
	public R updateStatus(@ApiParam(value = "主键集合", required = true) @RequestParam Long id) {
		goodsSpecService.updateStatus(id);
		return R.success("操作成功");
	}

	@PostMapping("/batchOnSale")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "批量上架", notes = "传入ids")
	public R batchOnSale(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		goodsSpecService.batchOnSale(Func.toLongList(ids));
		return R.success("操作成功");
	}

	@PostMapping("/batchShelves")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "批量下架", notes = "传入ids")
	public R batchShelves(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		goodsSpecService.batchShelves(Func.toLongList(ids));
		return R.success("操作成功");
	}

	@PostMapping("/batchModifyPrice")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "批量修改价格", notes = "传入ids")
	public R batchModifyPrice(@ApiParam(value = "主键集合", required = true) @RequestParam String ids, @ApiParam(value = "主键集合", required = true) @RequestParam BigDecimal salePrice) {
		goodsSpecService.batchModifyPrice(Func.toLongList(ids), salePrice);
		return R.success("操作成功");
	}
}
