package org.springblade.modules.redenvelopemall.controller;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.apache.commons.lang3.StringUtils;
import org.springblade.common.base.BaseEntity;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.modules.redenvelopemall.entity.RedEnvelope;
import org.springblade.modules.redenvelopemall.entity.RedEnvelopeReceiveLog;
import org.springblade.modules.redenvelopemall.param.RedEnvelopeParam;
import org.springblade.modules.redenvelopemall.service.IRedEnvelopeManagerService;
import org.springblade.modules.redenvelopemall.service.IRedEnvelopeReceiveLogService;
import org.springblade.modules.redenvelopemall.service.IRedEnvelopeService;
import org.springblade.modules.redenvelopemall.task.RedTask;
import org.springblade.modules.redenvelopemall.vo.RedEnvelopeReceiveLogVo;
import org.springblade.modules.redenvelopemall.vo.RedEnvelopeStatisticsVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

@RestController
@Api(value = "re-红包管理", tags = "re-红包管理")
@RequestMapping("/re/manager")
public class RedEnvelopeManagerController {
	@Autowired
	private IRedEnvelopeService redEnvelopeService;
	@Autowired
	private IRedEnvelopeReceiveLogService redEnvelopeReceiveLogService;
	@Autowired
	private IRedEnvelopeManagerService redEnvelopeManagerService;

	@GetMapping("/grab")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "抢红包")
	public R<RedEnvelopeReceiveLog> grab() {
		RedEnvelopeReceiveLog log=redEnvelopeService.grab();
		return R.data(log);
	}

	@Autowired
	private RedTask redTask;

	@PostMapping("/create")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "生成红包")
	public R create() {
		redTask.createRedEnvelope();
		return R.success("成功");
	}

	/**
	 * 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "分页", notes = "传入param")
	public R<IPage<RedEnvelope>> list(RedEnvelopeParam param, Query query) {
		LambdaQueryWrapper<RedEnvelope> queryWrapper = new LambdaQueryWrapper<>();
		if (ObjectUtil.isNotEmpty(param.getNum())) {
			queryWrapper.eq(RedEnvelope::getNum, param.getNum());
		}
		if (StringUtils.isNotEmpty(param.getTitle())) {
			queryWrapper.like(RedEnvelope::getTitle, param.getTitle());
		}
		if (ObjectUtil.isNotEmpty(param.getStartTime())) {
			queryWrapper.gt(BaseEntity::getCreateTime, param.getStartTime());
		}
		if (ObjectUtil.isNotEmpty(param.getEndTime())) {
			queryWrapper.lt(BaseEntity::getCreateTime, param.getEndTime());
		}
		queryWrapper.orderByDesc(BaseEntity::getCreateTime);
		IPage<RedEnvelope> pages = redEnvelopeService.page(Condition.getPage(query), queryWrapper);
		return R.data(pages);
	}

	/**
	 * 获取红包领取情况
	 */
	@GetMapping("/logByRedEnvelopeId")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "获取红包领取情况", notes = "传入红包id")
	public R<IPage<RedEnvelopeReceiveLogVo>> list(@ApiParam(value = "主键", required = true) @RequestParam String redEnvelopeId,
												  @ApiParam(value = "主键", required = false) @RequestParam(required = false) String userName, Query query) {
		IPage<RedEnvelopeReceiveLogVo> page = redEnvelopeReceiveLogService.logByRedEnvelopeId(redEnvelopeId,userName, query);
		return R.data(page);
	}



	@GetMapping("/todayStatistics")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "统计", notes = "今日统计")
	public R<RedEnvelopeStatisticsVO> todayStatistics() {
		RedEnvelopeStatisticsVO vo = redEnvelopeManagerService.todayStatistics();
		return R.data(vo);
	}

	@GetMapping("/totalRedEnvelopeAmountByUserId")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "根据用户Id查询领取的总红包金额", notes = "根据用户Id查询领取的总红包金额")
	public R<BigDecimal> totalRedEnvelopeAmountByUserId(@ApiParam(value = "用户Id", required = true) @RequestParam Long userId,
														@ApiParam(value = "开始时间", required = false) @RequestParam Date startTime,
														@ApiParam(value = "结束时间", required = false) @RequestParam Date endTime) {
		BigDecimal total=redEnvelopeReceiveLogService.totalRedEnvelopeAmountByUserId(userId,startTime,endTime);
		return R.data(total);
	}

	@GetMapping("/logListByUserId")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "根据用户Id查询领取的红包列表", notes = "根据用户Id查询领取的红包列表")
	public R<List<RedEnvelopeReceiveLog>> logListByUserId(@ApiParam(value = "用户Id", required = true) @RequestParam String userId,
														@ApiParam(value = "开始时间", required = false) @RequestParam Date startTime,
														@ApiParam(value = "结束时间", required = false) @RequestParam Date endTime) {
		LambdaQueryWrapper<RedEnvelopeReceiveLog> queryWrapper = new LambdaQueryWrapper<>();
		queryWrapper.eq(StringUtils.isNotBlank(userId),BaseEntity::getCreateUserId,userId);
		queryWrapper.gt(ObjectUtil.isNotNull(startTime),BaseEntity::getCreateTime,startTime);
		queryWrapper.lt(ObjectUtil.isNotNull(endTime),BaseEntity::getCreateTime,endTime);
		queryWrapper.orderByDesc(BaseEntity::getCreateTime);
		List<RedEnvelopeReceiveLog> list = redEnvelopeReceiveLogService.list(queryWrapper);
		return R.data(list);
	}



}
