package org.springblade.modules.redenvelopemall.controller;

import cn.hutool.core.util.RandomUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springblade.common.constant.SupplyChainConstant;
import org.springblade.common.enums.GoodsStateEnum;
import org.springblade.core.log.logger.BladeLogger;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.redenvelopemall.dto.MessagePushDTO;
import org.springblade.modules.redenvelopemall.dto.SupplyChainDTO;
import org.springblade.modules.redenvelopemall.entity.SupplyChain;
import org.springblade.modules.redenvelopemall.service.ISupplyChainService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;

/**
 * Author pangqijun
 * Date 2022/5/13
 * Description 供应链服务接口
 */
@Slf4j
@RestController
@RequestMapping("supplyChain")
@Api(value = "供应链服务接口", tags = "供应链服务接口")
public class SupplyChainController {

	@Resource
	private ISupplyChainService supplyChainService;
	@Resource
	private BladeLogger bladeLogger;


	@GetMapping("/list")
	@ApiOperationSupport(order = 12)
	@ApiOperation(value = "分页", notes = "传入supplyChain")
	public R<IPage<SupplyChain>> list(@RequestParam HashMap<String, String> param, Query query) {
		QueryWrapper<SupplyChain> queryWrapper = Wrappers.query();
		if (param.get("is_import") != null) {
			queryWrapper.eq("is_import", param.get("is_import"));
		}
		if (param.get("source") != null) {
			queryWrapper.eq("source", param.get("source"));
		}
		if (param.get("status") != null) {
			queryWrapper.eq("status", param.get("status"));
		}
		if (param.get("group_id") != null) {
			queryWrapper.like("groups_ids", param.get("group_id"));
		}
		if (param.get("search_words") != null) {
			queryWrapper.like("title", param.get("search_words"));
		}
		if (param.get("discountRange") != null) {
			String[] discountRanges = param.get("discountRange").split("-");
			queryWrapper.and(i -> i.ge("discount", discountRanges[0]).le("discount", discountRanges[1]));
		}
		IPage<SupplyChain> pages = supplyChainService.page(Condition.getPage(query), queryWrapper);
		return R.data(pages);
	}

	@PostMapping("/GoodsStorage/list")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "在线选品")
	public R<IPage<SupplyChain>> list(@RequestBody SupplyChainDTO supplyChainDTO) {
		JSONObject jsonObject = supplyChainService.newList(supplyChainDTO);
		JSONObject data = jsonObject.getJSONObject("data");
		IPage<SupplyChain> pages = new Page<>();
		pages.setTotal(data.getLong("count"));
		pages.setRecords(data.getJSONArray("list").toJavaList(SupplyChain.class));
		return R.data(pages);
	}

	@GetMapping("/activityLists")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "营销活动标签列表")
	public R activityLists() {
		HashMap<String, String> param = new HashMap<>();
		param.put("limit", "20");
		param.put("page", "1");
		JSONObject jsonObject = supplyChainService.apiActivityLists(param);
		JSONObject data = jsonObject.getJSONObject("data");
		return R.data(data.getJSONArray("list"));
	}

	@GetMapping("/group/list")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "获取分组列表")
	public R groupList(@RequestParam HashMap<String, String> param) {
		JSONObject jsonObject = supplyChainService.groupList(param);
		JSONArray data = jsonObject.getJSONObject("data").getJSONArray("list");;
		return R.data(data);
	}

	@GetMapping("/GoodsStorage/myList")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "选品分组商品列表")
	public R myList(@RequestParam HashMap<String, String> param) {
		JSONObject jsonObject = supplyChainService.myLists(param);
		JSONObject data = jsonObject.getJSONObject("data");
		return R.data(data);
	}

	@GetMapping("/Category/getCategory")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "获取逐级类目v2")
	public R getCategory(@ApiParam(value = "默认0代表一级 （父级分类id）") @RequestParam Integer parentId,
						 @ApiParam(value = "来源0聚合分类1云仓2京东6阿里巴巴7天猫") @RequestParam Integer source) {
		HashMap<String, String> param = new HashMap<>();
		param.put("parent_id", parentId.toString());
		param.put("source", source.toString());
		JSONObject jsonObject = supplyChainService.getCategory(param);
		return R.data(jsonObject.getJSONArray("data"));
	}

	@PostMapping("/importData")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "导入商品数据")
	public R importData(@ApiParam(value = "主键集合", required = true) @RequestParam String ids,
						@ApiParam(value = "毛利", required = true) @RequestParam Double grossRate,
						@ApiParam(value = "categoryIds") @RequestParam(required = false) String categoryIds,
						@ApiParam(value = "zoneType") @RequestParam(required = false) Integer zoneType) {
		if (grossRate < 0) {
			return R.fail("毛利不能小于0");
		}
		List<String> list = Func.toStrList(ids);

		supplyChainService.importGoods(list, categoryIds, grossRate, zoneType);
		return R.data("操作成功");
	}

	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "供应链回调")
	@PostMapping("/callBack")
	public String callBack(@RequestBody MessagePushDTO messagePushDTO) {
		bladeLogger.info("供应链回调", JSON.toJSONString(messagePushDTO));
		if (SupplyChainConstant.CALLBACK_GOODS_STORAGE_ADD.equalsIgnoreCase(messagePushDTO.getType())) {
			log.info("商品库添加回调");
			List<String> goodsIds = messagePushDTO.getData().getGoodsIds();
			for (String goodsId : goodsIds) {
				supplyChainService.saveSupplyChain(goodsId);
			}
		} else if (SupplyChainConstant.CALLBACK_GOODS_STORAGE_REMOVE.equalsIgnoreCase(messagePushDTO.getType())){
			log.info("移除商品库商品回调");
			supplyChainService.goodsStorageRemove(messagePushDTO.getData().getGoodsIds());
		} else if (SupplyChainConstant.CALLBACK_GOODS_UNDERCARRIAGE.equalsIgnoreCase(messagePushDTO.getType())){
			log.info("商品下架回调");
			supplyChainService.updateGoodsState(messagePushDTO.getData().getGoodsIds(),  GoodsStateEnum.UNDERCARRIAGE);
		} else if (SupplyChainConstant.CALLBACK_GOODS_ON_SALE.equalsIgnoreCase(messagePushDTO.getType())){
			log.info("商品上架回调");
			supplyChainService.updateGoodsState(messagePushDTO.getData().getGoodsIds(), GoodsStateEnum.ON_SALE);
		} else if (SupplyChainConstant.CALLBACK_GOODS_ALTER.equalsIgnoreCase(messagePushDTO.getType())){
			log.info("商品修改回调");
			try {
				// 因此接口调用频繁，随机睡眠几秒，防止第三方服务触发限流
				long l = RandomUtil.randomLong(1, 10);
				Thread.sleep(l);
			} catch (InterruptedException e) {
				e.printStackTrace();
			}
			supplyChainService.goodsAlter(messagePushDTO.getData().getGoodsIds());
		} else if (SupplyChainConstant.CALLBACK_GOODS_PRICE_ALTER.equalsIgnoreCase(messagePushDTO.getType())){
			log.info("商品价格变更回调");
			supplyChainService.goodsPriceAlter(messagePushDTO.getData().getGoodsIds());
		} else if (SupplyChainConstant.CALLBACK_ORDER_SUCCESS.equalsIgnoreCase(messagePushDTO.getType())){
			log.info("交易成功回调");
			supplyChainService.orderSuccess(messagePushDTO.getData());
		} else if (SupplyChainConstant.CALLBACK_ORDER_DELIVERED.equalsIgnoreCase(messagePushDTO.getType())){
			log.info("商品已收货回调");
//			supplyChainService.orderDelivered(messagePushDTO.getData());
		} else if (SupplyChainConstant.CALLBACK_ORDER_DELIVERY.equalsIgnoreCase(messagePushDTO.getType())){
			log.info("商家已发货回调");
			supplyChainService.orderDelivery(messagePushDTO.getData());
		} else if (SupplyChainConstant.CALLBACK_ORDER_CANCEL.equalsIgnoreCase(messagePushDTO.getType())){
			log.info("订单取消回调");
			supplyChainService.orderCancel(messagePushDTO.getData());
			return "{\"code\":-1}";
		} else if (SupplyChainConstant.CALLBACK_AFTER_SALE_AGREE.equalsIgnoreCase(messagePushDTO.getType())){
			log.info("售后同意回调");
			supplyChainService.afterSaleAgree(messagePushDTO.getData());
		} else if (SupplyChainConstant.CALLBACK_AFTER_SALE_REFUSE.equalsIgnoreCase(messagePushDTO.getType())){
			log.info("售后拒绝回调");
			supplyChainService.afterSaleRefuse(messagePushDTO.getData());
		} else if (SupplyChainConstant.CALLBACK_AFTER_SALE_SUCCESS.equalsIgnoreCase(messagePushDTO.getType())){
			log.info("售后退款到账回调, 订单号：[{}]", messagePushDTO.getData().getOrderSn());
			supplyChainService.afterSaleSuccess(messagePushDTO.getData());
		} else {
			log.info("回调失败");
			return "{\"code\":-1}";
		}
		return "{\"code\":1}";
	}

	public static void main(String[] args) {
		for (int i = 0; i < 20; i++) {
			System.out.println(RandomUtil.randomLong(1, 10));
		}
	}

//	@ApiOperation(value = "fixData")
//	@GetMapping("/fixData")
//	public void fixData() {
//		supplyChainService.fixData();
//	}

//	@ApiOperation(value = "fixData")
//	@GetMapping("/fixData2")
//	public void fixData2() {
//		supplyChainService.fixData2();
//	}


//	@ApiOperation(value = "syncData")
//	@GetMapping("/syncData")
//	public String syncData(@RequestParam String source) {
//		return supplyChainService.syncData(source) + "";
//	}

	@GetMapping("/removeGroupGoods/{groupId}")
	public void removeGroupGoods(@PathVariable("groupId") String groupId) throws InterruptedException {
		String[] split = groupId.split(",");
		for (String s : split) {
			supplyChainService.removeGroupGoods(s);
		}

	}
}
