package org.springblade.modules.redenvelopemall.controller;



import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springblade.core.log.logger.BladeLogger;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.redenvelopemall.entity.WeiPinShangGoods;
import org.springblade.modules.redenvelopemall.param.ImportCheckParam;
import org.springblade.modules.redenvelopemall.service.IWeiPinShangService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * Author pangqijun
 * Date 2022/7/11
 * Description 唯品尚供应链服务
 */
@Slf4j
@RestController
@RequestMapping("/sc/wps")
@Api(value = "唯品尚供应链服务", tags = "唯品尚供应链服务")
public class WeiPinShangController {

	@Resource
	private IWeiPinShangService weiPinShangService;
	@Resource
	private BladeLogger bladeLogger;


	@ApiOperation(value = "列表")
	@GetMapping("/list")
	public R list(WeiPinShangGoods weiPinShangGoods, Query query, Double minDiscount, Double maxDiscount) {
		QueryWrapper<WeiPinShangGoods> queryWrapper = Wrappers.query();
		if (weiPinShangGoods.getIsImport() != null) {
			queryWrapper.eq("is_import", weiPinShangGoods.getIsImport());
		}
		if (StrUtil.isNotBlank(weiPinShangGoods.getGoodsName())) {
			queryWrapper.like("goods_name", weiPinShangGoods.getGoodsName());
		}
		if (StrUtil.isNotBlank(weiPinShangGoods.getClassId())) {
			queryWrapper.eq("class_id", weiPinShangGoods.getClassId());
		}
		if (StrUtil.isNotBlank(weiPinShangGoods.getClass2Id())) {
			queryWrapper.eq("class2_id", weiPinShangGoods.getClass2Id());
		}
		if (StrUtil.isNotBlank(weiPinShangGoods.getClass3Id())) {
			queryWrapper.eq("class3_id", weiPinShangGoods.getClass3Id());
		}
		if (minDiscount != null) {
			queryWrapper.ge("discount", minDiscount);
		}
		if (maxDiscount != null) {
			queryWrapper.le("discount", maxDiscount);
		}
		queryWrapper.orderByDesc("create_time");
		IPage<WeiPinShangGoods> pages = weiPinShangService.page(Condition.getPage(query), queryWrapper);
		return R.data(pages);
	}

	@PostMapping("/importGoods")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "导入商品数据")
	public R importGoods(@ApiParam(value = "主键集合", required = true) @RequestParam String ids,
						@ApiParam(value = "毛利") @RequestParam(required = false) Double grossRate,
						@ApiParam(value = "categoryIds") @RequestParam(required = false) String categoryIds,
						@ApiParam(value = "zoneType") @RequestParam(required = false) Integer zoneType) {
		if (grossRate != null && grossRate < 0) {
			return R.fail("毛利不能小于0");
		}
		weiPinShangService.importGoods(Func.toStrList(ids), categoryIds, grossRate, zoneType);
		return R.data("操作成功");
	}


	@ApiOperation(value = "唯品尚供应链消息通知")
	@PostMapping("/notice")
	public String notice(@RequestBody JSONObject param) {
		log.info("唯品尚通知回调: [{}]", param.toJSONString());
		Integer type = param.getInteger("type");
		bladeLogger.info("唯品尚通知回调", param.toJSONString());
		if (type == 2) {// 价格变更
			weiPinShangService.priceUpdate(param.getJSONObject("c_content").getJSONArray("goods"));
		} else if (type == 4){ // 商品上下架变更消息
			weiPinShangService.shelvesUpdate(param.getJSONArray("c_content"));
		} else if (type == 16){ // 商品介绍及规格参数变更消息
			weiPinShangService.detailUpdate(param.getJSONArray("c_content"));
		} else if (type == 23){ // 订单配送退货消息

		} else if (type == 28){ // 售后服务单进度消息
			JSONObject content = param.getJSONObject("c_content");
			if ("RETURN_MONEY".equals(content.getString("refuse_type"))) {
				weiPinShangService.refund(content);
			}

		} else if (type == 30){ // 已选商品推送
			weiPinShangService.saveThirdGoodsInfo(param.getJSONArray("c_content"));
		} else {
			bladeLogger.info("唯品尚通知其他消息", param.toJSONString());
		}
		return "success";
	}

	@ApiOperation(value = "订单回调接口")
	@PostMapping("/orderNotice")
	public String orderNotice(@RequestBody JSONObject param) {
		log.info("唯品尚订单回调: [{}]", param.toJSONString());
		Integer type = param.getInteger("type");
		bladeLogger.info("唯品尚订单回调", param.toJSONString());
		if (type == 1) {// 发货
			weiPinShangService.delivery(param.getString("orderid"), param.getString("delivery_no"), param.getString("delivery_name"));
		} else if (type == 2){ // 售后
			if ("RETURN_MONEY".equals(param.getString("refuse_type"))) {
				weiPinShangService.refund(param);
			}
		} else {
			bladeLogger.info("其他订单回调消息", param.toJSONString());
		}
		return "success";
	}

	@ApiOperation(value = "查询商品分类")
	@GetMapping("getGoodsClassify")
	public R getGoodsClassify(String level, String parentCode) {
		return R.data(weiPinShangService.getGoodsClassify(level, parentCode).getJSONArray("data"));
	}

	@GetMapping("fixDiscount")
	public R fixDiscount() {
		weiPinShangService.fixDiscount();
		return R.success("ok");
	}

	@ApiOperation(value = "导入前检验")
	@PostMapping("importCheck")
	public R importCheck(@RequestBody ImportCheckParam param) {
		return R.data(weiPinShangService.importCheck(param));
	}

	@PostMapping("fixSpec")
	public R fixSpec() {
		weiPinShangService.fixSpec();
		return R.success("ok");
	}
}
