/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.redenvelopemall.mapper;

import org.apache.ibatis.annotations.Param;
import org.springblade.modules.redenvelopemall.entity.RedAccelerateRecord;
import org.springblade.modules.redenvelopemall.vo.RedAccelerateRecordExclusiveVo;
import org.springblade.modules.redenvelopemall.vo.RedAccelerateRecordVO;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 加速积分记录 Mapper 接口
 *
 * @author BladeX
 * @since 2022-05-25
 */
public interface RedAccelerateRecordMapper extends BaseMapper<RedAccelerateRecord> {

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param redAccelerateRecord
	 * @return
	 */
	List<RedAccelerateRecordVO> selectRedAccelerateRecordPage(IPage page, RedAccelerateRecordVO redAccelerateRecord);

	/**
	 * 获取昨日红包
	 * @param userId
	 * @return
	 */
	BigDecimal getExclusive(@Param("userId") Long userId);

	/**
	 * 统计昨日加速积分
	 * @return
	 */
	BigDecimal countYesterdayAccelerate();

	/**
	 * 获取错失总金额
	 * @param userId
	 * @return
	 */
	BigDecimal countUnaccalimed(@Param("userId") Long userId);

	/**
	 * 获取红包记录
	 * @param page
	 * @param userId
	 * @return
	 */
	IPage<RedAccelerateRecordExclusiveVo> getExclusivePage(IPage page, @Param("userId") Long userId);
}
