/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.redenvelopemall.service;

import com.baomidou.mybatisplus.extension.service.IService;
import org.springblade.modules.finance.entity.Order;
import org.springblade.modules.platform.dto.AddUserTicketDTO;
import org.springblade.modules.redenvelopemall.entity.RedIntegral;
import org.springblade.modules.redenvelopemall.vo.RedIntegralVO;
import org.springblade.core.mp.base.BaseService;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.math.BigDecimal;

/**
 * 红色积分变更记录表 服务类
 *
 * @author BladeX
 * @since 2022-05-25
 */
public interface IRedIntegralService extends IService<RedIntegral> {

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param redIntegral
	 * @return
	 */
	IPage<RedIntegralVO> selectRedIntegralPage(IPage<RedIntegralVO> page, RedIntegralVO redIntegral);

	/**
	 * 统计昨日加速积分呢
	 * @return
	 */
	BigDecimal countYesterdayAccelerate();

	/**
	 * 新增红色积分
	 * @param outTradeNo 商品订单号
	 */
	void calculateIntegral(String outTradeNo);

	/**
	 * 积分扣除
	 * @param userId 用户id
	 * @param subIntegral 扣除积分
	 * @param type 扣除类型 1、订单，2、随机红包，3、专属红包
	 * @param dataId 来源id
	 */
	void subIntegral(Long userId, BigDecimal subIntegral, Integer type, Long dataId);

	/**
	 * 通过用户id获取今日可领取的专属红包
	 * @param userId
	 * @return
	 */
	BigDecimal getExclusive(Long userId);

	/**
	 * 通过用户id获取今日可领取的专属红包
	 * @param userId
	 * @return
	 */
	BigDecimal getAllExclusive(Long userId);

	/**
	 * 退款扣除
	 * @param order 订单
	 */
	void refundDeduct(Order order);

	/**
	 * 订单退还
	 * @param outTradeNo
	 */
	void orderReturn(String outTradeNo);

    void addUserScore(AddUserTicketDTO addUserTicketDTO);
}
