package org.springblade.modules.redenvelopemall.service;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springblade.common.enums.GoodsStateEnum;
import org.springblade.modules.redenvelopemall.dto.PushDataDTO;
import org.springblade.modules.redenvelopemall.dto.SupplyChainDTO;
import org.springblade.modules.redenvelopemall.entity.GoodsSpec;
import org.springblade.modules.redenvelopemall.entity.SupplyChain;
import org.springblade.modules.redenvelopemall.mapper.SupplyChainMapper;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;

/**
 * Author pangqijun
 * Date 2022/5/13
 * Description
 */
public interface ISupplyChainService extends IService<SupplyChain> {

	/**
	 * 在线选品
	 */
	JSONObject newList(SupplyChainDTO supplyChainDTO);

	/**
	 * 营销活动标签列表
	 * @param param
	 * @return
	 */
	JSONObject apiActivityLists(HashMap<String, String> param);

	/**
	 * 选品库商品列表
	 * @param param
	 * @return
	 */
	JSONObject myLists(HashMap<String, String> param);

	/**
	 * 选品库分组列表
	 * @param param
	 * @return
	 */
	JSONObject groupList(HashMap<String, String> param);

	/**
	 * 获取商品详情
	 */
	JSONObject detail(List<String> ids);
	/**
	 * 获取逐级类目
	 */
	JSONObject getCategory(HashMap<String, String> param);
	/**
	 * 导入商品
	 */
	void importGoods(List<String> ids, String categoryId, Double grossRate, Integer zoneType);

	void saveSupplyChain(String id);
	/**
	 *售后退款到账回调
	 */
	void afterSaleSuccess(PushDataDTO data);
	/**
	 *售后拒绝回调
	 */
	void afterSaleRefuse(PushDataDTO data);
	/**
	 *售后同意回调
	 */
	void afterSaleAgree(PushDataDTO data);
	/**
	 *订单取消回调
	 */
	void orderCancel(PushDataDTO data);

	/**
	 *商家已发货回调
	 */
	void orderDelivery(PushDataDTO data);

	/**
	 *商品已收货回调
	 */
	void orderDelivered(PushDataDTO data);

	/**
	 *交易成功回调
	 */
	void orderSuccess(PushDataDTO data);

	/**
	 *商品价格变更回调
	 */
	void goodsPriceAlter(List<String> goodsIds);

	/**
	 *商品修改回调
	 */
	void goodsAlter(List<String> goodsIds);

	/**
	 * 更新商品状态
	 */
	void updateGoodsState(List<String> goodsIds, GoodsStateEnum stateEnum);

	/**
	 * 移除商品库商品回调
	 */
	void goodsStorageRemove(List<String> goodsIds);

	/**
	 * 前置校验
	 */
	JSONObject beforeCheck(String optionId, Integer num, Long userAddressId);

	/**
	 * 可售检测
	 */
	JSONObject availableCheck(Long goodsInfoId, Long userAddressId);

	/**
	 * 提交下单
	 */
	JSONObject order(String orderSn, String optionId, Integer num, Long userAddressId);

	/**
	 * 查询物流
	 */
	JSONObject logistic(String orderSn, String sku);

	/**
	 * 售后前置校验
	 */
	JSONObject afterSaleBeforeCheck(String orderSn, String sku);

	/**
	 * 申请售后
	 */
	JSONObject afterSale(String orderSn, String sku, Integer num, Double logisticFee, String serviceTypeCode);

    void fixData();

	void fixData2();

	int syncData(String source);

    void removeGroupGoods(String groupId) throws InterruptedException;
}
