package org.springblade.modules.redenvelopemall.service;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springblade.modules.redenvelopemall.entity.GoodsInfo;
import org.springblade.modules.redenvelopemall.entity.WeiPinShangGoods;
import org.springblade.modules.redenvelopemall.param.ImportCheckParam;

import java.util.HashMap;
import java.util.List;
import java.util.Set;

/**
 * Author pangqijun
 * Date 2022/7/10
 * Description 唯品尚供应链服务
 */
public interface IWeiPinShangService extends IService<WeiPinShangGoods> {

	/**
	 * 获取单个商品所有详情信息
	 * @param fatherId 商品父级ID
	 * @return
	 */
	JSONObject getGoodsDetails(String fatherId);

	/**
	 * 查询商品邮费
	 * @param fatherGoodsId  商品id
	 * @param goodsId 商品规格id
	 * @param num 商品数量
	 * @param userAddressId 用户地址id
	 * @return
	 */
	JSONObject getPostage(String fatherGoodsId, String goodsId, Integer num, Long userAddressId);

	/**
	 *
	 * @param orderNo 订单号
	 * @param goodSpecId 商品ID(c_goods_id)
	 * @param goodsId 商品父ID(c_father_goods_id)
	 * @param num 数量
	 * @param userAddressId 用户地址id
	 * @return
	 */
	String createOrder(String orderNo, String goodSpecId, String goodsId, Integer num, Long userAddressId);

	/**
	 * 用户确认订单接口
	 * @param orderNo 订单号
	 * @param payType 支付方式 1支付宝，2手机微信支付，3H5支付方式，4预存款(余额)，目前只有预存款这个方式）
	 * @return
	 */
	JSONObject payCallBack(String orderNo, String payType);

	/**
	 * 用户取消订单
	 * @param orderNo 订单号
	 * @param cancelBy 关闭者 BUYER：被买家关闭 SYS：被系统自动关闭
	 * @return
	 */
	JSONObject cancelOrder(String orderNo, String cancelBy);

	/**
	 * 订单信息查询
	 * @param orderNo 订单号
	 * @return
	 */
	JSONObject getOrderInfo(String orderNo);

	/**
	 * 订单物流信息查询
	 * @param orderNo 订单号
	 * @return
	 */
	JSONObject getExpressInfo(String orderNo);

	/**
	 * 订单确认收货
	 * @param orderNo 订单号
	 * @return
	 */
	JSONObject receivedOrder(String orderNo);

	/**
	 * 申请售后
	 * @param mcOrderNo 子订单号
	 * @param customerExpect 售后类型 [退货(10)、仅退款(40)]
	 * @param isHasPackage 是否有包装
	 * @param userAddressId 用户地址id
	 * @return
	 */
	JSONObject createAfsApply(String mcOrderNo, String customerExpect, Boolean isHasPackage, Long userAddressId);

	/**
	 * 查询商品分类
	 * @param level 分类层级
	 * @param parentCode 上级分类code
	 * @return
	 */
	JSONObject getGoodsClassify(String level, String parentCode);


	/**
	 * 保存第三方商品信息
	 */
	void saveThirdGoodsInfo(JSONArray content);

	/**
	 * 上下架变更
	 * @param content
	 */
	void shelvesUpdate(JSONArray content);

	/**
	 * 价格变更
	 * @param content
	 */
	void priceUpdate(JSONArray content);

	/**
	 * 详情变更
	 * @param content
	 */
	void detailUpdate(JSONArray content);

	/**
	 * 同步商品数据
	 * @param fatherIds
	 */
	void syncGoodsInfo(List<String> fatherIds, boolean isUpdateSalePrice);

	/**
	 * 退款
	 * @param content
	 */
	void refund(JSONObject content);

	/**
	 * 发货
	 * @param orderNo 订单号
	 * @param deliveryNo 物流单号
	 * @param deliveryName 物流公司
	 */
	void delivery(String orderNo, String deliveryNo, String deliveryName);

	/**
	 * 导入商品
	 * @param ids 商品id
	 * @param categoryIds 分类id
	 * @param grossRate 毛利率
	 * @param zoneType 专区类型
	 */
	void importGoods(List<String> ids, String categoryIds, Double grossRate, Integer zoneType);

    void fixDiscount();

	Set<Long> importCheck(ImportCheckParam param);

    void fixSpec();

	/**
	 * 前置校验
	 * @param goodsInfo
	 * @param userAddressId
	 * @return
	 */
	Boolean availableCheck(GoodsInfo goodsInfo, Long userAddressId);
}
