package org.springblade.modules.redenvelopemall.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.modules.redenvelopemall.mapper.FinanceMapper;
import org.springblade.modules.redenvelopemall.service.IFinanceService;
import org.springblade.modules.redenvelopemall.vo.CostBreakdownVO;
import org.springblade.modules.redenvelopemall.vo.GrossProfitVO;
import org.springblade.modules.redenvelopemall.vo.SalesVO;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class FinanceServiceImpl implements IFinanceService {
	@Resource
	private FinanceMapper financeMapper;

	@Override
	public IPage<SalesVO> salesOfTheDay(String source, Integer zoneType, Date startTime, Date endTime, Query query) {
		IPage page = Condition.getPage(query);
		return financeMapper.salesOfTheDay(page, source, zoneType, startTime, endTime);
	}

	@Override
	public IPage<SalesVO> salesOfTheDayStatistics(String source, Date startTime, Date endTime, Query query) {
		IPage page = Condition.getPage(query);
		return financeMapper.salesOfTheDayStatistics(page, source, startTime, endTime);
	}

	@Override
	public List<GrossProfitVO> grossProfitStatistics() {
		//按供应商分组查询实收金额
		List<GrossProfitVO> paidList = financeMapper.selectPaidInAmount();
		for (GrossProfitVO grossProfitVO : paidList) {
			CostBreakdownVO costBreakdownVO = financeMapper.selectCostBreakdown(grossProfitVO.getSource());
			if (costBreakdownVO != null) {
				//设置成本价
				grossProfitVO.setTotalAgreementPrice(costBreakdownVO.getTotalAgreementPrice());
				//计算毛利=总实收金额-总协议价
				grossProfitVO.setGrossProfit(grossProfitVO.getTotalPaidInAmount().subtract(costBreakdownVO.getTotalAgreementPrice()));
			}
		}
		//整个商城的毛利
		BigDecimal reduce = paidList.stream().map(GrossProfitVO::getGrossProfit).reduce(BigDecimal.ZERO, BigDecimal::add);
		List<GrossProfitVO> collect = paidList.stream().map(
			grossProfitVO ->
			{
				GrossProfitVO vo = new GrossProfitVO();
				vo.setSource(grossProfitVO.getSource());
				vo.setTotalAgreementPrice(grossProfitVO.getTotalAgreementPrice());
				vo.setTotalPaidInAmount(grossProfitVO.getTotalPaidInAmount());
				if (grossProfitVO.getGrossProfit().compareTo(BigDecimal.ZERO)!=0){
					//毛利率=毛利/总协议价=(总实收金额-总协议价)/totalPaidInAmount
					vo.setRateOfGrossProfit(grossProfitVO.getGrossProfit().divide(grossProfitVO.getTotalPaidInAmount(),2,BigDecimal.ROUND_HALF_UP).toString());
				}
				if (grossProfitVO.getGrossProfit().compareTo(BigDecimal.ZERO)!=0){
					//毛利占比=毛利/总毛利
					vo.setRatio(grossProfitVO.getGrossProfit().divide(reduce,2,BigDecimal.ROUND_HALF_UP).toString());
				}
				vo.setTotalGrossProfit(reduce);
				return vo;
			}).collect(Collectors.toList());
		return collect;
	}

	@Override
	public IPage<CostBreakdownVO> costBreakdown(String source, String goodsName, Date startTime, Date endTime, Query query) {
		IPage page = Condition.getPage(query);
		return financeMapper.costBreakdown(page, source, goodsName, startTime, endTime);
	}

	@Override
	public IPage<CostBreakdownVO> costBreakdownStatistics(String source, Query query) {
		IPage page = Condition.getPage(query);
		return financeMapper.costBreakdownStatistics(page, source);
	}


}
