package org.springblade.modules.redenvelopemall.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.common.base.BaseEntity;
import org.springblade.common.constant.CacheBizConstant;
import org.springblade.common.utils.DateTimeUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.redis.cache.BladeRedis;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.modules.linked.entity.LinkedEarnings;
import org.springblade.modules.linked.service.ILinkedEarningsService;
import org.springblade.modules.redenvelopemall.entity.RedEnvelopeItem;
import org.springblade.modules.redenvelopemall.entity.RedEnvelopeReceiveLog;
import org.springblade.modules.redenvelopemall.entity.RedIntegral;
import org.springblade.modules.redenvelopemall.mapper.RedAccelerateRecordMapper;
import org.springblade.modules.redenvelopemall.mapper.RedEnvelopeItemMapper;
import org.springblade.modules.redenvelopemall.service.IRedEnvelopeManagerService;
import org.springblade.modules.redenvelopemall.service.IRedEnvelopeReceiveLogService;
import org.springblade.modules.redenvelopemall.service.IRedIntegralService;
import org.springblade.modules.redenvelopemall.vo.RedEnvelopeStatisticsVO;
import org.springblade.modules.system.entity.UserApp;
import org.springblade.modules.system.mapper.UserAppMapper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.*;

import static org.springblade.common.constant.CacheBizConstant.CACHE_RED_PACKET;

@Service
public class RedEnvelopeManagerServiceImpl implements IRedEnvelopeManagerService {

	@Resource
	private IRedEnvelopeReceiveLogService logService;
	@Resource
	private RedEnvelopeItemMapper redEnvelopeItemMapper;
	@Resource
	private BladeRedis bladeRedis;
	@Resource
	private RedAccelerateRecordMapper redAccelerateRecordMapper;
	@Resource
	private UserAppMapper userAppMapper;
	@Resource
	private IRedEnvelopeReceiveLogService redEnvelopeReceiveLogService;
	@Resource
	private IRedIntegralService redIntegralService;
	@Resource
	private ILinkedEarningsService linkedEarningsService;


	@Override
	public RedEnvelopeStatisticsVO todayStatistics() {
		RedEnvelopeStatisticsVO vo = new RedEnvelopeStatisticsVO();
		//今日红包
		List<RedEnvelopeItem> itemList = redEnvelopeItemMapper.listByTime(DateTimeUtil.earliestTime(new Date()), DateTimeUtil.lastestTime(new Date()));
		if (CollectionUtil.isNotEmpty(itemList)) {
			//今日红包个数
			vo.setRedEnvelopeItemCount(itemList.size());
			BigDecimal totalAmount = itemList.stream().map(RedEnvelopeItem::getAmount).reduce(BigDecimal.ZERO, BigDecimal::add);
			//今日红包总金额
			vo.setTotalRedEnvelopeAmount(totalAmount);
		}
		//今日领取的红包
		LambdaQueryWrapper<RedEnvelopeReceiveLog> logWrapper = new LambdaQueryWrapper<>();
		logWrapper.gt(BaseEntity::getCreateTime, DateTimeUtil.earliestTime(new Date()));
		logWrapper.lt(BaseEntity::getCreateTime, DateTimeUtil.lastestTime(new Date()));
		logWrapper.eq(RedEnvelopeReceiveLog::getType,0);
		List<RedEnvelopeReceiveLog> logList = logService.list(logWrapper);
		if (CollectionUtil.isNotEmpty(logList)) {
			//今日已领红包个数
			vo.setReceiveItemCount(logList.size());
			BigDecimal totalAmount = logList.stream().map(RedEnvelopeReceiveLog::getAmount).reduce(BigDecimal.ZERO, BigDecimal::add);
			//今日红包总金额
			vo.setTotalReceivedRedEnvelopeAmount(totalAmount);
			//红包池剩余的红包总金额=总金额-已领取
			vo.setTotalRemainItemAmount(vo.getTotalRedEnvelopeAmount().subtract(totalAmount));
		}
		BigDecimal unaccalimed = redAccelerateRecordMapper.countUnaccalimed(AuthUtil.getUserId());
		vo.setLossTotalAmount(unaccalimed);
		return vo;
	}

	/**
	 * app今日统计
	 *
	 * @return
	 */
	@Override
	public RedEnvelopeStatisticsVO todayAppStatistics() {
		RedEnvelopeStatisticsVO vo = new RedEnvelopeStatisticsVO();
		//今日红包
		List<RedEnvelopeItem> itemList = redEnvelopeItemMapper.listByTime(DateTimeUtil.earliestTime(new Date()), DateTimeUtil.lastestTime(new Date()));
		if (CollectionUtil.isNotEmpty(itemList)) {
			//今日红包个数
			vo.setRedEnvelopeItemCount(itemList.size());
			BigDecimal totalAmount = itemList.stream().map(RedEnvelopeItem::getAmount).reduce(BigDecimal.ZERO, BigDecimal::add);
			//今日红包总金额
			vo.setTotalRedEnvelopeAmount(totalAmount);
		}
		//当天已领取的红包总金额
		BigDecimal todayReceivedTotalRedEnvelopeAmount = redEnvelopeReceiveLogService.totalRedEnvelopeAmount(DateTimeUtil.earliestTime(new Date()), DateTimeUtil.lastestTime(new Date()));
		vo.setTotalReceivedRedEnvelopeAmount(todayReceivedTotalRedEnvelopeAmount);
		//红包池剩余的红包总金额=总金额-已领取
		vo.setTotalRemainItemAmount(vo.getTotalRedEnvelopeAmount().subtract(todayReceivedTotalRedEnvelopeAmount));
		//当前登录人领取的所有红包总金额
		BigDecimal totalUserRedEnvelopeAmount = redEnvelopeReceiveLogService.totalRedEnvelopeAmountByUserId(AuthUtil.getUserId(), null, null);
		vo.setReceiveItemAmount(totalUserRedEnvelopeAmount);
		//当前登录人领取的红包总个数
		LambdaQueryWrapper<RedEnvelopeReceiveLog> wrapper = new LambdaQueryWrapper<>();
		wrapper.eq(BaseEntity::getCreateUserId, AuthUtil.getUserId());
		int count = redEnvelopeReceiveLogService.count(wrapper);
		vo.setReceiveItemCount(count);
		BigDecimal unaccalimed = redAccelerateRecordMapper.countUnaccalimed(AuthUtil.getUserId());
		vo.setLossTotalAmount(unaccalimed == null ? new BigDecimal(0) : unaccalimed);
		return vo;
	}

	@Override
	public Map<String, Object> grabFlag(Integer type) {
		Map<String, Object> map = new HashMap<>();
		map.put("flag", 0);
		map.put("msg", "");
		if(false){
			map.put("flag", 1);
			return map;
		}
		//如果没有抢过同时红色积分大于0同时有红包
		LambdaQueryWrapper<UserApp> queryWrapper = new LambdaQueryWrapper<>();
		queryWrapper.eq(UserApp::getUserId, AuthUtil.getUserId());
		UserApp userApp = userAppMapper.selectOne(queryWrapper);

		if (!Arrays.asList(2, 3).contains(userApp.getIsRole())) {
			map.put("msg", "您未在创客专区购买商品，不可以领红包!");
			return map;
		}

		BigDecimal sub = new BigDecimal(userApp.getIntegral());
		if (BigDecimal.ZERO.compareTo(sub)==1 && type != 2){
			throw new RuntimeException("当前红色积分为0不可以领红包");
		}
		LambdaQueryWrapper<RedIntegral> wrapper = new LambdaQueryWrapper<>();
		wrapper.eq(RedIntegral::getUserId, AuthUtil.getUserId());
		wrapper.lt(BaseEntity::getCreateTime, DateTimeUtil.earliestTime(new Date()));
		wrapper.orderByDesc(BaseEntity::getCreateTime);
		Query query = new Query().setSize(1).setCurrent(1);
		IPage<RedIntegral> page = Condition.getPage(query);
		IPage<RedIntegral> redIntegralPage = redIntegralService.page(page, wrapper);
		if(2 != type){
			if (CollectionUtil.isNotEmpty(redIntegralPage.getRecords())) {
				//取当前登录人前一天最后一条记录，判断前一天最后剩余的红色积分
				List<RedIntegral> records = redIntegralPage.getRecords();
				BigDecimal lastIntegral = records.get(0).getLastIntegral();
				if (lastIntegral == null || lastIntegral.compareTo(BigDecimal.ZERO) != 1) {
					map.put("msg", "您今天之前没有红色积分，不可以领红包!");
					return map;
				}
			} else {
				map.put("msg", "您今天之前没有红色积分，不可以领红包!");
				return map;
			}
		}

		String strDate = DateTimeUtil.getFormatStrDate(new Date(), "yyyyMMdd");

		if (0 == type) { //随机红包判断
			//判断当天已消费的红包map中是否存在当前登录人id
			Boolean exists = bladeRedis.hExists(CacheBizConstant.CACHE_RED_PACKET_MAP + strDate, AuthUtil.getUserId());
			if (exists) {
				map.put("msg", "您今天已经领过了随机红包!");
				return map;
			} else {
				if (bladeRedis.getListOps().size(CACHE_RED_PACKET + strDate) > 0) {
					map.put("flag", 1);
				}else {
					map.put("flag", 0);
					map.put("msg", "红包已经领完了!");
				}
			}
		} else if (1 == type) {
			//查询昨天的专属红包
			BigDecimal belongAmount = redIntegralService.getExclusive(AuthUtil.getUserId());
			if (belongAmount == null||belongAmount.compareTo(new BigDecimal(0))==0) {
				map.put("msg", "您推荐的人员没有购买商品,不可以领专属红包!");
				return map;
			}
			LambdaQueryWrapper<RedEnvelopeReceiveLog> lambdaQueryWrapper = new LambdaQueryWrapper<>();
			lambdaQueryWrapper.eq(RedEnvelopeReceiveLog::getType, 1);
			lambdaQueryWrapper.gt(BaseEntity::getCreateTime, DateTimeUtil.earliestTime(new Date()));
			lambdaQueryWrapper.lt(BaseEntity::getCreateTime, DateTimeUtil.lastestTime(new Date()));
			lambdaQueryWrapper.eq(BaseEntity::getCreateUserId, AuthUtil.getUserId());
			int count = redEnvelopeReceiveLogService.count(lambdaQueryWrapper);
			if (count > 0) {
				map.put("msg", "您今天已经领过了专属红包!");
				return map;
			}else {
				map.put("flag", 1);
			}
		} else if(2 == type){
			//查询昨天的专属红包
//			BigDecimal belongAmount = linkedEarningsService.getLastEarningsBeforeToday(AuthUtil.getUserId()).getAfterAmount();
			LinkedEarnings earnings = linkedEarningsService.getLastEarningsBeforeToday(AuthUtil.getUserId());

			if (ObjectUtil.isNull(earnings) || BigDecimal.ZERO.compareTo(earnings.getAfterAmount()) >= 0) {
				map.put("msg", "您今天之前没有1580收益，无法领取1580红包!");
				return map;
			}
			LambdaQueryWrapper<RedEnvelopeReceiveLog> lambdaQueryWrapper = new LambdaQueryWrapper<>();
			lambdaQueryWrapper.eq(RedEnvelopeReceiveLog::getType, 2);
			lambdaQueryWrapper.gt(BaseEntity::getCreateTime, DateTimeUtil.earliestTime(new Date()));
			lambdaQueryWrapper.lt(BaseEntity::getCreateTime, DateTimeUtil.lastestTime(new Date()));
			lambdaQueryWrapper.eq(BaseEntity::getCreateUserId, AuthUtil.getUserId());
			int count = redEnvelopeReceiveLogService.count(lambdaQueryWrapper);

			if (count > 0) {
				map.put("msg", "您今天已经领过了1580红包!");
				return map;
			}else {
				map.put("flag", 1);
			}
		} else {
			throw new RuntimeException("参数错误");
		}
		return map;
	}
}
