package org.springblade.modules.redenvelopemall.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.common.enums.LinkedEarningsTypeEnum;
import org.springblade.common.enums.RedMoneySourceEnum;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.modules.linked.service.ILinkedUserInfoService;
import org.springblade.modules.platform.service.UserAppService;
import org.springblade.modules.redenvelopemall.entity.RedAccelerateRecord;
import org.springblade.modules.redenvelopemall.entity.RedEnvelopeReceiveLog;
import org.springblade.modules.redenvelopemall.mapper.RedEnvelopeReceiveLogMapper;
import org.springblade.modules.redenvelopemall.param.RedEnvelopeReceiveLogParam;
import org.springblade.modules.redenvelopemall.service.IRedAccelerateRecordService;
import org.springblade.modules.redenvelopemall.service.IRedEnvelopeReceiveLogService;
import org.springblade.modules.redenvelopemall.service.IRedIntegralService;
import org.springblade.modules.redenvelopemall.vo.RedEnvelopeReceiveLogVo;
import org.springblade.modules.system.entity.UserApp;
import org.springblade.modules.system.service.IRedMoneyRecordService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.Map;

@Service
public class RedEnvelopeReceiveLogServiceImpl extends ServiceImpl<RedEnvelopeReceiveLogMapper, RedEnvelopeReceiveLog> implements IRedEnvelopeReceiveLogService {

	@Resource
	private UserAppService userAppService;

	@Resource
	private IRedIntegralService redIntegralService;

	@Resource
	private IRedAccelerateRecordService redAccelerateRecordService;

	@Resource
	private ILinkedUserInfoService linkedUserInfoService;

	@Resource
	private IRedMoneyRecordService redMoneyRecordService;

	@Override
	@Async("redPacket_save")
	@Transactional(rollbackFor = Exception.class)
	public void saveReceiveLog(RedEnvelopeReceiveLog log , RedEnvelopeReceiveLog belongLog) {
		//当专属红包不为空且金额大于0保存专属红包
		if (belongLog!=null&&belongLog.getAmount()!=null&&belongLog.getAmount().compareTo(new BigDecimal(0))==1){
			LambdaQueryWrapper<UserApp> wrapper = new LambdaQueryWrapper<>();
			wrapper.eq(UserApp::getUserId, belongLog.getCreateUserId());
			UserApp userApp = userAppService.getOne(wrapper);
			BigDecimal bigDecimal=new BigDecimal(0);
			if (userApp!=null&&userApp.getRedMoney()!=null){
				bigDecimal=userApp.getRedMoney();
			}
			belongLog.setBeforeAmount(bigDecimal);
			belongLog.setAfterAmount(bigDecimal.add(belongLog.getAmount()));
			//1、保存专属红包日志
			this.baseMapper.insert(belongLog);
			//2、扣减积分
			redIntegralService.subIntegral(belongLog.getCreateUserId(),belongLog.getAmount(),3,belongLog.getId());
			//3、更新昨天的加速积分记录
			//根据收益Id与使用时间更新
			LambdaUpdateWrapper<RedAccelerateRecord> updateWrapper = new LambdaUpdateWrapper<>();
			updateWrapper.eq(RedAccelerateRecord::getBenefitUserId, belongLog.getCreateUserId());
			updateWrapper.eq(RedAccelerateRecord::getIsUse, 0);
			updateWrapper.last(" and to_days(create_time) = (to_days(now()) -1) ");
			updateWrapper.set(RedAccelerateRecord::getUseTime,new Date());
			updateWrapper.set(RedAccelerateRecord::getIsUse,1);
			//来源id这里不应该传
			//updateWrapper.set(RedAccelerateRecord::getDataId,belongLog.getId());
			redAccelerateRecordService.update(updateWrapper);
			//4、更新用户余额
			UpdateWrapper wrapper1 = new UpdateWrapper();
			wrapper1.eq("user_id",belongLog.getCreateUserId());
			wrapper1.setSql(" red_money = ( CASE WHEN IFNULL( red_money, '' ) = '' THEN '' ELSE red_money END) + "+belongLog.getAmount());
			redMoneyRecordService.redMoneyUpdateRecord(belongLog.getCreateUserId(), RedMoneySourceEnum.RECEIVING_RED, belongLog.getAmount(), new BigDecimal(0), belongLog.getId());
//			userAppService.update(wrapper1);
		}
		//随机红包不为空则保存随机红包
		if (log!=null){
			LambdaQueryWrapper<UserApp> userAppWrapper = new LambdaQueryWrapper<>();
			userAppWrapper.eq(UserApp::getUserId, log.getCreateUserId());
			UserApp userApp = userAppService.getOne(userAppWrapper);
			BigDecimal bigDecimal=new BigDecimal(0);
			if (userApp!=null&&userApp.getRedMoney()!=null){
				bigDecimal=userApp.getRedMoney();
			}
			log.setBeforeAmount(bigDecimal);
			log.setAfterAmount(bigDecimal.add(log.getAmount()));
			//1、保存随机红包日志
			this.baseMapper.insert(log);
			//2、扣减积分
			redIntegralService.subIntegral(log.getCreateUserId(),log.getAmount(),2,log.getId());
			//3、更新用户余额
			UpdateWrapper wrapper = new UpdateWrapper();
			wrapper.eq("user_id",log.getCreateUserId());
			wrapper.setSql(" red_money = ( CASE WHEN IFNULL( red_money, '' ) = '' THEN '' ELSE red_money END) + "+log.getAmount());
			redMoneyRecordService.redMoneyUpdateRecord(log.getCreateUserId(), RedMoneySourceEnum.RECEIVING_RED, log.getAmount(), new BigDecimal(0), log.getId());
//			userAppService.update(wrapper);
		}
	}

	/**
	 * 保存专属红包
	 *
	 * @param belongLog 专属红包
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public void saveReceiveBelongLog(RedEnvelopeReceiveLog belongLog) {
		LambdaQueryWrapper<UserApp> wrapper = new LambdaQueryWrapper<>();
		wrapper.eq(UserApp::getUserId, belongLog.getCreateUserId());
		UserApp userApp = userAppService.getOne(wrapper);
		BigDecimal bigDecimal=new BigDecimal(0);
		if (userApp!=null&&userApp.getRedMoney()!=null){
			bigDecimal=userApp.getRedMoney();
		}
		belongLog.setBeforeAmount(bigDecimal);
		belongLog.setAfterAmount(bigDecimal.add(belongLog.getAmount()));
		//1、保存专属红包日志
		this.baseMapper.insert(belongLog);
		//2、扣减积分
		redIntegralService.subIntegral(belongLog.getCreateUserId(),belongLog.getAmount(),3,belongLog.getId());
		//3、更新昨天的加速积分记录
		//根据收益Id与使用时间更新
		LambdaUpdateWrapper<RedAccelerateRecord> updateWrapper = new LambdaUpdateWrapper<>();
		updateWrapper.eq(RedAccelerateRecord::getBenefitUserId, belongLog.getCreateUserId());
		updateWrapper.eq(RedAccelerateRecord::getIsUse, 0);
		updateWrapper.last(" and to_days(create_time) = (to_days(now()) -1) ");
		updateWrapper.set(RedAccelerateRecord::getUseTime,new Date());
		updateWrapper.set(RedAccelerateRecord::getIsUse,1);
		//来源id这里不应该传
		//updateWrapper.set(RedAccelerateRecord::getDataId,belongLog.getId());
		redAccelerateRecordService.update(updateWrapper);
		//4、更新用户余额
		UpdateWrapper wrapper1 = new UpdateWrapper();
		wrapper1.eq("user_id",belongLog.getCreateUserId());
		wrapper1.setSql(" red_money = ( CASE WHEN IFNULL( red_money, '' ) = '' THEN '' ELSE red_money END) + "+belongLog.getAmount());
		redMoneyRecordService.redMoneyUpdateRecord(belongLog.getCreateUserId(), RedMoneySourceEnum.RECEIVING_RED, belongLog.getAmount(), new BigDecimal(0), belongLog.getId());
//		userAppService.update(wrapper1);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public void saveLinkedBelongLog(RedEnvelopeReceiveLog belongLog) {
		LambdaQueryWrapper<UserApp> wrapper = new LambdaQueryWrapper<>();
		wrapper.eq(UserApp::getUserId, belongLog.getCreateUserId());
		UserApp userApp = userAppService.getOne(wrapper);
		BigDecimal bigDecimal=new BigDecimal(0);
		if (userApp!=null&&userApp.getRedMoney()!=null){
			bigDecimal=userApp.getRedMoney();
		}
		belongLog.setBeforeAmount(bigDecimal);
		belongLog.setAfterAmount(bigDecimal.add(belongLog.getAmount()));
		//1、保存联动收益红包日志
		this.baseMapper.insert(belongLog);
		//2、扣减积分
	//	redIntegralService.subIntegral(belongLog.getCreateUserId(),belongLog.getAmount(),3,belongLog.getId());
		//3、联动收益扣减
		Map<String, Object> map = linkedUserInfoService.changeEarnings(belongLog.getCreateUserId(), belongLog.getAmount(), LinkedEarningsTypeEnum.SUBTRACT);
		if(!(Boolean)map.get("flag")){
			throw new RuntimeException(map.get("msg").toString());
		}
		//4、更新用户余额
		UpdateWrapper wrapper1 = new UpdateWrapper();
		wrapper1.eq("user_id",belongLog.getCreateUserId());
		wrapper1.setSql(" red_money = ( CASE WHEN IFNULL( red_money, '' ) = '' THEN '' ELSE red_money END) + "+belongLog.getAmount());
		redMoneyRecordService.redMoneyUpdateRecord(belongLog.getCreateUserId(), RedMoneySourceEnum.RECEIVING_RED, belongLog.getAmount(), new BigDecimal(0), belongLog.getId());
//		userAppService.update(wrapper1);
	}

	@Override
	public IPage<RedEnvelopeReceiveLogVo> logByRedEnvelopeId(String redEnvelopeId, String userName,Query query) {
		IPage page = Condition.getPage(query);
		return this.baseMapper.pageByRedEnvelopeId(page,redEnvelopeId,userName);
	}

	@Override
	public IPage<RedEnvelopeReceiveLogVo> logPage(RedEnvelopeReceiveLogParam param, Query query) {
		IPage page = Condition.getPage(query);
		return this.baseMapper.logPage(page,param);
	}

	@Override
	public BigDecimal totalRedEnvelopeAmountByUserId(Long userId, Date startTime, Date endTime) {
		BigDecimal total = new BigDecimal("0");
		QueryWrapper<RedEnvelopeReceiveLog> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq(ObjectUtil.isNotNull(userId),"create_user_id",userId);
		queryWrapper.gt(ObjectUtil.isNotNull(startTime),"create_time",startTime);
		queryWrapper.lt(ObjectUtil.isNotNull(endTime),"create_time",endTime);
		queryWrapper.select("sum(amount) as totalAmount");
		if (this.baseMapper.selectOne(queryWrapper)!=null){
			total=this.baseMapper.selectOne(queryWrapper).getTotalAmount();
		}
		return total;
	}

	@Override
	public BigDecimal totalRedEnvelopeAmount(Date startTime, Date endTime) {
		BigDecimal total = new BigDecimal("0");
		QueryWrapper<RedEnvelopeReceiveLog> queryWrapper = new QueryWrapper<>();
		queryWrapper.gt(ObjectUtil.isNotNull(startTime),"create_time",startTime);
		queryWrapper.lt(ObjectUtil.isNotNull(endTime),"create_time",endTime);
		queryWrapper.eq("type",0);
		queryWrapper.select("sum(amount) as totalAmount");
		if (this.baseMapper.selectOne(queryWrapper)!=null){
			total=this.baseMapper.selectOne(queryWrapper).getTotalAmount();
		}
		return total;
	}

	@Override
	public IPage<RedEnvelopeReceiveLogVo> leaderboard(Date startTime, Date endTime, Query query, Integer type) {
		IPage page = Condition.getPage(query);
		return this.baseMapper.leaderboard(page, startTime,  endTime, type);
	}
}
