package org.springblade.modules.redenvelopemall.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springblade.common.base.BaseEntity;
import org.springblade.common.constant.CacheBizConstant;
import org.springblade.common.utils.DateTimeUtil;
import org.springblade.core.log.exception.ServiceException;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.modules.linked.service.ILinkedEarningsService;
import org.springblade.modules.platform.service.UserAppService;
import org.springblade.modules.redenvelopemall.entity.RedEnvelope;
import org.springblade.modules.redenvelopemall.entity.RedEnvelopeItem;
import org.springblade.modules.redenvelopemall.entity.RedEnvelopeReceiveLog;
import org.springblade.modules.redenvelopemall.mapper.RedEnvelopeMapper;
import org.springblade.modules.redenvelopemall.service.IRedEnvelopeReceiveLogService;
import org.springblade.modules.redenvelopemall.service.IRedEnvelopeService;
import org.springblade.modules.redenvelopemall.service.IRedIntegralService;
import org.springblade.modules.system.entity.UserApp;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.core.script.DefaultRedisScript;
import org.springframework.data.redis.serializer.StringRedisSerializer;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import static org.springblade.common.constant.CacheBizConstant.CACHE_RED_PACKET;

@Service
public class RedEnvelopeServiceImpl extends ServiceImpl<RedEnvelopeMapper, RedEnvelope> implements IRedEnvelopeService {
	private static final Logger log = LoggerFactory.getLogger(IRedEnvelopeService.class);

	@Resource
	private RedisTemplate redisTemplate;
	@Resource
	private IRedEnvelopeReceiveLogService redEnvelopeReceiveLogService;
	@Resource
	private UserAppService userAppService;

	@Resource
	private IRedIntegralService redIntegralService;

	@Resource
	private ILinkedEarningsService linkedEarningsService;


	@Override
	public RedEnvelopeReceiveLog grab() {
		String strDate = DateTimeUtil.getFormatStrDate(new Date(), "yyyyMMdd");
		String script = "if redis.call('hexists', KEYS[3], KEYS[4]) ~= 0 then"
			+ " return nil"
			+ " else"
			+ " local hongBao = redis.call('rpop', KEYS[1]);"
			+ " if hongBao then"
			+ " local x = cjson.decode(hongBao);"
			+ " x['userId'] = KEYS[4];"
			+ " local re = cjson.encode(x);"
			+ " redis.call('hset', KEYS[3], KEYS[4], KEYS[4]);"
			+ " redis.call('lpush', KEYS[2], re);"
			+ " return re;"
			+ " end"
			+ " end"
			+ " return nil";
		while (true) {
			List<String> keys = new ArrayList<>();
			keys.add(CacheBizConstant.CACHE_RED_PACKET + strDate);
			keys.add(CacheBizConstant.CACHE_RED_PACKET_LIST + strDate);
			keys.add(CacheBizConstant.CACHE_RED_PACKET_MAP + strDate);
			keys.add(AuthUtil.getUserId().toString());
			Object object = redisTemplate.execute(new DefaultRedisScript<>(script, JSONObject.class), new StringRedisSerializer(), new StringRedisSerializer(),
				keys);
			if (object != null) {
				log.info("get hongBao:" + JSONUtil.toJsonStr(object));
				RedEnvelopeItem redEnvelopeItem = JSONUtil.toBean(JSONUtil.toJsonStr(object), RedEnvelopeItem.class);
				RedEnvelopeReceiveLog randomLog = new RedEnvelopeReceiveLog();
				BeanUtil.copyProperties(redEnvelopeItem, log);
				randomLog.setRedEnvelopeItemId(redEnvelopeItem.getId());
				//抢到的金额
				randomLog.setGrabAmount(redEnvelopeItem.getAmount());
				randomLog.setId(null);
				randomLog.setType(0);
				randomLog.setCreateTime(new Date());
				randomLog.setUpdateTime(new Date());
				randomLog.setCreateUserId(AuthUtil.getUserId());
				randomLog.setUpdateUserId(AuthUtil.getUserId());
				randomLog.setAmount(redEnvelopeItem.getAmount());
//				//查询昨天的专属红包
//				BigDecimal belongAmount = redIntegralService.getExclusive(AuthUtil.getUserId());
//				if (belongAmount==null){
//					belongAmount=new BigDecimal(0);
//				}
				//查询当前的红色积分
				UserApp userApp = userAppService.getOne(Wrappers.lambdaQuery(UserApp.class).eq(UserApp::getUserId, AuthUtil.getUserId()));
//				RedEnvelopeReceiveLog belongLog = new RedEnvelopeReceiveLog();
//				belongLog.setAmount(belongAmount);
//				belongLog.setGrabAmount(belongAmount);
//				belongLog.setId(null);
//				belongLog.setType(1);
//				belongLog.setRedEnvelopeItemId(redEnvelopeItem.getId());
//				belongLog.setCreateTime(new Date());
//				belongLog.setUpdateTime(new Date());
//				belongLog.setCreateUserId(AuthUtil.getUserId());
//				belongLog.setUpdateUserId(AuthUtil.getUserId());
				//如果当前红色积分小于随机红包，则实际领取的红包等于当前红色积分
				BigDecimal sub = new BigDecimal(userApp.getIntegral());
				if (BigDecimal.ZERO.compareTo(sub)==1){
					log.warn(AuthUtil.getUserId()+"当前红色积分为0不可以领红包");
					throw new RuntimeException("当前红色积分为0不可以领红包");
				}
				if (sub.compareTo(redEnvelopeItem.getAmount()) == -1) {
					randomLog.setAmount(sub);
				}
				//randomLog.setBelongAmount(belongAmount);
				redEnvelopeReceiveLogService.saveReceiveLog(randomLog, null);
				return randomLog;
			} else {
				//已经取完了
				if (redisTemplate.opsForList().size(CACHE_RED_PACKET + strDate) == 0) {
					log.warn("已经取完了");
					throw new ServiceException("今天的红包已经取完了");
				} else {
					log.warn(AuthUtil.getUserId()+"您已经领过了");
					throw new ServiceException("您已经领过了");
				}
			}
		}


	}

	/**
	 * 领专属红包
	 *
	 * @return
	 */
	@Override
	public RedEnvelopeReceiveLog grabBelong() {

		LambdaQueryWrapper<RedEnvelopeReceiveLog> lambdaQueryWrapper = new LambdaQueryWrapper<>();
		lambdaQueryWrapper.eq(RedEnvelopeReceiveLog::getType, 1);
		lambdaQueryWrapper.gt(BaseEntity::getCreateTime, DateTimeUtil.earliestTime(new Date()));
		lambdaQueryWrapper.lt(BaseEntity::getCreateTime, DateTimeUtil.lastestTime(new Date()));
		lambdaQueryWrapper.eq(BaseEntity::getCreateUserId, AuthUtil.getUserId());
		int count = redEnvelopeReceiveLogService.count(lambdaQueryWrapper);
		if (count>0){
			throw new RuntimeException("您已经领过了");
		}
		//查询昨天的专属红包
		BigDecimal belongAmount = redIntegralService.getExclusive(AuthUtil.getUserId());
		if (belongAmount == null||belongAmount.compareTo(new BigDecimal(0))==0) {
			throw new RuntimeException("您推荐的人员没有购买商品,不可以领专属红包!");
		}
		//查询当前的红色积分
		UserApp userApp = userAppService.getOne(Wrappers.lambdaQuery(UserApp.class).eq(UserApp::getUserId, AuthUtil.getUserId()));
		BigDecimal sub = new BigDecimal(userApp.getIntegral());
		if (BigDecimal.ZERO.compareTo(sub)==1){
			log.warn(AuthUtil.getUserId()+"当前红色积分为0不可以领红包");
			throw new RuntimeException("当前红色积分为0不可以领红包");
		}
		RedEnvelopeReceiveLog belongLog = new RedEnvelopeReceiveLog();
		belongLog.setAmount(belongAmount);
		belongLog.setGrabAmount(belongAmount);
		belongLog.setId(null);
		belongLog.setType(1);
		belongLog.setCreateTime(new Date());
		belongLog.setUpdateTime(new Date());
		belongLog.setCreateUserId(AuthUtil.getUserId());
		belongLog.setUpdateUserId(AuthUtil.getUserId());
		//如果当前红色积分小于专属红包后小于领取的红包，则实际领取的红包等于当前红色积分
		if (new BigDecimal(userApp.getIntegral()).compareTo(belongAmount) == -1) {
			belongLog.setAmount(new BigDecimal(userApp.getIntegral()));
		}
		redEnvelopeReceiveLogService.saveReceiveBelongLog(belongLog);
		return belongLog;
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public RedEnvelopeReceiveLog grabLinked() {
		LambdaQueryWrapper<RedEnvelopeReceiveLog> lambdaQueryWrapper = new LambdaQueryWrapper<>();
		lambdaQueryWrapper.eq(RedEnvelopeReceiveLog::getType, 2);
		lambdaQueryWrapper.gt(BaseEntity::getCreateTime, DateTimeUtil.earliestTime(new Date()));
		lambdaQueryWrapper.lt(BaseEntity::getCreateTime, DateTimeUtil.lastestTime(new Date()));
		lambdaQueryWrapper.eq(BaseEntity::getCreateUserId, AuthUtil.getUserId());
		int count = redEnvelopeReceiveLogService.count(lambdaQueryWrapper);
		if (count>0){
			throw new RuntimeException("您已经领过了");
		}
		//查询昨天的联动收益红包
		BigDecimal belongAmount = linkedEarningsService.getLastEarningsBeforeToday(AuthUtil.getUserId()).getAfterAmount();
		if (BigDecimal.ZERO.compareTo(belongAmount) >= 0){
			log.warn(AuthUtil.getUserId()+"当前没有1580的收益不可以领红包");
			throw new RuntimeException("当前没有1580的收益不可以领红包");
		}
		RedEnvelopeReceiveLog belongLog = new RedEnvelopeReceiveLog();
		belongLog.setAmount(belongAmount);
		belongLog.setGrabAmount(belongAmount);
		belongLog.setId(null);
		belongLog.setType(2);
		belongLog.setCreateTime(new Date());
		belongLog.setUpdateTime(new Date());
		belongLog.setCreateUserId(AuthUtil.getUserId());
		belongLog.setUpdateUserId(AuthUtil.getUserId());
		//如果当前红色积分小于专属红包后小于领取的红包，则实际领取的红包等于当前红色积分
//		if (new BigDecimal(userApp.getIntegral()).compareTo(belongAmount) == -1) {
//			belongLog.setAmount(new BigDecimal(userApp.getIntegral()));
//		}
		redEnvelopeReceiveLogService.saveLinkedBelongLog(belongLog);
		return belongLog;
	}


}
