package org.springblade.modules.redenvelopemall.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.GoodsStateEnum;
import org.springblade.common.enums.YesOrNoEnum;
import org.springblade.common.enums.ZoneTypeEnum;
import org.springblade.core.log.exception.ServiceException;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.modules.api.response.CartListResponse;
import org.springblade.modules.api.service.impl.ReOrderServiceImpl;
import org.springblade.modules.redenvelopemall.entity.GoodsInfo;
import org.springblade.modules.redenvelopemall.entity.GoodsSpec;
import org.springblade.modules.redenvelopemall.entity.ShoppingCart;
import org.springblade.modules.redenvelopemall.mapper.ShoppingCartMapper;
import org.springblade.modules.redenvelopemall.service.IGoodsInfoService;
import org.springblade.modules.redenvelopemall.service.IGoodsSpecService;
import org.springblade.modules.redenvelopemall.service.IShoppingCartService;
import org.springblade.modules.redenvelopemall.vo.BrandsInfoVO;
import org.springblade.modules.redenvelopemall.vo.ShoppingCartVO;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.List;

/**
 * Author pangqijun
 * Date 2022/7/28
 * Description
 */
@Service
public class ShoppingCartServiceImpl extends ServiceImpl<ShoppingCartMapper, ShoppingCart> implements IShoppingCartService {

	@Resource
	private ReOrderServiceImpl reOrderService;
	@Resource
	private IGoodsInfoService goodsInfoService;
	@Resource
	private IGoodsSpecService goodsSpecService;

	@Override
	public void add(ShoppingCart cart) {
		GoodsInfo goodsInfo = goodsInfoService.getById(cart.getGoodsInfoId());
		Assert.notNull(goodsInfo, "商品数据不存在");
		if (ZoneTypeEnum.CITY_PARTNER.getValue().equals(goodsInfo.getZoneType())) {
			throw new ServiceException("城市合伙人暂不支持添加到购物车");
		}
		ShoppingCart one = this.lambdaQuery().eq(ShoppingCart::getUserId, cart.getUserId()).eq(ShoppingCart::getGoodsInfoId, cart.getGoodsInfoId())
			.eq(ShoppingCart::getGoodsSpecId, cart.getGoodsSpecId()).one();
		if (one == null) {
			this.save(cart);
		} else {
			one.setGoodsNum(one.getGoodsNum() + cart.getGoodsNum());
			this.updateById(one);
		}
	}

	@Override
	public List<ShoppingCartVO> list(Query query) {
		List<ShoppingCartVO> cartVOS = this.baseMapper.selectPage(Condition.getPage(query), AuthUtil.getUserId());
		for (ShoppingCartVO vo : cartVOS) {
			vo.setCover(vo.getGoodsSpecImg());
			if (StrUtil.isBlank(vo.getGoodsSpecImg())) {
				vo.setCover(vo.getGoodsInfoImg());
			}
			// 设置积分兑换所需要的积分和需要付款的金额
			if (ZoneTypeEnum.INTEGRAL_CONVERT.getValue().equals(vo.getZoneType())) {
				BigDecimal salePrice = vo.getSalePrice();
				BigDecimal needExchangeIntegral = reOrderService.calNeedExchangeIntegral(salePrice, vo.getAgreementPrice());
				vo.setNeedAmount(salePrice.subtract(needExchangeIntegral));
				vo.setNeedIntegral(needExchangeIntegral);
			}
			if (vo.getIsActivity().equals(YesOrNoEnum.NO.getValue())) {
				String exchangeRedIntegralMul = ParamCache.getValueDefault(CommonConstant.EXCHANGE_RED_INTEGRAL_MULTIPLE, "3");
				String buyRedIntegralMul = ParamCache.getValueDefault(CommonConstant.BUY_RED_INTEGRAL_MULTIPLE, "2");
				if (ZoneTypeEnum.INTEGRAL_CONVERT.getValue().equals(vo.getZoneType()) || ZoneTypeEnum.CITY_PARTNER.getValue().equals(vo.getZoneType())) {
					vo.setObtainIntegral(vo.getSalePrice().multiply(new BigDecimal(exchangeRedIntegralMul)).setScale(2, BigDecimal.ROUND_HALF_UP));
				} else if (ZoneTypeEnum.RED_INTEGRAL.getValue().equals(vo.getZoneType()) || ZoneTypeEnum.GUEST.getValue().equals(vo.getZoneType()) || ZoneTypeEnum.HOT_STYLE.getValue().equals(vo.getZoneType())) {
					vo.setObtainIntegral(vo.getSalePrice().multiply(new BigDecimal(buyRedIntegralMul)).setScale(2, BigDecimal.ROUND_HALF_UP));
				} else if (ZoneTypeEnum.GREEN_INTEGRAL.getValue().equals(vo.getZoneType())) {
					vo.setObtainIntegral(vo.getObtainIntegral());
				} else {
					vo.setObtainIntegral(vo.getSalePrice().setScale(2, BigDecimal.ROUND_HALF_UP));
				}
			} else {
				if (vo.getSalePrice().doubleValue() > 3000) {
					vo.setObtainIntegral(BigDecimal.valueOf(vo.getSalePrice().doubleValue() * 5));
				} else {
					vo.setObtainIntegral(BigDecimal.valueOf(vo.getSalePrice().doubleValue() * 4));
				}
			}

		}
		return cartVOS;
	}

	@Override
	public int increase(Long shoppingCartId) {
		ShoppingCart cart = this.getById(shoppingCartId);
		Assert.notNull(cart, "数据不存在");
		cart.setGoodsNum(cart.getGoodsNum() + 1);
		this.updateById(cart);
		return cart.getGoodsNum();
	}

	@Override
	public int reduce(Long shoppingCartId) {
		ShoppingCart cart = this.getById(shoppingCartId);
		Assert.notNull(cart, "数据不存在");
		if (cart.getGoodsNum() == 1) {
			throw new ServiceException("宝贝数量不能再减少了");
		}
		cart.setGoodsNum(cart.getGoodsNum() - 1);
		this.updateById(cart);
		return cart.getGoodsNum();
	}

	@Override
	public Integer quantity(Long userId) {
		return this.lambdaQuery().eq(ShoppingCart::getUserId, userId).count();
	}

	@Override
	public void clear(Long userId) {
		List<ShoppingCart> list = this.lambdaQuery().eq(ShoppingCart::getUserId, userId).list();
		for (ShoppingCart shoppingCart : list) {
			this.removeById(shoppingCart.getId());
		}
	}

	@Override
	public List<GoodsSpec> getGoodsSpec(Long goodsInfoId) {
		return goodsSpecService.lambdaQuery().eq(GoodsSpec::getGoodsId, goodsInfoId).eq(GoodsSpec::getIsSale, YesOrNoEnum.YES.getValue()).list();
	}

	@Override
	public void bindGoodsSpec(Long shoppingCartId, Long goodsSpecId) {
		ShoppingCart cart = this.getById(shoppingCartId);
		Assert.notNull(cart, "购物车数据不存在");
		cart.setGoodsSpecId(goodsSpecId);
		this.updateById(cart);
	}

	@Override
	public void remove(List<Long> shoppingCartIds) {
		this.removeByIds(shoppingCartIds);
	}
}
