package org.springblade.modules.redenvelopemall.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.map.MapUtil;
import cn.hutool.core.text.UnicodeUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.crypto.SecureUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alipay.api.AlipayApiException;
import com.alipay.api.AlipayClient;
import com.alipay.api.request.AlipayTradeRefundRequest;
import com.alipay.api.response.AlipayTradeRefundResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.impl.client.CloseableHttpClient;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.constant.SupplyChainConstant;
import org.springblade.common.enums.*;
import org.springblade.common.utils.HttpUtil;
import org.springblade.core.log.exception.ServiceException;
import org.springblade.core.log.logger.BladeLogger;
import org.springblade.core.mp.support.Condition;
import org.springblade.modules.api.service.IAliService;
import org.springblade.modules.finance.entity.Order;
import org.springblade.modules.finance.entity.OrderGoods;
import org.springblade.modules.finance.service.IOrderGoodsService;
import org.springblade.modules.finance.service.IOrderService;
import org.springblade.modules.platform.entity.UserAddress;
import org.springblade.modules.platform.service.IUserAddressService;
import org.springblade.modules.redenvelopemall.dto.PushDataDTO;
import org.springblade.modules.redenvelopemall.dto.SupplyChainDTO;
import org.springblade.modules.redenvelopemall.entity.*;
import org.springblade.modules.redenvelopemall.mapper.GoodsSpecMapper;
import org.springblade.modules.redenvelopemall.mapper.SupplyChainMapper;
import org.springblade.modules.redenvelopemall.service.IRedIntegralService;
import org.springblade.modules.redenvelopemall.service.ISupplyChainService;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.support.atomic.RedisAtomicLong;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.sql.Timestamp;
import java.util.*;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.function.Function;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.stream.Collectors;


/**
 * Author pangqijun
 * Date 2022/5/13
 * Description
 */
@Slf4j
@Service
public class SupplyChainServiceImpl extends ServiceImpl<SupplyChainMapper, SupplyChain> implements ISupplyChainService {

	@Value("${supply.chain.appKey}")
	private String appKey;
	@Value("${supply.chain.secretKey}")
	private String secretKey;
	@Value("${supply.chain.host}")
	private String host;
	@Resource
	private BladeLogger bladeLogger;
	@Resource
	private GoodsInfoServiceImpl goodsInfoService;
	@Resource
	private GoodsSpecServiceImpl goodsSpecService;
	@Resource
	private BrandsInfoServiceImpl brandsInfoService;
	@Resource
	private GoodsParamsServiceImpl goodsParamsService;
	@Resource
	private IUserAddressService userAddressService;
	@Resource
	private IOrderService orderService;
	@Resource
	private CategoryInfoServiceImpl categoryInfoService;
	@Resource
	private AlipayClient alipayClient;
	@Resource
	private IRedIntegralService redIntegralService;
	@Resource
	private IOrderGoodsService orderGoodsService;
	@Resource
	private IAliService aliService;
	@Resource
	private GoodsSpecMapper goodsSpecMapper;
	@Resource
	private HttpUtil httpUtil;

	@Override
	public JSONObject newList(SupplyChainDTO supplyChainDTO) {
		String jsonString = JSON.toJSONString(supplyChainDTO);
		return this.post(jsonString, SupplyChainConstant.V2_GOODSSTORAGE_NEWLIST);
	}

	@Override
	public JSONObject apiActivityLists(HashMap<String, String> param) {
		return this.get(param, SupplyChainConstant.APIACTIVITYLISTS);
	}

	@Override
	public JSONObject myLists(HashMap<String, String> param) {
		return this.get(param, SupplyChainConstant.V2_GOODSSTORAGE_MYLISTS);
	}

	@Override
	public JSONObject groupList(HashMap<String, String> param) {
		return this.get(param, SupplyChainConstant.V2_GROUP_LIST);
	}

	@Override
	public JSONObject detail(List<String> ids) {
		log.info("胜天半子查询详情参数[{}]", JSON.toJSONString(ids));
		long l = System.currentTimeMillis();
		String shard = ParamCache.getValueDefault("stbz.detail.request.interval", "2");
		// 接口单次请求id最多20条
		if (ids.size() <= Integer.parseInt(shard)) {
			HashMap<String, String> body = new HashMap<>();
			body.put("ids", CollUtil.join(ids, ","));
			JSONObject post = this.post(JSON.toJSONString(body), SupplyChainConstant.V2_GOODS_GETBULKGOODDETAIL);
			long l1 = System.currentTimeMillis();
			log.info("胜天半子查询详情时长[{}]", l1 - l);
			return post;
		}
		// 大于20条分批次查询，然后将结果组合在一起
		JSONObject jsonObject = new JSONObject();
		double ceil = Math.ceil(ids.size() / Double.parseDouble(shard));
		for (int i = 0; i < ceil; i++) {
			List<String> list;
			if (i + 1 == ceil) {
				list = ids.subList(i * Integer.parseInt(shard), ids.size());
			} else {
				list = ids.subList(i * Integer.parseInt(shard), (((i + 1) * Integer.parseInt(shard))));
			}
			if (list.size() > 0) {
				HashMap<String, String> body = new HashMap<>();
				body.put("ids", CollUtil.join(list, ","));
				long a = System.currentTimeMillis();
				JSONObject post = this.post(JSON.toJSONString(body), SupplyChainConstant.V2_GOODS_GETBULKGOODDETAIL);
				long l1 = System.currentTimeMillis();
				log.info("胜天半子查询详情时长[{}]", l1 - a);
				JSONArray data = jsonObject.getJSONArray("data");
				if (data != null) {
					data.addAll(post.getJSONArray("data"));
					jsonObject.put("data", data);
				} else {
					jsonObject.put("data", post.getJSONArray("data"));
				}
			}
		}
		return jsonObject;
	}

	@Override
	public JSONObject getCategory(HashMap<String, String> param) {
		return this.get(param, SupplyChainConstant.V2_CATEGORY_GETCATEGORY);
	}

	@Transactional(rollbackFor = Exception.class)
	@Override
	public void afterSaleSuccess(PushDataDTO data) {
		Order order = orderService.lambdaQuery().eq(Order::getOutTradeNo, data.getOrderSn()).one();
		if (order == null) {
			throw new ServiceException("订单号不存在");
		}
		Integer payFlag = order.getPayFlag();
		if (PayFlagEnum.REFUNDED.getValue().equals(payFlag)) {
			log.info("订单号[{}]已退款", order.getOutTradeNo());
			return;
		}
		orderService.commonRefund(order);
	}

	@Override
	public void afterSaleRefuse(PushDataDTO data) {

	}

	@Override
	public void afterSaleAgree(PushDataDTO data) {

	}

	@Override
	public void orderCancel(PushDataDTO data) {
		Order order = orderService.lambdaQuery().eq(Order::getOutTradeNo, data.getOrderSn()).one();
		if (order != null) {
			order.setPayFlag(PayFlagEnum.CANCEL.getValue());
			order.setUpdateTime(new Date());
			orderService.updateById(order);
		}
	}

	@Override
	public void orderDelivery(PushDataDTO data) {
		Order order = orderService.lambdaQuery().eq(Order::getOutTradeNo, data.getOrderSn()).one();
		if (order != null) {
			OrderGoods orderGoods = orderGoodsService.lambdaQuery().eq(OrderGoods::getOutTradeNo, order.getOutTradeNo()).one();
			GoodsSpec goodsSpec = goodsSpecMapper.get(orderGoods.getGoodsSpecIds());
			// 查询物流单号
			JSONObject logistic = this.logistic(order.getOutTradeNo(), goodsSpec.getOptionId());
			JSONObject jsonObject = logistic.getJSONObject("data").getJSONObject("info");
			String name = jsonObject.getString("name");
			String no = jsonObject.getString("no");

			order.setPayFlag(PayFlagEnum.WAIT_RECEIVE.getValue());
			order.setSendTime(new Date());
			order.setUpdateTime(new Date());
			order.setWlName(name);
			order.setWlNum(no);
			orderService.updateById(order);
		}
	}

	@Override
	public void orderDelivered(PushDataDTO data) {
//		Order order = orderService.lambdaQuery().eq(Order::getOutTradeNo, data.getOrderSn()).one();
//		if (order != null && order.getSettleType().equals(SettleTypeEnum.SELF_SUPPORT.getValue())) {
//			order.setPayFlag(PayFlagEnum.COMPLETED.getValue());
//			order.setRecordTime(new Date());
//			order.setUpdateTime(new Date());
//			orderService.updateById(order);
//		}
	}

	@Override
	public void orderSuccess(PushDataDTO data) {
//		Order order = orderService.lambdaQuery().eq(Order::getOutTradeNo, data.getOrderSn()).one();
//		if (order != null) {
//			order.setPayFlag(PayFlagEnum.COMPLETED.getValue());
//			order.setUpdateTime(new Date());
//			orderService.updateById(order);
//		}
	}

	@Override
	public void goodsPriceAlter(List<String> goodsIds) {
		this.goodsAlter(goodsIds);
	}

	@Override
	public void goodsAlter(List<String> goodsIds) {
		if (CollUtil.isEmpty(goodsIds)) {
			throw new ServiceException("goodsIds参数不能为空");
		}
		try {
			List<GoodsInfo> list = goodsInfoService.lambdaQuery().in(GoodsInfo::getThirdId, goodsIds)
				.eq(GoodsInfo::getSource, GoodsSourceEnum.STBZ.getValue()).list();
			if (CollUtil.isNotEmpty(list)) {
				goodsInfoService.syncFull(list.stream().map(GoodsInfo::getId).collect(Collectors.toList()), false);
			}
		} catch (Exception e) {
			log.error("商品修改回调处理失败_" + e.getMessage(), e);
		}
	}

	@Override
	public void updateGoodsState(List<String> goodsIds, GoodsStateEnum stateEnum) {
		this.lambdaUpdate().set(SupplyChain::getStatus, 0)
			.set(SupplyChain::getUpdatedTime, Timestamp.valueOf(DateUtil.toLocalDateTime(DateUtil.date()))).in(SupplyChain::getId, goodsIds);
		List<GoodsInfo> goodsInfos = goodsInfoService.getByThirdIds(goodsIds, GoodsSourceEnum.STBZ);
		if (CollUtil.isNotEmpty(goodsInfos)) {
			List<GoodsInfo> updateList = new ArrayList<>();
			for (GoodsInfo goodsInfo : goodsInfos) {
				GoodsInfo update = new GoodsInfo();
				update.setId(goodsInfo.getId());
				update.setIsSale(stateEnum.getValue());
				updateList.add(update);
			}
			goodsInfoService.updateBatchById(updateList);
		}
	}

	@Override
	public void goodsStorageRemove(List<String> thirdGoodsIds) {
		this.removeByIds(thirdGoodsIds);
		List<GoodsInfo> goodsInfos = goodsInfoService.getByThirdIds(thirdGoodsIds, GoodsSourceEnum.STBZ);
		if (CollUtil.isNotEmpty(goodsInfos)) {
			List<Long> goodsIds = goodsInfos.stream().map(GoodsInfo::getId).collect(Collectors.toList());
			goodsInfoService.removeByIds(goodsIds);
			List<GoodsSpec> list = goodsSpecService.lambdaQuery().in(GoodsSpec::getGoodsId, goodsIds).list();
			goodsSpecService.removeByIds(list.stream().map(GoodsSpec::getId).collect(Collectors.toList()));
			this.removeByIds(thirdGoodsIds);
		}
	}

	@Override
	public JSONObject beforeCheck(String optionId, Integer num, Long userAddressId) {
		JSONObject jsonObject = new JSONObject();
		JSONArray spu = this.convertSpu(optionId, num);
		jsonObject.put("spu", spu);
		jsonObject.put("address", this.convertAddress(userAddressId));
		try {
			return this.post(jsonObject.toJSONString(), SupplyChainConstant.V2_ORDER_BEFORE_CHECK);
		} catch (Exception e) {
//			List<GoodsSpec> list = goodsSpecService.lambdaQuery().eq(GoodsSpec::getOptionId, optionId).list();
//			Long goodsId = list.get(0).getGoodsId();
//			GoodsInfo goodsInfo = goodsInfoService.getById(goodsId);
//			// 前置校验返回商品下架时，系统自动下架商品，避免第三方回调不及时导致商品没及时下架
//			if (goodsInfo != null && (e.getMessage().contains("商品下架") || e.getMessage().contains("商品已下架"))) {
//				String thirdId = goodsInfo.getThirdId();
//				this.lambdaUpdate().set(SupplyChain::getStatus, 0).eq(SupplyChain::getId, thirdId).update();
//				goodsInfoService.lambdaUpdate().set(GoodsInfo::getIsSale, GoodsStateEnum.UNDERCARRIAGE.getValue())
//					.eq(GoodsInfo::getThirdId, thirdId).update();
//			}
//			// 商品不存在则自动刷新商品数据
//			if (goodsInfo != null && e.getMessage().contains("商品不存在")) {
//				goodsInfoService.syncFull(CollUtil.newArrayList(goodsInfo.getId()), false);
//			}
			throw e;
		}
	}

	@Override
	public JSONObject availableCheck(Long goodsInfoId, Long userAddressId) {
		List<GoodsSpec> goodsSpecs = goodsSpecService.getByGoodsId(goodsInfoId);
		JSONArray jsonArray = new JSONArray();
		for (GoodsSpec goodsSpec : goodsSpecs) {
			JSONObject spu = new JSONObject();
			spu.put("sku", goodsSpec.getOptionId());
			spu.put("number", 1);
			jsonArray.add(spu);
		}
		JSONObject address = this.convertAddress(userAddressId);
		JSONObject jsonObject = new JSONObject();
		jsonObject.put("spu", jsonArray);
		jsonObject.put("address", address);
		JSONObject result = this.get(jsonObject.toJSONString(), SupplyChainConstant.V2_ORDER_AVAILABLECHECK);
		JSONArray available = result.getJSONObject("data").getJSONObject("data").getJSONArray("available");
		// 贵阳地区无货的商品进行自动下架
		if (available.isEmpty() && "贵州省".equals(address.getString("province")) && "贵阳市".equals(address.getString("city"))) {
			goodsInfoService.lambdaUpdate().eq(GoodsInfo::getId, goodsInfoId).set(GoodsInfo::getIsSale, YesOrNoEnum.NO.getValue()).update();
		}
		return result;
	}

	@Override
	public JSONObject order(String orderSn, String optionId, Integer num, Long userAddressId) {
		JSONObject jsonObject = new JSONObject();
		jsonObject.put("orderSn", orderSn);
		jsonObject.put("spu", this.convertSpu(optionId, num));
		jsonObject.put("address", convertAddress(userAddressId));
		return this.postNotValid(jsonObject.toJSONString(), SupplyChainConstant.V2_ORDER);
	}

	@Override
	public JSONObject logistic(String orderSn, String sku) {
		JSONObject jsonObject = new JSONObject();
		jsonObject.put("orderSn", orderSn);
		jsonObject.put("sku", sku);
		return this.get(jsonObject.toJSONString(), SupplyChainConstant.V2_LOGISTIC);
	}

	@Override
	public JSONObject afterSaleBeforeCheck(String orderSn, String sku) {
		JSONObject jsonObject = new JSONObject();
		jsonObject.put("orderSn", orderSn);
		jsonObject.put("sku", sku);
		return this.post(jsonObject.toJSONString(), SupplyChainConstant.AFTER_SALE_BEFORE_CHECK);
	}

	@Override
	public JSONObject afterSale(String orderSn, String sku, Integer num, Double logisticFee, String serviceTypeCode) {
		JSONObject jsonObject = new JSONObject();
		jsonObject.put("orderSn", orderSn);
		jsonObject.put("sku", sku);
		jsonObject.put("num", num);
		jsonObject.put("logisticFee", logisticFee);
		jsonObject.put("serviceTypeCode", serviceTypeCode);
		jsonObject.put("reasonsDescription", "申请退款");
		jsonObject.put("reasonsTypeCode", "8");// 售后原因类型 8-其他
		return this.post(jsonObject.toJSONString(), SupplyChainConstant.AFTER_SALE);
	}

	@Override
	public void fixData() {
		List<GoodsInfo> list = goodsInfoService.lambdaQuery().eq(GoodsInfo::getBusinessType, BusinessTypeEnum.NONE_SELF_SUPPORT.getValue()).list();
		for (GoodsInfo goodsInfo : list) {
			List<GoodsSpec> goodsSpecList = goodsSpecService.getByGoodsId(goodsInfo.getId());
			if (CollUtil.isNotEmpty(goodsSpecList) && goodsSpecList.get(0).getOptionId() == null) {
				Map<String, GoodsSpec> collect = goodsSpecList.stream().collect(Collectors.toMap(GoodsSpec::getSpceName, Function.identity()));
				JSONObject detail = this.detail(Collections.singletonList(goodsInfo.getThirdId()));
				JSONArray data = detail.getJSONArray("data");
				for (Object datum : data) {
					JSONObject next = (JSONObject) datum;
					JSONArray jsonArray = next.getJSONObject("specs").getJSONArray("options");
					for (int i = 0; i < jsonArray.size(); i++) {
						JSONObject json = jsonArray.getJSONObject(i);
						String specValueNames = json.getString("spec_value_names");
						GoodsSpec goodsSpec = collect.get(specValueNames);
						goodsSpec.setOptionId(json.getString("id"));
						goodsSpecService.updateById(goodsSpec);
					}
				}
			}
		}
	}

	@Override
	public void fixData2() {
		List<SupplyChain> list = this.lambdaQuery().isNull(SupplyChain::getCostPrice).list();
		for (SupplyChain supplyChain : list) {
			HashMap<String, String> param = new HashMap<>();
			param.put("page", "1");
			param.put("limit", "1");
			param.put("search_words", supplyChain.getId().toString());
			JSONObject result = myLists(param);
			JSONObject json = result.getJSONObject("data");
			if (json != null) {
				JSONArray array = json.getJSONArray("list");
				if (array != null && array.size() > 0) {
					JSONObject jsonObject = array.getJSONObject(0);
					SupplyChain sc = jsonObject.toJavaObject(SupplyChain.class);
					supplyChain.setSalePrice(sc.getSalePrice());
					supplyChain.setCostPrice(sc.getCostPrice());
					supplyChain.setMaxProfits(sc.getMaxProfits());
					supplyChain.setMinProfits(sc.getMinProfits());
					this.updateById(supplyChain);
				}
			}
		}
	}

	@Resource
	private SupplyChainMapper supplyChainMapper;

	private final ExecutorService executorService = Executors.newFixedThreadPool(10);

	@Override
	public void removeGroupGoods(String groupId) throws InterruptedException {
		for (int i = 1; i <= 100; i++) {
			System.out.println("当前处理序列号 " + i);
//			Thread.sleep(2000);
			int finalI = i;
			try {
				HashMap<String, String> body1 = new HashMap<>();
				body1.put("page", finalI + "");
				body1.put("limit", "10");
				body1.put("group_id", groupId);
				String jsonString = JSON.toJSONString(body1);
				JSONObject result = this.post(jsonString, SupplyChainConstant.V2_GROUP_GOODS_LIST);
				JSONArray jsonArray = result.getJSONObject("data").getJSONArray("list");
				List<String> list = new ArrayList<>();
				for (Object o : jsonArray) {
					JSONObject jsonObject = (JSONObject) o;
					list.add(jsonObject.getString("id"));
				}
				if (list.size() == 0) {
					return;
				}
				HashMap<String, String> map = new HashMap<>();
				map.put("goods_ids", CollUtil.join(list, ","));
				this.get(map, SupplyChainConstant.V2_GOODSSTORAGE_REMOVE);
			} catch (Exception e) {

			}
//			executorService.execute(() -> {

//			});
		}

	}

	@Override
	public int syncData(String groupId) {
		HashMap<Integer, SupplyChain> map = new HashMap<>();
		HashMap<Integer, Integer> exist = new HashMap<>();
		HashMap<String, String> body = new HashMap<>();
		body.put("page", "1");
		body.put("limit", "50");
		body.put("group_id", groupId);
		JSONObject jsonObject = myLists(body);
		Integer integer = jsonObject.getJSONObject("data").getInteger("count");
		for (int i = 0; i < (integer / 50) + 1; i++) {
			HashMap<String, String> param = new HashMap<>();
			param.put("page", (i + 1) + "");
			param.put("limit", "50");
			param.put("group_id", groupId);
			JSONObject result = myLists(param);
			JSONArray jsonArray = result.getJSONObject("data").getJSONArray("list");
			List<SupplyChain> list = new ArrayList<>();
			for (Object o : jsonArray) {
				JSONObject json = (JSONObject) o;
				SupplyChain supplyChain = json.toJavaObject(SupplyChain.class);

				SupplyChain s = map.get(supplyChain.getId());
				if (s == null) {
					map.put(supplyChain.getId(), supplyChain);
				} else {
					Integer e = exist.get(s.getId());
					if (e == null) {
						exist.put(s.getId(), 0);
					} else {
						exist.put(s.getId(), e + 1);
					}
				}
			}
		}

		this.saveBatch(map.values(), 1000);

		log.info("商品总数 -> [{}]", map.keySet().size());
		if (!exist.isEmpty()) {
			bladeLogger.info("重复的数据", JSON.toJSONString(exist));
		}

		return map.keySet().size();
	}

	@Transactional(rollbackFor = Exception.class)
	@Override
	public void importGoods(List<String> ids, String categoryId, Double grossRate, Integer zoneType) {
		JSONObject details = this.detail(ids);
		JSONArray data = details.getJSONArray("data");
		for (Object datum : data) {
			JSONObject next = (JSONObject) datum;
			String id = next.getString("id");
			// 查询商品是否导入过
			GoodsInfo goodsInfo = goodsInfoService.lambdaQuery().eq(GoodsInfo::getThirdId, id).one();
			if (goodsInfo != null) {
				continue;
			}
			// 更新导入状态
			this.lambdaUpdate().eq(SupplyChain::getId, id).set(SupplyChain::getIsImport, 1).update();
			// 保存品牌信息
			Long brandInfoId = this.saveGoodsBrandInfo(next);
			// 保存商品信息
			goodsInfo = this.saveGoodsInfo(next, categoryId, brandInfoId, grossRate, zoneType);
			// 保存规格信息
			this.saveGoodsSpecInfo(next, goodsInfo, grossRate);
			// 保存商品参数信息
			this.saveGoodsParam(next, goodsInfo.getId());
		}
	}

	@Override
	public void saveSupplyChain(String id) {
		SupplyChain chain = this.getById(id);
		if (chain != null) {
			return;
		}
		HashMap<String, String> param = new HashMap<>();
		param.put("page", "1");
		param.put("limit", "1");
		param.put("search_words", id);
		JSONObject result = myLists(param);
		JSONObject json = result.getJSONObject("data");
		if (json != null) {
			JSONArray array = json.getJSONArray("list");
			for (Object o : array) {
				JSONObject jsonObject = (JSONObject) o;
				if (!id.equals(jsonObject.getString("id"))) {
					continue;
				}
				SupplyChain supplyChain = jsonObject.toJavaObject(SupplyChain.class);
				supplyChain.setIsImport(0);
				Timestamp timestamp = Timestamp.valueOf(DateUtil.toLocalDateTime(DateUtil.date()));
				supplyChain.setCreatedTime(timestamp);
				supplyChain.setUpdatedTime(timestamp);
				this.save(supplyChain);
			}
		}
	}

	/**
	 * 获取商品分类id
	 * @return
	 */
	public String getCategoryId(String thirdCategoryName) {
		String[] categoryNames = thirdCategoryName.split(",");
		Long parentId = 0L;
		List<Long> categoryIds = new ArrayList<>();
		for (int i = 0; i < categoryNames.length; i++) {
			CategoryInfo categoryInfo = categoryInfoService.getByNameAndLevel(categoryNames[i], String.valueOf(i));
			if (categoryInfo == null) {
				categoryInfo = new CategoryInfo();
				categoryInfo.setParentId(parentId);
				categoryInfo.setLevel(i);
				categoryInfo.setState(1);
				categoryInfo.setTitle(categoryNames[i]);
				categoryInfo.setSort(this.getCategorySort(i));
				categoryInfoService.save(categoryInfo);
			}
			categoryIds.add(categoryInfo.getId());
			parentId = categoryInfo.getId();
		}
		return CollUtil.join(categoryIds, "-");
	}

	@Resource
	private RedisTemplate redisTemplate;

	private int getCategorySort(Integer level) {
		RedisAtomicLong redisAtomicLong = new RedisAtomicLong("goods:category:level:seq" + level, redisTemplate.getConnectionFactory());
		long seq = redisAtomicLong.incrementAndGet();
		if (seq == 1) {
			Integer count = categoryInfoService.lambdaQuery().eq(CategoryInfo::getLevel, level).count();
			redisAtomicLong.set(count + 1);
			return count + 1;
		}
		return (int) seq;
	}

	private JSONObject convertAddress(Long userAddressId) {
		UserAddress userAddress = userAddressService.getById(userAddressId);
		JSONObject address = new JSONObject();
		address.put("consignee", userAddress.getRealName());
		address.put("phone", userAddress.getPhone());
		address.put("province", userAddress.getProvince());
		address.put("city", userAddress.getCity());
		address.put("area", userAddress.getDistrict());
		address.put("street", userAddress.getDetail());
		address.put("description", userAddress.getDetail());
		return address;
	}

	public JSONArray convertSpu(String optionId, Integer num) {
		JSONObject spu = new JSONObject();
		spu.put("sku", optionId);
		spu.put("number", num);
		JSONArray jsonArray = new JSONArray();
		jsonArray.add(spu);
		return jsonArray;
	}

	/**
	 * 保存商品参数信息
	 */
	private void saveGoodsParam(JSONObject next, Long goodsId) {
		List<GoodsParams> goodsParamsList = new ArrayList<>();
		JSONArray attributes = next.getJSONArray("attributes");
		for (int i = 0; i < attributes.size(); i++) {
			JSONObject jsonObject = attributes.getJSONObject(i);
			GoodsParams goodsParams = new GoodsParams();
			goodsParams.setGoodsId(goodsId);
			goodsParams.setParamName(jsonObject.getString("name"));
			goodsParams.setParamValue(jsonObject.getString("value"));
			goodsParams.setSort(i+1);
			goodsParamsList.add(goodsParams);
		}
		goodsParamsService.saveBatch(goodsParamsList);
	}

	/**
	 * 保存商品规格信息
	 */
	public void saveGoodsSpecInfo(JSONObject next, GoodsInfo goodsInfo, Double grossRate) {
		List<GoodsSpec> goodsSpecList = new ArrayList<>();
		JSONArray jsonArray = next.getJSONObject("specs").getJSONArray("options");
		for (int i = 0; i < jsonArray.size(); i++) {
			JSONObject json = jsonArray.getJSONObject(i);
			GoodsSpec spec = new GoodsSpec();
			spec.setGoodsId(goodsInfo.getId());
			spec.setGoodsNo(goodsInfo.getGoodsNo());
			spec.setSpceNo(goodsSpecService.generateGoodsSpecNo());
			spec.setIsDefault(i == 0 ? 1 : 0);
			spec.setCover(json.getString("image"));
			spec.setSpceName(json.getString("spec_value_names"));
			spec.setIsSale(json.getIntValue("status"));
			spec.setStock(json.getIntValue("stock"));
			spec.setOptionId(json.getString("id"));
			spec.setSort(i + 1);
			spec.setSale(0);
			spec.setIsIntegralDeduction(1);
			spec.setActivityRate(BigDecimal.valueOf(json.getDoubleValue("activity_rate")));
			spec.setMarketPrice(BigDecimal.valueOf(json.getDoubleValue("market_price")).divide(new BigDecimal(100)));
			spec.setActivityPrice(BigDecimal.valueOf(json.getDoubleValue("activity_price")).divide(new BigDecimal(100)));
			BigDecimal agreementPrice = BigDecimal.valueOf(json.getDoubleValue("agreement_price")).divide(new BigDecimal(100));
			spec.setAgreementPrice(this.calAgreementPrice(agreementPrice));
			spec.setCostPrice(BigDecimal.valueOf(json.getDoubleValue("cost_price")).divide(new BigDecimal(100)));
			BigDecimal salePrice = goodsInfoService.calSalePrice(new BigDecimal(grossRate), spec.getAgreementPrice());
			spec.setSalePrice(salePrice);
			spec.setGuidePrice(salePrice);
			spec.setPromotionRate(new BigDecimal(grossRate));
			spec.setNeedIntegral(spec.getSalePrice());
			spec.setObtainIntegral(spec.getSalePrice());
			goodsSpecList.add(spec);
		}
		goodsSpecService.saveBatch(goodsSpecList);
	}

	/**
	 * 保存品牌信息
	 */
	private Long saveGoodsBrandInfo(JSONObject next) {
		String thirdBrandName = next.getString("third_brand_name");
		BrandsInfo brandsInfo = brandsInfoService.getByName(thirdBrandName);
		if (brandsInfo == null) {
			brandsInfo = new BrandsInfo();
			brandsInfo.setBrandName(thirdBrandName);
			brandsInfo.setSort(1);
			brandsInfo.setState(String.valueOf(1));
			brandsInfoService.save(brandsInfo);
		}
		return brandsInfo.getId();
	}

	/**
	 * 通过正则获取商品的详情图片地址
	 * @param imgData
	 * @return
	 */
	private List<String> getGoodsDetailImg(String imgData) {
		List<String> imgList = new ArrayList<>();
		Pattern compile = Pattern.compile("(src|data-lazyload)=\"(.*?)\"");
		Matcher matcher = compile.matcher(imgData);
		while (matcher.find()) {
			String group = matcher.group(2);
			imgList.add(group);
		}
		return imgList;
	}

	/**
	 * 将供应链返回的数据转换为 GoodsInfo 对象, 并保存
	 * @param json
	 * @param categoryId
	 * @return
	 */
	private GoodsInfo saveGoodsInfo(JSONObject json, String categoryId, Long brandId, Double grossRate, Integer zoneType) {
		GoodsInfo goodsInfo = new GoodsInfo();
		goodsInfo.setSource(GoodsSourceEnum.STBZ.getValue());
		goodsInfo.setThirdId(json.getString("id"));
		goodsInfo.setGoodsCover(json.getString("cover"));
		goodsInfo.setGoodsName(json.getString("title"));
		goodsInfo.setIsSale(json.getIntValue("status"));
//		goodsInfo.setIsSale(GoodsStateEnum.UNDERCARRIAGE.getValue());
		goodsInfo.setTotalSales(json.getIntValue("sale"));
		goodsInfo.setTotalStock(json.getInteger("total_stock"));
		goodsInfo.setUnit(json.getString("unit"));
		goodsInfo.setOrigin(json.getString("origin"));
		goodsInfo.setGoodsCategoryId(categoryId);
		goodsInfo.setBrandId(brandId);
		goodsInfo.setIsHot(YesOrNoEnum.NO.getValue());
		goodsInfo.setIsFreeShipping(YesOrNoEnum.YES.getValue());
		goodsInfo.setIsNew(YesOrNoEnum.YES.getValue());
		goodsInfo.setIsRecom(YesOrNoEnum.NO.getValue());
		goodsInfo.setIsPartner(YesOrNoEnum.NO.getValue());
		goodsInfo.setFreePrice(new BigDecimal(0));
		goodsInfo.setBusinessType(BusinessTypeEnum.NONE_SELF_SUPPORT.getValue());// 他营
		goodsInfo.setZoneType(zoneType);
		goodsInfo.setActivityRate(BigDecimal.valueOf(json.getDoubleValue("activity_rate")));
		goodsInfo.setMarketPrice(BigDecimal.valueOf(json.getDoubleValue("market_price")).divide(new BigDecimal(100)));
		goodsInfo.setActivityPrice(BigDecimal.valueOf(json.getDoubleValue("activity_price")).divide(new BigDecimal(100)));
		BigDecimal agreementPrice = BigDecimal.valueOf(json.getDoubleValue("agreement_price")).divide(new BigDecimal(100));
		goodsInfo.setAgreementPrice(this.calAgreementPrice(agreementPrice));
		goodsInfo.setCostPrice(BigDecimal.valueOf(json.getDoubleValue("cost_price")).divide(new BigDecimal(100)));
		BigDecimal salePrice = goodsInfoService.calSalePrice(new BigDecimal(grossRate), goodsInfo.getAgreementPrice());
		goodsInfo.setSalePrice(salePrice);
		goodsInfo.setGuidePrice(salePrice);

		SupplyChain supplyChain = this.getById(json.getInteger("id"));
		goodsInfo.setDiscount(supplyChain.getDiscount());
		goodsInfo.setPromotionRate(new BigDecimal(grossRate));
		// 详情图片
		List<String> goodsDetailImg = this.getGoodsDetailImg(UnicodeUtil.toString(json.getString("description")));
		goodsInfo.setDetailImgUrlList(goodsDetailImg);
		// 轮播图片
		JSONArray covers = json.getJSONArray("covers");
		goodsInfo.setSlideshowList(covers.toJavaList(String.class));
		goodsInfoService.submit(goodsInfo);
		return goodsInfo;
	}



	/**
	 * 计算协议价
	 */
	public BigDecimal calAgreementPrice(BigDecimal agreementPrice) {
		// 协议价服务费比例
		String agreementPriceServiceRate = ParamCache.getValueDefault(CommonConstant.AGREEMENT_PRICE_SERVICE_RATE, "0.05");
		return agreementPrice.add(agreementPrice.multiply(new BigDecimal(agreementPriceServiceRate).setScale(2, BigDecimal.ROUND_HALF_UP)).setScale(2, BigDecimal.ROUND_HALF_DOWN));
	}


	/**
	 * 获取公共的请求头信息
	 * @param body
	 * @return
	 */
	public Map getHeader(String body) {
		return getHeader(null, body);
	}

	/**
	 * 获取公共的请求头信息
	 * @param query
	 * @param body
	 * @return
	 */
	public Map<String, String> getHeader(HashMap<String, String> query, String body) {
		HashMap<String, String> headers = new HashMap<>();
		headers.put("Api-App-Key", appKey);
		headers.put("Api-Time-Stamp", System.currentTimeMillis() + "");
		headers.put("Api-Nonce", IdUtil.simpleUUID());
		headers.put("Api-Sign", getSign(headers, query, body));
		return headers;
	}

	/**
	 * 获取签名
	 * @return
	 */
	public String getSign(HashMap<String, String> headers, HashMap<String, String> query, String body) {
		HashMap<String, Object> params = new HashMap<>(headers);
		if (query != null && !query.isEmpty()) {
			params.putAll(query);
		}
		TreeMap<String, Object> sort = MapUtil.sort(params);
		StringBuilder stringBuilder = new StringBuilder();
		for (Map.Entry<String, Object> entry : sort.entrySet()) {
			stringBuilder.append(entry.getKey()).append(entry.getValue());
		}
		stringBuilder.append(secretKey);
		if (StrUtil.isNotBlank(body)) {
			stringBuilder.append(body);
		}
		return SecureUtil.md5(SecureUtil.sha1(stringBuilder.toString())).toUpperCase();
	}

	public JSONObject postNotValid(String body, String url) {
		String result = httpUtil.postJson(host + url, body, getHeader(null, body));
//		String result = HttpRequest.post(host + url)
//			.addHeaders(getHeader(null, body))
//			.body(body).execute().body();
		if (StrUtil.isNotBlank(result) && result.length() > 3000) {
			log.info("请求地址：[{}],请求参数：[{}], 返回结果过大，不打印", url, body);
		} else {
			log.info("请求地址：[{}],请求参数：[{}], 供应链返回数据：[{}]", url, body, result);
		}
		return JSON.parseObject(result);
	}


	public JSONObject post(String body, String url) {
		JSONObject jsonObject = postNotValid(body, url);
		Integer code = jsonObject.getInteger("code");
		if (code != 1) {
			String msg = jsonObject.getString("msg");
//			bladeLogger.error("供应链请求错误", msg + ",url:"+ url + ",result:" + jsonObject.toJSONString() + ",requestParam:" + body);
			throw new ServiceException(msg + "[S]");
		}
		return jsonObject;
	}

	private JSONObject get(String body, String url) {
		String result = HttpRequest.get(host + url)
			.addHeaders(getHeader(body))
			.body(body)
			.execute().body();
		if (StrUtil.isNotBlank(result) && result.length() > 3000) {
			log.info("请求地址：[{}],请求参数：[{}]", url, body);
		} else {
			log.info("请求地址：[{}],请求参数：[{}], 供应链返回数据：[{}]", url, body, result);
		}
		JSONObject jsonObject = JSON.parseObject(result);
		Integer code = jsonObject.getInteger("code");
		if (code != 1) {
			String msg = jsonObject.getString("msg");
//			bladeLogger.error("供应链请求错误", msg + ",url:"+ url + ",result:" + result + ",requestParam:" + body);
			throw new ServiceException(msg + "[S]");
		}
		return jsonObject;
	}

	private JSONObject get(HashMap<String, String> query, String url) {
		String result = HttpRequest.get(host + url + getRequestParam(query))
			.addHeaders(getHeader(query, null))
			.execute().body();
		log.info("请求地址：[{}],请求参数：[{}], 供应链返回数据：[{}]", url, JSONObject.toJSONString(query), result);
		JSONObject jsonObject = JSON.parseObject(result);
		Integer code = jsonObject.getInteger("code");
		if (code != 1) {
			String msg = jsonObject.getString("msg");
			bladeLogger.error("供应链请求错误", msg + ",url:"+ url + ",result:" + result + ",requestParam:" + JSONObject.toJSONString(query));
			throw new ServiceException(msg + "[S]");
		}
		return jsonObject;
	}

	public String getRequestParam(HashMap<String, String> query) {
		StringBuilder stringBuilder = new StringBuilder("?");
		for (Map.Entry<String, String> entry : query.entrySet()) {
			stringBuilder.append(entry.getKey()).append("=").append(entry.getValue()).append("&");
		}
		String s = stringBuilder.toString();
		s = s.substring(0, s.length() - 1);
		return s;
	}
}
