package org.springblade.modules.redenvelopemall.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.collection.ListUtil;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.text.UnicodeUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.crypto.SecureUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.*;
import org.springblade.common.utils.HttpUtil;
import org.springblade.core.log.exception.ServiceException;
import org.springblade.core.log.logger.BladeLogger;
import org.springblade.modules.api.service.IAliService;
import org.springblade.modules.finance.entity.Order;
import org.springblade.modules.finance.entity.OrderGoods;
import org.springblade.modules.finance.entity.OrderRefund;
import org.springblade.modules.finance.service.IOrderGoodsService;
import org.springblade.modules.finance.service.IOrderRefundService;
import org.springblade.modules.finance.service.IOrderService;
import org.springblade.modules.platform.entity.UserAddress;
import org.springblade.modules.platform.service.IUserAddressService;
import org.springblade.modules.redenvelopemall.entity.*;
import org.springblade.modules.redenvelopemall.mapper.SupplyChainMapper;
import org.springblade.modules.redenvelopemall.mapper.WeiPinShangMapper;
import org.springblade.modules.redenvelopemall.param.ImportCheckParam;
import org.springblade.modules.redenvelopemall.service.IRedIntegralService;
import org.springblade.modules.redenvelopemall.service.IWeiPinShangService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.Assert;

import javax.annotation.Resource;
import java.io.UnsupportedEncodingException;
import java.math.BigDecimal;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * Author pangqijun
 * Date 2022/7/10
 * Description 唯品尚供应链服务
 */
@Slf4j
@Service
public class WeiPinShangServiceImpl extends ServiceImpl<WeiPinShangMapper, WeiPinShangGoods> implements IWeiPinShangService {

	@Value("${weipingshang.channelNo}")
	private String channelNo;
	@Value("${weipingshang.key}")
	private String key;
	@Value("${weipingshang.server}")
	private String server;
	@Value("${weipingshang.orderNoticeUrl}")
	private String orderNoticeUrl;
	@Resource
	private BladeLogger bladeLogger;
	@Resource
	private GoodsInfoServiceImpl goodsInfoService;
	@Resource
	private GoodsSpecServiceImpl goodsSpecService;
	@Resource
	private BrandsInfoServiceImpl brandsInfoService;
	@Resource
	private IUserAddressService userAddressService;
	@Resource
	private IOrderService orderService;
	@Resource
	private IOrderGoodsService orderGoodsService;
	@Resource
	private IAliService aliService;
	@Resource
	private IRedIntegralService redIntegralService;
	@Resource
	private IOrderRefundService orderRefundService;
	@Resource
	private HttpUtil httpUtil;


	@Override
	public JSONObject getGoodsDetails(String fatherId) {
		HashMap<String, String> params = new HashMap<>();
		params.put("father_id", fatherId);
		return request(params, "mcang/Mcang/getDetailsGoods");
	}

	@Override
	public JSONObject getPostage(String fatherGoodsId, String goodsId, Integer num, Long userAddressId) {
		UserAddress userAddress = userAddressService.getById(userAddressId);
		Assert.notNull(userAddress, "用户地址数据不存在");
		HashMap<String, String> params = new HashMap<>();
		params.put("c_father_goods_id", fatherGoodsId);
		params.put("c_goods_id", goodsId);
		params.put("num", num.toString());
		params.put("province", userAddress.getProvince());
		params.put("city", userAddress.getCity());
		params.put("county", userAddress.getDistrict());
		params.put("address", userAddress.getDetail());
		return request(params, "mcang/Mcang/getPostage");
	}

	@Transactional(propagation = Propagation.NOT_SUPPORTED)
	@Override
	public String createOrder(String orderNo, String goodSpecId, String goodsId, Integer num, Long userAddressId) {
		try {
			UserAddress userAddress = userAddressService.getById(userAddressId);
			Assert.notNull(userAddress, "用户地址数据不存在");
			HashMap<String, String> params = new HashMap<>();
			params.put("orderNo", orderNo);
			params.put("goodSpecId", goodSpecId);
			params.put("goodsId", goodsId);
			params.put("num", num.toString());
			params.put("consigneeContacts", userAddress.getRealName());
			params.put("consigneePhone", userAddress.getPhone());
			params.put("province", userAddress.getProvince());
			params.put("city", userAddress.getCity());
			params.put("area", userAddress.getDistrict());
			params.put("address", userAddress.getDetail());
			params.put("source", channelNo);
			params.put("noticeUrl", orderNoticeUrl);
			JSONObject result = request(params, "mcang/Mcang/createOrder");
			return result.getJSONObject("data").getString("mcOrderNo");
		} catch (Exception e) {
			String message = e.getMessage();
			// 识别到下架的商品，将自动下架
			if (message.contains("下架")) {
				List<GoodsInfo> list = goodsInfoService.lambdaQuery().eq(GoodsInfo::getThirdId, goodsId).eq(GoodsInfo::getSource, GoodsSourceEnum.WPS.getValue()).list();
				if (CollUtil.isNotEmpty(list)) {
					GoodsInfo goodsInfo = list.get(0);
					goodsInfo.setIsSale(YesOrNoEnum.NO.getValue());
					goodsInfoService.updateById(goodsInfo);
					message = "[" + goodsInfo.getGoodsName() + "]已下架";
				}
			}
			throw new ServiceException(message);
		}
	}

	@Override
	public JSONObject payCallBack(String orderNo, String payType) {
		HashMap<String, String> params = new HashMap<>();
		params.put("orderNo", orderNo);
		params.put("payType", payType);
		return request(params, "mcang/Mcang/payCallBack");
	}

	@Override
	public JSONObject cancelOrder(String orderNo, String cancelBy) {
		HashMap<String, String> params = new HashMap<>();
		params.put("orderNo", orderNo);
		params.put("cancelBy", cancelBy);
		return request(params, "mcang/Mcang/cancelOrder");
	}

	@Override
	public JSONObject getOrderInfo(String orderNo) {
		HashMap<String, String> params = new HashMap<>();
		params.put("orderNo", orderNo);
		return request(params, "mcang/Mcang/getOrderInfo");
	}

	@Override
	public JSONObject getExpressInfo(String orderNo) {
		HashMap<String, String> params = new HashMap<>();
		params.put("orderNo", orderNo);
		return request(params, "mcang/Mcang/getExpressInfo");
	}

	@Override
	public JSONObject receivedOrder(String orderNo) {
		HashMap<String, String> params = new HashMap<>();
		params.put("orderNo", orderNo);
		return request(params, "mcang/Mcang/receivedOrder");
	}

	@Override
	public JSONObject getGoodsClassify(String level, String parentCode) {
		HashMap<String, String> params = new HashMap<>();
		params.put("c_level", level);
		params.put("c_parent_code", parentCode);
		return request(params, "mcang/Mcang/getGoodsClassify");
	}

	@Override
	public JSONObject createAfsApply(String mcOrderNo, String customerExpect, Boolean isHasPackage, Long userAddressId) {
		UserAddress userAddress = userAddressService.getById(userAddressId);
		HashMap<String, String> params = new HashMap<>();
		params.put("mcOrderNo", mcOrderNo);
		params.put("customerExpect", customerExpect);
		params.put("isHasPackage", isHasPackage.toString());
		params.put("customerContactName", userAddress.getRealName());
		params.put("customerTel", userAddress.getPhone());
		params.put("customerMobilePhone", userAddress.getPhone());
		params.put("pickwareProvince", userAddress.getProvince());
		params.put("pickwareCity", userAddress.getCity());
		params.put("pickwareCounty", userAddress.getDistrict());
		params.put("pickwareAddress", userAddress.getDetail());
		return request(params, "mcang/Refunds/createAfsApply");
	}

	@Override
	public void saveThirdGoodsInfo(JSONArray content) {
		List<String> fatherGoodsIds = new ArrayList<>();
		for (Object o : content) {
			LinkedHashMap<String, String> jsonObject = (LinkedHashMap) o;
			String fatherGoodsId = jsonObject.get("c_father_goods_id");
			fatherGoodsIds.add(fatherGoodsId);
		}
		JSONObject goodsDetails = this.getGoodsDetails(CollUtil.join(fatherGoodsIds, ","));
		JSONArray data = goodsDetails.getJSONArray("data");
		if (data == null) {
			throw new ServiceException("返回数据data为空");
		}
		List<WeiPinShangGoods> weiPinShangGoods = data.toJavaList(WeiPinShangGoods.class);
		for (WeiPinShangGoods weiPinShangGood : weiPinShangGoods) {
			weiPinShangGood.setDiscount(this.calDiscount(weiPinShangGood.getSalePrice(), weiPinShangGood.getInPrice()));
			weiPinShangGood.setProfits(weiPinShangGood.getSalePrice().subtract(weiPinShangGood.getInPrice()));
			weiPinShangGood.setCreateTime(DateUtil.date());
			weiPinShangGood.setUpdateTime(DateUtil.date());
			weiPinShangGood.setDetailsImages("");
			weiPinShangGood.setBannerImages("");
		}
		this.saveBatch(weiPinShangGoods);
	}

	@Override
	public void shelvesUpdate(JSONArray content) {
		for (Object o : content) {
			JSONObject jsonObject = JSON.parseObject(JSON.toJSONString(o));
			String fatherGoodsId = jsonObject.getString("c_father_goods_id");
			this.lambdaUpdate().set(WeiPinShangGoods::getIsShow, jsonObject.get("state")).eq(WeiPinShangGoods::getFatherGoodsId, fatherGoodsId).update();
			List<GoodsInfo> goodsInfos = goodsInfoService.getByThirdIds(CollUtil.newArrayList(fatherGoodsId), GoodsSourceEnum.WPS);
			if (CollUtil.isNotEmpty(goodsInfos)) {
				List<GoodsInfo> updateList = new ArrayList<>();
				for (GoodsInfo goodsInfo : goodsInfos) {
					GoodsInfo update = new GoodsInfo();
					update.setId(goodsInfo.getId());
					update.setIsSale(jsonObject.getInteger("state"));
					updateList.add(update);
				}
				goodsInfoService.updateBatchById(updateList);
			}
		}
	}

	@Override
	public void priceUpdate(JSONArray content) {
		Set<String> fatherGoodsIds = new HashSet<>();
		for (Object o : content) {
			JSONObject jsonObject = JSON.parseObject(JSON.toJSONString(o));
			String fatherGoodsId = jsonObject.getString("c_father_goods_id");
			fatherGoodsIds.add(fatherGoodsId);
		}
		JSONObject goodsDetails = this.getGoodsDetails(CollUtil.join(fatherGoodsIds, ","));
		JSONArray data = goodsDetails.getJSONArray("data");
		List<WeiPinShangGoods> weiPinShangGoods = data.toJavaList(WeiPinShangGoods.class);
		for (WeiPinShangGoods e : weiPinShangGoods) {
			WeiPinShangGoods goods = this.lambdaQuery().eq(WeiPinShangGoods::getFatherGoodsId, e.getFatherGoodsId()).one();
			if (goods != null) {
				goods.setInPrice(e.getInPrice());
				goods.setOriginalPrice(e.getOriginalPrice());
				goods.setSalePrice(e.getSalePrice());
				this.updateById(goods);
			}
			GoodsInfo goodsInfo = goodsInfoService.lambdaQuery().eq(GoodsInfo::getThirdId, e.getFatherGoodsId()).eq(GoodsInfo::getSource, GoodsSourceEnum.WPS.getValue()).one();
			// 创客专区不需要更新价格
			if (goodsInfo != null && !ZoneTypeEnum.GUEST.getValue().equals(goodsInfo.getZoneType())) {
				goodsInfo.setAgreementPrice(this.calAgreementPrice(e.getInPrice()));
//				BigDecimal salePrice = goodsInfoService.calSalePrice(goodsInfo.getPromotionRate(), goodsInfo.getAgreementPrice());
				goodsInfo.setSalePrice(e.getSalePrice());
				goodsInfo.setGuidePrice(e.getSalePrice());
				BigDecimal promotionRate = goodsInfoService.calPromotionRate(goodsInfo.getSalePrice(), goodsInfo.getAgreementPrice());
				goodsInfo.setPromotionRate(promotionRate);
				goodsInfoService.updateById(goodsInfo);

				List<GoodsSpec> list = goodsSpecService.lambdaQuery().eq(GoodsSpec::getGoodsId, goodsInfo.getId()).list();
				Map<String, GoodsSpec> specMap = list.stream().collect(Collectors.toMap(GoodsSpec::getOptionId, Function.identity()));
				List<WeiPinShangGoodsSku> goodsSku = e.getGoodsSku();
				// 更新规格价格
				for (WeiPinShangGoodsSku sku : goodsSku) {
					GoodsSpec goodsSpec = specMap.get(sku.getC_father_goods_id());
					if (goodsSpec != null) {
						goodsSpec.setAgreementPrice(this.calAgreementPrice(sku.getC_in_price()));
//						BigDecimal specSalePrice = goodsInfoService.calSalePrice(goodsSpec.getPromotionRate(), goodsSpec.getAgreementPrice());
						goodsSpec.setSalePrice(sku.getC_sale_price());
						goodsSpec.setGuidePrice(sku.getC_sale_price());
						BigDecimal specPromotionRate = goodsInfoService.calPromotionRate(goodsSpec.getSalePrice(), goodsSpec.getAgreementPrice());
						goodsSpec.setPromotionRate(specPromotionRate);
						goodsSpecService.updateById(goodsSpec);
					}
				}
			}
		}
	}

	@Override
	public void detailUpdate(JSONArray content) {
		List<String> ids = new ArrayList<>();
		for (Object o : content) {
			JSONObject jsonObject = JSON.parseObject(JSON.toJSONString(o));
			String fatherGoodsId = jsonObject.getString("c_father_goods_id");
			ids.add(fatherGoodsId);
		}
		this.syncGoodsInfo(ids, false);
	}

	@Override
	public void syncGoodsInfo(List<String> fatherIds, boolean isUpdateSalePrice) {
		JSONObject goodsDetails = this.getGoodsDetails(CollUtil.join(fatherIds, ","));
		JSONArray data = goodsDetails.getJSONArray("data");
		List<WeiPinShangGoods> weiPinShangGoods = data.toJavaList(WeiPinShangGoods.class);
		for (WeiPinShangGoods e : weiPinShangGoods) {
			WeiPinShangGoods goods = this.lambdaQuery().eq(WeiPinShangGoods::getFatherGoodsId, e.getFatherGoodsId()).one();
			if (goods != null) {
				BeanUtils.copyProperties(e, goods);
				this.updateById(goods);
			}
			GoodsInfo goodsInfo = goodsInfoService.lambdaQuery().eq(GoodsInfo::getThirdId, e.getFatherGoodsId()).eq(GoodsInfo::getSource, GoodsSourceEnum.WPS.getValue()).one();
			if (goodsInfo != null) {
				goodsInfo.setLastSyncTime(new Date());
				goodsInfo.setGoodsCover(e.getGoodsImage());
				goodsInfo.setGoodsName(this.getGoodsName(e.getGoodsName()));
				goodsInfo.setAgreementPrice(this.calAgreementPrice(e.getInPrice()));
				if (isUpdateSalePrice) {
					if (!ZoneTypeEnum.GUEST.getValue().equals(goodsInfo.getZoneType())) {
						// 计算售价
						BigDecimal salePrice = goodsInfoService.calSalePrice(goodsInfo.getPromotionRate(), goodsInfo.getAgreementPrice());
						goodsInfo.setSalePrice(salePrice);
						goodsInfo.setGuidePrice(salePrice);
					}
//					BigDecimal promotionRate = goodsInfoService.calPromotionRate(goodsInfo.getSalePrice(), goodsInfo.getAgreementPrice());
//					goodsInfo.setPromotionRate(promotionRate);
				}
				goodsInfoService.updateById(goodsInfo);
				List<WeiPinShangGoodsSku> goodsSku = e.getGoodsSku();
				List<GoodsSpec> list = goodsSpecService.lambdaQuery().eq(GoodsSpec::getGoodsId, goodsInfo.getId()).list();
				Map<String, GoodsSpec> specMap = list.stream().collect(Collectors.toMap(GoodsSpec::getOptionId, Function.identity()));
				List<GoodsSpec> addList = new ArrayList<>();
				for (WeiPinShangGoodsSku sku : goodsSku) {
					GoodsSpec goodsSpec = specMap.get(sku.getC_goods_id());
					if (goodsSpec != null) {
						goodsSpec.setCover(sku.getC_goods_image());
						goodsSpec.setSpceName(this.convertSpecName(sku));
						goodsSpec.setAgreementPrice(this.calAgreementPrice(sku.getC_in_price()));
						if (isUpdateSalePrice) {
							if (!ZoneTypeEnum.GUEST.getValue().equals(goodsInfo.getZoneType())) {
								BigDecimal specSalePrice = goodsInfoService.calSalePrice(goodsInfo.getPromotionRate(), goodsSpec.getAgreementPrice());
								goodsSpec.setSalePrice(specSalePrice);
								goodsSpec.setGuidePrice(specSalePrice);
							}
							goodsSpec.setPromotionRate(goodsInfoService.calPromotionRate(goodsSpec.getSalePrice(), goodsSpec.getAgreementPrice()));
						}
						goodsSpecService.updateById(goodsSpec);
						// 存在的商品从集合中移除
						specMap.remove(sku.getC_goods_id());
					} else {
						GoodsSpec spec = new GoodsSpec();
						spec.setGoodsId(goodsInfo.getId());
						spec.setGoodsNo(goodsInfo.getGoodsNo());
						spec.setSpceNo(goodsSpecService.generateGoodsSpecNo());
						spec.setIsDefault(0);
						spec.setCover(sku.getC_goods_image());
						spec.setSpceName(this.getGoodsName(sku.getC_goods_name()));
						spec.setIsSale(GoodsStateEnum.ON_SALE.getValue());
						spec.setStock(sku.getC_goods_stock_valid());
						spec.setOptionId(sku.getC_goods_id());
						spec.setSort(1);
						spec.setSale(0);
						spec.setIsIntegralDeduction(1);
						spec.setAgreementPrice(this.calAgreementPrice(sku.getC_in_price()));
						if (ZoneTypeEnum.GUEST.getValue().equals(goodsInfo.getZoneType())) {
							spec.setSalePrice(new BigDecimal(99));// 创客价格设置为99
							spec.setGuidePrice(new BigDecimal(99));
						}
						else {
//							BigDecimal salePrice = goodsInfoService.calSalePrice(goodsInfo.getPromotionRate(), spec.getAgreementPrice());
							spec.setSalePrice(sku.getC_sale_price());
							spec.setGuidePrice(sku.getC_sale_price());
						}
						spec.setPromotionRate(goodsInfoService.calPromotionRate(spec.getSalePrice(), spec.getAgreementPrice()));
						spec.setNeedIntegral(spec.getSalePrice());
						spec.setObtainIntegral(spec.getSalePrice());
						spec.setIsPackage(YesOrNoEnum.NO.getValue());
						spec.setPackageNum(0);
						addList.add(spec);
					}
				}
				if (CollUtil.isNotEmpty(specMap)) {
					// 删除集合中未移除的数据
					specMap.forEach((k, v) -> goodsSpecService.removeById(v.getId()));
				}
				if (CollUtil.isNotEmpty(addList)) {
					addList.forEach(item -> goodsSpecService.submit(item));
				}
			}
		}
	}

	@Transactional(rollbackFor = Exception.class)
	@Override
	public void refund(JSONObject content) {
		String mcOrderNo = content.getString("mcOrderNo");
		Order order = orderService.lambdaQuery().eq(Order::getThirdOrderNo, mcOrderNo).one();
		Assert.notNull(order, "订单不存在");
		Integer payFlag = order.getPayFlag();
		if (PayFlagEnum.REFUNDED.getValue().equals(payFlag)) {
			log.info("订单号[{}]已退款", order.getOutTradeNo());
			return;
		}
		String refuseStatus = content.getString("refuse_status");
		if ("ALLOW".equals(refuseStatus)) {//退款已受理，调用申请退款接口
			orderService.orderRefund(order.getId());
		}
		if ("SUCCESS".equals(refuseStatus)) {//退款成功
			orderService.commonRefund(order);
		}
		if("NOTALLOW".equals(refuseStatus)) {// 退款失败
			List<OrderRefund> list = orderRefundService.lambdaQuery().eq(OrderRefund::getOrderId, order.getId()).orderByDesc(OrderRefund::getCreateTime).list();
			orderRefundService.failure(list.get(0), content.getString("msg"));
		}
	}

	@Override
	public void delivery(String orderNo, String deliveryNo, String deliveryName) {
		Order order = orderService.lambdaQuery().eq(Order::getOutTradeNo, orderNo).one();
		if (order != null) {
			order.setPayFlag(PayFlagEnum.WAIT_RECEIVE.getValue());
			order.setSendTime(new Date());
			order.setUpdateTime(new Date());
			order.setWlName(deliveryName);
			order.setWlNum(deliveryNo);
			orderService.updateById(order);
		}
	}

	@Override
	public void fixDiscount() {
		List<WeiPinShangGoods> list = this.lambdaQuery().list();
		for (WeiPinShangGoods weiPinShangGoods : list) {
			this.lambdaUpdate().set(WeiPinShangGoods::getDiscount, this.calDiscount(weiPinShangGoods.getSalePrice(), weiPinShangGoods.getInPrice()))
				.eq(WeiPinShangGoods::getId, weiPinShangGoods.getId()).update();
		}
	}

	@Override
	public Boolean availableCheck(GoodsInfo goodsInfo, Long userAddressId) {
		WeiPinShangGoods weiPinShangGoods = this.lambdaQuery().eq(WeiPinShangGoods::getFatherGoodsId, goodsInfo.getThirdId()).one();
		if (weiPinShangGoods == null) {
			return true;
		}
		// 不发货地区，分号分割
		String noDeliveryArea = weiPinShangGoods.getNoDeliveryArea();
		UserAddress userAddress = userAddressService.getById(userAddressId);
		String province = userAddress.getProvince();
		if (province.contains("市") || province.contains("省")) {
			province = province.substring(0, province.length() - 1);
			if (noDeliveryArea.contains(province)) {
				return false;
			}
			if ("台湾".equals(province) && noDeliveryArea.contains("港澳台")) {
				return false;
			}
			if (("黑龙江".equals(province) || "吉林".equals(province) || "辽宁".equals(province)) && noDeliveryArea.contains("黑吉辽")) {
				return false;
			}
		} else if (province.contains("自治区")) {
			if (province.contains("内蒙古") && noDeliveryArea.contains("内蒙古")) {
				return false;
			} else if (province.contains("广西") && noDeliveryArea.contains("广西")) {
				return false;
			} else if (province.contains("西藏") && noDeliveryArea.contains("西藏")) {
				return false;
			} else if (province.contains("宁夏") && noDeliveryArea.contains("宁夏")) {
				return false;
			} else if (province.contains("新疆") && noDeliveryArea.contains("新疆")) {
				return false;
			}
		} else {
			if (noDeliveryArea.contains(province)) {
				return false;
			}
		}
		return true;
	}

	@Override
	public void fixSpec() {
		DateTime parse = DateUtil.parse("2022-08-10 00:00:00");
		List<GoodsInfo> goodsInfos = goodsInfoService.lambdaQuery().lt(GoodsInfo::getUpdateTime, parse).eq(GoodsInfo::getSource, GoodsSourceEnum.WPS.getValue()).list();
		log.info("商品总数:[{}]", goodsInfos.size());
		List<List<GoodsInfo>> partition = ListUtil.partition(goodsInfos, 100);
		log.info("分片总数:[{}]", partition.size());
		int index = 1;
		for (List<GoodsInfo> infos : partition) {
			log.info("当前循环[{}]", index++);
			List<String> thirds = infos.stream().map(GoodsInfo::getThirdId).collect(Collectors.toList());
			Map<String, GoodsInfo> goodsInfoMap = infos.stream().collect(Collectors.toMap(GoodsInfo::getThirdId, Function.identity()));
			JSONObject goodsDetails = this.getGoodsDetails(CollUtil.join(thirds, ","));
			JSONArray data = goodsDetails.getJSONArray("data");
			if (data == null) {
				continue;
			}
			List<WeiPinShangGoods> weiPinShangGoods = data.toJavaList(WeiPinShangGoods.class);
			for (WeiPinShangGoods e : weiPinShangGoods) {
				List<WeiPinShangGoodsSku> goodsSku = e.getGoodsSku();
				GoodsInfo goodsInfo = goodsInfoMap.get(e.getFatherGoodsId());
				if (goodsInfo != null && CollUtil.isNotEmpty(goodsSku)) {
					Map<String, WeiPinShangGoodsSku> skuMap = goodsSku.stream().collect(Collectors.toMap(WeiPinShangGoodsSku::getC_goods_id, Function.identity()));
					List<GoodsSpec> list = goodsSpecService.lambdaQuery().eq(GoodsSpec::getGoodsId, goodsInfo.getId()).list();
					for (GoodsSpec goodsSpec : list) {
						WeiPinShangGoodsSku weiPinShangGoodsSku = skuMap.get(goodsSpec.getOptionId());
						if (weiPinShangGoodsSku != null) {
							goodsSpecService.lambdaUpdate().set(GoodsSpec::getSpceName, this.convertSpecName(weiPinShangGoodsSku)).eq(GoodsSpec::getId, goodsSpec.getId()).update();
							goodsInfoService.lambdaUpdate().set(GoodsInfo::getUpdateTime, parse).eq(GoodsInfo::getId, goodsInfo.getId()).update();
						}
					}
				}
			}
		}
	}

	@Override
	public Set<Long> importCheck(ImportCheckParam param) {
		List<BrandsInfo> list = brandsInfoService.lambdaQuery().in(BrandsInfo::getBrandName, param.getBrandNames()).list();
		if (CollUtil.isEmpty(list)) {
			return Collections.emptySet();
		}
		List<Long> collect = list.stream().map(BrandsInfo::getId).collect(Collectors.toList());
		List<GoodsInfo> goodsInfos = goodsInfoService.lambdaQuery().in(GoodsInfo::getBrandId, collect).
			eq(GoodsInfo::getIsSale, YesOrNoEnum.YES.getValue()).eq(GoodsInfo::getSource, GoodsSourceEnum.STBZ.getValue()).list();
		if (CollUtil.isEmpty(goodsInfos)) {
			return Collections.emptySet();
		}
		List<Long> longs = goodsInfos.stream().map(GoodsInfo::getBrandId).collect(Collectors.toList());
		return CollUtil.newHashSet(longs);
	}

	@Override
	public void importGoods(List<String> ids, String categoryId, Double grossRate, Integer zoneType) {
		JSONObject goodsDetails = this.getGoodsDetails(CollUtil.join(ids, ","));
		JSONArray data = goodsDetails.getJSONArray("data");
		if (data == null) {
			throw new ServiceException("第三方返回data数据为空！");
		}
		List<WeiPinShangGoods> weiPinShangGoods = data.toJavaList(WeiPinShangGoods.class);
		for (WeiPinShangGoods goods : weiPinShangGoods) {
			// 查询商品是否导入过
			GoodsInfo goodsInfo = goodsInfoService.lambdaQuery().eq(GoodsInfo::getThirdId, goods.getFatherGoodsId())
				.eq(GoodsInfo::getSource, GoodsSourceEnum.WPS.getValue()).one();
			if (goodsInfo != null) {
				continue;
			}
			// 更新导入状态
			this.lambdaUpdate().eq(WeiPinShangGoods::getFatherGoodsId, goods.getFatherGoodsId()).set(WeiPinShangGoods::getIsImport, 1).update();
			// 保存品牌信息
			Long brandInfoId = this.saveGoodsBrandInfo(goods.getBrandName(), goods.getBrandIcon());
			// 保存商品信息
			goodsInfo = this.saveGoodsInfo(goods, categoryId, brandInfoId, grossRate, zoneType);
			// 保存规格信息
			this.saveGoodsSpecInfo(goods.getGoodsSku(), goodsInfo, grossRate);
		}
	}

	/**
	 * 保存商品规格信息
	 * @param goodsSku
	 * @param goodsInfo
	 * @param grossRate
	 */
	private void saveGoodsSpecInfo(List<WeiPinShangGoodsSku> goodsSku, GoodsInfo goodsInfo, Double grossRate) {
		List<GoodsSpec> goodsSpecList = new ArrayList<>();
		for (int i = 0; i < goodsSku.size(); i++) {
			WeiPinShangGoodsSku sku = goodsSku.get(i);
			GoodsSpec spec = new GoodsSpec();
			spec.setGoodsId(goodsInfo.getId());
			spec.setGoodsNo(goodsInfo.getGoodsNo());
			spec.setSpceNo(goodsSpecService.generateGoodsSpecNo());
			spec.setIsDefault(i == 0 ? 1 : 0);
			spec.setCover(sku.getC_goods_image());
			spec.setSpceName(this.convertSpecName(sku));
			spec.setIsSale(GoodsStateEnum.ON_SALE.getValue());
			spec.setStock(sku.getC_goods_stock_valid());
			spec.setOptionId(sku.getC_goods_id());
			spec.setSort(i + 1);
			spec.setSale(0);
			spec.setIsIntegralDeduction(1);
			spec.setAgreementPrice(this.calAgreementPrice(sku.getC_in_price()));
			if (grossRate != null) {
				BigDecimal salePrice = goodsInfoService.calSalePrice(new BigDecimal(grossRate), spec.getAgreementPrice());
				spec.setSalePrice(salePrice);
				spec.setPromotionRate(new BigDecimal(grossRate));
			} else {
				spec.setSalePrice(sku.getC_sale_price());
				spec.setPromotionRate(goodsInfoService.calPromotionRate(spec.getSalePrice(), spec.getAgreementPrice()));
			}
			spec.setGuidePrice(spec.getSalePrice());
			spec.setNeedIntegral(spec.getSalePrice());
			spec.setObtainIntegral(spec.getSalePrice());
			spec.setIsPackage(YesOrNoEnum.NO.getValue());
			spec.setPackageNum(0);
			goodsSpecList.add(spec);
		}
		goodsSpecService.saveBatch(goodsSpecList);
	}

	/**
	 * 获取规格名称
	 * @param sku
	 * @return
	 */
	private String convertSpecName(WeiPinShangGoodsSku sku) {
		return sku.getC_goods_color() + "," + sku.getC_goods_size();
	}

	/**
	 * 保存商品信息
	 * @param goods
	 * @param categoryId
	 * @param brandInfoId
	 * @param grossRate
	 * @param zoneType
	 * @return
	 */
	private GoodsInfo saveGoodsInfo(WeiPinShangGoods goods, String categoryId, Long brandInfoId, Double grossRate, Integer zoneType) {
		GoodsInfo goodsInfo = new GoodsInfo();
		goodsInfo.setSource(GoodsSourceEnum.WPS.getValue());
		goodsInfo.setThirdId(goods.getFatherGoodsId());
		goodsInfo.setGoodsCover(goods.getGoodsImage());
		goodsInfo.setGoodsName(this.getGoodsName(goods.getGoodsName()));
		goodsInfo.setIsSale("1".equals(goods.getIsShow()) ? GoodsStateEnum.ON_SALE.getValue() : GoodsStateEnum.UNDERCARRIAGE.getValue());
		goodsInfo.setTotalSales(0);
		goodsInfo.setTotalStock(goods.getGoodsStockValid());
		goodsInfo.setUnit("");
		goodsInfo.setOrigin("");
		goodsInfo.setGoodsCategoryId(categoryId);
		goodsInfo.setBrandId(brandInfoId);
		goodsInfo.setIsHot(YesOrNoEnum.NO.getValue());
		goodsInfo.setIsFreeShipping(YesOrNoEnum.YES.getValue());
		goodsInfo.setIsNew(YesOrNoEnum.YES.getValue());
		goodsInfo.setIsRecom(YesOrNoEnum.NO.getValue());
		goodsInfo.setIsPartner(YesOrNoEnum.NO.getValue());
		goodsInfo.setFreePrice(new BigDecimal(0));
		goodsInfo.setBusinessType(BusinessTypeEnum.NONE_SELF_SUPPORT.getValue());// 他营
		goodsInfo.setZoneType(zoneType);
		goodsInfo.setActivityRate(new BigDecimal(0));
		goodsInfo.setMarketPrice(new BigDecimal(0));
		goodsInfo.setActivityPrice(new BigDecimal(0));
		goodsInfo.setAgreementPrice(this.calAgreementPrice(goods.getInPrice()));
		goodsInfo.setCostPrice(new BigDecimal(0));
		if (grossRate != null) {
			BigDecimal salePrice = goodsInfoService.calSalePrice(new BigDecimal(grossRate), goodsInfo.getAgreementPrice());
			goodsInfo.setSalePrice(salePrice);
			goodsInfo.setPromotionRate(new BigDecimal(grossRate));
		} else {
			goodsInfo.setSalePrice(goods.getSalePrice());
			goodsInfo.setPromotionRate(goodsInfoService.calPromotionRate(goodsInfo.getSalePrice(), goodsInfo.getAgreementPrice()));
		}

		goodsInfo.setGuidePrice(goodsInfo.getSalePrice());
		goodsInfo.setDiscount(this.calDiscount(goods.getSalePrice(), goods.getInPrice()).doubleValue());
		// 详情图片
		List<String> goodsDetailImg = CollUtil.newArrayList(goods.getDetailsImages().split(";"));
		goodsInfo.setDetailImgUrlList(goodsDetailImg);
		// 轮播图片
		goodsInfo.setSlideshowList(CollUtil.newArrayList(goods.getBannerImages().split(";")));
		goodsInfoService.submit(goodsInfo);
		return goodsInfo;
	}



	/**
	 * 计算协议价
	 * @param inPrice
	 * @return
	 */
	private BigDecimal calAgreementPrice(BigDecimal inPrice) {
		// 协议价服务费比例
		String agreementPriceServiceRate = ParamCache.getValueDefault(CommonConstant.AGREEMENT_PRICE_SERVICE_RATE, "0.05");
		return inPrice.add(inPrice.multiply(new BigDecimal(agreementPriceServiceRate)).setScale(2, BigDecimal.ROUND_HALF_UP));
	}

	/**
	 * 计算折扣
	 * @param salePrice 售价
	 * @param agreementPrice 协议价
	 * @return
	 */
	private BigDecimal calDiscount(BigDecimal salePrice, BigDecimal agreementPrice) {
		BigDecimal subtract = salePrice.subtract(agreementPrice);
		BigDecimal divide = subtract.divide(salePrice, 2, BigDecimal.ROUND_HALF_UP);
		return divide.multiply(new BigDecimal("10"));
	}

	/**
	 * 解释商品名称
	 * @param goodsName
	 * @return
	 */
	private String getGoodsName(String goodsName) {
		int i = goodsName.lastIndexOf("(.运费险");
		if (i > 0) {
			return goodsName.substring(0, i);
		}
		return goodsName;
	}

	/**
	 * 保存品牌信息
	 */
	private Long saveGoodsBrandInfo(String brandName, String brandIcon) {
		BrandsInfo brandsInfo = brandsInfoService.getByName(brandName);
		if (brandsInfo == null) {
			brandsInfo = new BrandsInfo();
			brandsInfo.setBrandName(brandName);
			brandsInfo.setBackgroundImage(brandIcon);
			brandsInfo.setSort(1);
			brandsInfo.setState(String.valueOf(1));
			brandsInfoService.save(brandsInfo);
		} else {
			if (!"其他品牌".equals(brandName)) {
				// 若存在相同品牌，则下架其他品牌，以唯品尚为主
				List<GoodsInfo> list = goodsInfoService.lambdaQuery().eq(GoodsInfo::getSource, GoodsSourceEnum.STBZ.getValue())
					.eq(GoodsInfo::getBrandId, brandsInfo.getId()).list();
				if (CollUtil.isNotEmpty(list)) {
					list.forEach(e -> e.setIsSale(YesOrNoEnum.NO.getValue()));
					goodsInfoService.updateBatchById(list);
				}
			}
		}
		return brandsInfo.getId();
	}

	/**
	 * 发送请求
	 * @param params
	 * @param url
	 * @return
	 */
	public JSONObject request(HashMap<String, String> params, String url) {
		String result = httpUtil.postFrom(server + url, params, this.getHeader(params));
//		String result = HttpRequest.post(server + url).addHeaders(this.getHeader(params)).formStr(params).execute().body();
		if (StrUtil.isNotBlank(result) && result.length() > 3000) {
			log.info("唯品尚请求地址:[{}], 请求参数：[{}], 结果过大，不打印", server + url, JSON.toJSONString(params));
		} else {
			log.info("唯品尚请求地址:[{}], 请求参数：[{}], 请求结果：[{}]", server + url, JSON.toJSONString(params), result);
		}
		JSONObject jsonObject = JSON.parseObject(result);
		Integer code = jsonObject.getInteger("code");
		if (code != 0) {
			String msg = jsonObject.getString("msg");
			bladeLogger.error("唯品尚请求错误", msg + ",url:"+ url + ",result:" + jsonObject.toJSONString() + ",requestParam:" + params);
			throw new ServiceException(msg + "," + code + "[W]");
		}
		return jsonObject;
	}

	/**
	 * 获取请求头
	 * @param params
	 * @return
	 */
	private HashMap<String, String> getHeader(HashMap<String, String> params) {
		HashMap<String, String> header = new HashMap<>();
		String sign = this.getSign(params, false);
		System.out.println(sign);
		header.put("channelType", channelNo);
		header.put("md5", sign);
		return header;
	}

	/**
	 * 获取签名
	 * @param params
	 * @param urlEncoder
	 * @return
	 */
	private String getSign(HashMap<String, String> params, boolean urlEncoder) {
		// 先将参数以其参数名的字典序升序进行排序
		TreeMap<String, String> sortedParams = new TreeMap<>(params);
		// 遍历排序后的字典，将所有参数按"key=value"格式拼接在一起
		StringBuilder sb = new StringBuilder();
		if (CollUtil.isNotEmpty(params)) {
			boolean first = true;
			for (Map.Entry<String, String> param : sortedParams.entrySet()) {
				String value = param.getValue();
				if (StrUtil.isBlank(value)) {
					continue;
				}
				if (first) {
					first = false;
				} else {
					sb.append("&");
				}
				sb.append(param.getKey()).append("=");
				if (urlEncoder) {
					try {
						value = urlEncode(value);
					} catch (UnsupportedEncodingException e) {
						log.error(e.getMessage(), e);
					}
				}
				sb.append(value);
			}
		}
		sb.append(channelNo).append(key);
		return SecureUtil.md5(sb.toString()).toLowerCase();
	}

	/**
	 * urlEncode
	 *s
	 * @param src 参数
	 * @return String
	 * @throws UnsupportedEncodingException 编码错误
	 */
	public static String urlEncode(String src) throws UnsupportedEncodingException {
		return URLEncoder.encode(src, StandardCharsets.UTF_8.name()).replace("+", "%20");
	}
}
