package org.springblade.modules.redenvelopemall.task;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springblade.common.constant.CacheBizConstant;
import org.springblade.common.utils.DateTimeUtil;
import org.springblade.modules.platform.service.UserAppService;
import org.springblade.modules.redenvelopemall.entity.EarningsDetail;
import org.springblade.modules.redenvelopemall.entity.RedEnvelope;
import org.springblade.modules.redenvelopemall.entity.RedEnvelopeItem;
import org.springblade.modules.redenvelopemall.entity.RedSetting;
import org.springblade.modules.redenvelopemall.service.*;
import org.springblade.modules.redenvelopemall.utils.RedPacketUtil2;
import org.springblade.modules.system.entity.UserApp;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.serializer.StringRedisSerializer;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

@Component("RedTask")
public class RedTask {
	private static final Logger log = LoggerFactory.getLogger(RedTask.class);
	@Autowired
	private IRedSettingService redSettingService;
	@Autowired
	private UserAppService userAppService;
	@Autowired
	private IRedEnvelopeService redEnvelopeService;
	@Autowired
	private IRedEnvelopeItemService redEnvelopeItemService;
	@Resource(name = "redRedisTemplate")
	private RedisTemplate redisTemplate;
	@Autowired
	private IEarningsDetailService earningsDetailService;

	@Autowired
	private IRedIntegralService redIntegralService;

	/**
	 * 每天1点生成红包
	 */
	@Scheduled(cron = "0 0 0 * * ?")
	@Transactional(rollbackFor = Exception.class)
	public void createRedEnvelope() {
		//1、查询最新的红包配置
		RedSetting redSetting = redSettingService.getFirst();
		//2、判断总金额是否大于0,大于0则按配置 否则获取前一天订单收益
		int i = redSetting.getTotalAmount().compareTo(new BigDecimal(0));
		if (i != 1) {
			//查询前一天收益并设置
			//前一天
			Date yesterday = DateTimeUtil.add(Calendar.DATE, -1);
			//前一天最早时间
			Date startTime = DateTimeUtil.earliestTime(yesterday);
			//前一天最晚时间
			Date endTime = DateTimeUtil.lastestTime(yesterday);
			QueryWrapper<EarningsDetail> queryWrapper = new QueryWrapper<>();
			queryWrapper.gt("create_time", startTime);
			queryWrapper.lt("create_time", endTime);
			queryWrapper.select("sum(amount) as totalAmount");
			EarningsDetail earningsDetail = earningsDetailService.getBaseMapper().selectOne(queryWrapper);
			if (earningsDetail == null) {
				log.warn("前一天收益为0,无法生成红包!!!");
				return;
			}
			//收益总金额
			BigDecimal income = earningsDetail.getTotalAmount();
			if (income == null || income.compareTo(new BigDecimal(0)) <= 0) {
				log.warn("前一天收益为0,无法生成红包!!!");
				return;
			}
			//前一天专属红包总金额
			//BigDecimal yesterdayAccelerate = redIntegralService.countYesterdayAccelerate();
			//yesterdayAccelerate = yesterdayAccelerate == null ? BigDecimal.ZERO : yesterdayAccelerate;
			//总金额=(收益总金额-前一天专属红包总金额)*比例
			//BigDecimal totalAmount = income.subtract(yesterdayAccelerate);
			BigDecimal totalAmount = income.multiply(new BigDecimal("0.5")).setScale(2, BigDecimal.ROUND_FLOOR);
			redSetting.setTotalAmount(totalAmount);

		}
		//如果红包个数小于等于0,则按照系统中有在创客专区买过东西且红色积分不能为0的人数来分配个数
		if (redSetting.getNum() <= 0) {
			LambdaQueryWrapper<UserApp> wrapper = new LambdaQueryWrapper<>();
			wrapper.gt(UserApp::getIsRole, 1);
			wrapper.gt(UserApp::getIntegral,0);
			int count = userAppService.count(wrapper);
			if (count <= 0) {
				log.warn("当前在创客专区买过东西的人数为0,无法生成红包!!!");
				return;
			}
			redSetting.setNum(count);
		}
		//如果最小金额*个数都小于总金额,则无法生成红包
		if (redSetting.getMinAmount().multiply(new BigDecimal(redSetting.getNum())).compareTo(redSetting.getTotalAmount())==1){
			log.error("最小金额*个数大于总金额,无法生成红包!!!");
			return;
		}
		log.info("红包任务生成【开始】,个数{}", redSetting.getNum());
		//封装红包对象
		RedEnvelope redEnvelope = new RedEnvelope();
		BeanUtil.copyProperties(redSetting, redEnvelope);
		redEnvelope.setId(IdUtil.getSnowflakeNextId());
		redEnvelope.setCreateTime(new Date());
		redEnvelope.setUpdateTime(new Date());
		//平台红包
		redEnvelope.setBelong(0);
		redEnvelope.setEffectiveStartTime(new Date());
		//当天最后一秒
		redEnvelope.setEffectiveEndTime(DateTimeUtil.lastestTime(null));

		//根据红包的设置生成红包项
		//转换为分为单位的整数,方便计算
		BigDecimal totalMoney = redEnvelope.getTotalAmount();
		//如果红包总金额不大于0,保存数据直接结束
		if (totalMoney.compareTo(BigDecimal.ZERO)!=1){
			redEnvelopeService.save(redEnvelope);
			log.info("红包任务生成【结束】,红包总金额不大于0");
			return;
		}
		List<BigDecimal> redItems = new ArrayList<>();
		if (redEnvelope.getType() == 0) {
			//生成随机红包
			RedPacketUtil2.setMinMoney(redEnvelope.getMinAmount());
			RedPacketUtil2.setMaxMoney(redEnvelope.getMaxAmount());
			redItems = RedPacketUtil2.splitRedPacket(totalMoney, new BigDecimal(redEnvelope.getNum().toString()));
		} else {
			//生成普通红包,每份都一样
			redItems = RedPacketUtil2.splitAvgRedPacket(totalMoney, redEnvelope.getNum());
		}

		ArrayList<RedEnvelopeItem> redEnvelopeItems = new ArrayList<>();
		BigDecimal sum = BigDecimal.ZERO;
		for (BigDecimal redItem : redItems) {
			RedEnvelopeItem redEnvelopeItem = new RedEnvelopeItem();
			redEnvelopeItem.setRedEnvelopeId(redEnvelope.getId());
			redEnvelopeItem.setAmount(redItem);
			redEnvelopeItems.add(redEnvelopeItem);
			sum = sum.add(redItem);
		}
		redEnvelope.setRealTotalAmount(sum);
		redEnvelopeService.save(redEnvelope);
		redEnvelopeItemService.saveBatch(redEnvelopeItems);
		redisTemplate.setValueSerializer(new StringRedisSerializer());
		String strDate = DateTimeUtil.getFormatStrDate(new Date(), "yyyyMMdd");
		for (RedEnvelopeItem redEnvelopeItem : redEnvelopeItems) {
			JSONObject obj = new JSONObject();
			obj.putOpt("id", String.valueOf(redEnvelopeItem.getId()));
			obj.putOpt("redEnvelopeId", String.valueOf(redEnvelopeItem.getRedEnvelopeId()));
			obj.putOpt("amount", String.valueOf(redEnvelopeItem.getAmount()));
			redisTemplate.opsForList().leftPush(CacheBizConstant.CACHE_RED_PACKET + strDate, JSONUtil.toJsonStr(obj));
		}
		log.info(strDate + "红包任务生成【结束】,总金额{},生成个数{},实际生成总金额{}", redEnvelope.getTotalAmount(), redEnvelopeItems.size(), sum);

	}


}
