package org.springblade.modules.redenvelopemall.utils;

import java.math.BigDecimal;
import java.util.LinkedList;
import java.util.List;

/**
 * 红包生成工具类
 */
public class RedPacketUtil {

	/**
	 * 生成红包最小值 1分
	 */
	private static int MIN_MONEY = 1;

	/**
	 * 生成红包最大值 200人民币
	 */
	private static int MAX_MONEY = 200 * 100;

	/**
	 * 小于最小值
	 */
	private static int LESS = -1;
	/**
	 * 大于最大值
	 */
	private static int MORE = -2;

	public static void setMaxMoney(int maxMoney) {
		MAX_MONEY = maxMoney;
	}

	public static void setMinMoney(int minMoney) {
		MIN_MONEY = minMoney;
	}

	/**
	 * 正常值
	 */
	private static final int OK = 1;

	/**
	 * 最大的红包是平均值的 TIMES 倍，防止某一次分配红包较大
	 */
	private static final double TIMES = 2.1F;

	private static int recursiveCount = 0;

	public static List<BigDecimal> splitRedPacket(int money, int count) {
		List<BigDecimal> moneys = new LinkedList<>();
		Integer money1 = new Integer(money);
		//金额检查，如果最大红包 * 个数 < 总金额；则需要调大最小红包 MAX_MONEY
		if (MAX_MONEY * count <= money1) {
			System.err.println("请调大最小红包金额 MAX_MONEY=[" + MAX_MONEY + "]");
			return moneys;
		}


		//计算出最大红包
		int max = (int) ((money1 / count) * TIMES);
		max = max > MAX_MONEY ? MAX_MONEY : max;

		for (int i = 0; i < count; i++) {
			int redPacket = randomRedPacket(money1, MIN_MONEY, max, count - i);
			moneys.add(new BigDecimal(redPacket).divide(
				new BigDecimal(100), 2, BigDecimal.ROUND_HALF_UP
			));
			//总金额每次减少
			money1 -= redPacket;
		}
		//随机获取红包
		try {

		} catch (Exception e) {
			recursiveCount=0;
			//如果发生异常,比如内存泄漏,说明之前的随机金额不合理,重新分配
			return splitRedPacket(money, count);
		}
		return moneys;
	}

	private static int randomRedPacket(int totalMoney, int minMoney, int maxMoney, int count) {
		//只有一个红包直接返回
		if (count == 1) {
			return totalMoney;
		}

		if (minMoney == maxMoney) {
			return minMoney;
		}

		//如果最大金额大于了剩余金额 则用剩余金额 因为这个 money 每分配一次都会减小
		maxMoney = maxMoney > totalMoney ? totalMoney : maxMoney;

		//在 minMoney到maxMoney 生成一个随机红包
		int redPacket = (int) (Math.random() * (maxMoney - minMoney) + minMoney);

		int lastMoney = totalMoney - redPacket;

		int status = checkMoney(lastMoney, count - 1);

		//正常金额
		if (OK == status) {
			return redPacket;
		}

		//如果生成的金额不合法 则递归重新生成
		if (LESS == status) {
			recursiveCount++;
			System.out.println("recursiveCount==" + recursiveCount);
			return randomRedPacket(totalMoney, minMoney, redPacket, count);
		}

		if (MORE == status) {
			recursiveCount++;
			System.out.println("recursiveCount===" + recursiveCount);
			return randomRedPacket(totalMoney, redPacket, maxMoney, count);
		}

		return redPacket;
	}

	/**
	 * 校验剩余的金额的平均值是否在 最小值和最大值这个范围内
	 *
	 * @param lastMoney
	 * @param count
	 * @return
	 */
	private static int checkMoney(int lastMoney, int count) {
		double avg = lastMoney / count;
		if (avg < MIN_MONEY) {
			return LESS;
		}

		if (avg > MAX_MONEY) {
			return MORE;
		}

		return OK;
	}


	public static void main(String[] args) {
		//这里的值1表示0.01元 10000表示100元
		setMaxMoney(20000);
		setMinMoney(1);
		List<BigDecimal> redPackets = splitRedPacket(200000, 30);
		System.out.println(redPackets);
		System.out.println(redPackets.size());

		BigDecimal sum = new BigDecimal("0");
		for (BigDecimal red : redPackets) {
			sum = sum.add(red);
		}
		System.out.println(sum);
	}

	public static List<BigDecimal> splitAvgRedPacket(int totalMoney, Integer num) {
		List<BigDecimal> moneys = new LinkedList<>();
		int money = totalMoney / num;
		int mod = totalMoney % num;
		BigDecimal divide = new BigDecimal(money).divide(new BigDecimal(100), 2, BigDecimal.ROUND_HALF_UP);
		for (Integer i = 0; i < num - 1; i++) {
			moneys.add(divide);
		}
		//最后一个总是平均数+余数
		BigDecimal last = divide
			.add(new BigDecimal(mod).divide(new BigDecimal(100), 2, BigDecimal.ROUND_HALF_UP));
		moneys.add(last);
		return moneys;
	}
}
