/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.controller;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.common.param.SingleParam;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.log.annotation.ApiLog;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.api.request.ConsignPayRequest;
import org.springblade.modules.shopping.entity.Consign;
import org.springblade.modules.shopping.entity.ConsignConfig;
import org.springblade.modules.shopping.entity.Goods;
import org.springblade.modules.shopping.param.ExpExcelConsignParam;
import org.springblade.modules.shopping.service.IConsignConfigService;
import org.springblade.modules.shopping.service.IConsignService;
import org.springblade.modules.shopping.service.IGoodsService;
import org.springblade.modules.shopping.vo.ConsignVO;
import org.springblade.modules.shopping.vo.DeliveryVO;
import org.springblade.modules.shopping.vo.RemitDetailVO;
import org.springblade.modules.shopping.vo.UserConsignInfoVO;
import org.springblade.modules.shopping.wrapper.ConsignWrapper;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.service.IUserService;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.EOFException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 商品寄售表 控制器
 *
 * @author BladeX
 * @since 2022-02-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("shopping/consign")
@Api(value = "商品寄售表", tags = "商品寄售表接口")
public class ConsignController extends BladeController {

	private final IConsignService consignService;
	private final IConsignConfigService consignConfigService;
	private final IGoodsService goodsService;
	private final IUserService userService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入consign")
	public R<Consign> detail(Consign consign) {
		Consign detail = consignService.getOne(Condition.getQueryWrapper(consign));
		return R.data(detail);
	}

	@GetMapping("/deliveryConsign")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入consign")
	public R deliveryConsign(@RequestBody ConsignPayRequest payRequest){

		return R.success("");
	}

	/**
	 * 分页 商品寄售表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入consign")
	public R<IPage<ConsignVO>> list(Consign consign, Query query) {
		if (StrUtil.isNotBlank(consign.getConsignUserPhone())) {
			User one = userService.lambdaQuery().eq(User::getPhone, consign.getConsignUserPhone().trim()).one();
			if (one != null) {
				consign.setConsignUserId(one.getId());
			}
		}
		if (StrUtil.isNotBlank(consign.getConsignUserName())) {
			List<User> list = userService.lambdaQuery().eq(User::getRealName, consign.getConsignUserName().trim()).list();
			if (CollUtil.isNotEmpty(list)) {
				consign.setConsignUserId(list.get(0).getId());
			}
		}
		IPage<Consign> pages = consignService.page(Condition.getPage(query),
			Condition.getQueryWrapper(consign).orderByDesc("create_time"));
		return R.data(ConsignWrapper.build().pageVO(pages));
	}

	/**
	 * 分页 查询平台兜底的寄售订单
	 */
	@GetMapping("/platform_list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入consign")
	public R<IPage<ConsignVO>> platformList(Consign consign, Query query) {
		consign.setConsignState(2); //待付款
		consign.setConsignFor(2); //用户订单
		IPage<Consign> pages = consignService.page(Condition.getPage(query),
			Condition.getQueryWrapper(consign)
				.eq("now_stock", 0)
				.orderByDesc("create_time"));
		return R.data(ConsignWrapper.build().pageVO(pages));
	}

	/**
	 * 自定义分页 商品寄售表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入consign")
	public R<IPage<ConsignVO>> page(ConsignVO consign, Query query) {
		IPage<ConsignVO> pages = consignService.selectConsignPage(Condition.getPage(query), consign);
		return R.data(pages);
	}

	/**
	 * 新增 商品寄售表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入consign")
	public R save(@Valid @RequestBody ConsignVO consign) {
		if (consign.getProductNo() != null){
			Goods goods = goodsService.getOne(Wrappers.<Goods>lambdaQuery().eq(Goods::getProductNo, consign.getProductNo()));
			if (goods != null) {
				consign.setGoodsId(goods.getId());
				consign.setGoodsName(goods.getGoodsName());
			}
		}
		if (consign.getConsignConfigId() != null){
			ConsignConfig consignConfig = consignConfigService.getById(consign.getConsignConfigId());
			if (consignConfig != null){
				String ymd = DateUtil.format(DateUtil.now(), DateUtil.PATTERN_DATE);
				String st = DateUtil.format(consignConfig.getStartTime(), DateUtil.PATTERN_TIME);
				String et = DateUtil.format(consignConfig.getEndTime(), DateUtil.PATTERN_TIME);
				String startTime = ymd + " " + st;
				String endTime = ymd + " " + et;
				Date startDate = DateUtil.parse(startTime, DateUtil.PATTERN_DATETIME);
				Date endDate = DateUtil.parse(endTime, DateUtil.PATTERN_DATETIME);
				consign.setStartTime(startDate);
				consign.setEndTime(endDate);
			}
		}
		consign.setConsignUserId(0L);//0标识系统新增的
		consign.setConsignState(1);//寄售中/待抢购
		consign.setConsignFor(1);//寄售来源为商品
		consign.setConsignDays(0);//寄售天数为0,表示没有限制
		consign.setConsignType(0);//无
		consign.setNowStock(consign.getTotalNum());//开始库存一样
		return R.status(consignService.save(consign));
	}

	/**
	 * 修改 商品寄售表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入consign")
	public R update(@Valid @RequestBody ConsignVO consign) {
		if (consign.getProductNo() != null){
			Goods goods = goodsService.getOne(Wrappers.<Goods>lambdaQuery().eq(Goods::getProductNo, consign.getProductNo()));
			if (goods != null) {
				consign.setGoodsId(goods.getId());
				consign.setGoodsName(goods.getGoodsName());
			}
		}
		if (consign.getConsignConfigId() != null){
			ConsignConfig consignConfig = consignConfigService.getById(consign.getConsignConfigId());
			if (consignConfig != null){
				consign.setStartTime(consignConfig.getStartTime());
				consign.setEndTime(consignConfig.getEndTime());
			}
		}
		return R.status(consignService.updateById(consign));
	}

	/**
	 * 新增或修改 商品寄售表
	 */
	@ApiLog("新增修改寄售商品")
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入consign")
	public R submit(@Valid @RequestBody ConsignVO consign) {

		return R.status(consignService.saveOrUpdate(consign));
	}


	/**
	 * 删除 商品寄售表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(consignService.removeByIds(Func.toLongList(ids)));
	}

	@ApiOperation(value = "根据用户id获取场次抢购信息", notes = "传入用户id")
	@GetMapping("/getByUserId")
	public R getByUserId(@RequestParam("userId") Long userId, Query query) {
		LambdaQueryWrapper<Consign> wrapper = Wrappers.<Consign>lambdaQuery()
			.eq(Consign::getConsignUserId, userId).orderByAsc(Consign::getCreateTime);
		IPage<Consign> page = consignService.getBaseMapper().selectPage(Condition.getPage(query), wrapper);
		if (CollUtil.isEmpty(page.getRecords())) {
			return R.data(page);
		}
		Map<Long, List<Consign>> collect = page.getRecords().stream().collect(Collectors.groupingBy(Consign::getConsignConfigId));
		List<UserConsignInfoVO> list = new ArrayList<>();
		if (CollUtil.isNotEmpty(collect)) {
			for (Long consignConfigId : collect.keySet()) {
				List<Consign> consigns = collect.get(consignConfigId);
				Consign consign = consigns.get(0);
				UserConsignInfoVO vo = new UserConsignInfoVO();
				vo.setTotal(consigns.size());
				vo.setTime(consign.getCreateTime());
				vo.setObtainPrice(consign.getObtainPrice());
				vo.setConsignPrice(consign.getConsignPrice());
				list.add(vo);
			}
		}
		IPage<UserConsignInfoVO> pageVo = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
		pageVo.setRecords(list);
		return R.data(pageVo);
	}

	/**
	 * 交割数据分页
	 */
	@GetMapping("/deliveryPage")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "交割数据分页", notes = "")
	public R deliveryPage(@RequestParam(name = "account",required = false) String account,@RequestParam(name = "realName",required = false) String realName, Query query) {
		IPage<DeliveryVO> page=consignService.deliveryPage(account,realName,Condition.getPage(query));
		return R.data(page);
	}

	/**
	 * 根据用户Id查询未交割的分页数据
	 */
	@GetMapping("/noDeliveryPageByUserId")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "根据用户Id查询未交割的分页数据", notes = "")
	public R noDeliveryPageByUserId(@RequestParam(name = "consignUserId") String consignUserId, Query query) {
		LambdaQueryWrapper<Consign> wrapper = new LambdaQueryWrapper<>();
		wrapper.eq(Consign::getConsignUserId,consignUserId);
		wrapper.ne(Consign::getIsDelivery, 0);//不等于0 表示未交割
		wrapper.eq(Consign::getIsPayment, 0);
		IPage<Consign> page = consignService.page(Condition.getPage(query), wrapper);
		return R.data(ConsignWrapper.build().pageVO(page));
	}
	/**
	 * 批量交割
	 */
	@PostMapping("/batchDelivery")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "批量交割", notes = "传入ids")
	public R batchDelivery(@Valid @RequestBody SingleParam<List> param) {
		if (CollectionUtil.isEmpty(param.getKey())){
			return R.fail("参数传递为null");
		}
		consignService.batchDelivery(param.getKey());
		return R.success("交割成功");
	}

	/**
	 * 批量查询需要打款的详情
	 */
	@PostMapping("/getRemitDetail")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "批量查询需要打款的详情", notes = "传入ids")
	public R<List<RemitDetailVO>> getRemitDetail(@Valid @RequestBody SingleParam<List> param) throws Exception {
		if (param.getKey().size()<=0){
			return R.fail("参数传递为null");
		}
		List<String> collect =(List<String>) param.getKey().stream().distinct().collect(Collectors.toList());
		List<RemitDetailVO> remitDetailVOS= consignService.getRemitDetail(collect);
		return R.data(remitDetailVOS);
	}


	/**
	 * 批量线下打款
	 */
	@PostMapping("/offlineRemit")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "批量线下打款", notes = "传入ids")
	public R offlineRemit(@Valid @RequestBody SingleParam<List> param) throws Exception {
		if (param.getKey().size()<=0){
			return R.fail("参数传递为null");
		}
		BladeUser user = getUser();
		List<String> collect =(List<String>)  param.getKey().stream().distinct().collect(Collectors.toList());
		consignService.offlineRemit(collect,user);
		return R.success("批量线下打款成功");
	}


	/**
	 * 导出寄售订单数据
	 *
	 * @param param
	 * @return
	 */
	@ApiOperation(value = "进度列表导出")
	@PostMapping(value = "/expExcelConsign")
	public void expExcelConsign(@Valid @RequestBody ExpExcelConsignParam param, HttpServletResponse response) throws Exception {
		if (param.getAccounts().size()<=0){
			throw new EOFException("电话不能为空");
		}
		consignService.expExcelConsign(param, response);
	}

	/**
	 * 交割数据导出
	 *
	 * @return
	 */
	@ApiOperation(value = "交割数据导出")
	@PostMapping(value = "/expExcelDelivery")
	public void expExcelDelivery(HttpServletResponse response) throws Exception {

		consignService.expExcelDelivery(response);
	}


}
