/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.annotation.Resource;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.shopping.entity.IntegerConsign;
import org.springblade.modules.shopping.vo.IntegerConsignVO;
import org.springblade.modules.shopping.service.IIntegerConsignService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 积分寄售表 控制器
 *
 * @author BladeX
 * @since 2022-08-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("shopping/integerconsign")
@Api(value = "积分寄售表", tags = "积分寄售表接口")
public class IntegerConsignController extends BladeController {

	@Resource
	private IIntegerConsignService integerConsignService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入integerConsign")
	public R<IntegerConsign> detail(IntegerConsign integerConsign) {
		IntegerConsign detail = integerConsignService.getOne(Condition.getQueryWrapper(integerConsign));
		return R.data(detail);
	}

	/**
	 * 分页 积分寄售表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入integerConsign")
	public R<IPage<IntegerConsign>> list(IntegerConsign integerConsign, Query query) {
		IPage<IntegerConsign> pages = integerConsignService.page(Condition.getPage(query), Condition.getQueryWrapper(integerConsign));
		return R.data(pages);
	}

	/**
	 * 自定义分页 积分寄售表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入integerConsign")
	public R<IPage<IntegerConsignVO>> page(IntegerConsignVO integerConsign, Query query) {
		if (integerConsign.getType() == 1){
			integerConsign.setConsignUserId(getUser().getUserId());
		}else if (integerConsign.getType() == 2) {
			integerConsign.setBuyerUserId(getUser().getUserId());
		}
		IPage<IntegerConsignVO> pages = integerConsignService.selectIntegerConsignPage(Condition.getPage(query), integerConsign);
		return R.data(pages);
	}

	/**
	 * 新增 积分寄售表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入integerConsign")
	public R save(@Valid @RequestBody IntegerConsign integerConsign) {
		return R.status(integerConsignService.save(integerConsign));
	}

	/**
	 * 修改 积分寄售表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入integerConsign")
	public R update(@Valid @RequestBody IntegerConsign integerConsign) {
		return R.status(integerConsignService.updateById(integerConsign));
	}

	/**
	 * 新增或修改 积分寄售表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入integerConsign")
	public R submit(@Valid @RequestBody IntegerConsign integerConsign) {
		return R.status(integerConsignService.saveOrUpdate(integerConsign));
	}


	/**
	 * 删除 积分寄售表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(integerConsignService.removeByIds(Func.toLongList(ids)));
	}


}
