/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.mapper;

import org.apache.ibatis.annotations.Param;
import org.springblade.modules.api.param.StatisticsConsignParam;
import org.springblade.modules.api.vo.StatisticsConsignVO;
import org.springblade.modules.shopping.entity.Consign;
import org.springblade.modules.shopping.param.ExpExcelConsignParam;
import org.springblade.modules.shopping.vo.*;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.util.List;

/**
 * 商品寄售表 Mapper 接口
 *
 * @author BladeX
 * @since 2022-02-13
 */
public interface ConsignMapper extends BaseMapper<Consign> {

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param consign
	 * @return
	 */
	List<ConsignVO> selectConsignPage(IPage page, ConsignVO consign);

	/**
	 * 获取所有需要付款的批次统计
	 * @return
	 */
	List<ConsignListVO> findOderConsignList(@Param("param") StatisticsConsignParam param);

	/**
	 * 通过批次号获取寄售商品列表
	 * @return
	 */
	List<Consign> getConsignListByConfigId(@Param("consignConfigId") Long consignConfigId);

	/**
	 * 获取用户单
	 * @param consignConfigId 批次ID
	 * @param userId 用户ID
	 * @return Consign
	 */
	Consign randomConsignNew(@Param("consignConfigId") Long consignConfigId, @Param("userId") Long userId, Long oldId);



	/**
	 * 查询是否有单可抢
	 * @param consignConfigId 批次ID
	 * @param userId 用户ID
	 * @return Consign
	 */
	Consign queryConsign(@Param("consignConfigId") Long consignConfigId, @Param("userId") Long userId);

	/**
	 * 获取用户单
	 * @param consignConfigId 批次ID
	 * @param userId 用户ID
	 * @return Consign
	 */
	Consign randomConsign(@Param("consignConfigId") Long consignConfigId, @Param("userId") Long userId);


	/**
	 * 获取平台单
	 * @param consignConfigId 批次ID
	 * @param consignId 寄售ID
	 * @return Consign
	 */
	Consign platformConsign(@Param("consignConfigId") Long consignConfigId, @Param("consignId") Long consignId);

	StatisticsConsignVO getStatisticsConsign(StatisticsConsignParam param);

	List<Consign> getByUserId(IPage page, @Param("userId") Long userId);


	RemitDetailVO getRemitDetail(@Param("id")String id);

	List<ExpExcelConsignVO> expExcelConsign(@Param("param") ExpExcelConsignParam param);

	/**
	 * 交割数据分页
	 * @param page
	 * @param account
	 * @param realName
	 * @return
	 */
	IPage<DeliveryVO> deliveryPage(IPage page, @Param("account")String account, @Param("realName")String realName);
	/**
	 * 交割数据list
	 * @return
	 */
	List<DeliveryVO> delivery();
}
