/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springblade.core.secure.BladeUser;
import org.springblade.modules.api.param.StatisticsConsignParam;
import org.springblade.modules.api.vo.StatisticsConsignVO;
import org.springblade.modules.shopping.entity.Consign;
import org.springblade.modules.shopping.param.ExpExcelConsignParam;
import org.springblade.modules.shopping.vo.ConsignListVO;
import org.springblade.modules.shopping.vo.ConsignVO;
import org.springblade.modules.shopping.vo.DeliveryVO;
import org.springblade.modules.shopping.vo.RemitDetailVO;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

/**
 * 商品寄售表 服务类
 *
 * @author BladeX
 * @since 2022-02-13
 */
public interface IConsignService extends IService<Consign> {

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param consign
	 * @return
	 */
	IPage<ConsignVO> selectConsignPage(IPage<ConsignVO> page, ConsignVO consign);

	List<ConsignListVO> findOderConsignList(StatisticsConsignParam param);

	/**
	 * 通过寄售id列表进行打款
	 *
	 * @param consignIds
	 */
	void checkConsignPay(List<Consign> consigns);

	/**
	 * 通过批次号获取寄售商品列表
	 *
	 * @return
	 */
	List<Consign> getConsignListByConfigId(Long consignConfigId);

	/**
	 * 抢购页面展示两条数据
	 *
	 * @param consignConfigId 场次ID
	 * @return List
	 */
	List<ConsignVO> selectConsignList(Long consignConfigId);


	Consign queryConsign(Long consignConfigId, Long userId);

	/**
	 * 获取随机数
	 *
	 * @param consignConfigId 批次ID
	 * @return Consign
	 */
	Consign randomConsign(Long consignConfigId, Long userId);

	StatisticsConsignVO getStatisticsConsign(StatisticsConsignParam param);

	List<Consign> getByUserId(IPage page, Long userId);

	void batchDelivery(List<Long> toLongList);

	List<RemitDetailVO> getRemitDetail(List<String> key) throws Exception;

	void offlineRemit(List<String> collect, BladeUser user) throws Exception;

	void expExcelConsign(ExpExcelConsignParam param, HttpServletResponse response) throws Exception;

	IPage<DeliveryVO> deliveryPage(String account, String realName, IPage<Object> page);

	Consign getNewestByUserId(Long userId);

	void expExcelDelivery(HttpServletResponse response) throws IOException;
}
