/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.MoneySourceEnum;
import org.springblade.common.enums.RemitTypeEnum;
import org.springblade.common.enums.TicketTypeEnum;
import org.springblade.common.utils.DateTimeUtil;
import org.springblade.common.utils.EasyExcelUtil;
import org.springblade.core.secure.BladeUser;
import org.springblade.modules.api.param.StatisticsConsignParam;
import org.springblade.modules.api.vo.StatisticsConsignVO;
import org.springblade.modules.platform.entity.UserTicket;
import org.springblade.modules.platform.service.IUserTicketService;
import org.springblade.modules.shopping.entity.Consign;
import org.springblade.modules.shopping.entity.RemitRecord;
import org.springblade.modules.shopping.mapper.ConsignMapper;
import org.springblade.modules.shopping.param.ExpExcelConsignParam;
import org.springblade.modules.shopping.service.IConsignService;
import org.springblade.modules.shopping.service.RemitRecordService;
import org.springblade.modules.shopping.vo.*;
import org.springblade.modules.shopping.wrapper.ConsignWrapper;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.param.RecordParam;
import org.springblade.modules.system.service.INowMoneyRecordService;
import org.springblade.modules.system.service.IUserService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.math.BigDecimal;
import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 商品寄售表 服务实现类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Service
public class ConsignServiceImpl extends ServiceImpl<ConsignMapper, Consign> implements IConsignService {
	@Resource
	private IUserTicketService userTicketService;
	@Resource
	private RemitRecordService remitRecordService;
	@Resource
	private IUserService userService;
	@Resource
	private INowMoneyRecordService nowMoneyRecordService;

	@Override
	public IPage<ConsignVO> selectConsignPage(IPage<ConsignVO> page, ConsignVO consign) {
		return page.setRecords(baseMapper.selectConsignPage(page, consign));
	}

	public List<ConsignListVO> findOderConsignList(StatisticsConsignParam param) {
		return baseMapper.findOderConsignList(param);
	}

	/**
	 * 通过寄售id列表进行打款
	 * @param consigns
	 */
	@Override
	public void checkConsignPay(List<Consign> consigns){
		//获取配置参数
		BigDecimal taxRatio = new BigDecimal(ParamCache.getValue(CommonConstant.PLATFORM_TAX_RATIO));
		for (Consign consign : consigns) {
			Consign consign1 = baseMapper.selectById(consign.getId());
			if(consign1.getIsPayment() > 0){
				throw  new RuntimeException("该订单已进行打款，请不要重复点击");
			}
			//收益金额 收益金额等于抢购价减去取得价
			BigDecimal bigDecimal = new BigDecimal(consign.getConsignPrice()).subtract(new BigDecimal(consign.getObtainPrice())).setScale(2, BigDecimal.ROUND_HALF_UP);
			RecordParam recordParam = new RecordParam();
			recordParam.setChargeAmount(new BigDecimal(consign.getConsignPrice()).multiply(new BigDecimal(0.006)).setScale(2, BigDecimal.ROUND_UP));
			recordParam.setUserId(consign.getConsignUserId());
			recordParam.setDataId(consign.getId());
			recordParam.setFluctuantAmount(new BigDecimal(consign.getConsignPrice()).setScale(2, BigDecimal.ROUND_UP));
			recordParam.setMoneySourceEnum(MoneySourceEnum.JINHUO_REFUND);
			recordParam.setTaxAmount(bigDecimal.multiply(taxRatio).setScale(2, BigDecimal.ROUND_UP));
			Map<String, Object> map = nowMoneyRecordService.insertRecord(recordParam);
			if ((Boolean) map.get("flag")){
				consign.setIsPayment(1);
				consign.setConsignState(3);
				baseMapper.updateById(consign);
			}
		}
	}

	/**
	 * 通过批次号获取寄售商品列表
	 *
	 * @return
	 */
	public List<Consign> getConsignListByConfigId(Long consignConfigId) {
		return baseMapper.getConsignListByConfigId(consignConfigId);
	}

	@Override
	public List<ConsignVO> selectConsignList(Long consignConfigId) {
		//String startTime = DateUtil.format(DateUtil.now(), DateUtil.PATTERN_DATETIME);
		List<Consign> list = baseMapper.selectList(Wrappers.<Consign>lambdaQuery()
				.eq(Consign::getIsSale, 2)
				.eq(Consign::getConsignFor, 1)
				.gt(Consign::getNowStock, 0)
				.eq(Consign::getConsignConfigId, consignConfigId)
			//.last(" and to_days(start_time) = to_days(now())")
		);
		return ConsignWrapper.build().listVO(list);
	}

	@Override
	public Consign queryConsign(Long consignConfigId, Long userId) {
		return baseMapper.queryConsign(consignConfigId, userId);
	}

	@Override
	public Consign randomConsign(Long consignConfigId, Long userId) {
		return baseMapper.randomConsign(consignConfigId, userId);
	}

	@Override
	public StatisticsConsignVO getStatisticsConsign(StatisticsConsignParam param) {
		return baseMapper.getStatisticsConsign(param);
	}

	@Override
	public List<Consign> getByUserId(IPage page, Long userId) {
		return baseMapper.getByUserId(page, userId);
	}

	@Override
	@Transactional
	public void batchDelivery(List<Long> idList) {
		LambdaQueryWrapper<Consign> wrapper = Wrappers.lambdaQuery(Consign.class);
		wrapper.in(Consign::getId, idList);
		wrapper.ne(Consign::getIsDelivery, 0);//不等于0 表示未交割
		wrapper.eq(Consign::getIsPayment, 0);
		List<Consign> consigns = baseMapper.selectList(wrapper);
		if (CollectionUtil.isEmpty(consigns)) {
			return;
		}
		for (Consign consign : consigns) {
			//抢购价
			BigDecimal consignPrice = BigDecimal.valueOf(consign.getConsignPrice());
			//比例
			String ratio = ParamCache.getValue(CommonConstant.CONSIGN_ACCELERATE_RATIO);
			BigDecimal con = consignPrice.multiply(new BigDecimal(ratio));
			userTicketService.addScoreBySrc2Data(consign.getConsignUserId(), con, 10, "完结交易送积分", TicketTypeEnum.INCOME, consign.getId());
			//修改交割状态
			consign.setIsDelivery(0);//设置为交割
			consign.setIsPayment(3);
		}
		//更新
		this.saveOrUpdateBatch(consigns);
	}

	@Override
	public List<RemitDetailVO> getRemitDetail(List<String> key) throws Exception {
		List<RemitDetailVO> remitDetailList = new ArrayList<>();

		List<RemitDetailVO> remitDetailVOS = new ArrayList<>();

		for (String id : key) {
			RemitDetailVO remitDetailVO = this.getBaseMapper().getRemitDetail(id);

			if (Objects.nonNull(remitDetailVO)) {
				remitDetailVOS.add(remitDetailVO);
			}
		}

		if (remitDetailVOS.size() < key.size()) {
			throw new Exception("查询结果数与传参数不匹配！");
		}
		Map<Long, List<RemitDetailVO>> listMap = remitDetailVOS.stream().collect(Collectors.groupingBy(RemitDetailVO::getConsignUserId));

		for (Long userId : listMap.keySet()) {
			List<RemitDetailVO> remitDetailVOS1 = listMap.get(userId);
			RemitDetailVO remitDetailVO = new RemitDetailVO();
			remitDetailVO.setCount(remitDetailVOS1.size());
			remitDetailVO.setConsignUserId(remitDetailVOS1.get(0).getConsignUserId());
			remitDetailVO.setConsignUserName(remitDetailVOS1.get(0).getConsignUserName());
			remitDetailVO.setConsignUserPhone(remitDetailVOS1.get(0).getConsignUserPhone());
			BigDecimal obtainPrice = new BigDecimal(0);
			BigDecimal consignPrice = new BigDecimal(0);
			BigDecimal remitPrice = new BigDecimal(0);
			BigDecimal procedurePrice = new BigDecimal(0);
			BigDecimal taxPrice = new BigDecimal(0);
			for (RemitDetailVO detailVO : remitDetailVOS1) {
				obtainPrice = obtainPrice.add(detailVO.getObtainPrice());
				consignPrice = consignPrice.add(detailVO.getConsignPrice());
				remitPrice = remitPrice.add(detailVO.getRemitPrice());
				procedurePrice = procedurePrice.add(detailVO.getProcedurePrice());
				taxPrice = taxPrice.add(detailVO.getTaxPrice());
			}
			remitDetailVO.setConsignPrice(consignPrice);
			remitDetailVO.setObtainPrice(obtainPrice);
			remitDetailVO.setRemitPrice(remitPrice);
			remitDetailVO.setProcedurePrice(procedurePrice);
			remitDetailVO.setTaxPrice(taxPrice);
			remitDetailList.add(remitDetailVO);
		}
		return remitDetailList;
	}

	@Override
	@Transactional
	public void offlineRemit(List<String> collect, BladeUser user) throws Exception {

		List<Consign> consignList = new ArrayList<>();
		List<RemitRecord> remitRecordList = new ArrayList<>();

		for (String id : collect) {
			Consign consign = this.getById(id);
			if (Objects.isNull(consign)) {
				throw new Exception("寄售商品不存在！商品id:" + consign.getId());
			}
			if (consign.getIsPayment() != 0) {
				throw new Exception("寄售商品不是未付款状态！商品id:" + consign.getId());
			}
			consign.setIsPayment(1);
			consignList.add(consign);
			RemitDetailVO remitDetail = this.getBaseMapper().getRemitDetail(id);
			RemitRecord remitRecord = createRemitRecord(consign, remitDetail, user);
			remitRecordList.add(remitRecord);
		}
		this.saveOrUpdateBatch(consignList);
		remitRecordService.saveBatch(remitRecordList);
	}

	@Override
	public void expExcelConsign(ExpExcelConsignParam param, HttpServletResponse response) throws Exception {

		List<ExpExcelConsignVO> expExcelConsignVO = this.getBaseMapper().expExcelConsign(param);
		Map<String, List<ExpExcelConsignVO>> listMap = expExcelConsignVO.stream().collect(Collectors.groupingBy(ExpExcelConsignVO::getUserId));

		//文件名
		SimpleDateFormat format = new SimpleDateFormat("yyyyMMdd");
		String dateStr = format.format(new Date());
		String fileName = "寄售订单数据" + dateStr + ".xlsx";

		response.setContentType("application/vnd.ms-excel");
		response.setCharacterEncoding("utf-8");
		response.setHeader("Content-disposition", "attachment;filename=" + URLEncoder.encode(fileName, "UTF-8"));
		response.addHeader("Access-Control-Expose-Headers", "Content-Disposition");

		ExcelWriter excelWriter = EasyExcel.write(response.getOutputStream(), ExpExcelConsignVO.class).build();

		for (String s : listMap.keySet()) {
			List<ExpExcelConsignVO> expExcelConsignVOS = listMap.get(s);
			String sheetName = expExcelConsignVOS.get(0).getRealName();
			WriteSheet writeSheet = EasyExcel.writerSheet(sheetName).build();
			excelWriter.write(expExcelConsignVOS, writeSheet);
		}
		excelWriter.finish();


	}

	@Override
	public IPage<DeliveryVO> deliveryPage(String account, String realName, IPage<Object> page) {
		IPage<DeliveryVO> deliveryPage = baseMapper.deliveryPage(page, account, realName);
		//判断上个月到现在是否交割
		for (DeliveryVO record : deliveryPage.getRecords()) {
			//上个月第一天
			Date monthFirstDay = DateTimeUtil.getMonthFirstDay(Calendar.getInstance().get(Calendar.MONTH)-1);
			LambdaQueryWrapper<UserTicket> wrapper = new LambdaQueryWrapper<>();
			wrapper.eq(UserTicket::getUserId,record.getConsignUserId());//寄售用户Id
			wrapper.eq(UserTicket::getDataSrc,10); //来源类型
			wrapper.gt(UserTicket::getCreateTime,monthFirstDay);//上个月第一天以后的数据
			int count = userTicketService.count(wrapper);
			if (count>0){
				record.setDeliveryState(1);
			}else {
				record.setDeliveryState(0);
			}

		}
		return deliveryPage;
	}

	@Override
	public Consign getNewestByUserId(Long userId) {
		LambdaQueryWrapper<Consign> query = new LambdaQueryWrapper<>();
		query.eq(Consign::getIsDeleted,0);
		query.eq(Consign::getConsignUserId,userId);
		query.orderByAsc(Consign::getCreateTime);
		query.last("limit 1");
		return this.getOne(query);
	}

	@Override
	public void expExcelDelivery(HttpServletResponse response) throws IOException {
		List<DeliveryVO> delivery = this.baseMapper.delivery();
		//文件名
		SimpleDateFormat format = new SimpleDateFormat("yyyyMMdd");
		String dateStr = format.format(new Date());
		String fileName = "用户数据" + dateStr + ".xlsx";
		EasyExcelUtil.downLoadExcel(response,fileName,DeliveryVO.class,delivery);
	}

	private RemitRecord createRemitRecord(Consign consign, RemitDetailVO remitDetail, BladeUser user) {

		RemitRecord remitRecord = new RemitRecord();
		remitRecord.setConsignId(consign.getId());
		remitRecord.setRemitType(RemitTypeEnum.OFFLINE.getValue());
		remitRecord.setRemitPrice(remitDetail.getRemitPrice());
		remitRecord.setPayeeUserId(consign.getConsignUserId());
		remitRecord.setRequestJson(remitDetail.toString());

		Date date = new Date();
		remitRecord.setCreateUserId(user.getUserId());
		User userById = userService.getById(user.getUserId());
		remitRecord.setCreateUserName(userById.getRealName());
		remitRecord.setUpdateUserId(user.getUserId());
		remitRecord.setCreateTime(date);
		remitRecord.setUpdateTime(date);
		remitRecord.setIsDelete(0);
		return remitRecord;


	}

}
