/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.service.impl;

import org.springblade.common.enums.MoneySourceEnum;
import org.springblade.common.enums.TicketTypeEnum;
import org.springblade.modules.platform.service.IUserTicketService;
import org.springblade.modules.shopping.entity.IntegerConsign;
import org.springblade.modules.shopping.vo.IntegerConsignVO;
import org.springblade.modules.shopping.mapper.IntegerConsignMapper;
import org.springblade.modules.shopping.service.IIntegerConsignService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.modules.system.param.RecordParam;
import org.springblade.modules.system.service.INowMoneyRecordService;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.Map;

/**
 * 积分寄售表 服务实现类
 *
 * @author BladeX
 * @since 2022-08-15
 */
@Service
public class IntegerConsignServiceImpl extends ServiceImpl<IntegerConsignMapper, IntegerConsign> implements IIntegerConsignService {

	@Resource
	private IUserTicketService userTicketService;

	@Resource
	private INowMoneyRecordService nowMoneyRecordService;

	@Override
	public IPage<IntegerConsignVO> selectIntegerConsignPage(IPage<IntegerConsignVO> page, IntegerConsignVO integerConsign) {
		return page.setRecords(baseMapper.selectIntegerConsignPage(page, integerConsign));
	}

	@Override
	@Transactional
	public Boolean updateByStatus(IntegerConsign integerConsign, Integer type) {
		if(type == 0){
			save(integerConsign);
			userTicketService.addScoreBySrc2Data(integerConsign.getConsignUserId(), integerConsign.getIntegral(), 11, "积分寄售扣除", TicketTypeEnum.EXPENDITURE, integerConsign.getId());
			return true;
		} else if(type == 1) {
			//购买用户付款
			RecordParam recordParam = new RecordParam();
			recordParam.setFluctuantAmount(integerConsign.getConsignPrice());
			recordParam.setMoneySourceEnum(MoneySourceEnum.CONSIGNMENT_PAY);
			recordParam.setUserId(integerConsign.getBuyerUserId());
			recordParam.setDataId(integerConsign.getId());
			Map<String, Object> res = nowMoneyRecordService.insertRecord(recordParam);
			Boolean flag = (Boolean) res.get("flag");
			if (flag) {//判断购买用户付款是否成功
				//付款成功后进行寄卖用户收款
				recordParam = new RecordParam();
				recordParam.setFluctuantAmount(integerConsign.getConsignPrice());
				//计算5%的手续费
				BigDecimal chargeAmount = integerConsign.getConsignPrice().multiply(new BigDecimal(0.05)).setScale(2, BigDecimal.ROUND_HALF_UP);
				recordParam.setChargeAmount(chargeAmount);
				recordParam.setMoneySourceEnum(MoneySourceEnum.CONSIGNMENT_REFUND);
				recordParam.setUserId(integerConsign.getConsignUserId());
				recordParam.setDataId(integerConsign.getId());
				res = nowMoneyRecordService.insertRecord(recordParam);
			}
			userTicketService.addScoreBySrc2Data(integerConsign.getBuyerUserId(), integerConsign.getIntegral(), 11, "积分寄售购买", TicketTypeEnum.INCOME, integerConsign.getId());
		} else {
			userTicketService.addScoreBySrc2Data(integerConsign.getConsignUserId(), integerConsign.getIntegral(), 11, "积分寄售退回", TicketTypeEnum.INCOME, integerConsign.getId());
			integerConsign.setUpdateTime(new Date());
			return removeById(integerConsign.getId());
		}
		return updateById(integerConsign);
	}

}
