/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.vo;

import io.swagger.annotations.ApiModelProperty;
import org.springblade.modules.shopping.entity.IntegerConsign;
import lombok.Data;
import lombok.EqualsAndHashCode;
import io.swagger.annotations.ApiModel;

import javax.validation.constraints.NotNull;
import java.math.BigDecimal;

/**
 * 积分寄售表视图实体类
 *
 * @author BladeX
 * @since 2022-08-15
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "IntegerConsignVO对象", description = "积分寄售表")
public class IntegerConsignVO extends IntegerConsign {
	private static final long serialVersionUID = 1L;

	@NotNull(message = "查询类型不能为空")
	@ApiModelProperty(value = "查询类型：0寄售大厅，1我寄卖的，2我购买的")
	private Integer type;

	@ApiModelProperty(value = "最小积分")
	private BigDecimal startInteger;

	@ApiModelProperty(value = "最大积分")
	private BigDecimal endInteger;

	@ApiModelProperty(value = "显示状态名称")
	private String des;

	@ApiModelProperty(value = "头像")
	private String avatar;

	public String getDes(){
		if (new Integer(0).equals(this.getStatus())) {
			return "寄售中";
		} else if (new Integer(1).equals(this.getStatus())) {
			return "已完成";
		} else {
			return "已下架";
		}
	}
}
