/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.system.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.system.entity.WithdrawalAccelerateRecord;
import org.springblade.modules.system.vo.WithdrawalAccelerateRecordVO;
import org.springblade.modules.system.service.IWithdrawalAccelerateRecordService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 余额加速提现 控制器
 *
 * @author BladeX
 * @since 2022-10-24
 */
@RestController
@AllArgsConstructor
@RequestMapping("shopping/withdrawalacceleraterecord")
@Api(value = "余额加速提现", tags = "余额加速提现接口")
public class WithdrawalAccelerateRecordController extends BladeController {

	private final IWithdrawalAccelerateRecordService withdrawalAccelerateRecordService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入withdrawalAccelerateRecord")
	public R<WithdrawalAccelerateRecord> detail(WithdrawalAccelerateRecord withdrawalAccelerateRecord) {
		WithdrawalAccelerateRecord detail = withdrawalAccelerateRecordService.getOne(Condition.getQueryWrapper(withdrawalAccelerateRecord));
		return R.data(detail);
	}

	/**
	 * 分页 余额加速提现
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入withdrawalAccelerateRecord")
	public R<IPage<WithdrawalAccelerateRecord>> list(WithdrawalAccelerateRecord withdrawalAccelerateRecord, Query query) {
		IPage<WithdrawalAccelerateRecord> pages = withdrawalAccelerateRecordService.page(Condition.getPage(query), Condition.getQueryWrapper(withdrawalAccelerateRecord));
		return R.data(pages);
	}

	/**
	 * 自定义分页 余额加速提现
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入withdrawalAccelerateRecord")
	public R<IPage<WithdrawalAccelerateRecordVO>> page(WithdrawalAccelerateRecordVO withdrawalAccelerateRecord, Query query) {
		IPage<WithdrawalAccelerateRecordVO> pages = withdrawalAccelerateRecordService.selectWithdrawalAccelerateRecordPage(Condition.getPage(query), withdrawalAccelerateRecord);
		return R.data(pages);
	}

	/**
	 * 新增 余额加速提现
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入withdrawalAccelerateRecord")
	public R save(@Valid @RequestBody WithdrawalAccelerateRecord withdrawalAccelerateRecord) {
		return R.status(withdrawalAccelerateRecordService.save(withdrawalAccelerateRecord));
	}

	/**
	 * 修改 余额加速提现
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入withdrawalAccelerateRecord")
	public R update(@Valid @RequestBody WithdrawalAccelerateRecord withdrawalAccelerateRecord) {
		return R.status(withdrawalAccelerateRecordService.updateById(withdrawalAccelerateRecord));
	}

	/**
	 * 新增或修改 余额加速提现
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入withdrawalAccelerateRecord")
	public R submit(@Valid @RequestBody WithdrawalAccelerateRecord withdrawalAccelerateRecord) {
		return R.status(withdrawalAccelerateRecordService.saveOrUpdate(withdrawalAccelerateRecord));
	}

	
	/**
	 * 删除 余额加速提现
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(withdrawalAccelerateRecordService.removeByIds(Func.toLongList(ids)));
	}

	
}
