/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.system.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springblade.common.cache.ParamCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.common.enums.MoneySourceEnum;
import org.springblade.core.log.logger.BladeLogger;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.modules.linked.vo.LinkedVerifyVO;
import org.springblade.modules.platform.service.UserAppService;
import org.springblade.modules.redenvelopemall.service.IRedEnvelopeService;
import org.springblade.modules.system.entity.NowMoneyRecord;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.entity.UserApp;
import org.springblade.modules.system.entity.WithdrawalAccelerateRecord;
import org.springblade.modules.system.mapper.NowMoneyRecordMapper;
import org.springblade.modules.system.mapper.UserMapper;
import org.springblade.modules.system.mapper.WithdrawalAccelerateRecordMapper;
import org.springblade.modules.system.param.RecordParam;
import org.springblade.modules.system.service.INowMoneyRecordService;
import org.springblade.modules.system.service.IUserService;
import org.springblade.modules.system.vo.NowMoneyRecordVO;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.*;

/**
 * 服务实现类
 *
 * @author BladeX
 * @since 2022-07-18
 */
@Service
public class NowMoneyRecordServiceImpl extends ServiceImpl<NowMoneyRecordMapper, NowMoneyRecord> implements INowMoneyRecordService {

	private static final Logger log = LoggerFactory.getLogger(INowMoneyRecordService.class);

	@Resource
	private UserAppService userAppService;

	@Resource
	private WithdrawalAccelerateRecordMapper accMapper;

	@Resource
	private BladeLogger logger;

	@Resource
	private UserMapper userMapper;

	@Override
	@Transactional
	public Map<String,Object> insertRecord(RecordParam param) {
		boolean flag = false;
		//进货打款验证
		if (param.getMoneySourceEnum() == MoneySourceEnum.JINHUO_REFUND ){
			LambdaQueryWrapper<NowMoneyRecord> query = new LambdaQueryWrapper<>();
			query.eq(NowMoneyRecord::getDataId,param.getDataId());
			//查询统一订单是否存在多次
			List<NowMoneyRecord> list = this.list(query);
			if (list.size()>0){
				throw new RuntimeException("重复打款，请核实！");
			}
		}

		Map<String,Object> map = new HashMap<>();
		String str = Objects.isNull(param.getDataId()) ? "" : "来源ID：" + param.getDataId();
		LambdaQueryWrapper<UserApp> query = new LambdaQueryWrapper<>();
		query.eq(UserApp::getUserId,param.getUserId());
		query.eq(UserApp::getState,1);
		//查询用户钱包
		UserApp userApp = userAppService.getOne(query);
		if (Objects.isNull(userApp)){
			map.put("flag",flag);
			map.put("msg","用户钱包不存在或被冻结!");
			log.info(param.getMoneySourceEnum().getName()+"失败","用户钱包不存在或被冻结！"  + str);
			logger.info(param.getMoneySourceEnum().getName()+"失败","用户钱包不存在或被冻结！"  + str);
			return map;
		}
		//判断定时任务返回是没有登录用户的情况
		BladeUser user = AuthUtil.getUser();
		if(ObjectUtil.isNull(user)){
			user = new BladeUser();
			user.setUserId(0L);
		}
		NowMoneyRecord nowMoneyRecord = new NowMoneyRecord();
		BigDecimal beforeMoney = new BigDecimal(0);
		//判断余额之前是否为空
		if(Objects.nonNull(userApp.getNowMoney())){
			beforeMoney = userApp.getNowMoney();
		}
		//核对当前的钱包的余额是否和余额变更记录的最后一条相等
		NowMoneyRecord newestRecord = getNewestRecord(user.getUserId());
		if (false){
			if (!newestRecord.getAfterMoney().equals(userApp.getNowMoney())){
				map.put("flag",flag);
				map.put("msg","余额数据异常，请联系管理员!");
				log.info(param.getMoneySourceEnum().getName()+"失败","余额数据异常！"  + str);
				logger.info(param.getMoneySourceEnum().getName()+"失败","余额数据异常！"  + str);
				return map;
			}
		}
		nowMoneyRecord.setBeforeMoney(beforeMoney);
		BigDecimal newFluctuantAmount  =new BigDecimal(0);
		BigDecimal afterMoney = new BigDecimal(0);
		//判断当前记录为  收入
		if (param.getMoneySourceEnum().getType() == 1){
			//计算变动后的金额
			afterMoney = beforeMoney
				.add(param.getFluctuantAmount())
				.subtract(param.getChargeAmount())
				.subtract(param.getTaxAmount());
			newFluctuantAmount = param.getFluctuantAmount().subtract(param.getChargeAmount()).subtract(param.getTaxAmount());
		}
		//判断当前记录为  支出
		if (param.getMoneySourceEnum().getType() == 2){
			//计算变动后的金额
			afterMoney = beforeMoney
				.subtract(param.getFluctuantAmount())
				.subtract(param.getChargeAmount())
				.subtract(param.getTaxAmount());
			//判断计算后的金额是否小于0
			if (afterMoney.compareTo(new BigDecimal(0)) < 0){ //余额不足
				map.put("flag",flag);
				map.put("msg","用户钱包余额不足!");
				log.info(param.getMoneySourceEnum().getName()+"失败","用户钱包余额不足！钱包id：" + userApp.getId() + str);
				logger.info(param.getMoneySourceEnum().getName()+"失败","用户钱包余额不足！钱包id：" + userApp.getId() + str);
				return map;
			}
			newFluctuantAmount = param.getFluctuantAmount().add(param.getChargeAmount()).add(param.getTaxAmount());
		}
		nowMoneyRecord.setAfterMoney(afterMoney);
		nowMoneyRecord.setType(param.getMoneySourceEnum().getType());
		nowMoneyRecord.setFluctuantAmount(newFluctuantAmount);
		nowMoneyRecord.setChargeAmount(param.getChargeAmount());
		nowMoneyRecord.setTaxAmount(param.getTaxAmount());
		nowMoneyRecord.setSource(param.getMoneySourceEnum().getName());
		nowMoneyRecord.setUserAppId(userApp.getId());
		nowMoneyRecord.setSourceCode(param.getMoneySourceEnum().getValue());
		nowMoneyRecord.setUserId(param.getUserId());
		nowMoneyRecord.setParamStr(param.toString());
		nowMoneyRecord.setDataId(param.getDataId());
		Date date = new Date();
		nowMoneyRecord.setCreateUserId(user.getUserId());
		nowMoneyRecord.setUpdateUserId(user.getUserId());
		nowMoneyRecord.setCreateTime(date);
		nowMoneyRecord.setUpdateTime(date);
		nowMoneyRecord.setIsDelete(0);
		userApp.setNowMoney(afterMoney);
		if(param.getMoneySourceEnum().getValue().equals(0)){//余额提现加速计算
			WithdrawalAccelerateRecord record = new WithdrawalAccelerateRecord();
			User user1 = userMapper.selectById(nowMoneyRecord.getUserId());
			UserApp puserApp = userAppService.getByUserId(userApp.getParentId());
			//计算加速提现金额
			record.setRemark("充值余额加速");
			BigDecimal amount = nowMoneyRecord.getFluctuantAmount().multiply(new BigDecimal(ParamCache.getValue(CommonConstant.ACCELERATE_WITHDRAWAL_RATIO)));
			if (puserApp.getAccBalance().compareTo(new BigDecimal(ParamCache.getValue(CommonConstant.ACCELERATE_WITHDRAWAL_CAPS))) >= 0){//判断余额是否大于封顶值
				amount = new BigDecimal(0);
				record.setRemark("加速封顶");
			}
			record.setAccelerateAmount(nowMoneyRecord.getFluctuantAmount());
			record.setRatio(new BigDecimal(ParamCache.getValue(CommonConstant.ACCELERATE_WITHDRAWAL_RATIO)));
			record.setDataId(nowMoneyRecord.getId());
			record.setAccelerateUserId(nowMoneyRecord.getUserId());
			record.setAccelerateUserName(user1.getRealName());
			record.setBeforeAmout(puserApp.getAccBalance());
			BigDecimal add = puserApp.getAccBalance().add(amount);
			if(add.compareTo(new BigDecimal(ParamCache.getValue(CommonConstant.ACCELERATE_WITHDRAWAL_CAPS))) >= 0){//判断金额是否超过封顶了
				add = new BigDecimal(ParamCache.getValue(CommonConstant.ACCELERATE_WITHDRAWAL_CAPS));
				amount = add.subtract(puserApp.getAccBalance());
				record.setRemark("加速封顶");
			}
			record.setAfterAmout(add);
			record.setAmount(amount);
			record.setBenefitUserId(userApp.getParentId());
			record.setType(0);
			record.setSrc(0);
			puserApp.setAccBalance(add);
			userAppService.updateById(puserApp);
			accMapper.insert(record);
		}
		userAppService.updateById(userApp);
		this.save(nowMoneyRecord);
		flag = true;
		map.put("flag",flag);
		map.put("id",nowMoneyRecord.getId());
		map.put("msg",param.getMoneySourceEnum().getName()+"成功");
		log.info(param.getMoneySourceEnum().getName()+"成功","钱包id：" + userApp.getId() + str);
		logger.info(param.getMoneySourceEnum().getName()+"成功","钱包id：" + userApp.getId() +str);
		return map;
	}

	@Override
	public List<LinkedVerifyVO> getnowMoneyUnlikenessRecord() {
		return getBaseMapper().getnowMoneyUnlikenessRecord();
	}

	private NowMoneyRecord getNewestRecord(Long userId) {
		LambdaQueryWrapper<NowMoneyRecord> query = new LambdaQueryWrapper<>();
		query.eq(NowMoneyRecord::getUserId,userId);
		query.eq(NowMoneyRecord::getIsDelete,0);
		query.orderByDesc(NowMoneyRecord::getCreateTime);
		query.orderByDesc(NowMoneyRecord::getAfterMoney);
		query.last("limit 1");
		return this.getOne(query);
	}

}
